@@ -7,11 +7,14 @@ OC.L10N.register(
     "Activity feed" : "Feed de atividade",
     "Your settings have been updated." : "Suas configurações foram atualizadas.",
     "Settings have been updated." : "As configurações foram atualizadas.",
+    "remote user" : "usuário remoto",
     "Recent activity" : "Atividade recente",
     "No activities" : "Sem atividades",
     "More activities" : "Mais atividades",
     "Daily activity summary for %s" : "Resumo de atividade diária para %s",
-    "_and %n more…_::_and %n more…_" : ["e %n mais…","e %n mais…","e %n mais…"],
+    "_and %n more…_::_and %n more…_" : ["e mais %n…","e mais %n…","e mais %n…"],
+    "You can disable daily digest emails in the <a href=\"%s\">settings</a>." : "Você pode desativar os e-mails diários com resumos nas <a href=\"%s\">configurações</a>.",
+    "You can disable daily digest emails in the settings: %s" : "Você pode desativar os e-mails diários com resumos nas configurações: %s",
     "All activities" : "Todas as atividades",
     "By others" : "Por outros",
     "By you" : "Por você",
@@ -20,15 +23,17 @@ OC.L10N.register(
     "Hello %s," : "Olá %s,",
     "There was some activity at %s" : "Houve alguma atividade em %s",
     "_and %n more _::_and %n more _" : ["e %n mais","e %n mais","e %n mais"],
+    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Você pode alterar a frequência destes e-mails ou desativá-los nas <a href=\"%s\">configurações</a>.",
+    "You can change the frequency of these emails or disable them in the settings: %s" : "Você pode alterar a frequência destes e-mails ou desativá-los nas configurações: %s",
     "Mail" : "E-mail",
     "Push" : "Pressionar",
     "Activity" : "Atividade",
     "Notifications" : "Notificações",
-    "This application enables people to view a log of activities about them, their files or other data." : "Este aplicativo permite que as pessoas visualizem um registro de atividades sobre eles ou sobre arquivos.",
-    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Este aplicativo permite que as pessoas vejam ações relacionadas a seus arquivos e dados no Nextcloud.\n\t\tCada pessoa pode definir suas configurações de atividade individuais nas configurações pessoais,\n\t\tpara escolher qual atividade deve ser enviada para telefones celulares, enviada por e-mail\n\t\tou se um resumo diário é enviado todas as manhãs.\n\t\tMais informações estão disponíveis na documentação da atividade.",
+    "This application enables people to view a log of activities about them, their files or other data." : "Esse aplicativo permite que as pessoas visualizem um registro de atividades sobre elas, seus arquivos ou outros dados.",
+    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Este aplicativo permite que as pessoas vejam ações relacionadas a seus arquivos e dados no Nextcloud.\n\t\tCada pessoa pode definir suas configurações de atividade individuais nas configurações pessoais,\n\t\tpara escolher qual atividade deve ser enviada para telefones celulares, enviada por e-mail\n\t\tou se um resumo diário é enviado todas as manhãs.\n\t\tMais informações estão disponíveis na documentação da Atividade.",
     "Send email" : "Enviar e-mail",
     "Send push notification" : "Enviar notificação push",
-    "Activity notification configuration" : "Configuração de notificação de atividade",
+    "Activity notification configuration" : "Configuração de notificações de atividade",
     "Today" : "Hoje",
     "Yesterday" : "Ontem",
     "You need to set up your email address before you can receive notification emails." : "Você precisa configurar o endereço de e-mail para receber mensagens de notificação.",
@@ -54,17 +59,17 @@ OC.L10N.register(
     "Activity settings" : "Configurações de atividade",
     "Enable RSS feed" : "Ativar feed RSS",
     "RSS feed" : "Feed RSS",
-    "Copy RSS feed link" : "Copy RSS feed link",
-    "Personal notification settings" : "Configurações de notificação pessoal",
+    "Copy RSS feed link" : "Copiar o link do feed RSS",
+    "Personal notification settings" : "Configurações de notificação pessoais",
     "Unable to load the activity list" : "Não foi possível carregar a lista de atividades",
     "Choose for which activities you want to get an email or push notification." : "Escolha para quais atividades você gostaria de receber um e-mail ou uma notificação por push.",
     "Choose for which activities you want to get a push notification." : "Escolha para quais atividades você gostaria de receber uma notificação por push.",
     "Notification" : "Notificação",
     "Enable notification emails" : "Ativar e-mails de notificação",
-    "Daily activity summary" : "Resumo da atividade diária",
+    "Daily activity summary" : "Resumo diário de atividades",
     "Send daily activity summary in the morning" : "Enviar o resumo da atividade diária pela manhã",
     "Default settings" : "Configurações padrões",
-    "Configure the default notification settings for new accounts." : "Configurar as definições padrão de notificação para novos usuários.",
+    "Configure the default notification settings for new accounts." : "Configuras as definições de notificação padrão para novas contas.",
     "Unable to save the settings" : "Não foi possível salvar as configurações",
     "No more events to load" : "Não há mais eventos para carregar"
 },
