@@ -13,6 +13,8 @@ OC.L10N.register(
     "More activities" : "更多动态",
     "Daily activity summary for %s" : "%s 的每日动态概况",
     "_and %n more…_::_and %n more…_" : ["以及 %n 项..."],
+    "You can disable daily digest emails in the <a href=\"%s\">settings</a>." : "您可以在<a href=\"%s\">设置</a>中禁用每日摘要邮件。",
+    "You can disable daily digest emails in the settings: %s" : "您可以在设置中禁用每日摘要邮件：%s",
     "All activities" : "所有动态",
     "By others" : "他人动态",
     "By you" : "你的动态",
@@ -21,13 +23,15 @@ OC.L10N.register(
     "Hello %s," : "%s 你好，",
     "There was some activity at %s" : "在 %s 里有一些动态",
     "_and %n more _::_and %n more _" : ["更多 %n 项"],
+    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "您可以更改这些邮件的频率或在<a href=\"%s\">设置</a>中禁用它们。",
+    "You can change the frequency of these emails or disable them in the settings: %s" : "您可以更改这些邮件的频率或在设置中禁用它们：%s",
     "Mail" : "邮件",
     "Push" : "推送",
     "Activity" : "动态",
     "Notifications" : "通知",
     "This application enables people to view a log of activities about them, their files or other data." : "这个应用使用户可以查看关于自己或文件或其他数据的动态日志。 ",
     "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "此应用允许用户查看与他们在 Nextcloud 中的文档与其他数据相关的操作。\n\t\t每个人都可以在他们的个人设置中设定自己的个人活动记录，\n\t\t选择要推送到手机或通过电子邮件推送的活动\n\t\t或是否每天早上推送每日摘要。\n\t\t可在活动记录文档中查看更多信息。",
-    "Send email" : "发送邮件",
+    "Send email" : "发送电子邮件",
     "Send push notification" : "发送推送通知",
     "Activity notification configuration" : "动态通知配置",
     "Today" : "今天",
@@ -50,8 +54,8 @@ OC.L10N.register(
     "Loading more activities" : "正在加载更多动态",
     "No more activities." : "暂无更多动态。",
     "Could not enable RSS link" : "无法激活 RSS 链接",
-    "RSS link copied to clipboard" : "RSS 链接已拷贝至剪贴板",
-    "Could not copy the RSS link, please copy manually:" : "无法复制 RSS 链接，请手动进行该操作：",
+    "RSS link copied to clipboard" : "RSS 链接已复制至剪贴板",
+    "Could not copy the RSS link, please copy manually:" : "无法复制 RSS 链接，请手动进行复制操作：",
     "Activity settings" : "动态设置",
     "Enable RSS feed" : "启用 RSS 订阅源",
     "RSS feed" : "RSS 订阅源",
