@@ -4,10 +4,12 @@ OC.L10N.register(
     "Brute-force settings" : "Configuración escontra la fuercia bruta",
     "Whitelist IPs" : "IPs permitíes",
     "Your remote address was identified as \"{remoteAddress}\" and is bypassing brute-force protection." : "La to direición remota identificóse como «{remoteAddress}» y ta omitiendo la proteición escontra la fuercia bruta.",
-    "There was an error adding the IP to the whitelist." : "Hebo un error al amestar la direición a la llista d'IPs permitíes.",
     "IP address" : "Direición IP",
     "Mask" : "Mázcara",
+    "Comment" : "Comentariu",
     "Add" : "Amestar",
-    "Delete entry for {subnet}" : "Desaniciar la entrada de {subnet}"
+    "Save" : "Guardar",
+    "Delete entry for {subnet}" : "Desaniciar la entrada de {subnet}",
+    "There was an error adding the IP to the whitelist." : "Hebo un error al amestar la direición a la llista d'IPs permitíes."
 },
 "nplurals=2; plural=(n != 1);");
