@@ -1,6 +1,8 @@
 OC.L10N.register(
     "bruteforcesettings",
     {
-    "Add" : "Ավելացնել"
+    "Comment" : "Մեկնաբանել",
+    "Add" : "Ավելացնել",
+    "Save" : "Պահպանել"
 },
 "nplurals=2; plural=(n != 1);");
