@@ -1,7 +1,6 @@
 OC.L10N.register(
     "circles",
     {
-    "Teams" : "Ομάδες",
     "You created the team {circle}" : "Δημιουργήσατε την ομάδα {circle}",
     "{author} created the team {circle}" : "Ο/Η {author} δημιούργησε την ομάδα {circle}",
     "You deleted {circle}" : "Διαγράψατε τον {circle}",
@@ -52,6 +51,7 @@ OC.L10N.register(
     "{member} sent a request to join {circle}" : "Ο {member} έστειλε αίτημα συμμετοχής στο {circle}",
     "You are the new owner of {circle}" : "Είστε ο νέος κάτοχος του {circle}",
     "{member} is the new owner of {circle}" : "Ο/η {member} είναι ο νέος κάτοχος του {circle}",
+    "Teams" : "Ομάδες",
     "On events happening in a <strong>team</strong> of which you are a member" : "Για συμβάντα που συμβαίνουν σε μια <strong>ομάδα</strong> της οποίας είστε μέλος",
     "Any important event in a <strong>team</strong> you are moderating" : "Οποιοδήποτε σημαντικό συμβάν σε μια <strong>ομάδα</strong> που διαχειρίζεστε",
     "On global events happening in any <strong>team</strong>" : "Για καθολικά συμβάντα που συμβαίνουν σε οποιαδήποτε <strong>ομάδα</strong>",
@@ -106,12 +106,10 @@ OC.L10N.register(
     "Circles App Initialization" : "Προετοιμασία Εφαρμογής Circles",
     "Fresh installation status" : "Κατάσταση νέας εγκατάστασης",
     "Building Local Database" : "Δημιουργία Τοπικής Βάσης Δεδομένων",
-    "Testing Basic Circle Creation" : "Δοκιμή Βασικής Δημιουργίας Κύκλου",
     "Adding local users and moderators" : "Προσθήκη τοπικών χρηστών και συντονιστών",
     "Show all teams" : "Εμφάνιση όλων των ομάδων",
     "Create a new team" : "Δημιουργία νέας ομάδας",
     "Files" : "Αρχεία",
-    "This feature is not available for personal circles" : "Αυτή η επιλογή δεν είναι διαθέσιμη για προσωπικούς κύκλους",
     "The team is not federated" : "Η ομάδα δεν είναι federated",
     "You cannot join this team" : "Δεν μπορείτε να συμμετάσχετε σε αυτήν την ομάδα",
     "This member is not a moderator" : "Αυτό το μέλος δεν είναι επιμελητής",
@@ -119,10 +117,6 @@ OC.L10N.register(
     "This member does not exist" : "Αυτό το μέλος δεν υπάρχει",
     "This member is the owner of the team" : "Αυτό το μέλος είναι ο ιδιοκτήτης της ομάδας",
     "Level cannot be changed for this type of member" : "Το επίπεδο δεν μπορεί να αλλάξει για αυτόν τον τύπο χρηστών",
-    "You are already a member of this circle" : "Είστε ήδη μέλος αυτού του κύκλου",
-    "You have been blocked from this circle" : "Έχετε αποκλειστεί από αυτόν τον κύκλο",
-    "The account is already a member of this circle" : "Ο λογαριασμός είναι ήδη μέλος του κύκλου",
-    "The account has already been invited into this circle" : "Ο λογαριασμός έχει ήδη προσκληθεί για συμμετοχή στον κύκλο",
     "%s (Team owned by %s)" : "%s (Ομάδα που ανήκει στον %s)",
     "You are now a member of the Team \"%2$s\"" : "Είστε πλέον μέλος της Ομάδας \"%2$s\"",
     "You have been invited by %1$s into the Team \"%2$s\"" : "Έχετε προσκληθεί από τον/την %1$s στην Ομάδα \"%2$s\"",
@@ -158,11 +152,6 @@ OC.L10N.register(
     "Name" : "Όνομα",
     "Size" : "Μέγεθος",
     "Modified" : "Τροποποιήθηκε",
-    "Teams' files" : "Αρχεία ομάδων",
-    "Select team to filter by" : "Επιλέξτε ομάδα για φιλτράρισμα",
-    "Please select teams to filter by" : "Παρακαλώ επιλέξτε ομάδες για φιλτράρισμα",
-    "No files found for the selected teams" : "Δεν βρέθηκαν αρχεία για τις επιλεγμένες ομάδες",
-    "Shared to Circles" : "Κοινόχρηστο στους Κύκλους",
-    "Circle" : "Κύκλος"
+    "Shared to Circles" : "Κοινόχρηστο στους Κύκλους"
 },
 "nplurals=2; plural=(n != 1);");
