@@ -1,7 +1,6 @@
 OC.L10N.register(
     "circles",
     {
-    "Teams" : "Teymi",
     "You created the team {circle}" : "Þú bjóst til teymið {circle}",
     "{author} created the team {circle}" : "{author} bjó til teymið {circle}",
     "You deleted {circle}" : "Þú eyddir {circle}",
@@ -52,6 +51,7 @@ OC.L10N.register(
     "{member} sent a request to join {circle}" : "{member} sendi beiðni um að taka þátt í {circle}",
     "You are the new owner of {circle}" : "Þú ert nýr eigandi {circle}",
     "{member} is the new owner of {circle}" : "{member} er nýr eigandi {circle}",
+    "Teams" : "Teymi",
     "On events happening in a <strong>team</strong> of which you are a member" : "Við atburði sem gerast í <strong>teymi</strong> sem þú tilheyrir",
     "Any important event in a <strong>team</strong> you are moderating" : "Hvaða mikilvægi atburður sem er í <strong>teymi</strong> sem þú hefur umsjón með",
     "On global events happening in any <strong>team</strong>" : "Við almenna atburði sem gerast í hvaða <strong>teymi</strong> sem er",
@@ -76,8 +76,10 @@ OC.L10N.register(
     "Nextcloud Group" : "Nextcloud-hópur",
     "Email address" : "Tölvupóstfang",
     "Contact" : "Tengiliður",
-    "Circle" : "Hringur",
+    "Team" : "Teymi",
     "Nextcloud App" : "Nextcloud-forrit",
+    "Teams App" : "Forrit teymis",
+    "Admin Command Line" : "Skipanalína kerfisstjóra",
     "Member" : "Meðlimur",
     "Moderator" : "Umsjónarmaður",
     "Admin" : "Stjórnandi",
@@ -104,12 +106,10 @@ OC.L10N.register(
     "Circles App Initialization" : "Frumstilling Circles forrits",
     "Fresh installation status" : "Staða ferskrar uppsetningar",
     "Building Local Database" : "Byggi staðværan gagnagrunn",
-    "Testing Basic Circle Creation" : "Prófa einfalda gerð hrings",
     "Adding local users and moderators" : "Bæti við notendum og umsjónarmönnum",
     "Show all teams" : "Sýna öll teymi",
     "Create a new team" : "Búa til nýtt teymi",
     "Files" : "Skráaforrit",
-    "This feature is not available for personal circles" : "Þessi eiginleiki er ekki tiltækur fyrir persónulega hringi",
     "The team is not federated" : "Teymið er ekki í skýjasambandi",
     "You cannot join this team" : "Þú getur ekki tekið þátt í þessu teymi",
     "This member is not a moderator" : "Þessi meðlimur er ekki umsjónarmaður",
@@ -117,10 +117,6 @@ OC.L10N.register(
     "This member does not exist" : "Þessi meðlimur er ekki til",
     "This member is the owner of the team" : "Þessi meðlimur er eigandi teymisins",
     "Level cannot be changed for this type of member" : "Ekki er hægt að breyta stigi fyrir þessa gerð meðlims",
-    "You are already a member of this circle" : "Þú ert nú þegar meðlimur í þessum hring",
-    "You have been blocked from this circle" : "Þú hefur verið útilokaður frá þessum hring",
-    "The account is already a member of this circle" : "Notandaaðgangurinn er nú þegar meðlimur í þessum hring",
-    "The account has already been invited into this circle" : "Notandaaðgangnum hefur þegar verið boðið að taka þátt í þessum hring",
     "%s (Team owned by %s)" : "%s (Teymi í eigu notandans %s)",
     "You are now a member of the Team \"%2$s\"" : "Þú ert núna meðlimur í teyminu \"%2$s\"",
     "You have been invited by %1$s into the Team \"%2$s\"" : "%1$s bauð þér að ganga í teymið \"%2$s\"",
@@ -134,6 +130,9 @@ OC.L10N.register(
     "You have no permission to create a new team" : "Þú hefur ekki leyfi til að búa til nýtt teymi",
     "%s shared a file with \"%s\"." : "%s deildi skrá með \"%s\".",
     "%s shared a file with you." : "%s deildi skrá með þér",
+    "%1$s shared %2$s with %3$s" : "%1$s deildi %2$s með %3$s",
+    "%1$s shared %2$s with \"%3$s\"" : "%1$s deildi %2$s með \"%3$s\"",
+    "Open %s" : "Opna %s",
     "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s deildi einhverju efni með þér.\nÞú ættir að hafa fengið sérstakan tölvupóst með tengli sem vísar á gögnin.\n",
     "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s deildi einhverju efni með þér. Þú ættir að hafa fengið sérstakan tölvupóst með tengli sem vísar á gögnin.\n",
     "Password to access content shared with you by %1$s" : "Lykilorði fyrir aðgang að efni var deilt með þér af %1$s",
@@ -141,21 +140,18 @@ OC.L10N.register(
     "This item is already shared with this team" : "Þessu atriði er þegar deilt með þessu teymi",
     "Bring cloud-users closer together." : "Færir notendur tölvuskýja nær hver öðrum.",
     "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Teymi/Teams gerir fólki kleift að búa til sína eigin hópa af fólki/samstarfsaðilum/vinum.\nÞessa hópa (eða \"hringi\") má síðan nota í deilingaskyni af allskyns öðrum forritum.",
+    "Failed to load teams" : "Mistókst að hlaða inn teymum",
+    "Try again" : "Reyndu aftur",
+    "No teams found" : "Engin teymi fundust",
+    "Join or create teams to see them here." : "Útbúðu eða gakktu til liðs við teymi til að sjá þau hér.",
+    "Create your first team" : "Útbúðu fyrsta teymið þitt",
+    "Loading…" : "Hleð inn…",
+    "More teams" : "Fleiri teymi",
     "No files in here" : "Engar skrár hér",
     "No entries found in this folder" : "Engar færslur fundust í þessari möppu",
     "Name" : "Nafn",
     "Size" : "Stærð",
     "Modified" : "Breytt",
-    "Teams' files" : "Skrár teymisins",
-    "Select team to filter by" : "Veldu teymi til að sía eftir",
-    "No teams found" : "Engin teymi fundust",
-    "Please select teams to filter by" : "Veldu teymi til að sía eftir",
-    "No files found for the selected teams" : "Engar skrár fundust fyrir valin teymi",
-    "{author} added team {member} has been added as member to {circle}" : "Teyminu {member} var bætt við sem meðlimi í {circle} af {author}",
-    "Shared to Circles" : "Deilt til hringja",
-    "You are now a member of the Circle \"%2$s\"" : "Þú ert núna meðlimur í hringnum \"%2$s\"",
-    "You have been invited by %1$s into the Circle \"%2$s\"" : "%1$s bauð þér að ganga í hringinn \"%2$s\"",
-    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s sendi beiðni um að taka þátt í hringnum \"%2$s\"",
-    "Leave the circle" : "Ganga úr þessum hring"
+    "Shared to Circles" : "Deilt til hringja"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
