@@ -1,7 +1,6 @@
 OC.L10N.register(
     "circles",
     {
-    "Teams" : "Team",
     "You created the team {circle}" : "Hai creato il team {circle}",
     "{author} created the team {circle}" : "{author} ha creato il team {circle}",
     "You deleted {circle}" : "Hai eliminato {circle}",
@@ -52,6 +51,7 @@ OC.L10N.register(
     "{member} sent a request to join {circle}" : "{member} ha inviato una richiesta di unirsi a {circle}",
     "You are the new owner of {circle}" : "Sei il nuovo proprietario di {circle}",
     "{member} is the new owner of {circle}" : "{member} è il nuovo proprietario di {circle}",
+    "Teams" : "Team",
     "On events happening in a <strong>team</strong> of which you are a member" : "Sugli eventi che accadono in un <strong>team</strong> di cui sei membro",
     "Any important event in a <strong>team</strong> you are moderating" : "Qualsiasi evento importante in un <strong>team</strong> che stai moderando",
     "On global events happening in any <strong>team</strong>" : "Sugli eventi globali che accadono in qualsiasi <strong>team</strong>",
@@ -78,6 +78,8 @@ OC.L10N.register(
     "Contact" : "Contatto",
     "Team" : "Team",
     "Nextcloud App" : "Applicazione Nextcloud",
+    "Teams App" : "App Teams",
+    "Admin Command Line" : "Riga di comando amministratore",
     "Member" : "Membro",
     "Moderator" : "Moderatore",
     "Admin" : "Amministratore",
@@ -104,12 +106,12 @@ OC.L10N.register(
     "Circles App Initialization" : "Inizializzazione app Cerchie",
     "Fresh installation status" : "Stato nuova installazione",
     "Building Local Database" : "Costruzione database locale",
-    "Testing Basic Circle Creation" : "Test creazione cerchia di base",
+    "Testing Basic Team Creation" : "Test creazione team di base",
     "Adding local users and moderators" : "Aggiunta di utenti locali e moderatori",
     "Show all teams" : "Mostra tutti i team",
     "Create a new team" : "Crea un nuovo team",
     "Files" : "File",
-    "This feature is not available for personal circles" : "Questa funzionalità non è disponibile nelle cerchie personali",
+    "This feature is not available for personal teams" : "Questa funzionalità non è disponibile nei team personali",
     "The team is not federated" : "Il team non è federato",
     "You cannot join this team" : "Non puoi unirti a questo team",
     "This member is not a moderator" : "Questo membro non è un moderatore",
@@ -117,10 +119,10 @@ OC.L10N.register(
     "This member does not exist" : "Questo membro non esiste",
     "This member is the owner of the team" : "Questo membro è il proprietario del team",
     "Level cannot be changed for this type of member" : "Il livello non può essere modificato per questo tipo di membro",
-    "You are already a member of this circle" : "Sei già un membro di questa cerchia",
-    "You have been blocked from this circle" : "Sei stato bloccato da questa cerchia",
-    "The account is already a member of this circle" : "L'account è già membro di questa cerchia",
-    "The account has already been invited into this circle" : "L'account è già stato invitato in questa cerchia",
+    "You are already a member of this team" : "Sei già un membro di questo team",
+    "You have been blocked from this team" : "Sei stato bloccato da questo team",
+    "The account is already a member of this team" : "L'account è già membro di questo team",
+    "The account has already been invited into this team" : "L'account è già stato invitato in questo team",
     "%s (Team owned by %s)" : "%s (Team di proprietà di %s)",
     "You are now a member of the Team \"%2$s\"" : "Ora sei un membro del Team \"%2$s\"",
     "You have been invited by %1$s into the Team \"%2$s\"" : "Sei stato invitato da %1$s dentro al Team \"%2$s\"",
@@ -156,11 +158,6 @@ OC.L10N.register(
     "Name" : "Nome",
     "Size" : "Dimensione",
     "Modified" : "Modificato",
-    "Teams' files" : "File team",
-    "Select team to filter by" : "Seleziona team per filtrare",
-    "Please select teams to filter by" : "Seleziona i team per filtrare ",
-    "No files found for the selected teams" : "Nessun file trovato per i team selezionati",
-    "Shared to Circles" : "Condivisi con cerchie",
-    "Circle" : "Cerchia"
+    "Shared to Circles" : "Condivisi con cerchie"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
