@@ -1,13 +1,18 @@
 OC.L10N.register(
     "circles",
     {
-    "Teams" : "Teams",
+    "You created the team {circle}" : "Je hebt het team {circle} aangemaakt",
+    "{author} created the team {circle}" : "{author} heeft het team {circle} aangemaakt",
     "You deleted {circle}" : "Je hebt {circle} verwijderd",
     "{author} deleted {circle}" : "{author} verwijderde {circle}",
-    "You made {member} leave {circle}" : "JIj creëerde {member}verlaat {circle}",
-    "{author} made {member} leave {circle}" : "{author}creëerde {member}verliet {circle}",
-    "You removed {member} from {circle}" : "Je hebt {member} van {circle} verwijderd",
-    "{author} removed {member} from {circle}" : "{author} verwijderde {member} van {circle}",
+    "You made {member} join {circle}" : "Je hebt {member} toegevoegd aan {circle}",
+    "{author} made {member} join {circle}" : "{author} heeft {member} toegevoegd aan {circle}",
+    "You added team {member} as member to {circle}" : "Je hebt team {member} als lid toegevoegd aan {circle}",
+    "{author} added team {member} as member to {circle}" : "{author} heeft team {member} als lid toegevoegd aan {circle}",
+    "You made {member} leave {circle}" : "JIj hebt {member} {circle} laten verlaten",
+    "{author} made {member} leave {circle}" : "{author}heeft {member} {circle} laten verlaten",
+    "You removed {member} from {circle}" : "Je hebt {member} verwijderd van {circle}",
+    "{author} removed {member} from {circle}" : "{author} heeft {member} verwijderd van {circle}",
     "You joined {circle}" : "Je bent lid geworden van {circle}",
     "{member} joined {circle}" : "{member} werd lid van {circle}",
     "You accepted the invitation to join {circle}" : "Je hebt de uitnodiging voor {circle} geaccepteerd",
@@ -21,7 +26,7 @@ OC.L10N.register(
     "Your request to join {circle} has been accepted by {author}" : "Je verzoek om lid te worden van {circle} is door {author} geaccepteerd",
     "{member}'s request to join {circle} has been accepted by {author}" : "{member}'s verzoek om lid te worden van {circle} is door {author} geaccepteerd",
     "You left {circle}" : "Je hebt {circle} verlaten",
-    "{member} left {circle}" : "{member} verliet {circle}",
+    "{member} left {circle}" : "{member} heeft {circle} verlaten",
     "You declined the invitation to join {circle}" : "Je hebt de uitnodiging om lid te worden van {circle} afgewezen",
     "{member} declined an invitation to join {circle}" : "{member} heeft de uitnodiging om lid te worden van {circle} afgewezen",
     "You cancelled your request to join {circle}" : "Je hebt je verzoek om lid te worden van {circle} ingetrokken",
@@ -46,12 +51,17 @@ OC.L10N.register(
     "{member} sent a request to join {circle}" : "{member} verzond een verzoek om lid te worden van {circle}",
     "You are the new owner of {circle}" : "Je bent de nieuwe eigenaar van {circle}",
     "{member} is the new owner of {circle}" : "{member} is de nieuwe eigenaar van {circle}",
+    "Teams" : "Teams",
+    "On events happening in a <strong>team</strong> of which you are a member" : "Over gebeurtenissen binnen een <strong>team</strong> waarvan jij deel uitmaakt",
+    "Any important event in a <strong>team</strong> you are moderating" : "Elke belangrijke gebeurtenis in een <strong>team</strong> waarvan jij moderator bent",
+    "On global events happening in any <strong>team</strong>" : "Over algemene gebeurtenissen binnen in elk <strong>team</strong>",
     "Single" : "Alleen",
     "Personal" : "Persoonlijk",
     "System" : "Systeem",
     "Visible" : "Zichtbaar",
     "Open" : "Open",
     "Invite" : "Uitnodigen",
+    "Join request" : "Deelnameverzoek",
     "Friends" : "Vrienden",
     "Password protected" : "Wachtwoord-beveiligd",
     "No Owner" : "Geen eigenaar",
@@ -59,13 +69,14 @@ OC.L10N.register(
     "Backend" : "Backend",
     "Local" : "Lokaal",
     "Root" : "Root",
+    "Team invite" : "Teamuitnodiging",
     "Federated" : "Gefedereerd",
     "Mount point" : "Aankoppelpunt",
     "Nextcloud Account" : "Nextcloud Account",
     "Nextcloud Group" : "Nextcloud Groep",
     "Email address" : "E-mailadres",
     "Contact" : "Contact",
-    "Circle" : "Kring",
+    "Team" : "Team",
     "Nextcloud App" : "Nextcloud App",
     "Member" : "Lid",
     "Moderator" : "Moderator",
@@ -93,40 +104,52 @@ OC.L10N.register(
     "Circles App Initialization" : "Circles App Initialisatie",
     "Fresh installation status" : "Nieuwe installatiestatus",
     "Building Local Database" : "Aanmaken lokale database",
-    "Testing Basic Circle Creation" : "Testen basis kringcreatie",
     "Adding local users and moderators" : "Toevoegen lokale gebruikers en moderatoren",
+    "Show all teams" : "Geef alle teams weer",
+    "Create a new team" : "Nieuw team aanmaken",
     "Files" : "Bestanden",
-    "This feature is not available for personal circles" : "Deze functie is niet beschikbaar voor persoonlijke kringen",
+    "The team is not federated" : "Het team is niet gefedereerd",
+    "You cannot join this team" : "Je kunt niet lid worden van dit team",
     "This member is not a moderator" : "Dit lid is geen moderator",
     "Insufficient privileges" : "Onvoldoende rechten",
     "This member does not exist" : "Dit lid bestaat niet",
     "This member is the owner of the team" : "Dit lid is eigenaar van dit team",
     "Level cannot be changed for this type of member" : "Het niveau van dit type lid kan niet veranderd worden.",
-    "You are already a member of this circle" : "Je bent al lid van deze kring",
-    "You have been blocked from this circle" : "Je bent geblokkeerd van deze kring",
-    "The account is already a member of this circle" : "Dit account is al lid van deze cirkel",
-    "The account has already been invited into this circle" : "Dit account is al uitgenodigt voor deze cirkel",
+    "%s (Team owned by %s)" : "%s (Team met eigenaar %s)",
     "You are now a member of the Team \"%2$s\"" : "Je bent nu lid van team \"%2$s\"",
+    "You have been invited by %1$s into the Team \"%2$s\"" : "Je bent door %1$s uitgenodigd bij het Team \"%2$s\".",
+    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s stuurde een verzoek om lid te worden van het Team \"%2$s\"",
     "Accept" : "Accepteren",
     "Refuse" : "Weigeren",
+    "Leave the team" : "Team verlaten",
     "%s" : "%s",
+    "Personal team" : "Persoonlijk team",
     "%s owned by %s" : "%s is eigendom van %s",
+    "You have no permission to create a new team" : "Je hebt geen machtiging om een nieuw team aan te maken",
     "%s shared a file with \"%s\"." : "%s deelde een bestand met \"%s\".",
     "%s shared a file with you." : "%s heeft een bestand met u gedeeld",
+    "%1$s shared %2$s with %3$s" : "%1$s deelt %2$s met %3$s",
+    "%1$s shared %2$s with \"%3$s\"" : "%1$s deelt %2$s met \"%3$s\"",
+    "Open %s" : "%s openen",
     "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s heeft enige informatie met je gedeeld.\nJe moet al een aparte e-mail hebben ontvangen met een link om er te komen.\n",
     "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s heeft enige informatie met je gedeeld.\nJe moet al een aparte e-mail hebben ontvangen met een link om er te komen.",
     "Password to access content shared with you by %1$s" : "Wachtwoord om toegang te krijgen tot inhoud gedeeld met u door %1$s",
     "Password to access content" : "Wachtwoord voor toegang tot info",
+    "This item is already shared with this team" : "Dit object is al gedeeld met dit team",
     "Bring cloud-users closer together." : "Breng cloudgebruikers dichter bij elkaar.",
+    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Teams stelt mensen in staat om hun eigen groepen van mensen/collega's/vrienden aan te maken. Deze groepen kunnen vervolgens door andere apps worden gebruikt om gegevens te delen.",
+    "Failed to load teams" : "Teams laden is mislukt",
+    "Try again" : "Probeer opnieuw",
+    "No teams found" : "Geen teams gevonden",
+    "Join or create teams to see them here." : "Sluit je aan bij een team of maak er een aan om ze hier te zien.",
+    "Create your first team" : "Maak je eerste team",
+    "Loading…" : "Laden…",
+    "More teams" : "Meer teams",
     "No files in here" : "Hier geen bestanden",
     "No entries found in this folder" : "Niets in deze map gevonden",
     "Name" : "Naam",
     "Size" : "Omvang",
     "Modified" : "Gewijzigd",
-    "Shared to Circles" : "Gedeeld met Kringen",
-    "You are now a member of the Circle \"%2$s\"" : "Je bent nu lid van Kring \"%2$s\"",
-    "You have been invited by %1$s into the Circle \"%2$s\"" : "Je bent uitgenodigd door %1$sin Kring voor  \"%2$s\"",
-    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s verstuurde een lidmaatschapsverzoek voor Kring \"%2$s\"",
-    "Leave the circle" : "Verlaat de kring"
+    "Shared to Circles" : "Gedeeld met Kringen"
 },
 "nplurals=2; plural=(n != 1);");
