@@ -84,17 +84,13 @@ OC.L10N.register(
     "Boot up" : "Avia",
     "Fresh installation status" : "Istadu de s'installatzione noa",
     "Building Local Database" : "Creschende sa base de datos locale",
-    "Testing Basic Circle Creation" : " Proa de creatzione de giru de base",
     "Adding local users and moderators" : "Agiunta de utentes locales e persones chi moderent",
     "Create a new team" : "Crea un'iscuadra noa",
     "Files" : "Archìvios",
-    "This feature is not available for personal circles" : "Sa funtzionalidade no est a disponimentu pro giros personales",
     "This member is not a moderator" : "Custa persone no est chie mòderat",
     "Insufficient privileges" : "Permissos non sufitzientes",
     "This member does not exist" : "Custa persone no esistit",
     "Level cannot be changed for this type of member" : "Non faghet a cambiare su livellu pro custa genia de cumponente",
-    "You are already a member of this circle" : "Ses giai cumponente de custu giru",
-    "You have been blocked from this circle" : "T'ant blocadu dae custu giru",
     "Accept" : "Atzeta",
     "Refuse" : "Refuda",
     "%s" : "%s",
@@ -110,7 +106,6 @@ OC.L10N.register(
     "Name" : "Nùmene",
     "Size" : "Mannària",
     "Modified" : "Modificadu",
-    "Shared to Circles" : "Cumpartzidu cun is giros\\",
-    "Circle" : "Giru"
+    "Shared to Circles" : "Cumpartzidu cun is giros\\"
 },
 "nplurals=2; plural=(n != 1);");
