@@ -798,6 +798,9 @@ class CoreQueryBuilder extends ExtendedQueryBuilder {
 		if (!is_null($initiator)) {
 			$this->leftJoinInitiator($aliasBasedOn, $initiator);
 			$this->leftJoinOwner($aliasBasedOn);
+
+			$aliasInitiatorMemberships = $this->generateAlias($aliasBasedOn, self::MEMBERSHIPS);
+			$this->andWhere($expr->gt($aliasInitiatorMemberships . '.level', $this->createNamedParameter(0, self::PARAM_INT)));
 		}
 	}
 
@@ -843,7 +846,7 @@ class CoreQueryBuilder extends ExtendedQueryBuilder {
 	 * @param string $field
 	 */
 	public function innerJoinMembership(
-		CircleProbe $probe,
+		?CircleProbe $probe,
 		string $alias,
 		string $field = 'unique_id',
 	): void {
@@ -862,7 +865,7 @@ class CoreQueryBuilder extends ExtendedQueryBuilder {
 		$on = $expr->andX($expr->eq($aliasMembership . '.circle_id', $alias . '.' . $field));
 
 		// limit on membership level if requested
-		$minLevel = $probe->getMinimumLevel();
+		$minLevel = $probe?->getMinimumLevel() ?? 0;
 		if ($minLevel > Member::LEVEL_MEMBER) {
 			$on->add($this->exprGt('level', $minLevel, true, $aliasMembership));
 		}
