@@ -10,14 +10,14 @@ OC.L10N.register(
     "{author} commented on {file}" : "{author} kommenterede {file}",
     "<strong>Comments</strong> for files" : "<strong>Kommentarer</strong> for filer",
     "Files" : "Filer",
-    "You were mentioned on \"{file}\", in a comment by an account that has since been deleted" : "Du blev nævnt på \"{file}\", i en kommentar af en konto, som siden er blevet slettet",
-    "{user} mentioned you in a comment on \"{file}\"" : "{user} nævnte dig i en kommentar til \"{file}\"",
+    "You were mentioned on \"{file}\", in a comment by an account that has since been deleted" : "Du blev omtalt på \"{file}\", i en kommentar af en konto, som siden er blevet slettet",
+    "{user} mentioned you in a comment on \"{file}\"" : "{user} omtalte dig i en kommentar til \"{file}\"",
     "Files app plugin to add comments to files" : "Files app plugin til at tilføje kommentarer til filer",
     "Edit comment" : "Redigér kommentar",
     "Delete comment" : "Slet kommentar",
     "Cancel edit" : "Annullér redigering",
     "New comment" : "Ny kommentar",
-    "Write a comment …" : "Skriv kommentar…",
+    "Write a comment …" : "Skriv kommentar …",
     "Post comment" : "Skriv kommentar",
     "@ for mentions, : for emoji, / for smart picker" : "\"@\" for at omtale, \":\" for emojis, \"/\" for Smart Vælger",
     "Could not reload comments" : "Kunne ikke indlæse kommentarer",
@@ -31,6 +31,7 @@ OC.L10N.register(
     "An error occurred while trying to edit the comment" : "Der opstod en fejl under forsøget på at redigere kommentaren",
     "Comment deleted" : "Kommentar slettet",
     "An error occurred while trying to delete the comment" : "Der opstod en fejl under forsøget på at slette kommentaren",
-    "An error occurred while trying to create the comment" : "Der opstod en fejl under forsøget på at oprette kommentaren"
+    "An error occurred while trying to create the comment" : "Der opstod en fejl under forsøget på at oprette kommentaren",
+    "Write a comment …" : "Skriv kommentar…"
 },
 "nplurals=2; plural=(n != 1);");
