@@ -13,13 +13,15 @@ OC.L10N.register(
     "Good evening, {name}" : "Bună seara, {name}",
     "Hello" : "Bună",
     "Hello, {name}" : "Bună, {name}",
+    "Happy birthday 🥳🤩🎂🎉" : "La mulți ani 🥳🤩🎂🎉",
+    "Happy birthday, {name} 🥳🤩🎂🎉" : "La mulți ani, {name} 🥳🤩🎂🎉",
     "Customize" : "Personalizează",
     "Edit widgets" : "Editează widget",
     "Get more widgets from the App Store" : "Obține mai multe widget-uri din App Store",
     "Weather service" : "Serviciu de vreme",
-    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Pentru securitatea ta, datele despre vreme sunt cerute de către serverul Nextcloud din partea ta pentru ca serviciul de vreme să nu primească date confidențiale.",
     "Weather data from Met.no" : "Date despre vreme de la Met.no",
     "geocoding with Nominatim" : "geocoding cu Nominatim",
-    "elevation data from OpenTopoData" : "date despre elevație de la OpenTopoData"
+    "elevation data from OpenTopoData" : "date despre elevație de la OpenTopoData",
+    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Pentru securitatea ta, datele despre vreme sunt cerute de către serverul Nextcloud din partea ta pentru ca serviciul de vreme să nu primească date confidențiale."
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
