@@ -180,8 +180,6 @@ OC.L10N.register(
     "First day" : "Prvi dan",
     "Last day (inclusive)" : "Zadnji dan (vključujoče)",
     "Name of the replacement" : "Ime zamenjave",
-    "No results." : "Ni zadetkov",
-    "Start typing." : "Začnite vpisovati.",
     "Short absence status" : "Stanje kratke odsotnosti",
     "Long absence Message" : "Sporočilo dolge odsostnosti",
     "Save" : "Shrani",
@@ -189,7 +187,6 @@ OC.L10N.register(
     "Failed to load availability" : "Nalaganje seznama razpoložljivih polj je spodletelo",
     "Saved availability" : "Čas razpoložljivosti je shranjen",
     "Failed to save availability" : "Shranjevanje časa razpoložljivosti je spodletelo",
-    "Time zone:" : "Časovni pas:",
     "to" : "do",
     "Delete slot" : "Izbriši možnost",
     "No working hours set" : "Ni navedenih delovnih ur",
@@ -202,10 +199,6 @@ OC.L10N.register(
     "Import" : "Uvozi",
     "Error while saving settings" : "Prišlo je do napake med shranjevanjem nastavitev",
     "Reset to default" : "Ponastavi na privzeto",
-    "Availability" : "Razpoložljivost",
-    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Če nastavite delovni čas, bodo drugi uporabniki pri izbiri časa sestanka videli, kdaj ste zasedeni.",
-    "Absence" : "Odsotnost",
-    "Configure your next absence period." : "Nastavitev naslednjega časa odsotnosti",
     "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Namestite tudi {calendarappstoreopen}Koledar{linkclose}, ali pa se povežite z {calendardocopen}namiznim oziroma mobilnim usklajevalnikom ↗{linkclose}.",
     "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Prepričajte se, da je {emailopen}poštni strežnik{linkclose} pravilno nastavljen.",
     "Calendar server" : "Strežnik koledarja",
@@ -218,10 +211,17 @@ OC.L10N.register(
     "Send reminder notifications to calendar sharees as well" : "Pošiljanje opomnikov tudi naročnikom koledarja.",
     "Reminders are always sent to organizers and attendees." : "Opomniki bodo vedno poslani organizatorjem in udeležencem.",
     "Enable notifications for events via push" : "Omogoči potisna obvestila za dogodke",
+    "Availability" : "Razpoložljivost",
+    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Če nastavite delovni čas, bodo drugi uporabniki pri izbiri časa sestanka videli, kdaj ste zasedeni.",
+    "Absence" : "Odsotnost",
+    "Configure your next absence period." : "Nastavitev naslednjega časa odsotnosti",
     "There was an error updating your attendance status." : "Prišlo je do napake med posodabljanjem vaše udeležbe.",
     "Please contact the organizer directly." : "Z organizatorjem stopite neposredno v stik.",
     "Are you accepting the invitation?" : "Ali želite sprejeti povabilo?",
     "Tentative" : "Začasno",
-    "Your attendance was updated successfully." : "Vaša prisotnost je uspešno posodobljena."
+    "Your attendance was updated successfully." : "Vaša prisotnost je uspešno posodobljena.",
+    "No results." : "Ni zadetkov",
+    "Start typing." : "Začnite vpisovati.",
+    "Time zone:" : "Časovni pas:"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
