@@ -73,7 +73,19 @@ OC.L10N.register(
     "Where: %s" : "地点：%s",
     "%1$s via %2$s" : "%1$s 通过 %2$s",
     "In the past on %1$s for the entire day" : "过去全天 %1$s ",
+    "_In %n minute on %1$s for the entire day_::_In %n minutes on %1$s for the entire day_" : ["在 %n 分钟后全天 %1$s"],
+    "_In %n hour on %1$s for the entire day_::_In %n hours on %1$s for the entire day_" : ["在 %n 小时后全天 %1$s"],
+    "_In %n day on %1$s for the entire day_::_In %n days on %1$s for the entire day_" : ["在 %n 天后全天 %1$s"],
+    "_In %n week on %1$s for the entire day_::_In %n weeks on %1$s for the entire day_" : ["在 %n 周后全天 %1$s"],
+    "_In %n month on %1$s for the entire day_::_In %n months on %1$s for the entire day_" : ["在 %n 个月后全天 %1$s"],
+    "_In %n year on %1$s for the entire day_::_In %n years on %1$s for the entire day_" : ["在 %n 年后全天 %1$s"],
     "In the past on %1$s between %2$s - %3$s" : "过去  %2$s - %3$s %1$s",
+    "_In %n minute on %1$s between %2$s - %3$s_::_In %n minutes on %1$s between %2$s - %3$s_" : ["在 %2$s - %3$s %n 分钟后 %1$s"],
+    "_In %n hour on %1$s between %2$s - %3$s_::_In %n hours on %1$s between %2$s - %3$s_" : ["在 %2$s - %3$s %n 小时后 %1$s"],
+    "_In %n day on %1$s between %2$s - %3$s_::_In %n days on %1$s between %2$s - %3$s_" : ["在 %2$s - %3$s %n 天后 %1$s"],
+    "_In %n week on %1$s between %2$s - %3$s_::_In %n weeks on %1$s between %2$s - %3$s_" : ["在 %2$s - %3$s %n 周后 %1$s"],
+    "_In %n month on %1$s between %2$s - %3$s_::_In %n months on %1$s between %2$s - %3$s_" : ["在 %2$s - %3$s %n 个月后 %1$s"],
+    "_In %n year on %1$s between %2$s - %3$s_::_In %n years on %1$s between %2$s - %3$s_" : ["在 %2$s - %3$s %n 年后 %1$s"],
     "Could not generate when statement" : "无法生成 when 语句",
     "Every Day for the entire day" : "每天全天",
     "Every Day for the entire day until %1$s" : "每天全天，直到 %1$s",
@@ -111,8 +123,26 @@ OC.L10N.register(
     "On specific dates for the entire day until %1$s" : "在特定日期全天，直到 %1$s",
     "On specific dates between %1$s - %2$s until %3$s" : "在 %1$s - %2$s 特定日期，直到 %3$s",
     "In the past on %1$s" : "在过去 %1$s",
+    "_In %n minute on %1$s_::_In %n minutes on %1$s_" : ["%n 分钟后 %1$s"],
+    "_In %n hour on %1$s_::_In %n hours on %1$s_" : ["%n 小时后 %1$s"],
+    "_In %n day on %1$s_::_In %n days on %1$s_" : ["%n 天后 %1$s"],
+    "_In %n week on %1$s_::_In %n weeks on %1$s_" : ["%n 周后 %1$s"],
+    "_In %n month on %1$s_::_In %n months on %1$s_" : ["%n 个月后 %1$s"],
+    "_In %n year on %1$s_::_In %n years on %1$s_" : ["%n 年后 %1$s"],
     "In the past on %1$s then on %2$s" : "过去 %1$s，然后 %2$s",
+    "_In %n minute on %1$s then on %2$s_::_In %n minutes on %1$s then on %2$s_" : ["%n 分钟后 %1$s，然后 %2$s"],
+    "_In %n hour on %1$s then on %2$s_::_In %n hours on %1$s then on %2$s_" : ["%n 小时后 %1$s，然后 %2$s"],
+    "_In %n day on %1$s then on %2$s_::_In %n days on %1$s then on %2$s_" : ["%n 天后 %1$s，然后 %2$s"],
+    "_In %n week on %1$s then on %2$s_::_In %n weeks on %1$s then on %2$s_" : ["%n 周后 %1$s，然后 %2$s"],
+    "_In %n month on %1$s then on %2$s_::_In %n months on %1$s then on %2$s_" : ["%n 个月后 %1$s，然后 %2$s"],
+    "_In %n year on %1$s then on %2$s_::_In %n years on %1$s then on %2$s_" : ["%n 年后 %1$s，然后 %2$s"],
     "In the past on %1$s then on %2$s and %3$s" : "在过去 %1$s，然后 %2$s 和 %3$s",
+    "_In %n minute on %1$s then on %2$s and %3$s_::_In %n minutes on %1$s then on %2$s and %3$s_" : ["%n 分钟后 %1$s，然后 %2$s 和 %3$s"],
+    "_In %n hour on %1$s then on %2$s and %3$s_::_In %n hours on %1$s then on %2$s and %3$s_" : ["%n 小时后 %1$s，然后 %2$s 和 %3$s"],
+    "_In %n day on %1$s then on %2$s and %3$s_::_In %n days on %1$s then on %2$s and %3$s_" : ["%n 天后 %1$s，然后 %2$s 和 %3$s"],
+    "_In %n week on %1$s then on %2$s and %3$s_::_In %n weeks on %1$s then on %2$s and %3$s_" : ["%n 周后 %1$s，然后 %2$s 和 %3$s"],
+    "_In %n month on %1$s then on %2$s and %3$s_::_In %n months on %1$s then on %2$s and %3$s_" : ["%n 个月后 %1$s，然后 %2$s 和 %3$s"],
+    "_In %n year on %1$s then on %2$s and %3$s_::_In %n years on %1$s then on %2$s and %3$s_" : ["%n 年后 %1$s，然后 %2$s 和 %3$s"],
     "Could not generate next recurrence statement" : "无法生成下一个重复语句",
     "Cancelled: %1$s" : "已取消：%1$s",
     "\"%1$s\" has been canceled" : "“%1$s”已取消",
