@@ -45,7 +45,7 @@ use Sabre\VObject\Reader;
  * @license http://sabre.io/license/ Modified BSD License
  */
 class IMipPlugin extends SabreIMipPlugin {
-	
+
 	private ?VCalendar $vCalendar = null;
 	public const MAX_DATE = '2038-01-01';
 	public const METHOD_REQUEST = 'request';
@@ -165,7 +165,7 @@ class IMipPlugin extends SabreIMipPlugin {
 			$iTipMessage->scheduleStatus = '1.0;We got the message, but it\'s not significant enough to warrant an email';
 			return;
 		}
-		$this->imipService->setL10n($attendee);
+		$this->imipService->setL10nFromAttendee($attendee);
 
 		// Build the sender name.
 		// Due to a bug in sabre, the senderName property for an iTIP message can actually also be a VObject Property
@@ -186,7 +186,7 @@ class IMipPlugin extends SabreIMipPlugin {
 		switch (strtolower($iTipMessage->method)) {
 			case self::METHOD_REPLY:
 				$method = self::METHOD_REPLY;
-				$data = $this->imipService->buildBodyData($vEvent, $oldVevent);
+				$data = $this->imipService->buildReplyBodyData($vEvent);
 				$replyingAttendee = $this->imipService->getReplyingAttendee($iTipMessage);
 				break;
 			case self::METHOD_CANCEL:
@@ -249,7 +249,6 @@ class IMipPlugin extends SabreIMipPlugin {
 		// convert iTip Message to string
 		$itip_msg = $iTipMessage->message->serialize();
 
-		$user = null;
 		$mailService = null;
 
 		try {
@@ -261,8 +260,14 @@ class IMipPlugin extends SabreIMipPlugin {
 					$mailService = $this->mailManager->findServiceByAddress($user->getUID(), $sender);
 				}
 			}
+
+			// The display name in Nextcloud can use utf-8.
+			// As the default charset for text/* is us-ascii, it's important to explicitly define it.
+			// See https://www.rfc-editor.org/rfc/rfc6047.html#section-2.4.
+			$contentType = 'text/calendar; method=' . $iTipMessage->method . '; charset="utf-8"';
+
 			// evaluate if a mail service was found and has sending capabilities
-			if ($mailService !== null && $mailService instanceof IMessageSend) {
+			if ($mailService instanceof IMessageSend) {
 				// construct mail message and set required parameters
 				$message = $mailService->initiateMessage();
 				$message->setFrom(
@@ -274,10 +279,12 @@ class IMipPlugin extends SabreIMipPlugin {
 				$message->setSubject($template->renderSubject());
 				$message->setBodyPlain($template->renderText());
 				$message->setBodyHtml($template->renderHtml());
+				// Adding name=event.ics is a trick to make the invitation also appear
+				// as a file attachment in mail clients like Thunderbird or Evolution.
 				$message->setAttachments((new Attachment(
 					$itip_msg,
 					null,
-					'text/calendar; name=event.ics; method=' . $iTipMessage->method,
+					$contentType . '; name=event.ics',
 					true
 				)));
 				// send message
@@ -293,10 +300,12 @@ class IMipPlugin extends SabreIMipPlugin {
 					(($senderName !== null) ? [$sender => $senderName] : [$sender])
 				);
 				$message->useTemplate($template);
+				// Using a different content type because Symfony Mailer/Mime will append the name to
+				// the content type header and attachInline does not allow null.
 				$message->attachInline(
 					$itip_msg,
 					'event.ics',
-					'text/calendar; method=' . $iTipMessage->method
+					$contentType,
 				);
 				$failed = $this->mailer->send($message);
 			}
