@@ -7,9 +7,9 @@ OC.L10N.register(
     "Couldn't establish a federated share, maybe the password was wrong." : "Federierte Freigabe konnte nicht erstellt werden, vielleicht ist das Passwort falsch.",
     "Federated Share request sent, you will receive an invitation. Check your notifications." : "Anfrage für die federierte Freigabe gesendet, du solltest eine Einladung erhalten. Bitte in Deinen Benachrichtigungen nachsehen. ",
     "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Federierte Freigabe konnte nicht aufgebaut werden, da der Zielserver eine zu alte Version verwendet (Nextcloud <=9).",
-    "It is not allowed to send federated group shares from this server." : "Das Erstellen einer Federated Cloud Freigabe ist von diesem Server aus nicht erlaubt.",
+    "It is not allowed to send federated group shares from this server." : "Das Erstellen einer Federated-Cloud-Freigabe ist von diesem Server aus nicht erlaubt.",
     "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Freigeben von %1$s ist fehlgeschlagen, da dieses Element schon mit dem Konto %2$s geteilt wurde",
-    "Not allowed to create a federated share to the same account" : "Das Erstellen einer Federated-Cloud-Freigabe mit dem selben Konto ist uzulässig",
+    "Not allowed to create a federated share to the same account" : "Das Erstellen einer Federated-Cloud-Freigabe mit dem selben Konto ist unzulässig",
     "Federated shares require read permissions" : "Federated-Freigaben benötigen Leseberechtigungen",
     "File is already shared with %s" : "Datei wird bereits mit %s geteilt",
     "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Freigabe von %1$s fehlgeschlagen, da %2$s nicht gefunden wurde. Möglicherweise ist der Server nicht erreichbar oder nutzt ein selbst-erstelltes Zertifikat.",
@@ -19,12 +19,12 @@ OC.L10N.register(
     "You received {share} as a remote share from {user}" : "Du hast {share} als externe Freigabe von {user} empfangen",
     "Accept" : "Ok",
     "Decline" : "Abgelehnt",
-    "Federated Cloud Sharing" : "Federierte-Cloud-Freigabe",
+    "Federated Cloud Sharing" : "Federated-Cloud-Freigabe",
     "Sharing" : "Teilen",
-    "Federated file sharing" : "Federierte Datei-Freigabe",
+    "Federated file sharing" : "Federated Datei-Freigabe",
     "Provide federated file sharing across servers" : "Bietet Federated Datei-Freigaben über Servergrenzen hinweg",
     "Confirm data upload to lookup server" : "Hochladen der Daten zum Lookup-Server bestätigen",
-    "When enabled, all account properties (e.g. email address) with scope visibility set to \"published\", will be automatically synced and transmitted to an external system and made available in a public, global address book." : "Wenn diese Option aktiviert ist, werden alle Kontoeigenschaften (z. B. E-Mail-Adresse) mit der auf „veröffentlicht“ eingestellten Bereichssichtbarkeit automatisch synchronisiert und an ein externes System übertragen sowie in einem öffentlichen, globalen Adressbuch verfügbar gemacht.",
+    "When enabled, all account properties (e.g. email address) with scope visibility set to \"published\", will be automatically synced and transmitted to an external system and made available in a public, global address book." : "Wenn diese Option aktiviert ist, werden alle Kontoeigenschaften (z. B. E-Mail-Adresse) mit der auf \"veröffentlicht\" eingestellten Bereichssichtbarkeit automatisch synchronisiert und an ein externes System übertragen sowie in einem öffentlichen, globalen Adressbuch verfügbar gemacht.",
     "Disable upload" : "Hochladen deaktivieren",
     "Enable data upload" : "Hochladen von Daten aktivieren",
     "Confirm querying lookup server" : "Abfrage des Lookup-Servers bestätigen",
@@ -39,33 +39,38 @@ OC.L10N.register(
     "Allow people on this server to receive shares from other servers" : "Ermögliche es Personen auf diesem Server, Freigaben von anderen Servern zu erhalten",
     "Allow people on this server to send shares to groups on other servers" : "Ermögliche es Personen auf diesem Server, Freigaben an Gruppen auf anderen Servern zu senden",
     "Allow people on this server to receive group shares from other servers" : "Ermögliche es Personen auf diesem Server, Gruppenfreigaben von anderen Servern zu erhalten",
-    "The lookup server is only available for global scale." : "Der Lookup-Server ist nur für den globalen Scale verfügbar.",
+    "The lookup server is only available for global scale." : "Der Lookup-Server ist nur für Global Scale verfügbar.",
     "Search global and public address book for people" : "Durchsuche globales und öffentliches Adressbuch nach Personen",
     "Allow people to publish their data to a global and public address book" : "Erlaube es Personen, ihre Daten in einem globalen und öffentlichen Adressbuch zu veröffentlichen",
     "Trusted federation" : "Vertrauenswürdige Federation",
-    "Automatically accept shares from trusted federated accounts and groups by default" : "Freigaben von vertrauenswürdigen Federations-Konten und -Gruppen standardmäßig automatisch akzeptieren",
+    "Automatically accept shares from trusted federated accounts and groups by default" : "Freigaben von vertrauenswürdigen Federated-Konten und -Gruppen standardmäßig automatisch akzeptieren",
     "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Teile mit mir über meine #Nextcloud Federated-Cloud-ID, siehe {url}",
     "Share with me through my #Nextcloud Federated Cloud ID" : "Teile mit mir über meine #Nextcloud Federated-Cloud-ID",
     "Share with me via Nextcloud" : "Teile mit mir über Nextcloud",
-    "Cloud ID copied to the clipboard" : "Cloud-ID in die Zwischenablage kopiert",
-    "Copy to clipboard" : "In die Zwischenablage kopieren",
+    "Cloud ID copied" : "Cloud-ID kopiert",
+    "Copy" : "Kopieren",
     "Clipboard not available. Please copy the cloud ID manually." : "Zwischenablage nicht verfügbar. Bitte die Cloud-ID manuell kopieren.",
     "Copied!" : "Kopiert!",
     "Federated Cloud" : "Federated Cloud",
-    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Du kannst mit jedem teilen, der einen Nextcloud-Server oder andere Open Cloud Mesh (OCM) kompatible Server und Dienste verwendet! Gib einfach deren Federated-Cloud-ID in den Teilen-Dialog ein. Diese sieht wie folgt aus: person@cloud.example.com",
+    "You can share with anyone who uses a {productName} server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Du kannst mit jedem teilen, der einen {productName}-Server oder andere Open Cloud Mesh (OCM) kompatible Server und Dienste verwendet! Gebe einfach deren Federated-Cloud-ID in den Teilen-Dialog ein. Diese sieht wie folgt aus: person@cloud.example.com",
     "Your Federated Cloud ID" : "Deine Federated-Cloud-ID",
     "Share it so your friends can share files with you:" : "Teile es, damit deine Freunde Dateien mit dir teilen können:",
     "Facebook" : "Facebook",
     "X (formerly Twitter)" : "X (früher Twitter)",
     "formerly Twitter" : "früher Twitter",
     "Mastodon" : "Mastodon",
+    "Bluesky" : "Bluesky",
     "Add to your website" : "Zu deiner Webseite hinzufügen",
+    "Share with me via {productName}" : "Mit mir über {productName} teilen",
     "HTML Code:" : "HTML-Code:",
     "Cancel" : "Abbrechen",
     "Add remote share" : "Externe Freigabe hinzufügen",
     "Remote share" : "Externe Freigabe",
     "Do you want to add the remote share {name} from {owner}@{remote}?" : "Soll die externe Freigabe {name} von {owner}@{remote} hinzugefügt werden?",
     "Remote share password" : "Passwort für die externe Freigabe",
-    "Incoming share could not be processed" : "Eingehende Freigabe konnte nicht verarbeitet werden"
+    "Incoming share could not be processed" : "Eingehende Freigabe konnte nicht verarbeitet werden",
+    "Cloud ID copied to the clipboard" : "Cloud-ID in die Zwischenablage kopiert",
+    "Copy to clipboard" : "In die Zwischenablage kopieren",
+    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Du kannst mit jedem teilen, der einen Nextcloud-Server oder andere Open Cloud Mesh (OCM) kompatible Server und Dienste verwendet! Gib einfach deren Federated-Cloud-ID in den Teilen-Dialog ein. Diese sieht wie folgt aus: person@cloud.example.com"
 },
 "nplurals=2; plural=(n != 1);");
