@@ -44,7 +44,6 @@ OC.L10N.register(
     "A file or folder has been <strong>changed</strong>" : "Hai un ficheru o una carpeta que <strong>camudó</strong>",
     "A favorite file or folder has been <strong>changed</strong>" : "Hai un ficheru o una carpeta de Favoritos que <strong>camudó</strong>",
     "No favorites" : "Nengún favoritu",
-    "Upload (max. %s)" : "Xubir (%s como máximu)",
     "Accept" : "Aceptar",
     "Reject" : "Refugar",
     "Incoming ownership transfer from {user}" : "Recibióse una tresferencia de propiedá de: {user}",
@@ -75,22 +74,34 @@ OC.L10N.register(
     "This node is unavailable" : "Esti noyu nun ta disponible",
     "Renamed \"{oldName}\" to \"{newName}\"" : "Renomóse «{oldName}» a «{newName}»",
     "Rename file" : "Renomar el ficheru",
+    "Folder" : "Carpeta",
     "Pending" : "Pendiente",
     "Modified" : "Modificóse",
     "Type" : "Tipu",
     "Remove filter" : "Quitar la peñera",
+    "Appearance" : "Aspeutu",
+    "Show hidden files" : "Amosar los ficheros anubríos",
+    "Crop image previews" : "Recortar la previsualización d'imáxenes",
+    "General" : "Xeneral",
+    "Sort favorites first" : "Ordenar los favoritos primero",
+    "Sort folders before files" : "Ordenar les carpetes enantes que los ficheros",
+    "All files" : "Tolos ficheros",
+    "Personal files" : "Ficheros personales",
+    "Additional settings" : "Configuración adicional",
+    "Actions" : "Aiciones",
+    "Selection" : "Seleición",
+    "Navigation" : "Navegación",
+    "View" : "Ver",
+    "Toggle grid view" : "Alternar la vista de rexáu",
+    "WebDAV URL" : "URL de WebDAV",
     "Total rows summary" : "Resume total de fieleres",
     "Toggle selection for all files and folders" : "Alternar la seleición de tolos ficheros y toles carpetes",
     "Name" : "Nome",
     "Size" : "Tamañu",
-    "\"{displayName}\" batch action executed successfully" : "L'aición per llotes «{displayName}» executóse correutamente",
-    "\"{displayName}\" action failed" : "L'aición «{displayName}» falló",
-    "Actions" : "Aiciones",
     "List of files and folders." : "Una llista de ficheros y carpetes.",
     "Column headers with buttons are sortable." : "Les testeres de les columnes con botones puen ordenase.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Esta llista nun ta completa por motivos de rindimientu. Los ficheros van apaecer a midida que navegues pela llista.",
     "File not found" : "Nun s'atopó'l ficheru",
-    "{count} selected" : "{count} na seleición",
     "{usedQuotaByte} used" : "{usedQuotaByte} n'usu",
     "{used} of {quota} used" : "{used} de {quota} n'usu",
     "{relative}% used" : "{relative}% n'usu",
@@ -99,6 +110,8 @@ OC.L10N.register(
     "New folder" : "Carpeta nueva",
     "Create new folder" : "Crear una carpeta",
     "Create" : "Crear",
+    "Refresh" : "Anovar",
+    "Limit" : "Llende",
     "Submit" : "Unviar",
     "Choose a file or folder to transfer" : "Escueyi un ficheru o una carpeta a tresferir",
     "Transfer" : "Tresferir",
@@ -113,6 +126,7 @@ OC.L10N.register(
     "New owner" : "Propietariu nuevu",
     "Select file or folder to link to" : "Seleicionar un ficheru o una carpeta a la qu'enllaciar",
     "Choose {file}" : "Escoyer «{file}»",
+    "Files settings" : "Configuración de Ficheros",
     "Share" : "Compartir",
     "Shared by link" : "Compartir pente un enllaz",
     "Shared" : "Compartío",
@@ -124,35 +138,12 @@ OC.L10N.register(
     "Error during upload: {message}" : "Hebo un error demientres la xuba: {message}",
     "Error during upload, status code {status}" : "Hebo un error demientres la xuba. Cödigu d'estáu: {status}",
     "Unknown error during upload" : "Hebo un error desconocíu demientres la xuba",
-    "\"{displayName}\" action executed successfully" : "L'aición «{displayName}» executóse correutamente",
     "Loading current folder" : "Cargando la carpeta actual",
     "Retry" : "Retentar",
     "No files in here" : "Nun hai ficheros",
     "Upload some content or sync with your devices!" : "¡Xubi conteníu o sincroniza daqué colos tos preseos!",
     "Go back" : "Dir p'atrás",
     "Views" : "Vistes",
-    "Files settings" : "Configuración de Ficheros",
-    "Your files" : "Los tos ficheros",
-    "Open in files" : "Abrir en Ficheros",
-    "File cannot be accessed" : "Nun se pue acceder al ficheru",
-    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Nun se pudo atopar el ficheru o nun tienes permisu pa velu. Pidi al remitente que lu comparta.",
-    "Clipboard is not available" : "El cartafueyu nun ta disponible",
-    "WebDAV URL copied to clipboard" : "La URL de WebDAV copióse nel cartafueyu",
-    "Sort favorites first" : "Ordenar los favoritos primero",
-    "Sort folders before files" : "Ordenar les carpetes enantes que los ficheros",
-    "Show hidden files" : "Amosar los ficheros anubríos",
-    "Crop image previews" : "Recortar la previsualización d'imáxenes",
-    "Enable the grid view" : "Activar la vista de rexáu",
-    "Additional settings" : "Configuración adicional",
-    "WebDAV" : "WebDAV",
-    "WebDAV URL" : "URL de WebDAV",
-    "Copy to clipboard" : "Copiar nel cartafueyu",
-    "Use this address to access your Files via WebDAV" : "Usa esta direición p'acceder a los ficheros per WebDAV",
-    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Si tienes activada l'autenticación en dos pasos, tienes de crear y usar una contraseña p'aplicaciones nueva calcando equí.",
-    "Keyboard shortcuts" : "Atayos del tecláu",
-    "Selection" : "Seleición",
-    "Navigation" : "Navegación",
-    "View" : "Ver",
     "You" : "Tu",
     "Shared multiple times with different people" : "Compartióse múltiples vegaes con otres persones",
     "Error while loading the file data" : "Hebo un error mentanto de cargaben los datos de los ficheros",
@@ -160,12 +151,16 @@ OC.L10N.register(
     "Remove from favorites" : "Quitar de Favoritos",
     "Add to favorites" : "Meter en Favoritos",
     "Tags" : "Etiquetes",
+    "Your files" : "Los tos ficheros",
+    "Open in files" : "Abrir en Ficheros",
+    "File cannot be accessed" : "Nun se pue acceder al ficheru",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Nun se pudo atopar el ficheru o nun tienes permisu pa velu. Pidi al remitente que lu comparta.",
     "Blank" : "Baleru",
     "Unable to create new file from template" : "Nun ye posible crear un ficheru a partir d'una plantía",
     "Pick a template for {name}" : "Escoyer una plantía pa: {name}",
     "Create a new file with the selected template" : "Crea un ficheru cola plantía seleicionada",
     "Creating file" : "Creando'l ficheru",
-    "Deletion cancelled" : "Anulóse'l desaniciu",
+    "Delete" : "Desaniciar",
     "Leave this share" : "Dexar esta compartición",
     "Leave these shares" : "Dexar estes comparticiones",
     "Disconnect storage" : "Desconectar l'almacenamientu",
@@ -176,13 +171,14 @@ OC.L10N.register(
     "Delete files" : "Desaniciar los ficheros",
     "Delete folder" : "Desaniciar la carpeta",
     "Delete folders" : "Desaniciar les carpetes",
-    "Delete" : "Desaniciar",
     "Confirm deletion" : "Confirmar el desaniciu",
     "Cancel" : "Encaboxar",
+    "Download" : "Baxar",
+    "Destination is not a folder" : "El destín nun ye una carpeta",
+    "This file/folder is already in that directory" : "Esti ficheru o esta carpeta yá ta nel direutoriu",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Nun pues mover un ficheru/carpeta a sigo mesma o la mesma socarpeta de la mesma carpeta",
     "(copy)" : "(copia)",
     "(copy %n)" : "(copia %n)",
-    "Move cancelled" : "Anulóse la operación de mover",
     "A file or folder with that name already exists in this folder" : "Nesta carpeta, yá estie un ficheru o una carpeta con esi nome",
     "The files are locked" : "Los ficheros tán bloquiaos",
     "The file does not exist anymore" : "El ficheru yá nun esiste",
@@ -193,13 +189,12 @@ OC.L10N.register(
     "Move" : "Mover",
     "Move or copy operation failed" : "La operación de mover o copiar falló",
     "Move or copy" : "Mover o copiar",
-    "Cancelled move or copy operation" : "Anulóse la operación de mover o copiar",
     "Open folder {displayName}" : "Abrir la carpeta «{displayName}»",
     "Open in Files" : "Abrir en Ficheros",
-    "Failed to redirect to client" : "Nun se pue redirixir al veceru",
     "Open locally" : "Abrir llocalmente",
+    "Failed to redirect to client" : "Nun se pue redirixir al veceru",
     "Rename" : "Renomar",
-    "Open details" : "Abrir los detalles",
+    "Details" : "Detalles",
     "View in folder" : "Ver na carpeta",
     "Today" : "Güei",
     "Last 7 days" : "Los últimos 7 díes",
@@ -207,6 +202,7 @@ OC.L10N.register(
     "Documents" : "Documentos",
     "Folders" : "Carpetes",
     "Audio" : "Audiu",
+    "Images" : "Imáxenes",
     "Videos" : "Vídeos",
     "Created new folder \"{name}\"" : "Creóse la carpeta «{name}»",
     "Unable to initialize the templates directory" : "Nun ye posible aniciar el direutoriu de plantíes",
@@ -227,20 +223,16 @@ OC.L10N.register(
     "Files moved successfully" : "Los ficheros copiáronse correutamente",
     "Conflicts resolution skipped" : "Saltóse la resolución de conflictos",
     "Upload cancelled" : "Encaboxóse la busca",
+    "Could not rename \"{oldName}\", it does not exist any more" : "Nun se pue renomar «{oldName}». Yá nun esiste",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "El nome «{newName}» yá ta n'usu na carpeta «{dir}». Escueyi otru nome.",
+    "Could not rename \"{oldName}\"" : "Nun se pudo renomar «{oldName}»",
     "This operation is forbidden" : "Esta operación ta prohibida",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Esti direutoriu nun ta disponible, revisa'l rexistru o ponte en contautu cola alministración.",
     "Storage is temporarily not available" : "L'almacenamientu nun ta disponible temporalmente",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} carpeta","{folderCount} carpetes"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} ficheru","{fileCount} ficheros"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 ficheru y {folderCount} carpeta","1 ficheru y {folderCount} carpetes"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} ficheru y 1 carpeta","{fileCount} ficheros y 1 carpeta"],
-    "{fileCount} files and {folderCount} folders" : "{fileCount} ficheros y {folderCount} carpetes",
+    "_%n file_::_%n files_" : ["%n ficheru","%n ficheros"],
+    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetes"],
     "No favorites yet" : "Entá nun hai nengún elementu favoritu",
     "Files and folders you mark as favorite will show up here" : "Equí apaecen los ficheros y carpetes que metas en Favoritos",
-    "All files" : "Tolos ficheros",
     "List of your files and folders." : "Una llista de los ficheros y les carpetes de to.",
-    "All folders" : "Toles carpetes",
-    "Personal files" : "Ficheros personales",
     "List of your files and folders that are not shared." : "Una llista de ficheros y carpetes que nun se compartieron.",
     "No personal files found" : "Nun s'atopó nengún ficheru personal",
     "Files that are not shared will show up here." : "Equí apaecen los ficheros que nun se compartan.",
@@ -248,101 +240,29 @@ OC.L10N.register(
     "List of recently modified files and folders." : "Una llista de ficheros y carpetes modificaos de recién.",
     "No recently modified files" : "Nun hai nengún ficheru modificáu de recién",
     "Files and folders you recently modified will show up here." : "Equí apaecen los ficheros y les carpetes modificaes de recién.",
+    "Search" : "Buscar",
     "No entries found in this folder" : "Nun s'atopó nenguna entrada nesta carpeta",
     "Select all" : "Seleicionar too",
     "Upload too large" : "La xuba ye mui grande",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Los ficheros que tentes de xubir superen el tamañu máximu qu'esti sirvidor permite.",
-    "File could not be found" : "Nun se pudo atopar el ficheru",
-    "Download" : "Baxar",
-    "Show list view" : "Amosar la vista en llista",
-    "Show grid view" : "Amosar la vista en rexáu",
-    "Close" : "Zarrar",
-    "Could not create folder \"{dir}\"" : "Nun se pudo crear la carpeta «{dir}»",
-    "This will stop your current uploads." : "Esta aición va parar les xubes actuales.",
-    "Upload cancelled." : "Encaboxóse la xuba.",
-    "Processing files …" : "Procesando los ficheros…",
-    "…" : "…",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nun ye posible xubir «{filename}» darréu que ye un direutoriu o tien 0 bytes",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nun hai abondu espaciu porque namás queda {size2} y tas xubiendo {size1}",
-    "Target folder \"{dir}\" does not exist any more" : "La carpeta de destín «{dir}» xá nun esiste",
-    "An unknown error has occurred" : "Prodúxose un error desconocíu",
-    "File could not be uploaded" : "Nun se pudo xubir el ficheru",
-    "Uploading …" : "Xubiendo…",
-    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
-    "Uploading … ({currentNumber}/{total})" : "Xubiendo… ({currentNumber}/{total})",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
-    "Uploading that item is not supported" : "La xuba d'esi elementu nun ye compatible",
-    "Error when assembling chunks, status code {status}" : "Hebo un error al atropar los cachos. Códigu d'estáu {status}",
-    "Choose target folder" : "Escoyer la carpeta de destín",
-    "Set reminder" : "Configurar un recordatoriu",
+    "Upload (max. %s)" : "Xubir (%s como máximu)",
+    "\"{displayName}\" batch action executed successfully" : "L'aición per llotes «{displayName}» executóse correutamente",
+    "\"{displayName}\" action failed" : "L'aición «{displayName}» falló",
+    "\"{displayName}\" action executed successfully" : "L'aición «{displayName}» executóse correutamente",
+    "Clipboard is not available" : "El cartafueyu nun ta disponible",
+    "WebDAV URL copied to clipboard" : "La URL de WebDAV copióse nel cartafueyu",
+    "Enable the grid view" : "Activar la vista de rexáu",
+    "WebDAV" : "WebDAV",
+    "Copy to clipboard" : "Copiar nel cartafueyu",
+    "Use this address to access your Files via WebDAV" : "Usa esta direición p'acceder a los ficheros per WebDAV",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Si tienes activada l'autenticación en dos pasos, tienes de crear y usar una contraseña p'aplicaciones nueva calcando equí.",
+    "Keyboard shortcuts" : "Atayos del tecláu",
+    "Deletion cancelled" : "Anulóse'l desaniciu",
     "Edit locally" : "Editar llocalmente",
-    "Open" : "Abrir",
-    "Could not load info for file \"{file}\"" : "Nun se pudo cargar la información del ficheru «{file}»",
-    "Details" : "Detalles",
-    "Please select tag(s) to add to the selection" : "Seleiciona les etiquetes que quies amestar a la seleición",
-    "Apply tag(s) to selection" : "Aplicar les etiquetes a la seleición",
-    "Select directory \"{dirName}\"" : "Seleicionar el direutoriu «{dirName}»",
-    "Select file \"{fileName}\"" : "Seleicionar el ficheru «{fileName}»",
-    "Unable to determine date" : "Nun ye posible determinar la data",
-    "Could not move \"{file}\", target exists" : "Nun se pudo mover «{file}», el destín esiste",
-    "Could not move \"{file}\"" : "Nun se pudo mover «{file}»",
-    "copy" : "copia",
-    "Could not copy \"{file}\", target exists" : "Nun se pudo copiar «{file}», el destín esiste",
-    "Could not copy \"{file}\"" : "Nun se pudo copiar «{file}»",
-    "Copied {origin} inside {destination}" : "Copióse «{origin}» dientro de: {destination}",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "Copióse «{origin}» y {nbfiles} ficheros más dientro de: {destination}",
-    "{newName} already exists" : "«{newName}» xá esiste",
-    "Could not rename \"{fileName}\", it does not exist any more" : "Nun se pudo nomar «{fileName}». Yá nun esiste",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "El nome «{targetName}» yá ta n'usu pola carpeta «{dir}». Escueyi otru nome.",
-    "Could not rename \"{fileName}\"" : "Nun se pudo renomar «{fileName}»",
-    "Could not create file \"{file}\"" : "Nun se pudo crear el ficheru «{file}»",
-    "Could not create file \"{file}\" because it already exists" : "Nun se pudo crear el ficheru «{file}» porque yá esiste",
-    "Could not create folder \"{dir}\" because it already exists" : "Nun se pudo crear la carpeta «{dir}» porque yá esiste",
-    "Could not fetch file details \"{file}\"" : "Nun se pudo dir en cata de los detalles del ficheru «{file}»",
-    "Error deleting file \"{fileName}\"." : "Hebo un error al desaniciar «{fileName}»",
-    "No search results in other folders for {tag}{filter}{endtag}" : "Nun hai nengún resultáu de busca nes demás carpetes pa: {tag}{filter}{endtag}",
-    "Enter more than two characters to search in other folders" : "Introduz más de dos carátueres pa buscar nes demás carpetes",
-    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetes"],
-    "_%n file_::_%n files_" : ["%n ficheru","%n ficheros"],
-    "{dirs} and {files}" : "{dirs} ya {files}",
-    "_including %n hidden_::_including %n hidden_" : ["incluyendo %n elementu anubríu","incluyendo %n elementos anubríos"],
-    "You do not have permission to upload or create files here" : "Nun tienes permisu pa xubir o crear ficheros equí",
-    "_Uploading %n file_::_Uploading %n files_" : ["Xubiendo %n ficheru","Xubiendo %n ficheros"],
-    "New" : "Nuevu",
-    "New file/folder menu" : "Menú de carpeta/ficheru nuevos",
-    "Select file range" : "Seleicionar el rangu de ficheros",
-    "{used}%" : "{used}%",
-    "{used} used" : "{used} n'usu",
-    "\"{name}\" is an invalid file name." : "«{name}» ye un nome inválidu.",
-    "File name cannot be empty." : "El nome del ficheru nun pue tar baleru.",
-    "\"/\" is not allowed inside a file name." : "«/» ye un caráuter que nun ta permitíu nel nome del ficheru.",
-    "\"{name}\" is not an allowed filetype" : "«{name}» nun ye un tipu de ficheru permitíu",
-    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "L'almacenamientu del usuariu «{owner}» ta enllén. ¡Yá nun se puen xubir o sincronizar ficheros!",
-    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "La carpeta del grupu «{mountPoint}» ta enllena, ¡yá nun se puen xubir nin sincronizar ficheros!",
-    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "L'almacenamientu esternu «{mountPoint}» ta enllén. ¡Yá nun se puen xubir o sincronizar ficheros!",
-    "Your storage is full, files cannot be updated or synced anymore!" : "El to almacenamientu ta enllén. ¡Yá nun se puen xubir o sincronizar ficheros!",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "L'almacenamientu del usuariu «{owner}» ta cuasi enllén ({usedSpacePercent}%).",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "La carpeta del grupu «{mountPoint}» ta cuasi enllena ({usedSpacePercent}%).",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "L'almacenamientu esternu «{mountPoint}» ta cuasi enllén ({usedSpacePercent}%).",
-    "Your storage is almost full ({usedSpacePercent}%)." : "El to almacenamientu ta cuasi enllén ({usedSpacePercent}%).",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["concasa con «{filter}»","concasen con «{filter}»"],
-    "Direct link was copied (only works for people who have access to this file/folder)" : "Copióse l'enllaz direutu (namás funciona coles persones que tienen accesu a esti ficheru o esta carpeta)",
-    "Path" : "Camín",
-    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
-    "Favorited" : "Metióse en Favoritos",
-    "Copy direct link (only works for people who have access to this file/folder)" : "Copiar l'enllaz direutu (namás funciona coles persones que tienen accesu a esti ficheru o esta carpeta)",
-    "Upload file" : "Xubir un ficheru",
-    "Not favorited" : "Nun ta en Favoritos",
-    "An error occurred while trying to update the tags" : "Prodúxose un error al tentar d'anovar les etiquetes",
-    "Storage informations" : "Información del almacenamientu",
-    "Choose file" : "Escoyer un ficheru",
-    "Go to the previous folder" : "Dir a la carpeta anterior",
-    "Open the files app settings" : "Abrir la configuración de Ficheros",
-    "Unable to change the favourite state of the file" : "Nun ye posible camudar l'estáu favoritu del ficheru",
-    "Create new templates folder" : "Crear una carpeta de plantíes",
-    "List of favorites files and folders." : "Una llista de ficheros y carpetes favoritos.",
-    "Personal Files" : "Ficheros personales",
-    "Text file" : "Ficheru de testu",
-    "New text file.txt" : "ficheru_nuevu.txt"
+    "Move cancelled" : "Anulóse la operación de mover",
+    "Cancelled move or copy operation" : "Anulóse la operación de mover o copiar",
+    "Open details" : "Abrir los detalles",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Esti direutoriu nun ta disponible, revisa'l rexistru o ponte en contautu cola alministración.",
+    "All folders" : "Toles carpetes"
 },
 "nplurals=2; plural=(n != 1);");
