@@ -51,10 +51,13 @@ OC.L10N.register(
     "You do not have permission to create a file at the specified location" : "You do not have permission to create a file at the specified location",
     "The file could not be converted." : "The file could not be converted.",
     "Could not get relative path to converted file" : "Could not get relative path to converted file",
+    "Limit must be a positive integer." : "Limit must be a positive integer.",
+    "The replacement character may only be a single character." : "The replacement character may only be a single character.",
+    "Filename sanitization already started." : "Filename sanitization already started.",
+    "No filename sanitization in progress." : "No filename sanitation in progress.",
     "Favorite files" : "Favorite files",
     "No favorites" : "No favourites",
     "More favorites" : "More favorites",
-    "Upload (max. %s)" : "Upload (max. %s)",
     "Accept" : "Accept",
     "Reject" : "Reject",
     "Incoming ownership transfer from {user}" : "Incoming ownership transfer from {user}",
@@ -69,10 +72,6 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "The ownership transfer of {path} from {user} has completed.",
     "in %s" : "in %s",
     "Transferred from %1$s on %2$s" : "Transferred from %1$s on %2$s",
-    "Files compatibility" : "Files compatibility",
-    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed.",
-    "Enforce Windows compatibility" : "Enforce Windows compatibility",
-    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity.",
     "File Management" : "File Management",
     "Home" : "Home",
     "Target folder does not exist any more" : "Target folder does not exist any more",
@@ -95,28 +94,76 @@ OC.L10N.register(
     "Invalid filename." : "Invalid filename.",
     "Renamed \"{oldName}\" to \"{newName}\"" : "Renamed \"{oldName}\" to \"{newName}\"",
     "Rename file" : "Rename file",
+    "Folder" : "Folder",
+    "Unknown file type" : "Unknown file type",
+    "{ext} image" : "{ext} image",
+    "{ext} video" : "{ext} video",
+    "{ext} audio" : "{ext} audio",
+    "{ext} text" : "{ext} text",
     "Pending" : "Pending",
     "Unknown date" : "Unknown date",
     "Clear filter" : "Clear filter",
     "Modified" : "Modified",
+    "Search everywhere" : "Search everywhere",
     "Type" : "Type",
     "Active filters" : "Active filters",
     "Remove filter" : "Remove filter",
+    "Appearance" : "Appearance",
+    "Show hidden files" : "Show hidden files",
+    "Show file type column" : "Show file type column",
+    "Show file extensions" : "Show file extensions",
+    "Crop image previews" : "Crop image previews",
+    "General" : "General",
+    "Sort favorites first" : "Sort favourites first",
+    "Sort folders before files" : "Sort folders before files",
+    "Enable folder tree view" : "Enable folder tree view",
+    "Default view" : "Default view",
+    "All files" : "All files",
+    "Personal files" : "Personal files",
+    "Additional settings" : "Additional settings",
+    "Actions" : "Actions",
+    "File actions" : "File actions",
+    "Selection" : "Selection",
+    "Select all files" : "Select all files",
+    "Deselect all" : "Deselect all",
+    "Select or deselect" : "Select or deselect",
+    "Select a range" : "Select a range",
+    "Navigation" : "Navigation",
+    "Go to parent folder" : "Go to parent folder",
+    "Go to file above" : "Go to file above",
+    "Go to file below" : "Go to file below",
+    "Go left in grid" : "Go left in grid",
+    "Go right in grid" : "Go right in grid",
+    "View" : "View",
+    "Toggle grid view" : "Toggle grid view",
+    "Open file sidebar" : "Open file sidebar",
+    "Show those shortcuts" : "Show those shortcuts",
+    "Warnings" : "Warnings",
+    "Warn before changing a file extension" : "Warn before changing a file extension",
+    "Warn before deleting a file" : "Warn before deleting a file",
+    "WebDAV URL" : "WebDAV URL",
+    "Create an app password" : "Create an app password",
+    "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account.",
+    "How to access files using WebDAV" : "How to access files using WebDAV",
     "Total rows summary" : "Total rows summary",
     "Toggle selection for all files and folders" : "Toggle selection for all files and folders",
     "Name" : "Name",
+    "File type" : "File type",
     "Size" : "Size",
-    "\"{displayName}\" failed on some elements" : "\"{displayName}\" failed on some elements",
-    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" batch action executed successfully",
-    "\"{displayName}\" action failed" : "\"{displayName}\" action failed",
-    "Actions" : "Actions",
+    "{displayName}: failed on some elements" : "{displayName}: failed on some elements",
+    "{displayName}: done" : "{displayName}: done",
+    "{displayName}: failed" : "{displayName}: failed",
     "(selected)" : "(selected)",
     "List of files and folders." : "List of files and folders.",
     "You have used your space quota and cannot upload files anymore." : "You have used your space quota and cannot upload files anymore.",
     "Column headers with buttons are sortable." : "Column headers with buttons are sortable.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list.",
     "File not found" : "File not found",
-    "{count} selected" : "{count} selected",
+    "_{count} selected_::_{count} selected_" : ["{count} selected","{count} selected"],
+    "Search everywhere …" : "Search everywhere …",
+    "Search here …" : "Search here …",
+    "Search scope options" : "Search scope options",
+    "Search here" : "Search here",
     "{usedQuotaByte} used" : "{usedQuotaByte} used",
     "{used} of {quota} used" : "{used} of {quota} used",
     "{relative}% used" : "{relative}% used",
@@ -128,8 +175,27 @@ OC.L10N.register(
     "Create new folder" : "Create new folder",
     "This name is already in use." : "This name is already in use.",
     "Create" : "Create",
+    "Files starting with a dot are hidden by default" : "Files starting with a dot are hidden by default",
+    "Failed to start filename sanitization." : "Failed to start filename sanitization.",
+    "Failed to refresh filename sanitization status." : "Failed to refresh filename sanitization status.",
+    "Filename sanitization in progress." : "Filename sanitization in progress.",
+    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "Currently {processedUsers} of {totalUsers} accounts are already processed.",
+    "Preparing …" : "Preparing …",
+    "Refresh" : "Refresh",
+    "All files have been santized for Windows filename support." : "All files have been santized for Windows filename support.",
+    "Some files could not be sanitized, please check your logs." : "Some files could not be sanitized, please check your logs.",
+    "Sanitization errors" : "Sanitization errors",
+    "Not sanitized filenames" : "Not sanitized filenames",
+    "Windows filename support has been enabled." : "Windows filename support has been enabled.",
+    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows.",
+    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time.",
+    "Please note that this may cause high workload on the sync clients." : "Please note that this may cause high workload on the sync clients.",
+    "Limit" : "Limit",
+    "This allows to configure how many users should be processed in one background job run." : "This allows to configure how many users should be processed in one background job run.",
+    "Sanitize filenames" : "Sanitize filenames",
+    "(starting)" : "(starting)",
     "Fill template fields" : "Fill template fields",
-    "Submitting fields …" : "Submitting fields …",
+    "Submitting fields …" : "Submitting fields …",
     "Submit" : "Submit",
     "Choose a file or folder to transfer" : "Choose a file or folder to transfer",
     "Transfer" : "Transfer",
@@ -153,6 +219,7 @@ OC.L10N.register(
     "Do not show this dialog again." : "Do not show this dialogue again.",
     "Select file or folder to link to" : "Select file or folder to link to",
     "Choose {file}" : "Choose {file}",
+    "Files settings" : "Files settings",
     "Share" : "Share",
     "Shared by link" : "Shared by link",
     "Shared" : "Shared",
@@ -165,85 +232,52 @@ OC.L10N.register(
     "Error during upload: {message}" : "Error during upload: {message}",
     "Error during upload, status code {status}" : "Error during upload, status code {status}",
     "Unknown error during upload" : "Unknown error during upload",
-    "\"{displayName}\" action executed successfully" : "\"{displayName}\" action executed successfully",
     "Loading current folder" : "Loading current folder",
     "Retry" : "Retry",
     "No files in here" : "No files in here",
     "Upload some content or sync with your devices!" : "Upload some content or sync with your devices!",
     "Go back" : "Go back",
-    "Filter file names …" : "Filter file names …",
     "Views" : "Views",
-    "Files settings" : "Files settings",
-    "Your files" : "Your files",
-    "Open in files" : "Open in files",
-    "File cannot be accessed" : "File cannot be accessed",
-    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "The file could not be found or you do not have permissions to view it. Ask the sender to share it.",
-    "Clipboard is not available" : "Clipboard is not available",
-    "WebDAV URL copied to clipboard" : "WebDAV URL copied to clipboard",
-    "Sort favorites first" : "Sort favourites first",
-    "Sort folders before files" : "Sort folders before files",
-    "Show hidden files" : "Show hidden files",
-    "Crop image previews" : "Crop image previews",
-    "Enable the grid view" : "Enable the grid view",
-    "Enable folder tree" : "Enable folder tree",
-    "Additional settings" : "Additional settings",
-    "WebDAV" : "WebDAV",
-    "WebDAV URL" : "WebDAV URL",
-    "Copy to clipboard" : "Copy to clipboard",
-    "Use this address to access your Files via WebDAV" : "Use this address to access your Files via WebDAV",
-    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "If you have enabled 2FA, you must create and use a new app password by clicking here.",
-    "Warnings" : "Warnings",
-    "Prevent warning dialogs from open or reenable them." : "Prevent warning dialogues from opening or reenable them.",
-    "Show a warning dialog when changing a file extension." : "Show a warning dialogue when changing a file extension.",
-    "Keyboard shortcuts" : "Keyboard shortcuts",
-    "Speed up your Files experience with these quick shortcuts." : "Speed up your Files experience with these quick shortcuts.",
-    "Open the actions menu for a file" : "Open the actions menu for a file",
-    "Rename a file" : "Rename a file",
-    "Delete a file" : "Delete a file",
-    "Favorite or remove a file from favorites" : "Favourite or remove a file from favourites",
-    "Manage tags for a file" : "Manage tags for a file",
-    "Selection" : "Selection",
-    "Select all files" : "Select all files",
-    "Deselect all files" : "Deselect all files",
-    "Select or deselect a file" : "Select or deselect a file",
-    "Select a range of files" : "Select a range of files",
-    "Navigation" : "Navigation",
-    "Navigate to the parent folder" : "Navigate to the parent folder",
-    "Navigate to the file above" : "Navigate to the file above",
-    "Navigate to the file below" : "Navigate to the file below",
-    "Navigate to the file on the left (in grid mode)" : "Navigate to the file on the left (in grid mode)",
-    "Navigate to the file on the right (in grid mode)" : "Navigate to the file on the right (in grid mode)",
-    "View" : "View",
-    "Toggle the grid view" : "Toggle the grid view",
-    "Open the sidebar for a file" : "Open the sidebar for a file",
-    "Show those shortcuts" : "Show those shortcuts",
     "You" : "You",
     "Shared multiple times with different people" : "Shared multiple times with different people",
+    "Unable to change the favorite state of the file" : "Unable to change the favorite state of the file",
     "Error while loading the file data" : "Error while loading the file data",
     "Owner" : "Owner",
     "Remove from favorites" : "Remove from favourites",
     "Add to favorites" : "Add to favourites",
     "Tags" : "Tags",
+    "Your files" : "Your files",
+    "Open in files" : "Open in files",
+    "File cannot be accessed" : "File cannot be accessed",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "The file could not be found or you do not have permissions to view it. Ask the sender to share it.",
+    "No search results for “{query}”" : "No search results for “{query}”",
+    "Search for files" : "Search for files",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed.",
+    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner.",
+    "Failed to toggle Windows filename support" : "Failed to toggle Windows filename support",
+    "Files compatibility" : "Files compatibility",
+    "Enforce Windows compatibility" : "Enforce Windows compatibility",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity.",
     "Blank" : "Blank",
     "Unable to create new file from template" : "Unable to create new file from template",
     "Pick a template for {name}" : "Pick a template for {name}",
     "Create a new file with the selected template" : "Create a new file with the selected template",
     "Creating file" : "Creating file",
     "Save as {displayName}" : "Save as {displayName}",
-    "Save as …" : "Save as …",
-    "Converting files …" : "Converting files …",
+    "Save as …" : "Save as …",
+    "Converting files …" : "Converting files …",
     "Failed to convert files: {message}" : "Failed to convert files: {message}",
     "All files failed to be converted" : "All files failed to be converted",
     "One file could not be converted: {message}" : "One file could not be converted: {message}",
-    "_One file could not be converted_::_%n files could not be converted_" : ["One file could not be converted","%n files could not be converted"],
-    "_One file successfully converted_::_%n files successfully converted_" : ["One file successfully converted","%n files successfully converted"],
-    "Files successfully converted" : "Files successfully converted",
+    "_%n file could not be converted_::_%n files could not be converted_" : ["%n file could not be converted","%n files could not be converted"],
+    "_%n file converted_::_%n files converted_" : ["%n file converted","%n files converted"],
+    "Files converted" : "Files converted",
     "Failed to convert files" : "Failed to convert files",
-    "Converting file …" : "Converting file …",
+    "Converting file …" : "Converting file …",
     "File successfully converted" : "File successfully converted",
     "Failed to convert file: {message}" : "Failed to convert file: {message}",
     "Failed to convert file" : "Failed to convert file",
-    "Deletion cancelled" : "Deletion cancelled",
+    "Delete" : "Delete",
     "Leave this share" : "Leave this share",
     "Leave these shares" : "Leave these shares",
     "Disconnect storage" : "Disconnect storage",
@@ -254,17 +288,21 @@ OC.L10N.register(
     "Delete files" : "Delete files",
     "Delete folder" : "Delete folder",
     "Delete folders" : "Delete folders",
-    "Delete" : "Delete",
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["You are about to permanently delete {count} item","You are about to permanently delete {count} items"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["You are about to delete {count} item","You are about to delete {count} items"],
     "Confirm deletion" : "Confirm deletion",
     "Cancel" : "Cancel",
-    "Moving \"{source}\" to \"{destination}\" …" : "Moving \"{source}\" to \"{destination}\" …",
-    "Copying \"{source}\" to \"{destination}\" …" : "Copying \"{source}\" to \"{destination}\" …",
+    "Download" : "Download",
+    "The requested file is not available." : "The requested file is not available.",
+    "The requested files are not available." : "The requested files are not available.",
+    "Add or remove favorite" : "Add or remove favorite",
+    "Moving \"{source}\" to \"{destination}\" …" : "Moving \"{source}\" to \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Copying \"{source}\" to \"{destination}\" …",
+    "Destination is not a folder" : "Destination is not a folder",
+    "This file/folder is already in that directory" : "This file/folder is already in that directory",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "You cannot move a file/folder onto itself or into a subfolder of itself",
     "(copy)" : "(copy)",
     "(copy %n)" : "(copy %n)",
-    "Move cancelled" : "Move cancelled",
     "A file or folder with that name already exists in this folder" : "A file or folder with that name already exists in this folder",
     "The files are locked" : "The files are locked",
     "The file does not exist anymore" : "The file does not exist anymore",
@@ -275,18 +313,16 @@ OC.L10N.register(
     "Move" : "Move",
     "Move or copy operation failed" : "Move or copy operation failed",
     "Move or copy" : "Move or copy",
-    "Cancelled move or copy of \"{filename}\"." : "Cancelled move or copy of \"{filename}\".",
-    "Cancelled move or copy operation" : "Cancelled move or copy operation",
     "Open folder {displayName}" : "Open folder {displayName}",
     "Open in Files" : "Open in Files",
+    "Open locally" : "Open locally",
+    "Failed to redirect to client" : "Failed to redirect to client",
     "Open file locally" : "Open file locally",
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "The file should now open on your device. If it doesn't, please check that you have the desktop app installed.",
     "Retry and close" : "Retry and close",
     "Open online" : "Open online",
-    "Failed to redirect to client" : "Failed to redirect to client",
-    "Open locally" : "Open locally",
     "Rename" : "Rename",
-    "Open details" : "Open details",
+    "Details" : "Details",
     "View in folder" : "View in folder",
     "Today" : "Today",
     "Last 7 days" : "Last 7 days",
@@ -299,15 +335,15 @@ OC.L10N.register(
     "PDFs" : "PDFs",
     "Folders" : "Folders",
     "Audio" : "Audio",
-    "Photos and images" : "Photos and images",
+    "Images" : "Images",
     "Videos" : "Videos",
-    "New folder creation cancelled" : "New folder creation cancelled",
     "Created new folder \"{name}\"" : "Created new folder \"{name}\"",
     "Unable to initialize the templates directory" : "Unable to initialize the templates directory",
     "Create templates folder" : "Create templates folder",
     "Templates" : "Templates",
     "New template folder" : "New template folder",
     "In folder" : "In folder",
+    "Search in all files" : "Search in all files",
     "Search in folder: {folder}" : "Search in folder: {folder}",
     "One of the dropped files could not be processed" : "One of the dropped files could not be processed",
     "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Your browser does not support the Filesystem API. Directories will not be uploaded",
@@ -322,16 +358,16 @@ OC.L10N.register(
     "Files moved successfully" : "Files moved successfully",
     "Conflicts resolution skipped" : "Conflicts resolution skipped",
     "Upload cancelled" : "Upload cancelled",
+    "Could not rename \"{oldName}\", it does not exist any more" : "Could not rename \"{oldName}\", it does not exist any more",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name.",
+    "Could not rename \"{oldName}\"" : "Could not rename \"{oldName}\"",
     "This operation is forbidden" : "This operation is forbidden",
-    "This directory is unavailable, please check the logs or contact the administrator" : "This directory is unavailable, please check the logs or contact the administrator",
+    "This folder is unavailable, please try again later or contact the administration" : "This folder is unavailable, please try again later or contact the administration",
     "Storage is temporarily not available" : "Storage is temporarily not available",
     "Unexpected error: {error}" : "Unexpected error: {error}",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} folder","{folderCount} folders"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} file","{fileCount} files"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 file and {folderCount} folder","1 file and {folderCount} folders"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} file and 1 folder","{fileCount} files and 1 folder"],
-    "{fileCount} files and {folderCount} folders" : "{fileCount} files and {folderCount} folders",
-    "_(%n hidden)_::_ (%n hidden)_" : ["(%n hidden)"," (%n hidden)"],
+    "_%n file_::_%n files_" : ["%n file","%n files"],
+    "_%n folder_::_%n folders_" : ["%n folder","%n folders"],
+    "_%n hidden_::_%n hidden_" : ["%n hidden","%n hidden"],
     "Filename must not be empty." : "Filename must not be empty.",
     "\"{char}\" is not allowed inside a filename." : "\"{char}\" is not allowed inside a filename.",
     "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" is a reserved name and not allowed for filenames.",
@@ -340,10 +376,8 @@ OC.L10N.register(
     "List of favorite files and folders." : "List of favourite files and folders.",
     "No favorites yet" : "No favourites yet",
     "Files and folders you mark as favorite will show up here" : "Files and folders you mark as favourite will show up here",
-    "All files" : "All files",
     "List of your files and folders." : "List of your files and folders.",
-    "All folders" : "All folders",
-    "Personal files" : "Personal files",
+    "Folder tree" : "Folder tree",
     "List of your files and folders that are not shared." : "List of your files and folders that are not shared.",
     "No personal files found" : "No personal files found",
     "Files that are not shared will show up here." : "Files that are not shared will show up here.",
@@ -351,111 +385,67 @@ OC.L10N.register(
     "List of recently modified files and folders." : "List of recently modified files and folders.",
     "No recently modified files" : "No recently modified files",
     "Files and folders you recently modified will show up here." : "Files and folders you recently modified will show up here.",
+    "Search" : "Search",
+    "Search results within your files." : "Search results within your files.",
     "No entries found in this folder" : "No entries found in this folder",
     "Select all" : "Select all",
     "Upload too large" : "Upload too large",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "The files you are trying to upload exceed the maximum size for file uploads on this server.",
-    "File could not be found" : "File could not be found",
-    "Download" : "Download",
-    "Show list view" : "Show list view",
-    "Show grid view" : "Show grid view",
-    "Close" : "Close",
-    "Could not create folder \"{dir}\"" : "Could not create folder \"{dir}\"",
-    "This will stop your current uploads." : "This will stop your current uploads.",
-    "Upload cancelled." : "Upload cancelled.",
-    "Processing files …" : "Processing files …",
-    "…" : "…",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Unable to upload {filename} as it is a directory or has 0 bytes",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Not enough free space, you are uploading {size1} but only {size2} is left",
-    "Target folder \"{dir}\" does not exist any more" : "Target folder \"{dir}\" does not exist any more",
-    "An unknown error has occurred" : "An unknown error has occurred",
-    "File could not be uploaded" : "File could not be uploaded",
-    "Uploading …" : "Uploading …",
-    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
-    "Uploading … ({currentNumber}/{total})" : "Uploading … ({currentNumber}/{total})",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} of {totalSize} ({bitrate})",
-    "Uploading that item is not supported" : "Uploading that item is not supported",
-    "Error when assembling chunks, status code {status}" : "Error when assembling chunks, status code {status}",
-    "Choose target folder" : "Choose target folder",
-    "Set reminder" : "Set reminder",
+    "%1$s (renamed)" : "%1$s (renamed)",
+    "renamed file" : "renamed file",
+    "Upload (max. %s)" : "Upload (max. %s)",
+    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner.",
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command.",
+    "\"{displayName}\" failed on some elements" : "\"{displayName}\" failed on some elements",
+    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" batch action executed successfully",
+    "\"{displayName}\" action failed" : "\"{displayName}\" action failed",
+    "Submitting fields …" : "Submitting fields …",
+    "\"{displayName}\" action executed successfully" : "\"{displayName}\" action executed successfully",
+    "Filter file names …" : "Filter file names …",
+    "Clipboard is not available" : "Clipboard is not available",
+    "WebDAV URL copied to clipboard" : "WebDAV URL copied to clipboard",
+    "Enable the grid view" : "Enable the grid view",
+    "Enable folder tree" : "Enable folder tree",
+    "WebDAV" : "WebDAV",
+    "Copy to clipboard" : "Copy to clipboard",
+    "Use this address to access your Files via WebDAV" : "Use this address to access your Files via WebDAV",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "If you have enabled 2FA, you must create and use a new app password by clicking here.",
+    "Prevent warning dialogs from open or reenable them." : "Prevent warning dialogues from opening or reenable them.",
+    "Show a warning dialog when changing a file extension." : "Show a warning dialog when changing a file extension.",
+    "Keyboard shortcuts" : "Keyboard shortcuts",
+    "Speed up your Files experience with these quick shortcuts." : "Speed up your Files experience with these quick shortcuts.",
+    "Open the actions menu for a file" : "Open the actions menu for a file",
+    "Rename a file" : "Rename a file",
+    "Delete a file" : "Delete a file",
+    "Favorite or remove a file from favorites" : "Favourite or remove a file from favourites",
+    "Manage tags for a file" : "Manage tags for a file",
+    "Deselect all files" : "Deselect all files",
+    "Select or deselect a file" : "Select or deselect a file",
+    "Select a range of files" : "Select a range of files",
+    "Navigate to the parent folder" : "Navigate to the parent folder",
+    "Navigate to the file above" : "Navigate to the file above",
+    "Navigate to the file below" : "Navigate to the file below",
+    "Navigate to the file on the left (in grid mode)" : "Navigate to the file on the left (in grid mode)",
+    "Navigate to the file on the right (in grid mode)" : "Navigate to the file on the right (in grid mode)",
+    "Toggle the grid view" : "Toggle the grid view",
+    "Open the sidebar for a file" : "Open the sidebar for a file",
+    "Save as …" : "Save as …",
+    "Converting files …" : "Converting files …",
+    "Converting file …" : "Converting file …",
+    "Deletion cancelled" : "Deletion cancelled",
     "Edit locally" : "Edit locally",
-    "Open" : "Open",
-    "Could not load info for file \"{file}\"" : "Could not load info for file \"{file}\"",
-    "Details" : "Details",
-    "Please select tag(s) to add to the selection" : "Please select tag(s) to add to the selection",
-    "Apply tag(s) to selection" : "Apply tag(s) to selection",
-    "Select directory \"{dirName}\"" : "Select directory \"{dirName}\"",
-    "Select file \"{fileName}\"" : "Select file \"{fileName}\"",
-    "Unable to determine date" : "Unable to determine date",
-    "Could not move \"{file}\", target exists" : "Could not move \"{file}\", target exists",
-    "Could not move \"{file}\"" : "Could not move \"{file}\"",
-    "copy" : "copy",
-    "Could not copy \"{file}\", target exists" : "Could not copy \"{file}\", target exists",
-    "Could not copy \"{file}\"" : "Could not copy \"{file}\"",
-    "Copied {origin} inside {destination}" : "Copied {origin} inside {destination}",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "Copied {origin} and {nbfiles} other files inside {destination}",
-    "{newName} already exists" : "{newName} already exists",
-    "Could not rename \"{fileName}\", it does not exist any more" : "Could not rename \"{fileName}\", it does not exist any more",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name.",
-    "Could not rename \"{fileName}\"" : "Could not rename \"{fileName}\"",
-    "Could not create file \"{file}\"" : "Could not create file \"{file}\"",
-    "Could not create file \"{file}\" because it already exists" : "Could not create file \"{file}\" because it already exists",
-    "Could not create folder \"{dir}\" because it already exists" : "Could not create folder \"{dir}\" because it already exists",
-    "Could not fetch file details \"{file}\"" : "Could not fetch file details \"{file}\"",
-    "Error deleting file \"{fileName}\"." : "Error deleting file \"{fileName}\".",
-    "No search results in other folders for {tag}{filter}{endtag}" : "No search results in other folders for {tag}{filter}{endtag}",
-    "Enter more than two characters to search in other folders" : "Enter more than two characters to search in other folders",
-    "_%n folder_::_%n folders_" : ["%n folder","%n folders"],
-    "_%n file_::_%n files_" : ["%n file","%n files"],
-    "{dirs} and {files}" : "{dirs} and {files}",
-    "_including %n hidden_::_including %n hidden_" : ["including %n hidden","including %n hidden"],
-    "You do not have permission to upload or create files here" : "You do not have permission to upload or create files here",
-    "_Uploading %n file_::_Uploading %n files_" : ["Uploading %n file","Uploading %n files"],
-    "New" : "New",
-    "New file/folder menu" : "New file/folder menu",
-    "Select file range" : "Select file range",
-    "{used}%" : "{used}%",
-    "{used} used" : "{used} used",
-    "\"{name}\" is an invalid file name." : "\"{name}\" is an invalid file name.",
-    "File name cannot be empty." : "File name cannot be empty.",
-    "\"/\" is not allowed inside a file name." : "\"/\" is not allowed inside a file name.",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\" is not an allowed filetype",
-    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Storage of {owner} is full, files cannot be updated or synced anymore!",
-    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!",
-    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!",
-    "Your storage is full, files cannot be updated or synced anymore!" : "Your storage is full, files cannot be updated or synced anymore!",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Storage of {owner} is almost full ({usedSpacePercent}%).",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%).",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%).",
-    "Your storage is almost full ({usedSpacePercent}%)." : "Your storage is almost full ({usedSpacePercent}%).",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["matches \"{filter}\"","match \"{filter}\""],
-    "Direct link was copied (only works for people who have access to this file/folder)" : "Direct link was copied (only works for people who have access to this file/folder)",
-    "Path" : "Path",
-    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
-    "Favorited" : "Added to Favourites",
-    "Copy direct link (only works for people who have access to this file/folder)" : "Copy direct link (only works for people who have access to this file/folder)",
-    "Upload file" : "Upload file",
-    "Not favorited" : "Not favourited",
-    "An error occurred while trying to update the tags" : "An error occurred whilst trying to update the tags",
-    "You don't have permission to upload or create files here." : "You don't have permission to upload or create files here.",
-    "Storage informations" : "Storage informations",
-    "Choose file" : "Choose file",
-    "Go to the previous folder" : "Go to the previous folder",
-    "Open the files app settings" : "Open the files app settings",
-    "Unable to change the favourite state of the file" : "Unable to change the favourite state of the file",
-    "Edit file locally" : "Edit file locally",
-    "Edit online" : "Edit online",
-    "Create new templates folder" : "Create new templates folder",
-    "List of favorites files and folders." : "List of favourite files and folders.",
-    "Personal Files" : "Personal Files",
-    "Text file" : "Text file",
-    "New text file.txt" : "New text file.txt",
-    "Favored" : "Favoured",
-    "Favor" : "Favour",
-    "Not favored" : "Not favoured",
-    "Submitting fields…" : "Submitting fields…",
-    "Filter filenames…" : "Filter filenames…",
-    "{count} files could not be converted" : "{count} files could not be converted",
-    "{count} files successfully converted" : "{count} files successfully converted"
+    "Moving \"{source}\" to \"{destination}\" …" : "Moving \"{source}\" to \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Copying \"{source}\" to \"{destination}\" …",
+    "Move cancelled" : "Move cancelled",
+    "Cancelled move or copy of \"{filename}\"." : "Cancelled move or copy of \"{filename}\".",
+    "Cancelled move or copy operation" : "Cancelled move or copy operation",
+    "Open details" : "Open details",
+    "Photos and images" : "Photos and images",
+    "New folder creation cancelled" : "New folder creation cancelled",
+    "This directory is unavailable, please check the logs or contact the administrator" : "This directory is unavailable, please check the logs or contact the administrator",
+    "All folders" : "All folders",
+    "Search everywhere …" : "Search everywhere …",
+    "Search here …" : "Search here …",
+    "Preparing …" : "Preparing …"
 },
 "nplurals=2; plural=(n != 1);");
