@@ -130,6 +130,7 @@ OC.L10N.register(
     "Warnings" : "Varoitukset",
     "Warn before changing a file extension" : "Varoita ennen tiedostopäätteen muuttamista",
     "WebDAV URL" : "WebDAV:in URL-osoite",
+    "Create an app password" : "Luo sovellussalasana",
     "Name" : "Nimi",
     "File type" : "Tiedoston tyyppi",
     "Size" : "Koko",
@@ -249,6 +250,8 @@ OC.L10N.register(
     "Download" : "Lataa",
     "The requested file is not available." : "Pyydetty tiedosto ei ole saatavilla.",
     "The requested files are not available." : "Pyydetyt tiedostot eivät ole saatavilla.",
+    "Moving \"{source}\" to \"{destination}\" …" : "Siirretään \"{source}\" kohteeseen \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Kopioidaan \"{source}\" kohteeseen \"{destination}\" …",
     "Destination is not a folder" : "Kohde ei ole kansio",
     "This file/folder is already in that directory" : "Tämä tiedosto/kansio on jo kyseisessä kansiossa",
     "(copy)" : "(kopioi)",
