@@ -108,6 +108,43 @@ OC.L10N.register(
     "Type" : "Type",
     "Active filters" : "Filtres actifs",
     "Remove filter" : "Retirer le filtre",
+    "Appearance" : "Apparence",
+    "Show hidden files" : "Montrer les fichiers masqués",
+    "Show file type column" : "Afficher la colonne du type de fichier",
+    "Show file extensions" : "Afficher les extensions de fichiers",
+    "Crop image previews" : "Afficher en miniatures carrées",
+    "General" : "Général",
+    "Sort favorites first" : "Trier les favoris en premier",
+    "Sort folders before files" : "Trier les dossiers avant les fichiers",
+    "Enable folder tree view" : "Activer l'affichage arborescent des dossiers",
+    "Default view" : "Vue par défaut",
+    "All files" : "Tous les fichiers",
+    "Personal files" : "Fichiers personnels",
+    "Additional settings" : "Paramètres supplémentaires",
+    "Actions" : "Actions",
+    "File actions" : "Actions de fichiers",
+    "Selection" : "Choix",
+    "Select all files" : "Sélectionner tous les fichiers",
+    "Deselect all" : "Tout désélectionner",
+    "Select or deselect" : "Sélectionner ou désélectionner",
+    "Select a range" : "Sélectionner une plage",
+    "Navigation" : "Navigation",
+    "Go to parent folder" : "Aller au dossier parent",
+    "Go to file above" : "Aller au fichier au-dessus",
+    "Go to file below" : "Aller au fichier au-dessous",
+    "Go left in grid" : "Aller à gauche dans la grille",
+    "Go right in grid" : "Aller à droite dans la grille",
+    "View" : "Voir",
+    "Toggle grid view" : "Activer/Désactiver l'affichage mosaïque",
+    "Open file sidebar" : "Ouvrir le panneau latéral du fichier",
+    "Show those shortcuts" : "Montrer ces raccourcis",
+    "Warnings" : "Avertissements",
+    "Warn before changing a file extension" : "Avertir avant de modifier l'extension d'un fichier",
+    "Warn before deleting a file" : "Avertir avant de supprimer un fichier",
+    "WebDAV URL" : "URL WebDAV",
+    "Create an app password" : "Créer un mot de passe d'application",
+    "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "Requis pour l'authentification WebDAV car l'authentification à deux facteurs est activée pour ce compte.",
+    "How to access files using WebDAV" : "Comment accéder aux fichiers en utilisant WebDAV",
     "Total rows summary" : "Récapitulatif du nombre total de lignes",
     "Toggle selection for all files and folders" : "Basculer la sélection pour tous les fichiers et dossiers",
     "Name" : "Nom",
@@ -116,7 +153,6 @@ OC.L10N.register(
     "{displayName}: failed on some elements" : "{displayName} : a échoué pour certains éléments",
     "{displayName}: done" : "{displayName} : terminé",
     "{displayName}: failed" : "{displayName} : échec",
-    "Actions" : "Actions",
     "(selected)" : "(sélectionné)",
     "List of files and folders." : "Liste des fichiers et dossiers.",
     "You have used your space quota and cannot upload files anymore." : "Vous avez utilisé votre quota d'espace et vous ne pouvez plus téléverser de fichiers",
@@ -124,8 +160,8 @@ OC.L10N.register(
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Cette liste n'est pas entièrement affichée pour des raisons de performances. Les fichiers seront affichés au fur et à mesure que vous naviguerez dans la liste.",
     "File not found" : "Fichier non trouvé",
     "_{count} selected_::_{count} selected_" : ["{count} sélectionné","{count} sélectionné(s)","{count} sélectionné(s)"],
-    "Search everywhere …" : "Rechercher partout...",
-    "Search here …" : "Rechercher ici...",
+    "Search everywhere …" : "Rechercher partout …",
+    "Search here …" : "Rechercher ici …",
     "Search scope options" : "Options de portée de recherche",
     "Search here" : "Rechercher ici",
     "{usedQuotaByte} used" : "{usedQuotaByte} utilisés",
@@ -144,7 +180,7 @@ OC.L10N.register(
     "Failed to refresh filename sanitization status." : "Impossible d'actualiser le statut du nettoyage de nom de fichier.",
     "Filename sanitization in progress." : "Nettoyage de nom de fichier en cours.",
     "Currently {processedUsers} of {totalUsers} accounts are already processed." : "Actuellement, {processedUsers} sur {totalUsers} comptes ont déjà été traités.",
-    "Preparing …" : "Préparation...",
+    "Preparing …" : "Préparation …",
     "Refresh" : "Actualiser",
     "All files have been santized for Windows filename support." : "Tous les fichiers ont été nettoyés pour être compatibles avec Windows.",
     "Some files could not be sanitized, please check your logs." : "Certains fichiers n'ont pas pu être nettoyés, veuillez vérifier les logs du serveur.",
@@ -159,7 +195,7 @@ OC.L10N.register(
     "Sanitize filenames" : "Nettoyer les noms de fichiers",
     "(starting)" : "(démarrage)",
     "Fill template fields" : "Remplir les champs modèle",
-    "Submitting fields …" : "Soumission des champs...",
+    "Submitting fields …" : "Soumission des champs …",
     "Submit" : "Envoyer",
     "Choose a file or folder to transfer" : "Sélectionnez un fichier ou un dossier à transférer",
     "Transfer" : "Transférer",
@@ -183,6 +219,7 @@ OC.L10N.register(
     "Do not show this dialog again." : "Ne plus montrer cette boite de dialogue.",
     "Select file or folder to link to" : "Sélection d'un fichier ou d'un dossier à lier",
     "Choose {file}" : "Choisir {file}",
+    "Files settings" : "Paramètres de Fichiers",
     "Share" : "Partager",
     "Shared by link" : "Partagés par lien",
     "Shared" : "Partagé",
@@ -201,63 +238,6 @@ OC.L10N.register(
     "Upload some content or sync with your devices!" : "Déposez du contenu ou synchronisez vos appareils !",
     "Go back" : "Revenir en arrière",
     "Views" : "Vues",
-    "Files settings" : "Paramètres de Fichiers",
-    "Your files" : "Vos fichiers",
-    "Open in files" : "Ouvrir dans Fichiers",
-    "File cannot be accessed" : "Impossible d'accéder au fichier",
-    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Le fichier n'a pas été trouvé ou vous n'avez pas les permissions pour le voir. Demandez à l'expéditeur de le partager.",
-    "No search results for “{query}”" : "Aucun résultat de recherche pour “{query}”",
-    "Search for files" : "Rechercher des fichiers",
-    "Clipboard is not available" : "Le presse-papiers n'est pas disponible",
-    "WebDAV URL copied" : "URL WebDAV copiée",
-    "General" : "Général",
-    "Default view" : "Vue par défaut",
-    "All files" : "Tous les fichiers",
-    "Personal files" : "Fichiers personnels",
-    "Sort favorites first" : "Trier les favoris en premier",
-    "Sort folders before files" : "Trier les dossiers avant les fichiers",
-    "Folder tree" : "Arborescence des dossiers",
-    "Appearance" : "Apparence",
-    "Show hidden files" : "Montrer les fichiers masqués",
-    "Show file type column" : "Afficher la colonne du type de fichier",
-    "Show file extensions" : "Afficher les extensions de fichiers",
-    "Crop image previews" : "Afficher en miniatures carrées",
-    "Additional settings" : "Paramètres supplémentaires",
-    "WebDAV" : "WebDAV",
-    "WebDAV URL" : "URL WebDAV",
-    "Copy" : "Copier",
-    "How to access files using WebDAV" : "Comment accéder aux fichiers en utilisant WebDAV",
-    "Two-Factor Authentication is enabled for your account, and therefore you need to use an app password to connect an external WebDAV client." : "L'authentification à deux facteurs est activée pour votre compte. Vous devez donc utiliser un mot de passe d'application pour connecter un client WebDAV externe.",
-    "Warnings" : "Avertissements",
-    "Warn before changing a file extension" : "Avertir avant de modifier l'extension d'un fichier",
-    "Warn before deleting files" : "Avertir avant de supprimer des fichiers",
-    "Keyboard shortcuts" : "Raccourcis clavier",
-    "File actions" : "Actions de fichiers",
-    "Rename" : "Renommer",
-    "Delete" : "Supprimer",
-    "Add or remove favorite" : "Ajouter ou supprimer un favoris",
-    "Manage tags" : "Gérer les étiquettes",
-    "Selection" : "Choix",
-    "Select all files" : "Sélectionner tous les fichiers",
-    "Deselect all" : "Tout désélectionner",
-    "Select or deselect" : "Sélectionner ou désélectionner",
-    "Select a range" : "Sélectionner une plage",
-    "Navigation" : "Navigation",
-    "Go to parent folder" : "Aller au dossier parent",
-    "Go to file above" : "Aller au fichier au-dessus",
-    "Go to file below" : "Aller au fichier au-dessous",
-    "Go left in grid" : "Aller à gauche dans la grille",
-    "Go right in grid" : "Aller à droite dans la grille",
-    "View" : "Voir",
-    "Toggle grid view" : "Activer/Désactiver l'affichage mosaïque",
-    "Open file sidebar" : "Ouvrir le panneau latéral du fichier",
-    "Show those shortcuts" : "Montrer ces raccourcis",
-    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Permet de restreindre les noms de fichiers pour s'assurer que les fichiers peuvent être synchronisés avec tous les clients. Par défaut, tous les noms de fichier valides sur POSIX (c'est à dire sur Linux ou MacOS) sont acceptés.",
-    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Après avoir activé les noms de fichiers compatibles Windows, les fichiers existants ne peuvent plus être modifiés mais peuvent être renommés avec de nouveaux noms valides par leur propriétaire.",
-    "Failed to toggle Windows filename support" : "Échec de l'activation de la prise en charge des noms de fichiers compatibles Windows",
-    "Files compatibility" : "Compatibilité des fichiers",
-    "Enforce Windows compatibility" : "Forcer la compatibilité Windows",
-    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Cela va bloquer les noms de fichier non valides sur les systèmes Windows, comme utiliser des noms réservés ou des caractères spéciaux. Mais cela ne renforcera pas la compatibilité de la sensibilité à la casse.",
     "You" : "Vous",
     "Shared multiple times with different people" : "Partagé plusieurs fois avec plusieurs personnes",
     "Unable to change the favorite state of the file" : "Impossible de modifier l'état de mise en favori du fichier",
@@ -266,25 +246,38 @@ OC.L10N.register(
     "Remove from favorites" : "Retirer des favoris",
     "Add to favorites" : "Ajouter aux favoris",
     "Tags" : "Étiquettes",
+    "Your files" : "Vos fichiers",
+    "Open in files" : "Ouvrir dans Fichiers",
+    "File cannot be accessed" : "Impossible d'accéder au fichier",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Le fichier n'a pas été trouvé ou vous n'avez pas les permissions pour le voir. Demandez à l'expéditeur de le partager.",
+    "No search results for “{query}”" : "Aucun résultat de recherche pour “{query}”",
+    "Search for files" : "Rechercher des fichiers",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Permet de restreindre les noms de fichiers pour s'assurer que les fichiers peuvent être synchronisés avec tous les clients. Par défaut, tous les noms de fichier valides sur POSIX (c'est à dire sur Linux ou MacOS) sont acceptés.",
+    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Après avoir activé les noms de fichiers compatibles Windows, les fichiers existants ne peuvent plus être modifiés mais peuvent être renommés avec de nouveaux noms valides par leur propriétaire.",
+    "Failed to toggle Windows filename support" : "Échec de l'activation de la prise en charge des noms de fichiers compatibles Windows",
+    "Files compatibility" : "Compatibilité des fichiers",
+    "Enforce Windows compatibility" : "Forcer la compatibilité Windows",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Cela va bloquer les noms de fichier non valides sur les systèmes Windows, comme utiliser des noms réservés ou des caractères spéciaux. Mais cela ne renforcera pas la compatibilité de la sensibilité à la casse.",
     "Blank" : "Vide",
     "Unable to create new file from template" : "Impossible de créer un nouveau fichier à partir du modèle",
     "Pick a template for {name}" : "Choisissez un modèle pour {name}",
     "Create a new file with the selected template" : "Créer un nouveau fichier avec le modèle sélectionné",
     "Creating file" : "Créer un fichier",
     "Save as {displayName}" : "Enregistrer sous {displayName}",
-    "Save as …" : "Enregistrer sous...",
-    "Converting files …" : "Conversion des fichiers...",
+    "Save as …" : "Enregistrer sous …",
+    "Converting files …" : "Conversion des fichiers …",
     "Failed to convert files: {message}" : "Impossible de convertir les fichiers : {message}",
     "All files failed to be converted" : "Aucun fichier n'a pu être converti",
     "One file could not be converted: {message}" : "Le fichier {message} n'a pas pu être converti",
-    "_One file could not be converted_::_%n files could not be converted_" : ["Un fichier n'a pas pu être converti","%n fichiers n'ont pas pu être convertis","%n fichiers n'ont pas pu être convertis"],
-    "_One file successfully converted_::_%n files successfully converted_" : ["Un fichier converti avec succès","%n fichiers convertis avec succès","%n fichiers convertis avec succès"],
-    "Files successfully converted" : "Fichiers convertis avec succès",
+    "_%n file could not be converted_::_%n files could not be converted_" : ["Un fichier n'a pas pu être converti","%n fichiers n'ont pas pu être convertis","%n fichiers n'ont pas pu être convertis"],
+    "_%n file converted_::_%n files converted_" : ["%n fichier converti","%n fichiers convertis","%n fichiers convertis"],
+    "Files converted" : "Fichiers convertis",
     "Failed to convert files" : "Impossible de convertir les fichiers",
-    "Converting file …" : "Conversion du fichier...",
+    "Converting file …" : "Conversion du fichier …",
     "File successfully converted" : "Fichier converti avec succès",
     "Failed to convert file: {message}" : "Impossible de convertir le fichier : {message}",
     "Failed to convert file" : "Impossible de convertir le fichier",
+    "Delete" : "Supprimer",
     "Leave this share" : "Quitter ce partage",
     "Leave these shares" : "Quitter ces partages",
     "Disconnect storage" : "Déconnecter ce support de stockage",
@@ -302,8 +295,9 @@ OC.L10N.register(
     "Download" : "Télécharger",
     "The requested file is not available." : "Le fichier demandé n'est pas disponible.",
     "The requested files are not available." : "Les fichiers demandés ne sont pas disponibles.",
-    "Moving \"{source}\" to \"{destination}\" …" : "Déplacement de \"{source}\" vers \"{destination}\" …",
-    "Copying \"{source}\" to \"{destination}\" …" : "Copie de \"{source}\" vers \"{destination}\" …",
+    "Add or remove favorite" : "Ajouter ou supprimer un favoris",
+    "Moving \"{source}\" to \"{destination}\" …" : "Déplacement de \"{source}\" vers \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Copie de \"{source}\" vers \"{destination}\" …",
     "Destination is not a folder" : "La destination n'est pas un dossier",
     "This file/folder is already in that directory" : "Ce fichier/dossier se trouve déjà dans ce dossier",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Vous ne pouvez pas déplacer un fichier/dossier sur lui-même ou dans un sous-dossier de celui-ci",
@@ -314,6 +308,7 @@ OC.L10N.register(
     "The file does not exist anymore" : "Le fichier n'existe plus",
     "Choose destination" : "Choisir la destination",
     "Copy to {target}" : "Copier vers {target}",
+    "Copy" : "Copier",
     "Move to {target}" : "Déplacer vers {target}",
     "Move" : "Déplacer",
     "Move or copy operation failed" : "L'opération de copie ou de déplacement a échoué",
@@ -326,6 +321,7 @@ OC.L10N.register(
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Le fichier devrait maintenant s'ouvrir sur votre appareil. Si ce n'est pas le cas, vérifiez que vous avez installé l'application de bureau.",
     "Retry and close" : "Réessayer et fermer",
     "Open online" : "Ouvrir en ligne",
+    "Rename" : "Renommer",
     "Details" : "Détails",
     "View in folder" : "Afficher dans le dossier",
     "Today" : "Aujourd’hui",
@@ -381,6 +377,7 @@ OC.L10N.register(
     "No favorites yet" : "Aucun favori pour l'instant",
     "Files and folders you mark as favorite will show up here" : "Les fichiers et dossiers ajoutés à vos favoris apparaîtront ici",
     "List of your files and folders." : "Liste de vos fichiers et dossiers.",
+    "Folder tree" : "Arborescence des dossiers",
     "List of your files and folders that are not shared." : "Liste de vos fichiers et dossiers non partagés.",
     "No personal files found" : "Aucun fichier personnel trouvé",
     "Files that are not shared will show up here." : "Les fichiers qui ne sont pas partagés apparaîtront ici.",
@@ -394,119 +391,28 @@ OC.L10N.register(
     "Select all" : "Tout sélectionner",
     "Upload too large" : "Données envoyées trop volumineuses",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Les fichiers que vous essayez d’envoyer dépassent la taille maximale d’envoi permise par ce serveur.",
-    "File could not be found" : "Fichier introuvable",
-    "Show list view" : "Afficher la vue en liste",
-    "Show grid view" : "Afficher la vue en grille",
-    "Close" : "Fermer",
-    "Could not create folder \"{dir}\"" : "Impossible de créer le dossier \"{dir}\"",
-    "This will stop your current uploads." : "Cela va arrêter vos envois en cours.",
-    "Upload cancelled." : "Téléversement annulé.",
-    "Processing files …" : "Fichiers en cours de traitement …",
-    "…" : "…",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Impossible de téléverser {filename} car il s'agit d'un dossier ou d'un fichier vide",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Espace libre insuffisant : vous tentez d’envoyer {size1} mais seulement {size2} sont disponibles",
-    "Target folder \"{dir}\" does not exist any more" : "Le dossier cible \"{dir}\" n'existe plus",
-    "An unknown error has occurred" : "Une erreur inconnue est survenue",
-    "File could not be uploaded" : "Le fichier n'a pas pu être téléversé",
-    "Uploading …" : "Envoi en cours...",
-    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
-    "Uploading … ({currentNumber}/{total})" : "Téléversement en cours… ({currentNumber}/{total})",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} sur {totalSize} ({bitrate})",
-    "Uploading that item is not supported" : "L'envoi de cet élément n'est pas supporté",
-    "Error when assembling chunks, status code {status}" : "Erreur lors de l'assemblage des blocs, code de statut {status}",
-    "Choose target folder" : "Sélectionner le dossier cible",
-    "Set reminder" : "Définir un rappel",
-    "Edit locally" : "Éditer localement",
-    "Open" : "Ouvrir",
-    "Could not load info for file \"{file}\"" : "Impossible de charger les informations du fichier \"{file}\"",
-    "Please select tag(s) to add to the selection" : "Veuillez sélectionner la ou les étiquette(s) à ajouter à la sélection",
-    "Apply tag(s) to selection" : "Appliquer la ou les étiquette(s) à la sélection",
-    "Select directory \"{dirName}\"" : "Sélectionner le dossier \"{dirName}\"",
-    "Select file \"{fileName}\"" : "Sélectionner le fichier \"{fileName}\"",
-    "Unable to determine date" : "Impossible de déterminer la date",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Ce répertoire est indisponible, merci de consulter les journaux ou de contacter votre administrateur",
-    "Could not move \"{file}\", target exists" : "Impossible de déplacer « {file} », la cible existe",
-    "Could not move \"{file}\"" : "Impossible de déplacer \"{file}\"",
-    "copy" : "copie",
-    "Could not copy \"{file}\", target exists" : "Impossible de copier \"{file}\", la cible existe",
-    "Could not copy \"{file}\"" : "Impossible de copier \"{file}\"",
-    "Copied {origin} inside {destination}" : "{origin} copié dans {destination}",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} et {nbfiles} autres fichiers copiés dans {destination}",
-    "{newName} already exists" : "{newName} existe déjà",
-    "Could not create file \"{file}\"" : "Impossible de créer le fichier « {file} »",
-    "Could not create file \"{file}\" because it already exists" : "Impossible de créer le fichier « {file} » car il existe déjà",
-    "Could not create folder \"{dir}\" because it already exists" : "Impossible de créer le dossier \"{dir}\" car il existe déjà",
-    "Could not fetch file details \"{file}\"" : "Impossible de récupérer les détails du fichier \"{file}\"",
-    "Error deleting file \"{fileName}\"." : "Erreur à la suppression du fichier \"{fileName}\".",
-    "No search results in other folders for {tag}{filter}{endtag}" : "Aucun résultat dans d'autres dossiers pour {tag}{filter}{endtag}",
-    "Enter more than two characters to search in other folders" : "Entrez plus de deux caractères pour effectuer une recherche dans d'autres dossiers",
-    "{dirs} and {files}" : "{dirs} et {files}",
-    "_including %n hidden_::_including %n hidden_" : ["dont %n masqué","dont %n masqués","dont %n masqués"],
-    "You do not have permission to upload or create files here" : "Vous n'avez pas la permission de téléverser ou de créer des fichiers ici",
-    "_Uploading %n file_::_Uploading %n files_" : ["Téléversement de %n fichier","Envoi de %n fichiers","Envoi de %n fichiers"],
-    "New" : "Nouveau",
-    "New file/folder menu" : "Menu nouveau fichier/dossier",
-    "Select file range" : "Activer la sélection d'une plage de fichiers",
-    "{used}%" : "{used}%",
-    "{used} used" : "{used} utilisés",
-    "\"{name}\" is an invalid file name." : "« {name} » n’est pas un nom de fichier valide.",
-    "File name cannot be empty." : "Le nom de fichier ne peut pas être vide.",
-    "\"/\" is not allowed inside a file name." : "\"/\" n'est pas autorisé dans un nom de fichier.",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\" n'est pas un type de fichier autorisé",
-    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "L'espace de stockage de {owner} est plein. Les fichiers ne peuvent plus être mis à jour ni synchronisés !",
-    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Le dossier du groupe \"{mountPoint}\" est plein, les fichiers ne peuvent plus être mis à jour ou synchronisés !",
-    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "L'espace de stockage externe \"{mountPoint}\" est plein, les fichiers ne peuvent plus être mis à jour ni synchronisés !",
-    "Your storage is full, files cannot be updated or synced anymore!" : "Votre espace de stockage est plein. Les fichiers ne peuvent plus être mis à jour ni synchronisés !",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "L'espace de stockage de {owner} est presque plein ({usedSpacePercent}%).",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Le dossier de groupe \"{mountPoint}\" est presque plein ({usedSpacePercent}%).",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "L'espace de stockage externe \"{mountPoint}\" est presque plein ({usedSpacePercent}%).",
-    "Your storage is almost full ({usedSpacePercent}%)." : "Votre espace de stockage est presque plein ({usedSpacePercent}%).",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["correspond à \"{filter}\"","correspondent à '{filter}'","correspondent à '{filter}'"],
-    "Direct link was copied (only works for people who have access to this file/folder)" : "Le lien direct a été copié (fonctionne uniquement pour les personnes qui ont accès à ce fichier ou à ce dossier)",
-    "Path" : "Chemin",
-    "_%n byte_::_%n bytes_" : ["%n octet","%n octets","%n octets"],
-    "Favored" : "Favoris",
-    "Favor" : "Mettre en favoris",
-    "Copy direct link (only works for people who have access to this file/folder)" : "Copier le lien direct (fonctionne uniquement pour les personnes pouvant accéder à ce fichier ou à ce dossier)",
-    "Upload file" : "Téléverser un fichier",
-    "Not favored" : "Non favoris",
-    "An error occurred while trying to update the tags" : "Une erreur est survenue lors de la mise à jour des étiquettes",
+    "%1$s (renamed)" : "%1$s (renommé)",
+    "renamed file" : "fichier renommé",
     "Upload (max. %s)" : "Envoi (max. %s)",
-    "\"{displayName}\" action executed successfully" : "Action \"{displayName}\" exécutée avec succès",
-    "\"{displayName}\" action failed" : "Échec de l'action \"{displayName}\"",
+    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Après avoir activé les noms de fichiers compatibles Windows, les fichiers existants ne peuvent plus être modifiés, mais peuvent être renommés avec des noms valides par leur propriétaire.",
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Il est également possible de migrer les fichiers automatiquement après avoir activé ce paramètre, veuillez vous référer à la documentation sur la commande occ.",
     "\"{displayName}\" failed on some elements" : "\"{displayName}\" a échoué pour certains éléments",
     "\"{displayName}\" batch action executed successfully" : "L’action « {displayName} » par lot a été exécutée avec succès",
-    "Submitting fields…" : "Validation des champs...",
-    "Filter filenames…" : "Filtrer par nom de fichier…",
+    "\"{displayName}\" action failed" : "Échec de l'action \"{displayName}\"",
+    "Submitting fields …" : "Soumission des champs...",
+    "\"{displayName}\" action executed successfully" : "Action \"{displayName}\" exécutée avec succès",
+    "Filter file names …" : "Filtrer les noms de fichier…",
+    "Clipboard is not available" : "Le presse-papiers n'est pas disponible",
     "WebDAV URL copied to clipboard" : "URL WebDAV copiée dans le presse-papier",
     "Enable the grid view" : "Activer la vue en grille",
     "Enable folder tree" : "Activer l'arborescence des dossiers",
+    "WebDAV" : "WebDAV",
     "Copy to clipboard" : "Copier dans le presse-papiers",
     "Use this address to access your Files via WebDAV" : "Utilisez cette adresse pour accéder à vos fichiers via WebDAV",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Si vous avez activé le 2FA, vous devez créer et utiliser un nouveau mot de passe d'application en cliquant ici.",
-    "Deletion cancelled" : "Suppression annulée",
-    "Move cancelled" : "Déplacement annulé",
-    "Cancelled move or copy of \"{filename}\"." : "Déplacement ou copie de \"{filename}\" annulé.",
-    "Cancelled move or copy operation" : "Opération de déplacement ou de copie annulée",
-    "Open details" : "Ouvrir les détails",
-    "Photos and images" : "Photos et images",
-    "New folder creation cancelled" : "La création du nouveau dossier est annulée",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} dossier","{folderCount} dossiers","{folderCount} dossiers"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} fichier","{fileCount} fichiers","{fileCount} fichiers"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 fichier et {folderCount} dossier","1 fichier et {folderCount} dossiers","1 fichier et {folderCount} dossiers"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} fichier et 1 dossier","{fileCount} fichiers et 1 dossier","{fileCount} fichiers et 1 dossier"],
-    "{fileCount} files and {folderCount} folders" : "{fileCount} fichiers et {folderCount} dossiers",
-    "All folders" : "Tous les dossiers",
-    "Personal Files" : "Fichiers personnels",
-    "Text file" : "Fichier texte",
-    "New text file.txt" : "Nouveau fichier texte.txt",
-    "%1$s (renamed)" : "%1$s (renommé)",
-    "renamed file" : "fichier renommé",
-    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Après avoir activé les noms de fichiers compatibles Windows, les fichiers existants ne peuvent plus être modifiés, mais peuvent être renommés avec des noms valides par leur propriétaire.",
-    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Il est également possible de migrer les fichiers automatiquement après avoir activé ce paramètre, veuillez vous référer à la documentation sur la commande occ.",
-    "Filter file names …" : "Filtrer les noms de fichier…",
     "Prevent warning dialogs from open or reenable them." : "Empêchez l'ouverture des boîtes de dialogue d'avertissement ou réactivez-les.",
     "Show a warning dialog when changing a file extension." : "Afficher un avertissement quand l'extension du fichier est modifiée.",
+    "Keyboard shortcuts" : "Raccourcis clavier",
     "Speed up your Files experience with these quick shortcuts." : "Accélérez votre expérience Fichiers avec ces raccourcis rapides.",
     "Open the actions menu for a file" : "Ouvrir le menu d'actions pour un fichier",
     "Rename a file" : "Renommer un fichier",
@@ -522,6 +428,24 @@ OC.L10N.register(
     "Navigate to the file on the left (in grid mode)" : "Naviguer vers le fichier à gauche (en mode grille)",
     "Navigate to the file on the right (in grid mode)" : "Naviguer vers le fichier à droite (en mode grille)",
     "Toggle the grid view" : "Activer/Désactiver la vue grille",
-    "Open the sidebar for a file" : "Ouvrir la barre latérale pour un fichier"
+    "Open the sidebar for a file" : "Ouvrir la barre latérale pour un fichier",
+    "Save as …" : "Enregistrer sous...",
+    "Converting files …" : "Conversion des fichiers...",
+    "Converting file …" : "Conversion du fichier...",
+    "Deletion cancelled" : "Suppression annulée",
+    "Edit locally" : "Éditer localement",
+    "Moving \"{source}\" to \"{destination}\" …" : "Déplacement de \"{source}\" vers \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Copie de \"{source}\" vers \"{destination}\" …",
+    "Move cancelled" : "Déplacement annulé",
+    "Cancelled move or copy of \"{filename}\"." : "Déplacement ou copie de \"{filename}\" annulé.",
+    "Cancelled move or copy operation" : "Opération de déplacement ou de copie annulée",
+    "Open details" : "Ouvrir les détails",
+    "Photos and images" : "Photos et images",
+    "New folder creation cancelled" : "La création du nouveau dossier est annulée",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Ce répertoire est indisponible, merci de consulter les journaux ou de contacter votre administrateur",
+    "All folders" : "Tous les dossiers",
+    "Search everywhere …" : "Rechercher partout...",
+    "Search here …" : "Rechercher ici...",
+    "Preparing …" : "Préparation..."
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
