@@ -46,8 +46,18 @@ OC.L10N.register(
     "Failed to authorize" : "Falhou a autorização",
     "Invalid folder path" : "Caminho da pasta inválido",
     "Folder not found" : "Pasta não encontrada",
+    "The file cannot be found" : "O ficheiro não foi encontrado",
+    "The destination path does not exist: %1$s" : "O caminho de destino não existe: %1$s",
+    "You do not have permission to create a file at the specified location" : "Você não tem permissão para criar um ficheiro no localização especificada",
+    "The file could not be converted." : "Não foi possível converter o ficheiro.",
+    "Could not get relative path to converted file" : "Não foi possível localizar o caminho relativo do ficheiro convertido",
+    "Limit must be a positive integer." : "O limite tem de ser um número inteiro positivo.",
+    "The replacement character may only be a single character." : "O caractere de substituição só pode ser um único caractere.",
+    "Filename sanitization already started." : "A limpeza do nome do ficheiro já foi iniciada.",
+    "No filename sanitization in progress." : "Nenhuma limpeza m curso de nomes de ficheiro.",
+    "Favorite files" : "Ficheiro favoritos",
     "No favorites" : "Sem favoritos",
-    "Upload (max. %s)" : "Envio (máx. %s)",
+    "More favorites" : "Mais favoritos",
     "Accept" : "Aceitar",
     "Reject" : "Rejeitar",
     "Incoming ownership transfer from {user}" : "Transferência de propriedade recebida de {user}",
@@ -62,10 +72,6 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "A sua transferência de propriedade de {path} de {user} foi concluída",
     "in %s" : "em %s",
     "Transferred from %1$s on %2$s" : "Transferido de %1$s em %2$s",
-    "Files compatibility" : "Compatibilidade de ficheiros",
-    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Permitir a restrição dos nomes de ficheiro para garantir que possam ser sincronizados com todos os clientes. Por predefinição, todos os nomes de ficheiro válidos em POSIX (por exemplo, Linux ou macOS) são permitidos.",
-    "Enforce Windows compatibility" : "Forçar a compatibilidade com Windows",
-    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : " Isto bloqueará os nomes de ficheiro não válidos nos sistemas Windows, como a utilização de nomes reservados ou carateres especiais. Mas isto não irá impor a compatibilidade da sensibilidade à caixa alta maiúsculas ou baixa minúsculas.",
     "File Management" : "Gestão de ficheiros",
     "Home" : "Início",
     "Target folder does not exist any more" : "A pasta de destino já não existe",
@@ -73,6 +79,7 @@ OC.L10N.register(
     "Go to the \"{dir}\" directory" : "Ir para a pasta \"{dir}\"",
     "Current directory path" : "Caminho da pasta atual",
     "Your have used your space quota and cannot upload files anymore" : "Utilizou a sua quota de espaço e já não pode carregar mais ficheiros",
+    "You do not have permission to upload or create files here." : "Não tem permissões para enviar ou criar ficheiros aqui.",
     "Drag and drop files here to upload" : "Arraste e largue os ficheiros aqui para carregar",
     "Favorite" : "Favorito",
     "Back" : "Voltar",
@@ -87,25 +94,76 @@ OC.L10N.register(
     "Invalid filename." : "Nome de ficheiro inválido",
     "Renamed \"{oldName}\" to \"{newName}\"" : "Renomeado de \"{oldName}\" para \"{newName}\"",
     "Rename file" : "Renomear ficheiro",
+    "Folder" : "Pasta",
+    "Unknown file type" : "Tipo de ficheiro desconhecido",
+    "{ext} image" : "{ext}imagem",
+    "{ext} video" : "{ext}vídeo",
+    "{ext} audio" : "{ext}áudio",
+    "{ext} text" : "{ext}texto",
     "Pending" : "Pendente",
+    "Unknown date" : "Data desconhecida",
     "Clear filter" : "Limpar filtro",
     "Modified" : "Modificado",
+    "Search everywhere" : "Pesquisar em todo o lado",
     "Type" : "Tipo",
     "Active filters" : "Filtros ativos",
     "Remove filter" : "Remover filtro",
+    "Appearance" : "Aspeto",
+    "Show hidden files" : "Mostrar ficheiros ocultos",
+    "Show file type column" : "Mostrar coluna de tipo de ficheiro",
+    "Show file extensions" : "Mostrar extensões de ficheiro",
+    "Crop image previews" : "Recortar pré-visualizações de imagens",
+    "General" : "Geral",
+    "Sort favorites first" : "Ordenar por favoritos primeiro",
+    "Sort folders before files" : "Ordenar as pastas antes dos ficheiros.",
+    "Enable folder tree view" : "Ativar visualização de pastas em árvore",
+    "Default view" : "Vista padrão",
+    "All files" : "Todos os ficheiros",
+    "Personal files" : "Ficheiros pessoais",
+    "Additional settings" : "Definições adicionais",
+    "Actions" : "Ações",
+    "File actions" : "Ações sobre ficheiros",
+    "Selection" : "Seleção",
+    "Select all files" : "Selecionar todos os ficheiros",
+    "Deselect all" : "Desselecionar tudo",
+    "Select or deselect" : "Selecionar ou desselecionar",
+    "Select a range" : "Selecionar um intervalo",
+    "Navigation" : "Navegação",
+    "Go to parent folder" : "Ir para a pasta anterior",
+    "Go to file above" : "Ir para o ficheiro acima",
+    "Go to file below" : "Ir para o ficheiro abaixo",
+    "Go left in grid" : "Ir para a esquerda na grelha",
+    "Go right in grid" : "Ir para a direita na grelha",
+    "View" : "Ver",
+    "Toggle grid view" : "Alternar visualização em grelha",
+    "Open file sidebar" : "Abrir barra lateral de ficheiro",
+    "Show those shortcuts" : "Mostrar esses atalhos",
+    "Warnings" : "Avisos",
+    "Warn before changing a file extension" : "Avisar antes de alterar uma extensão de ficheiro",
+    "Warn before deleting a file" : "Avisar antes de eliminar um ficheiro",
+    "WebDAV URL" : "URL WebDAV",
+    "Create an app password" : "Criar uma palavra-passe para a aplicação",
+    "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "Necessário para a autenticação WebDAV porque a autenticação de dois fatores está ativada para esta conta.",
+    "How to access files using WebDAV" : "Como aceder a ficheiros usando o WebDAV",
     "Total rows summary" : "Resumo do total de linhas",
     "Toggle selection for all files and folders" : "Alternar a seleção para todos os ficheiros e pastas",
     "Name" : "Nome",
+    "File type" : "Tipo de Ficheiro",
     "Size" : "Tamanho",
-    "\"{displayName}\" batch action executed successfully" : "Ação de lote “{displayName}” executada com sucesso",
-    "\"{displayName}\" action failed" : "\"{displayName}\" a ação falhou",
-    "Actions" : "Ações",
+    "{displayName}: failed on some elements" : "{displayName}: falhou em alguns elementos",
+    "{displayName}: done" : "{displayName}: concluído",
+    "{displayName}: failed" : "{displayName}: falhou",
     "(selected)" : "(selecionado)",
     "List of files and folders." : "Lista de ficheiros e pastas.",
+    "You have used your space quota and cannot upload files anymore." : "Você já utilizou a sua quota de espaço e não pode enviar mais arquivos.",
     "Column headers with buttons are sortable." : "Os cabeçalhos das colunas com botões são ordenáveis",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Por motivos de desempenho, esta lista não é totalmente processada. Os ficheiros serão processados à medida que navega na lista.",
     "File not found" : "Ficheiro não encontrado",
-    "{count} selected" : "{count} selecionado ",
+    "_{count} selected_::_{count} selected_" : ["{count} selecionado","{count} selecionado","{count} selecionado"],
+    "Search everywhere …" : "Procure em todo o lado …",
+    "Search here …" : "Procure aqui …",
+    "Search scope options" : "Opções do escopo da pesquisa",
+    "Search here" : "Pesquisar aqui",
     "{usedQuotaByte} used" : "{usedQuotaByte} usado",
     "{used} of {quota} used" : "utilizado {used} de {quota}",
     "{relative}% used" : "{relative}% usado",
@@ -117,6 +175,19 @@ OC.L10N.register(
     "Create new folder" : "Criar nova pasta",
     "This name is already in use." : "Este nome já está em uso.",
     "Create" : "Criar",
+    "Files starting with a dot are hidden by default" : "Os ficheiros que começam com um ponto são ocultados por omissão",
+    "Failed to start filename sanitization." : "Falha ao iniciar a limpeza do nome do ficheiro.",
+    "Failed to refresh filename sanitization status." : "Falha ao atualizar o estado da limpeza do nome do ficheiro.",
+    "Filename sanitization in progress." : "Limpeza do nome do ficheiro em curso.",
+    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "Atualmente, {processedUsers} das {totalUsers} contas já foram processadas.",
+    "Preparing …" : "Preparando …",
+    "Refresh" : "Atualizar",
+    "All files have been santized for Windows filename support." : "Todos os ficheiros foram tratados para serem compatíveis com os nomes de ficheiro do Windows.",
+    "Some files could not be sanitized, please check your logs." : "Alguns ficheiros não puderam ser tratados. Por favor verifique os seus registros.",
+    "Sanitization errors" : "Erros de tratamento",
+    "Not sanitized filenames" : "Ficheiros não tratados",
+    "Windows filename support has been enabled." : "O suporte a nomes de ficheiros do Windows foi ativado.",
+    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "Embora isto impeça os utilizadores de criar novos ficheiros com nomes não suportados, os ficheiros existentes ainda não foram renomeados e, portanto, ainda podem interromper a sincronização no Windows.",
     "Fill template fields" : "Preencher campos do modelo",
     "Submit" : "Submeter",
     "Choose a file or folder to transfer" : "Escolher um ficheiro ou pasta para transferir",
@@ -130,135 +201,87 @@ OC.L10N.register(
     "Choose file or folder to transfer" : "Escolher ficheiro ou pasta para transferir",
     "Change" : "Mudar",
     "New owner" : "Novo proprietário",
+    "Choose {file}" : "Escolher {file}",
+    "Files settings" : "Definições do Ficheiros",
     "Share" : "Partilhar",
     "Shared by link" : "Partilhado por hiperligação",
     "Shared" : "Partilhados",
     "Not enough free space" : "Espaço insuficiente",
     "Operation is blocked by access control" : "A operação está bloqueada pelo controlo de acesso",
-    "\"{displayName}\" action executed successfully" : "\"{displayName}\" ação executada com sucesso ",
     "Retry" : "Repetir",
     "No files in here" : "Nenhuns ficheiros aqui",
     "Upload some content or sync with your devices!" : "Envie algum conteúdo ou sincronize com os seus dispositivos!",
     "Go back" : "Voltar",
     "Views" : "Vistas",
-    "Files settings" : "Definições do Ficheiros",
-    "Show hidden files" : "Mostrar ficheiros ocultos",
-    "Additional settings" : "Definições adicionais",
-    "WebDAV" : "WebDAV",
-    "Copy to clipboard" : "Copiar para área de transferência",
-    "Keyboard shortcuts" : "Atalhos de teclado",
-    "Navigation" : "Navegação",
-    "View" : "Ver",
     "You" : "Vovê",
     "Owner" : "Proprietário",
     "Remove from favorites" : "Remover dos favoritos",
     "Add to favorites" : "Adicionar aos favoritos",
     "Tags" : "Etiquetas",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Permitir a restrição dos nomes de ficheiro para garantir que possam ser sincronizados com todos os clientes. Por predefinição, todos os nomes de ficheiro válidos em POSIX (por exemplo, Linux ou macOS) são permitidos.",
+    "Files compatibility" : "Compatibilidade de ficheiros",
+    "Enforce Windows compatibility" : "Forçar a compatibilidade com Windows",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : " Isto bloqueará os nomes de ficheiro não válidos nos sistemas Windows, como a utilização de nomes reservados ou carateres especiais. Mas isto não irá impor a compatibilidade da sensibilidade à caixa alta maiúsculas ou baixa minúsculas.",
+    "Delete" : "Apagar",
     "Leave this share" : "Sair desta partilha",
     "Disconnect storage" : "Desligar armazenamento",
     "Disconnect storages" : "Desligar armazenamentos",
     "Delete permanently" : "Eliminar permanentemente",
     "Delete file" : "Apagar ficheiro",
     "Delete folder" : "Apagar pasta",
-    "Delete" : "Apagar",
     "Cancel" : "Cancelar",
+    "Download" : "Transferir",
+    "Add or remove favorite" : "Adicionar ou remover favorito",
+    "Copy to {target}" : "Copiar para {target}",
     "Copy" : "Copiar",
+    "Move to {target}" : "Mover para {target}",
     "Move" : "Mover",
     "Move or copy" : "Mover ou copiar",
     "Failed to redirect to client" : "Erro ao redirecionar para o cliente",
     "Rename" : "Renomear",
+    "Details" : "Detalhes",
     "View in folder" : "Ver na pasta",
     "Today" : "Hoje",
+    "Last 7 days" : "Últimos 7 dias",
+    "Last 30 days" : "Últimos 30 dias",
     "Documents" : "Documentos",
     "Audio" : "Áudio",
+    "Images" : "Imagens",
     "Videos" : "Vídeos",
     "Templates" : "Modelos",
     "Some files could not be moved" : "Não foi possível mover alguns ficheiros",
+    "Could not rename \"{oldName}\", it does not exist any more" : "Não foi possível renomear “{oldName}”, já não existe",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "O nome “{newName}” já está a ser utilizado na pasta “{dir}”. Por favor, escolha um nome diferente.",
+    "Could not rename \"{oldName}\"" : "Não foi possível renomear \"{oldName}\"",
     "This operation is forbidden" : "Esta operação é proibida",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Esta diretoria está indisponível, por favor, verifique os registos ou contacte o administrador",
     "Storage is temporarily not available" : "Armazenamento temporariamente indisponível",
-    "{fileCount} files and {folderCount} folders" : "{fileCount} ficheiros e {folderCount} pastas",
+    "_%n file_::_%n files_" : ["%n ficheiro","%n ficheiros","%n ficheiros"],
+    "_%n folder_::_%n folders_" : ["%n pasta","%n pastas","%n pastas"],
     "No favorites yet" : "Sem favoritos",
     "Files and folders you mark as favorite will show up here" : "Os ficheiros e pastas que marcou como favoritos serão mostrados aqui",
-    "All files" : "Todos os ficheiros",
+    "Folder tree" : "Pastas em árvore",
     "Recent" : "Recentes",
+    "Search" : "Pesquisa sobre",
     "No entries found in this folder" : "Não foram encontradas entradas nesta pasta",
     "Select all" : "Selecionar todos",
     "Upload too large" : "Envio muito grande",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Os ficheiros que está a tentar enviar excedem o tamanho máximo para os envios de ficheiro neste servidor.",
-    "File could not be found" : "O ficheiro não foi encontrado",
-    "Download" : "Transferir",
-    "Show list view" : "Mostrar visualização em lista",
-    "Show grid view" : "Mostrar visualização em grelha",
-    "Close" : "Fechar",
-    "Could not create folder \"{dir}\"" : "Não foi possível criar a pasta \"{dir}\"",
-    "This will stop your current uploads." : "Isto irá interromper os seus carregamentos atuais.",
-    "Upload cancelled." : "Envio cancelado.",
-    "Processing files …" : "A processar ficheiros...",
-    "…" : "...",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Não é possível enviar {filename}, porque este é uma diretoria ou tem 0 bytes",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Não existe espaço suficiente, está a enviar {size1} mas resta apenas {size2}",
-    "Target folder \"{dir}\" does not exist any more" : "A pasta de destino \"{dir}\" já não existe",
-    "An unknown error has occurred" : "Ocorreu um erro desconhecido",
-    "File could not be uploaded" : "O ficheiro não foi carregado",
-    "Uploading …" : "A carregar ...",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
-    "Uploading that item is not supported" : "O carregamento do item não é suportado",
-    "Error when assembling chunks, status code {status}" : "Erro ao agregar partições, código de estado: {status}",
-    "Choose target folder" : "Escolher pasta de destino",
+    "%1$s (renamed)" : "%1$s (renomeado)",
+    "renamed file" : "ficheiro renomeado",
+    "Upload (max. %s)" : "Envio (máx. %s)",
+    "\"{displayName}\" batch action executed successfully" : "Ação de lote “{displayName}” executada com sucesso",
+    "\"{displayName}\" action failed" : "\"{displayName}\" a ação falhou",
+    "\"{displayName}\" action executed successfully" : "\"{displayName}\" ação executada com sucesso ",
+    "Enable folder tree" : "Ativar pastas em árvore",
+    "WebDAV" : "WebDAV",
+    "Copy to clipboard" : "Copiar para área de transferência",
+    "Keyboard shortcuts" : "Atalhos de teclado",
+    "Manage tags for a file" : "Gerir etiquetas para um ficheiro",
+    "Select or deselect a file" : "Selecionar ou desselecionar um ficheiro",
+    "Select a range of files" : "Selecionar um intervalo de ficheiros",
     "Edit locally" : "Editar localmente",
-    "Open" : "Abrir",
-    "Could not load info for file \"{file}\"" : "Não foi possível carregar informações do ficheiro \"{file}\"",
-    "Details" : "Detalhes",
-    "Please select tag(s) to add to the selection" : "Selecione a(s) etiquetas(s) para adicionar à seleção ",
-    "Apply tag(s) to selection" : "Aplicar etiqueta(s) à seleção",
-    "Select directory \"{dirName}\"" : "Selecionar o diretório \"{dirName}\"",
-    "Select file \"{fileName}\"" : "Selecionar o ficheiro \"{fileName}\"",
-    "Unable to determine date" : "Não é possível determinar a data",
-    "Could not move \"{file}\", target exists" : "Não foi possível mover \"{file}\", destino já existe",
-    "Could not move \"{file}\"" : "Não foi possivel mover o ficheiro \"{file}\"",
-    "copy" : "copiar",
-    "Could not copy \"{file}\", target exists" : "Não foi possível copiar \"{file}\", o destino já existe",
-    "Could not copy \"{file}\"" : "Impossível copiar \"{file}\"",
-    "Copied {origin} inside {destination}" : "Copiado {origin} para {destination}",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "Copiados {origin} e {nbfiles} outros ficheiros para dentro de {destination}",
-    "{newName} already exists" : "{newName} já existe",
-    "Could not rename \"{fileName}\", it does not exist any more" : "Não foi possível renomear \"{fileName}\", este já não existe",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "O nome \"{targetName}\" já está em utilização na pasta \"{dir}\". Por favor, escolha um nome diferente.",
-    "Could not rename \"{fileName}\"" : "Não foi possível renomear \"{fileName}\"",
-    "Could not create file \"{file}\"" : "Não foi possível criar o ficheiro \"{file}\"",
-    "Could not create file \"{file}\" because it already exists" : "Não foi possível criar o ficheiro \"{file}\", porque este já existe",
-    "Could not create folder \"{dir}\" because it already exists" : "Não foi possível criar a pasta \"{dir}\", porque esta já existe",
-    "Could not fetch file details \"{file}\"" : "Não foi possível obter os detalhes do ficheiro \"{file}\"",
-    "Error deleting file \"{fileName}\"." : "Erro ao eliminar o ficheiro \"{fileName}\".",
-    "No search results in other folders for {tag}{filter}{endtag}" : "Nenhum resultado noutras pastas para {tag}{filter}{endtag}",
-    "Enter more than two characters to search in other folders" : "Digite mais de dois caracteres para pesquisar noutras pastas",
-    "_%n folder_::_%n folders_" : ["%n pasta","%n pastas","%n pastas"],
-    "_%n file_::_%n files_" : ["%n ficheiro","%n ficheiros","%n ficheiros"],
-    "{dirs} and {files}" : "{dirs} e {files}",
-    "_including %n hidden_::_including %n hidden_" : ["incluindo %n ocultos","incluindo %n ocultos","incluindo %n ocultos"],
-    "You do not have permission to upload or create files here" : "Não tem permissão para carregar ou criar ficheiros aqui",
-    "_Uploading %n file_::_Uploading %n files_" : ["A enviar %n ficheiro","A enviar %n ficheiros","A enviar %n ficheiros"],
-    "New" : "Novo",
-    "New file/folder menu" : "Novo menu ficheiro/pasta",
-    "Select file range" : "Selecionar o intervalo",
-    "{used}%" : "{used}%",
-    "{used} used" : "{used} utilizado",
-    "\"{name}\" is an invalid file name." : "\"{name}\" é um nome de ficheiro inválido.",
-    "File name cannot be empty." : "O nome do ficheiro não pode estar em branco.",
-    "\"/\" is not allowed inside a file name." : "\"/\" não é permitido dentro de um nome de um ficheiro.",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\" não é um tipo de ficheiro permitido",
-    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "O armazenamento de {owner} está cheio. Os ficheiros não podem ser enviados ou sincronizados.",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "A pasta de grupo \"{mountPoint}\" está quase cheia ({usedSpacePercent}%).",
-    "Path" : "Caminho",
-    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes","%n bytes"],
-    "Favorited" : "Nos Favoritos",
-    "Upload file" : "Enviar ficheiro",
-    "Not favorited" : "Não favorito",
-    "An error occurred while trying to update the tags" : "Ocorreu um erro ao tentar atualizar as etiquetas",
-    "Personal Files" : "Ficheiros pessoais",
-    "Text file" : "Ficheiro de Texto",
-    "New text file.txt" : "Novo texto ficheiro.txt",
-    "Submitting fields…" : "Submeter campos…"
+    "This directory is unavailable, please check the logs or contact the administrator" : "Esta diretoria está indisponível, por favor, verifique os registos ou contacte o administrador",
+    "Search everywhere …" : "Pesquisar em todo o lado...",
+    "Search here …" : "Pesquisar aqui…"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
