@@ -46,13 +46,20 @@ OC.L10N.register(
     "Failed to authorize" : "Overitev je spodletela",
     "Invalid folder path" : "Neveljavna pot mape",
     "Folder not found" : "Mape ni mogoče najti",
-    "No favorites" : "Ni priljubljenih predmetov",
-    "Upload (max. %s)" : "Pošiljanje (omejitev %s)",
+    "The file cannot be found" : "Datoteke ni mogoče najti.",
+    "The destination path does not exist: %1$s" : "Cilja pot ne obstaja: %1$s",
+    "You do not have permission to create a file at the specified location" : "Nimate pravice za stvarjenje datoteke na podani lokaciji",
+    "The file could not be converted." : "Datoteke ni mogoče pretvoriti.",
+    "Could not get relative path to converted file" : "Ni mogoče pridobiti relativne poti do pretvorjene datoteke.",
+    "Favorite files" : "Priljubljene datoteke",
+    "No favorites" : "Ni priljubljenih datotek",
+    "More favorites" : "Več priljubljenih",
     "Accept" : "Sprejmi",
     "Reject" : "Zavrni",
     "Incoming ownership transfer from {user}" : "Vpisana je zahteva za prenos lastništva uporabnika {user}",
     "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Ali želite sprejeti pot {path}?\n\nOpomba: po sprejetju lahko prenos traja tudi več kot 1 uro.",
     "Ownership transfer denied" : "Prenos lastništva je spodletel",
+    "Your ownership transfer of {path} was denied by {user}." : "Prenos lastništva za {path} je onemogočil {user}.",
     "Ownership transfer failed" : "Prenos lastništva je spodletel",
     "Your ownership transfer of {path} to {user} failed." : "Prenos lastništva mesta {path} na uporabnika {user} je spodletel.",
     "The ownership transfer of {path} from {user} failed." : "Prenos lastništva mesta {path} na uporabnika {user} je spodletel.",
@@ -60,41 +67,67 @@ OC.L10N.register(
     "Your ownership transfer of {path} to {user} has completed." : "Prenos lastništva poti {path} na uporabnika {user} je končan.",
     "The ownership transfer of {path} from {user} has completed." : "Prenos lastništva poti {path} z uporabnika {user} je končan.",
     "in %s" : "v %s",
-    "Files compatibility" : "Skladnost datotek",
-    "Enforce Windows compatibility" : "Vsili skladnost s sistemom Windows",
+    "Transferred from %1$s on %2$s" : "Preneseno iz %1$s na %2$s",
     "File Management" : "Upravljanje datotek",
     "Home" : "Začetni pogled",
     "Target folder does not exist any more" : "Ciljna mapa ne obstaja več",
     "Reload current directory" : "Ponovno naloži trenutno mapo",
     "Go to the \"{dir}\" directory" : "Pojdi v mapo »{dir}«",
     "Current directory path" : "Trenutna pot mape",
+    "Your have used your space quota and cannot upload files anymore" : "Porabili ste svojo količino prostora in datotek več ne morete nalagati",
+    "You do not have permission to upload or create files here." : "Nimate pravic za ustvarjanje ali nalaganje datotek na to mesto.",
     "Drag and drop files here to upload" : "Za pošiljanje potegnite in spustite datoteke na to mesto",
     "Favorite" : "Priljubljene",
+    "Back" : "Nazaj",
+    "Toggle selection for file \"{displayName}\"" : "Preklopi izbor za datoteko \"{displayName}\"",
+    "Toggle selection for folder \"{displayName}\"" : "Preklopi izbor za mapo \"{displayName}\"",
     "File is loading" : "Poteka nalaganje datoteke",
     "Folder is loading" : "mape",
     "Filename" : "Ime datoteke",
     "Folder name" : "Ime mape",
     "This node is unavailable" : "To vozlišče ni na voljo.",
+    "Another entry with the same name already exists." : "Vpis z istim imenom že obstaja.",
     "Invalid filename." : "Neveljavno ime datoteke",
     "Renamed \"{oldName}\" to \"{newName}\"" : "Preimenuj »{oldName}« to »{newName}«",
     "Rename file" : "Preimenuj datoteke",
+    "Folder" : "Mapa",
     "Pending" : "Na čakanju ...",
+    "Unknown date" : "Neznani datum",
     "Clear filter" : "Počisti filter",
     "Modified" : "Spremenjeno",
+    "Search everywhere" : "Išči povsod",
     "Type" : "Vrsta",
     "Active filters" : "Dejavni filtri",
     "Remove filter" : "Odstrani filter",
+    "Appearance" : "Videz",
+    "Show hidden files" : "Pokaži skrite datoteke",
+    "Crop image previews" : "Obreži slike predogleda",
+    "General" : "Splošno",
+    "Sort favorites first" : "Razvrsti najprej priljubljene",
+    "Sort folders before files" : "Razvrsti mape pred datotekami",
+    "All files" : "Vse datoteke",
+    "Personal files" : "Osebne datoteke",
+    "Additional settings" : "Dodatne nastavitve",
+    "Actions" : "Dejanja",
+    "Selection" : "Izbor",
+    "Select all files" : "Izberi vse datoteke",
+    "Deselect all" : "Odstrani celoten izbor",
+    "Navigation" : "Krmarjenje",
+    "View" : "Pogled",
+    "Toggle grid view" : "Preklopi mrežni pogled",
+    "Show those shortcuts" : "Pokaži tipkovne bližnjice",
+    "Warnings" : "Opozorila",
+    "WebDAV URL" : "Naslov URL WebDAV",
     "Total rows summary" : "Skupni povzetek vrstic",
+    "Toggle selection for all files and folders" : "Preklopi izbor za vse datoteke in mape",
     "Name" : "Ime",
     "Size" : "Velikost",
-    "\"{displayName}\" batch action executed successfully" : "Paketno dejanje »{displayName}« je uspešno izvedeno",
-    "\"{displayName}\" action failed" : "Dejanje »{displayName}« je spodletelo",
-    "Actions" : "Dejanja",
     "(selected)" : "(izbrano)",
     "List of files and folders." : "Seznam datotek in map",
+    "You have used your space quota and cannot upload files anymore." : "Porabili ste dodeljeno količino prostora, zato datotek ni mogoče več pošiljati.",
+    "Column headers with buttons are sortable." : "Stolpce z gumbi je mogoče razvrščati.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Seznam datotek ni v celoti izpisan zaradi zagotavljanja hitrosti in odzivnosti sistema. Predmeti se bodo dopolnjevali med brskanjem.",
     "File not found" : "Datoteke ni mogoče najti",
-    "{count} selected" : "{count} izbranih",
     "{usedQuotaByte} used" : "Zasedeno {usedQuotaByte}",
     "{used} of {quota} used" : "V uporabi je {used} od {quota}",
     "{relative}% used" : "Zasedeno {relative} %",
@@ -106,6 +139,8 @@ OC.L10N.register(
     "Create new folder" : "Ustvari novo mapo",
     "This name is already in use." : "Vpisano uporabniško ime je že v uporabi",
     "Create" : "Ustvari",
+    "Refresh" : "Osveži",
+    "Limit" : "Omejitve",
     "Fill template fields" : "Zapolni polja predloge",
     "Submit" : "Pošlji",
     "Choose a file or folder to transfer" : "Izbor datoteke ali mape za prenos",
@@ -119,57 +154,66 @@ OC.L10N.register(
     "Choose file or folder to transfer" : "Izbor datoteke ali mape za prenos",
     "Change" : "Spremeni",
     "New owner" : "Nov lastnik",
+    "Keep {old}" : "Ohrani {old}",
+    "Keep without extension" : "Ohrani brez pripone",
+    "Use {new}" : "Uporabi {new}",
+    "Remove extension" : "Odstrani pripono",
+    "Change file extension" : "Spremeni pripono datoteke",
+    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Sprememba končnice datoteke iz \"{old}\" v \"{new}\" lahko naredi datoteko neberljivo.",
+    "Removing the file extension \"{old}\" may render the file unreadable." : "Odstranitev končnice datoteke \"{old}\" lahko naredi datoteko neberljivo.",
+    "Adding the file extension \"{new}\" may render the file unreadable." : "Dadajanje končnice datoteke \"{new}\" lahko naredi datoteko neberljivo.",
+    "Do not show this dialog again." : "Pogovornega okna ne pokaži več.",
     "Select file or folder to link to" : "Izbor datoteke ali mape za povezavo",
     "Choose {file}" : "Izberite datoteko {file}",
+    "Files settings" : "Nastavitve datotek",
     "Share" : "·Souporaba·",
     "Shared by link" : "V souporabi sk povezavo",
     "Shared" : "V souporabi",
     "Switch to list view" : "Preklopi na seznamski pogled",
     "Switch to grid view" : "Preklopi na mrežni pogled",
+    "The file could not be found" : "Datoteke ni mogoče najti.",
     "Upload was cancelled by user" : "Uporabnik je pošiljanje preklical",
     "Not enough free space" : "Ni dovolj prostora",
     "Operation is blocked by access control" : "Opravilo je zaustavljeno prek nadzora dostopa",
+    "Error during upload: {message}" : "Napaka med nalaganjem: {message}",
+    "Error during upload, status code {status}" : "Napaka med nalaganje s kodo stanja {status}",
     "Unknown error during upload" : "Med pošiljanjem je prišlo do neznane napake",
-    "\"{displayName}\" action executed successfully" : "Dejanje »{displayName}« je uspešno izvedeno",
     "Loading current folder" : "Poteka nalaganje trenutne mape",
     "Retry" : "Poskusi znova     ",
     "No files in here" : "V mapi ni datotek",
     "Upload some content or sync with your devices!" : "Uvozite vsebino, ali pa omogočite usklajevanje z napravami!",
     "Go back" : "Skoči nazaj",
     "Views" : "Pogledi",
-    "Files settings" : "Nastavitve datotek",
-    "Your files" : "Osebne datoteke",
-    "Open in files" : "Odpri datoteko v mapi",
-    "File cannot be accessed" : "Do datoteke dostop ni mogoč",
-    "Clipboard is not available" : "Odložišče ni na voljo",
-    "WebDAV URL copied to clipboard" : "Naslov URL WebDAV je kopiran v odložišče",
-    "Sort favorites first" : "Razvrsti najprej priljubljene",
-    "Sort folders before files" : "Razvrsti mape pred datotekami",
-    "Show hidden files" : "Pokaži skrite datoteke",
-    "Crop image previews" : "Obreži slike predogleda",
-    "Enable the grid view" : "Omogoči mrežni pogled",
-    "Enable folder tree" : "Omogoči drevesno strukturo map",
-    "Additional settings" : "Dodatne nastavitve",
-    "WebDAV" : "WebDAV",
-    "WebDAV URL" : "Naslov URL WebDAV",
-    "Copy to clipboard" : "Kopiraj v odložišče",
-    "Use this address to access your Files via WebDAV" : "Uporabite ta naslov za dostop do datotek z uporabo WebDAV",
-    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Če je omogočen sistem dvostopenjskega overjanja 2FA, je treba ustvariti in uporabiti novo geslo programa s klikom na to mesto.",
-    "Keyboard shortcuts" : "Tipkovne bližnjice",
-    "Selection" : "Izbor",
-    "Navigation" : "Krmarjenje",
-    "View" : "Pogled",
     "You" : "Jaz",
+    "Shared multiple times with different people" : "V več souporabah z različnimi uporabniki",
     "Error while loading the file data" : "Prišlo je do napake med nalaganjem podatkov računa",
+    "Owner" : "Lastnik",
     "Remove from favorites" : "Odstrani iz priljubljenih",
     "Add to favorites" : "Dodaj med priljubljene",
     "Tags" : "Oznake",
+    "Your files" : "Osebne datoteke",
+    "Open in files" : "Odpri datoteko v mapi",
+    "File cannot be accessed" : "Do datoteke dostop ni mogoč",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Datoteke ni bilo mogoče najti ali pa nimate ustreznih dovoljenj za ogled. Prosite pošiljatelja, da jo deli.",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Dovoli omejitev imen datotek za zagotovitev sinhronizacije datotek z vsemi odjemalci. Privzeto je dovoljenje za vsa imena datotek na POSIX (tj. Linux ali macOS).",
+    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Po vklopu imen, ki so združljiva z WIndows, obstoječih datotek ni več mogoče spreminjati, jih pa lahko lastnik preimenuje v ustrezno ime.",
+    "Files compatibility" : "Skladnost datotek",
+    "Enforce Windows compatibility" : "Vsili skladnost s sistemom Windows",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "To bo blokiralo imena datotek, ki niso ustrezna za Windows sisteme, kot so rezervirana imena ali posebni znaki, ne bo pa to vsililo združljivosti pri razlikovanju velikih in malih črk imena.",
     "Blank" : "Prazno",
     "Unable to create new file from template" : "Nove datoteke iz predloge ni mogoče ustvariti",
     "Pick a template for {name}" : "Izbor predloge za {name}",
     "Create a new file with the selected template" : "Ustvari novo datoteko z izbrano predlogo",
     "Creating file" : "Poteka ustvarjanje datoteke",
-    "Deletion cancelled" : "Brisanje je bilo preklicano",
+    "Save as {displayName}" : "Shrani kot {displayName}",
+    "Failed to convert files: {message}" : "Pretvarjanje datotek je spodletelo: {message}",
+    "All files failed to be converted" : "Spodletelo je pretvarjanje vseh datotek.",
+    "One file could not be converted: {message}" : "Ene datoteke ni mogoče pretvoriti: {message}",
+    "Failed to convert files" : "Pretvarjanje datotek je spodletelo",
+    "File successfully converted" : "Datoteka je uspešno pretvorjena",
+    "Failed to convert file: {message}" : "Pretvarjanje datoteek je spodletelo: {message}",
+    "Failed to convert file" : "Pretvarjanje datoteke je spodletelo",
+    "Delete" : "Izbriši",
     "Leave this share" : "Prekini to souporabo",
     "Leave these shares" : "Prekini to souporabo",
     "Disconnect storage" : "Odklopi shrambo",
@@ -177,16 +221,19 @@ OC.L10N.register(
     "Delete permanently" : "Izbriši trajno",
     "Delete and unshare" : "Izbriši in prekini souporabo",
     "Delete file" : "Izbriši datoteko",
-    "Delete files" : "Izbriši datoteki",
+    "Delete files" : "Izbriši datoteke",
     "Delete folder" : "Izbriši mapo",
     "Delete folders" : "Izbriši mape",
-    "Delete" : "Izbriši",
+    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Za stalno boste izbrisali {count} predmet","Za stalno boste izbrisali {count} predmeta","Za stalno boste izbrisali {count} predmete","Za stalno boste izbrisali {count} predmetov"],
+    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Izbrisali boste {count} predmet","Izbrisali boste {count} predmeta","Izbrisali boste {count} predmete","Izbrisali boste {count} predmetov"],
     "Confirm deletion" : "Potrdi brisanje",
     "Cancel" : "Prekliči",
+    "Download" : "Prejmi",
+    "Destination is not a folder" : "Ciljno mesto ni mapa",
+    "This file/folder is already in that directory" : "Ta datoteka oziroma mapa je že v določeni mapi",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Mape ali datoteke ni mogoče premakniti samo vase oziroma v podmapo same sebe",
     "(copy)" : "(kopija)",
     "(copy %n)" : "(kopija %n)",
-    "Move cancelled" : "Premikanje je bilo preklicano",
     "A file or folder with that name already exists in this folder" : "Datoteka oziroma mapa s tem imenom v tej mapi že obstaja",
     "The files are locked" : "Datoteke so zaklenjene",
     "The file does not exist anymore" : "Datoteka ne obstaja več",
@@ -197,14 +244,16 @@ OC.L10N.register(
     "Move" : "Premakni",
     "Move or copy operation failed" : "Opravilo kopiranja oziroma premikanja je spodletelo",
     "Move or copy" : "Premakni ali kopiraj",
-    "Cancelled move or copy operation" : "Opravilo kopiranje in premikanja je preklicano",
     "Open folder {displayName}" : "Odpri mapo {displayName}",
     "Open in Files" : "Open in Files",
-    "Open file locally" : "Odpri datoteko krajevno",
-    "Failed to redirect to client" : "Preusmerjanje odjemalca je spodletelo",
     "Open locally" : "Odpri krajevno",
+    "Failed to redirect to client" : "Preusmerjanje odjemalca je spodletelo",
+    "Open file locally" : "Odpri datoteko krajevno",
+    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Datoteka bi se sedaj morala odpreti z vaše naprave. Če se to ne zgodi, preverite namestitev namizne aplikacije.",
+    "Retry and close" : "Ponovno poskusi in zapri",
+    "Open online" : "Odpri v brskalniku",
     "Rename" : "Preimenuj",
-    "Open details" : "Odpri podrobnosti",
+    "Details" : "Podrobnosti",
     "View in folder" : "Pokaži v mapi",
     "Today" : "Danes",
     "Last 7 days" : "Zadnjih 7 dni",
@@ -217,9 +266,8 @@ OC.L10N.register(
     "PDFs" : "Dokumenti PDF",
     "Folders" : "Mape",
     "Audio" : "Zvočni posnetek",
-    "Photos and images" : "Slike in fotografije",
+    "Images" : "Slike",
     "Videos" : "Video posnetki",
-    "New folder creation cancelled" : "Ustvarjanje nove mape je bilo preklicano",
     "Created new folder \"{name}\"" : "Ustvarjena je nova mapa »{name}«.",
     "Unable to initialize the templates directory" : "Ni mogoče začeti mape predlog",
     "Create templates folder" : "Ustvari mapo predlog",
@@ -227,7 +275,10 @@ OC.L10N.register(
     "New template folder" : "Nova mapa predlog",
     "In folder" : "V mapi",
     "Search in folder: {folder}" : "Išči v mapi: {folder}",
+    "One of the dropped files could not be processed" : "Eno od podanih datotek ni bilo mogoče obdelati",
+    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Brskalnik ne podpira API datotečnega sistema. Mape ne bodo naložene",
     "No files to upload" : "Ni datotek za pošiljanje",
+    "Unable to create the directory {directory}" : "Mape {directory} ni mogoče ustvariti",
     "Some files could not be uploaded" : "Nekaterih datotek ni bilo mogoče poslati",
     "Files uploaded successfully" : "Datoteke so uspešno poslane v oblak",
     "No files to process" : "Ni datotek za obdelavo",
@@ -237,124 +288,85 @@ OC.L10N.register(
     "Files moved successfully" : "Datoteke so uspešno premaknjene",
     "Conflicts resolution skipped" : "Razreševanje sporov je preklicano",
     "Upload cancelled" : "Pošiljanje je bilo preklicano",
+    "Could not rename \"{oldName}\", it does not exist any more" : "Datoteke »{oldName}« ni mogoče preimenovati, ker ne obstaja več.",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Ime »{newName}« je v mapi »{dir}« že v uporabi. Izbrati je treba drugačno ime.",
+    "Could not rename \"{oldName}\"" : "Datoteke »{oldName}« ni mogoče preimenovati",
     "This operation is forbidden" : "To dejanje ni dovoljeno!",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Mapa ni na voljo. Preverite dnevnik in stopite v stik s skrbnikom sistema.",
     "Storage is temporarily not available" : "Shramba trenutno ni na voljo",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} mapa","{folderCount} mapi","{folderCount} mape","{folderCount} map"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} datoteka","{fileCount} datoteki","{fileCount} datoteke","{fileCount} datotek"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 datoteka in {folderCount} mapa","1 datoteka in {folderCount} mapi","1 datoteka in {folderCount} mape","1 datoteka in {folderCount} map"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} datoteka in 1 mapa","{fileCount} datoteki in 1 mapa","{fileCount} datoteke in 1 mapa","{fileCount} datotek in 1 mapa"],
-    "{fileCount} files and {folderCount} folders" : "{fileCount} datotek in {folderCount} map",
+    "Unexpected error: {error}" : "Nepričakovana napaka: {error}",
+    "_%n file_::_%n files_" : ["%n datoteka","%n datoteki","%n datoteke","%n datotek"],
+    "_%n folder_::_%n folders_" : ["%n mapa","%n mapi","%n mape","%n mape"],
+    "_%n hidden_::_%n hidden_" : ["%n skrita","%n skriti","%n skrite","%n skritih"],
     "Filename must not be empty." : "Ime datoteke ne sme biti prazno.",
+    "\"{char}\" is not allowed inside a filename." : "Znak \"{char}\" ni dovoljen v imenu datotek.",
+    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" je rezervirano ime in ni dovoljeno za ime datoteke.",
+    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" ni dovoljena vrsta končnice.",
+    "Filenames must not end with \"{extension}\"." : "Imena datotek naj nimajo končnice \"{extension}\".",
+    "List of favorite files and folders." : "Seznam priljubljenih datotek in map.",
     "No favorites yet" : "Ni še dodanih priljubljenih predmetov",
     "Files and folders you mark as favorite will show up here" : "Datoteke ali mape, ki so označene kot priljubljene, bodo zbrane na tem mestu.",
-    "All files" : "Vse datoteke",
     "List of your files and folders." : "Seznam datotek in map.",
-    "All folders" : "Vse mape",
+    "List of your files and folders that are not shared." : "Seznam datotek in map, ki niso v skupni rabi.",
     "No personal files found" : "Ni najdenih zasebnih datotek",
+    "Files that are not shared will show up here." : "Datoteke, ki niso v skupni rabi, bodo prikazane tukaj.",
     "Recent" : "Nedavne",
     "List of recently modified files and folders." : "Seznam nedavno spremenjenih datotek in map.",
     "No recently modified files" : "Ni nedavno spremenjenih datotek",
     "Files and folders you recently modified will show up here." : "Nedavno spremenjene datoteke ali mape, bodo zbrane na tem mestu.",
+    "Search" : "Poišči",
     "No entries found in this folder" : "V tej mapi ni najdenih predmetov.",
     "Select all" : "izberi vse",
     "Upload too large" : "Prekoračena je omejitev dovoljene velikosti",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Datoteke, ki jih želite poslati, presegajo največjo dovoljeno velikost na strežniku.",
-    "File could not be found" : "Datoteke ni mogoče najti",
-    "Download" : "Prejmi",
-    "Show list view" : "Pokaži seznamski pogled",
-    "Show grid view" : "Pokaži mrežni pogled",
-    "Close" : "Zapri",
-    "Could not create folder \"{dir}\"" : "Mape »{dir}« ni mogoče ustvariti.",
-    "This will stop your current uploads." : "S tem bodo zaustavljena vsa pošiljanja v oblak.",
-    "Upload cancelled." : "Pošiljanje je preklicano.",
-    "Processing files …" : "Poteka obdelava datotek ...",
-    "…" : "...",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Datoteke {filename} ni mogoče poslati, saj je to mapa, ali pa je velikost datoteke 0 bajtov.",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ni dovolj prostora. Velikost poslane datoteke je {size1}, na voljo pa je le {size2}.",
-    "Target folder \"{dir}\" does not exist any more" : "Ciljna mapa »{dir}« ne obstaja več.",
-    "An unknown error has occurred" : "Prišlo je do neznane napake!",
-    "File could not be uploaded" : "Datoteke ni mogoče poslati",
-    "Uploading …" : "Poteka pošiljanje ...",
-    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
-    "Uploading … ({currentNumber}/{total})" : "Pošiljanje … ({currentNumber}/{total})",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} od {totalSize} ({bitrate})",
-    "Uploading that item is not supported" : "Pošiljate te vrste predmeta ni podprto.",
-    "Error when assembling chunks, status code {status}" : "Napaka pri sestavljanju kosov datoteke, koda stanja je {status}",
-    "Choose target folder" : "Izbor ciljne mape",
-    "Set reminder" : "Nastavi opomnik",
+    "Upload (max. %s)" : "Pošiljanje (omejitev %s)",
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Datoteke lahko po vklopu te možnosti tudi same migrirajo. Preverite dokumentacijo o ukazu occ.",
+    "\"{displayName}\" failed on some elements" : "\"{displayName}\" ni uspel za nekatere elemente",
+    "\"{displayName}\" batch action executed successfully" : "Paketno dejanje »{displayName}« je uspešno izvedeno",
+    "\"{displayName}\" action failed" : "Dejanje »{displayName}« je spodletelo",
+    "Submitting fields …" : "Pošiljanje polj ...",
+    "\"{displayName}\" action executed successfully" : "Dejanje »{displayName}« je uspešno izvedeno",
+    "Filter file names …" : "Filtriraj imena datotek...",
+    "Clipboard is not available" : "Odložišče ni na voljo",
+    "WebDAV URL copied to clipboard" : "Naslov URL WebDAV je kopiran v odložišče",
+    "Enable the grid view" : "Omogoči mrežni pogled",
+    "Enable folder tree" : "Omogoči drevesno strukturo map",
+    "WebDAV" : "WebDAV",
+    "Copy to clipboard" : "Kopiraj v odložišče",
+    "Use this address to access your Files via WebDAV" : "Uporabite ta naslov za dostop do datotek z uporabo WebDAV",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Če je omogočen sistem dvostopenjskega overjanja 2FA, je treba ustvariti in uporabiti novo geslo programa s klikom na to mesto.",
+    "Prevent warning dialogs from open or reenable them." : "Preprečite odpiranje dialogov z opozorili ali jih ponovno omogočite.",
+    "Show a warning dialog when changing a file extension." : "Prikaži opozorilo ob spreminjanju končnice datoteke.",
+    "Keyboard shortcuts" : "Tipkovne bližnjice",
+    "Speed up your Files experience with these quick shortcuts." : "Pospešite uporabo upravljalnika Files s temi bližnjicami.",
+    "Open the actions menu for a file" : "Odpri meni dejanj za datoteko",
+    "Rename a file" : "Preimenuj datoteko",
+    "Delete a file" : "Izbriši datoteko",
+    "Favorite or remove a file from favorites" : "Označi ali odstrani koz priljubljeno",
+    "Manage tags for a file" : "Upravljanje oznak datoteke",
+    "Deselect all files" : "Ostrani izbor vseh datotek",
+    "Select or deselect a file" : "Izberi ali odstrani izbor datoteke",
+    "Select a range of files" : "Izbor obsega datotek",
+    "Navigate to the parent folder" : "Pojdi na nadrejeni imenik",
+    "Navigate to the file above" : "Pojdi na datoteko zgoraj",
+    "Navigate to the file below" : "Pojdi na doatoteko spodaj",
+    "Navigate to the file on the left (in grid mode)" : "Pojdi na datoteko na levi (v mrežnem načinu)",
+    "Navigate to the file on the right (in grid mode)" : "Pojdi na datoteko na desni (v mrežnem načinu)",
+    "Toggle the grid view" : "Preklopi mrežni način",
+    "Open the sidebar for a file" : "Odpri stransko okno za datoteko",
+    "Save as …" : "Shrani kot ...",
+    "Converting files …" : "Poteka pretvarjanje datotek ...",
+    "Converting file …" : "Poteka pretvarjanje datoteke ...",
+    "Deletion cancelled" : "Brisanje je bilo preklicano",
     "Edit locally" : "Uredi krajevno",
-    "Open" : "Odpri",
-    "Could not load info for file \"{file}\"" : "Ni mogoče naložiti podatkov za datoteko »{file}«.",
-    "Details" : "Podrobnosti",
-    "Please select tag(s) to add to the selection" : "Izbrati je treba oznake za dodajanje k izbiri",
-    "Apply tag(s) to selection" : "Poteka uveljavljanje oznak za izbiro",
-    "Select directory \"{dirName}\"" : "Izberi mapo »{dirName}«",
-    "Select file \"{fileName}\"" : "Izberi datoteko »{fileName}«.",
-    "Unable to determine date" : "Ni mogoče določiti datuma",
-    "Could not move \"{file}\", target exists" : "Datoteke »{file}« ni mogoče premakniti, ker na ciljnem mestu z istim imenom že obstaja.",
-    "Could not move \"{file}\"" : "Datoteke »{file}« ni mogoče premakniti",
-    "copy" : "kopija",
-    "Could not copy \"{file}\", target exists" : "Datoteke »{file}« ni mogoče kopirati, ker ta že obstaja.",
-    "Could not copy \"{file}\"" : "Datoteke »{file}« ni mogoče kopirati.",
-    "Copied {origin} inside {destination}" : "Kopirano {origin} v {destination}",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "Kopirano {origin} in {nbfiles} ostale datoteke v {destination}",
-    "{newName} already exists" : "Ime {newName} že obstaja",
-    "Could not rename \"{fileName}\", it does not exist any more" : "Datoteke »{fileName}« ni mogoče preimenovati, ker ne obstaja več",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Ime \"{targetName}\" je v mapi »{dir}« že v uporabi. Izbrati je treba drugačno ime.",
-    "Could not rename \"{fileName}\"" : "Datoteke »{fileName}« ni mogoče preimenovati",
-    "Could not create file \"{file}\"" : "Datoteke »{file}« ni mogoče ustvariti.",
-    "Could not create file \"{file}\" because it already exists" : "Datoteke »{file}« ni mogoče ustvariti, ker datoteka z istim imenom že obstaja.",
-    "Could not create folder \"{dir}\" because it already exists" : "Ni mogoče ustvariti mape »{dir}«, ker ta že obstaja",
-    "Could not fetch file details \"{file}\"" : "Ni mogoče pridobiti podrobnosti datoteke »{file}«.",
-    "Error deleting file \"{fileName}\"." : "Prišli je do napake med brisanjem datoteke »{fileName}«.",
-    "No search results in other folders for {tag}{filter}{endtag}" : "Za iskalni niz {tag}{filter}{endtag} ni zadetkov v nobeni mapi",
-    "Enter more than two characters to search in other folders" : "Vpišite več kot dva znaka za iskanje po drugih mapah",
-    "_%n folder_::_%n folders_" : ["%n mapa","%n mapi","%n mape","%n mape"],
-    "_%n file_::_%n files_" : ["%n datoteka","%n datoteki","%n datoteke","%n datotek"],
-    "{dirs} and {files}" : "{dirs} in {files}",
-    "_including %n hidden_::_including %n hidden_" : ["vključujoč %n skrito","vključujoč %n skriti","vključujoč %n skrite","vključujoč %n skritih"],
-    "You do not have permission to upload or create files here" : "Ni ustreznih dovoljenja za pošiljanje ali ustvarjanje novih datotek",
-    "_Uploading %n file_::_Uploading %n files_" : ["Posodabljanje %n datoteke","Posodabljanje %n datotek","Posodabljanje %n datotek","Poteka posodabljanje %n datotek"],
-    "New" : "Novo",
-    "New file/folder menu" : "Nov meni datoteke/mape",
-    "Select file range" : "Izbor obsega datotek",
-    "{used}%" : "{used} %",
-    "{used} used" : "V uporabi je {used}",
-    "\"{name}\" is an invalid file name." : "Ime »{name}« ni veljavno ime datoteke.",
-    "File name cannot be empty." : "Ime datoteke ne sme biti prazno polje.",
-    "\"/\" is not allowed inside a file name." : "znak » / « v imenu datoteke ni dovoljen.",
-    "\"{name}\" is not an allowed filetype" : "Ime »{name}« ni dovoljena vrsta datoteke.",
-    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Shramba uporabnika {owner} je polna, zato datotek ni več mogoče posodabljati in usklajevati!",
-    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Skupinska mapa »{mountPoint}« je do konca zasedena, zato datotek ni mogoče več posodobiti in usklajevati!",
-    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Zunanja shramba »{mountPoint}« je do konca zasedena, zato datotek ni mogoče več posodobiti in usklajevati!",
-    "Your storage is full, files cannot be updated or synced anymore!" : "Shramba je povsem napolnjena. Datotek ni več mogoče posodabljati in usklajevati!",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Shramba uporabnika {owner} je do konca zasedena ({usedSpacePercent}%).",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Skupinska mapa »{mountPoint}« je skoraj do konca zasedena ({usedSpacePercent}%).",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Zunanja shramba »{mountPoint}« je skoraj do konca zasedena ({usedSpacePercent}%).",
-    "Your storage is almost full ({usedSpacePercent}%)." : "Vaša shramba je skoraj do konca zasedena ({usedSpacePercent}%).",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["se skladajo s filtrom »{filter}«","se skladajo s filtroma »{filter}«","se skladajo s filtri »{filter}«","se skladajo s filtri »{filter}«"],
-    "Direct link was copied (only works for people who have access to this file/folder)" : "Kopirana je neposredna povezava (za uporabnike, ki imajo dostop do datoteke ali mape)",
-    "Path" : "Pot",
-    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajta","%n bajti","%n bajtov"],
-    "Favorited" : "Označeno kot priljubljeno",
-    "Copy direct link (only works for people who have access to this file/folder)" : "Kopiraj neposredno povezavo (za uporabnike, ki imajo dostop do datoteke ali mape)",
-    "Upload file" : "Pošlji datoteko",
-    "Not favorited" : "Ni priljubljeno",
-    "An error occurred while trying to update the tags" : "Prišlo je do napake med posodabljanjem oznak",
-    "Storage informations" : "Podrobnosti shrambe",
-    "Choose file" : "Izbor datotek",
-    "Go to the previous folder" : "Skoči na predhodno mapo",
-    "Open the files app settings" : "Odpri nastavitve programa Datoteke",
-    "Unable to change the favourite state of the file" : "Ni mogoče spremeniti stanja priljubljenosti datoteke",
-    "Edit file locally" : "Uredi datoteko krajevno",
-    "Edit online" : "Uredi na spletu",
-    "Create new templates folder" : "Ustvari novo začasno mapo",
-    "List of favorites files and folders." : "Seznam priljubljenih datotek in map.",
-    "Personal Files" : "Osebne datoteke",
-    "Text file" : "Besedilna datoteka",
-    "New text file.txt" : "nova_datoteka.txt",
-    "Submitting fields…" : "Poteka objavljanje vsebine polj ...",
-    "Filter filenames…" : "Filtriraj imena datotek ..."
+    "Moving \"{source}\" to \"{destination}\" …" : "Premik \"{source}\" v \"{destination}\"...",
+    "Copying \"{source}\" to \"{destination}\" …" : "Kopiranje \"{source}\" v \"{destination}\"...",
+    "Move cancelled" : "Premikanje je bilo preklicano",
+    "Cancelled move or copy of \"{filename}\"." : "Prekinjeno premikanje ali kopiranje za \"{filename}\".",
+    "Cancelled move or copy operation" : "Opravilo kopiranje in premikanja je preklicano",
+    "Open details" : "Odpri podrobnosti",
+    "Photos and images" : "Slike in fotografije",
+    "New folder creation cancelled" : "Ustvarjanje nove mape je bilo preklicano",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Mapa ni na voljo. Preverite dnevnik in stopite v stik s skrbnikom sistema.",
+    "All folders" : "Vse mape"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
