@@ -51,10 +51,13 @@ OC.L10N.register(
     "You do not have permission to create a file at the specified location" : "Belirtilen konumda bir dosya oluşturma izniniz yok",
     "The file could not be converted." : "Dosya dönüştürülemedi.",
     "Could not get relative path to converted file" : "Dönüştürülen dosyanın yolu göreli yolu alınamadı",
+    "Limit must be a positive integer." : "Sınır değeri bir pozitif tam sayı olmalıdır.",
+    "The replacement character may only be a single character." : "Değiştirilecek karakter yalnızca tek bir karakter olabilir.",
+    "Filename sanitization already started." : "Dosya adı sadeleştirme işlemi zaten başlatılmış.",
+    "No filename sanitization in progress." : "İşlenen bir dosya sadeleştirmesi yok.",
     "Favorite files" : "Sık kullanılan dosyalar",
     "No favorites" : "Sık kullanılan bir öge yok",
     "More favorites" : "Diğer sık kullanılanlar",
-    "Upload (max. %s)" : "Yükle (en büyük: %s)",
     "Accept" : "Kabul et",
     "Reject" : "Reddet",
     "Incoming ownership transfer from {user}" : "{user} kullanıcısından gelen sahiplik aktarımı ",
@@ -69,10 +72,6 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "{path} yolundaki {user} kullanıcısının sahipliği size aktarıldı.",
     "in %s" : "%s içinde",
     "Transferred from %1$s on %2$s" : "%1$s üzerinden %2$s zamanında aktarıldı",
-    "Files compatibility" : "Dosyalar uygulaması uyumluluğu",
-    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Dosyaların tüm istemcilerle eşitlenebilmesi için dosya adlarının kısıtlanmasını sağlar. Varsayılan olarak POSIX içinde geçerli olan tüm dosya adlarına (Linux veya macOS) izin verilir.",
-    "Enforce Windows compatibility" : "Windows uyumluluğu dayatılsın",
-    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Ayrılmış adlar veya özel karakterler kullanmak gibi Windows sistemlerinde geçerli olmayan dosya adlarını engeller. Ancak büyük/küçük harf duyarlılığı uyumluluğunu zorunlu kılmaz.",
     "File Management" : "Dosya yönetimi",
     "Home" : "Giriş",
     "Target folder does not exist any more" : "Hedef klasör artık yok",
@@ -95,28 +94,76 @@ OC.L10N.register(
     "Invalid filename." : "Dosya adı geçersiz.",
     "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" adı \"{newName}\" olarak değiştirildi",
     "Rename file" : "Dosyayı yeniden adlandır",
+    "Folder" : "Klasör",
+    "Unknown file type" : "Dosya türü bilinmiyor",
+    "{ext} image" : "{ext} görsel",
+    "{ext} video" : "{ext} görüntü",
+    "{ext} audio" : "{ext} ses",
+    "{ext} text" : "{ext} yazı",
     "Pending" : "Bekliyor",
     "Unknown date" : "Tarih bilinmiyor",
     "Clear filter" : "Süzgeci temizle",
     "Modified" : "Değiştirilme",
+    "Search everywhere" : "Her yerde ara",
     "Type" : "Tür",
     "Active filters" : "Etkin süzgeçler",
     "Remove filter" : "Süzgeci kaldır",
+    "Appearance" : "Görünüm",
+    "Show hidden files" : "Gizli dosyaları görüntüle",
+    "Show file type column" : "Dosya türü sütunu görüntülensin",
+    "Show file extensions" : "Dosya uzantıları görüntülensin",
+    "Crop image previews" : "Görsel ön izlemeleri kırpılsın",
+    "General" : "Genel",
+    "Sort favorites first" : "Sık kullanılanlar üstte sıralansın",
+    "Sort folders before files" : "Klasörler dosyaların üzerinde sıralansın",
+    "Enable folder tree view" : "Klasör ağacı görünümünü aç",
+    "Default view" : "Varsayılan görünüm",
+    "All files" : "Tüm dosyalar",
+    "Personal files" : "Kişisel dosyalar",
+    "Additional settings" : "Ek ayarlar",
+    "Actions" : "İşlemler",
+    "File actions" : "Dosya işlemleri",
+    "Selection" : "Seçim",
+    "Select all files" : "Tüm dosyaları seçer",
+    "Deselect all" : "Tümünü bırak",
+    "Select or deselect" : "Seç ya da bırak",
+    "Select a range" : "Bir aralık seçin",
+    "Navigation" : "Gezinme",
+    "Go to parent folder" : "Üst klasöre git",
+    "Go to file above" : "Yukarıdaki dosyaya git",
+    "Go to file below" : "Aşağıdaki dosyaya git",
+    "Go left in grid" : "Izgarada sola git",
+    "Go right in grid" : "Izgarada sağa git",
+    "View" : "Görüntüle",
+    "Toggle grid view" : "Tablo görünümünü aç/kapat",
+    "Open file sidebar" : "Dosya kenar çubuğunu aç",
+    "Show those shortcuts" : "Bu kısayolları görüntüler",
+    "Warnings" : "Uyarılar",
+    "Warn before changing a file extension" : "Dosya uzantıları değiştirilmeden önce uyarı görüntülensin",
+    "Warn before deleting a file" : "Bir dosya silinmeden önce uyarı verilsin",
+    "WebDAV URL" : "WebDAV adresi",
+    "Create an app password" : "Bir uygulama parolası oluştur",
+    "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "Bu hesap için iki adımlı doğrulama açıldığından WebDAV kimlik doğrulaması için gereklidir.",
+    "How to access files using WebDAV" : "WebDAV ile dosyalara nasıl erişilir",
     "Total rows summary" : "Toplam satır özeti",
     "Toggle selection for all files and folders" : "Tüm dosyaları ve klasörleri seç/bırak",
     "Name" : "Ad",
+    "File type" : "Dosya türü",
     "Size" : "Boyut",
-    "\"{displayName}\" failed on some elements" : "\"{displayName}\" bazı bileşenlerde tamamlanamadı",
-    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" toplu işlemi tamamlandı",
-    "\"{displayName}\" action failed" : "\"{displayName}\" işlemi tamamlanamadı",
-    "Actions" : "İşlemler",
+    "{displayName}: failed on some elements" : "{displayName}: Bazı bileşenlerde tamamlanamadı",
+    "{displayName}: done" : "{displayName}: Tamamlandı",
+    "{displayName}: failed" : "{displayName}: Tamamlanamadı",
     "(selected)" : "(seçilmiş)",
     "List of files and folders." : "Dosya ve klasörlerin listesi.",
     "You have used your space quota and cannot upload files anymore." : "Depolama alanınızın tümünü kullandığınız için başka dosya yüklemezsiniz.",
     "Column headers with buttons are sortable." : "Düğmeler olan sütunlar sıralanabilir.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Başarımı olumsuz etkilememek için listenin tümü görüntülenmiyor. Listede ilerledikçe dosyalar görüntülenecek.",
     "File not found" : "Dosya bulunamadı",
-    "{count} selected" : "{count} seçilmiş",
+    "_{count} selected_::_{count} selected_" : ["{count} seçilmiş","{count} seçilmiş"],
+    "Search everywhere …" : "Her yerde ara…",
+    "Search here …" : "Burada ara…",
+    "Search scope options" : "Arama kapsamı seçenekleri",
+    "Search here" : "Burada ara",
     "{usedQuotaByte} used" : "{usedQuotaByte} kullanılmış",
     "{used} of {quota} used" : "{used} / {quota} kullanılmış",
     "{relative}% used" : "%{relative} kullanılmış",
@@ -128,8 +175,27 @@ OC.L10N.register(
     "Create new folder" : "Klasör ekle",
     "This name is already in use." : "Bu ad zaten kullanılıyor.",
     "Create" : "Ekle",
+    "Files starting with a dot are hidden by default" : "Bir nokta ile başlayan dosyalar varsayılan olarak gizlidir",
+    "Failed to start filename sanitization." : "Dosya adı sadeleştirmesi başlatılamadı.",
+    "Failed to refresh filename sanitization status." : "Dosya adı sadeleştirmesi durumu yenilenemedi.",
+    "Filename sanitization in progress." : "Dosya adı sadeleştirmesi işleniyor.",
+    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "{processedUsers} / {totalUsers} hesap zaten işlenmiş.",
+    "Preparing …" : "Hazırlanıyor…",
+    "Refresh" : "Yenlle",
+    "All files have been santized for Windows filename support." : "Tüm dosya adları Windows dosya adı desteğine göre temizlendi.",
+    "Some files could not be sanitized, please check your logs." : "Bazı dosya adları sadeleştirilemedi. Lütfen günlük kayıtlarına bakın.",
+    "Sanitization errors" : "Sadeleştirme sorunları",
+    "Not sanitized filenames" : "Sadeleştirilmeyen dosya adları",
+    "Windows filename support has been enabled." : "Windows dosya adı desteği açıldı.",
+    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "Kullanıcıların desteklenmeyen dosya adlarıyla yeni dosyalar oluşturmasını engelleniyor ancak var olan dosyalar henüz yeniden adlandırılmadı ve bu nedenle Windows ile eşitlemeyi aksatabilir.",
+    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "Geçersiz adları olan dosyaların yeniden adlandırılması işlemini başlatabilirsiniz. Bu işlem arka planda yapılır ve biraz zaman alabilir.",
+    "Please note that this may cause high workload on the sync clients." : "Bu işlemin eşitleme istemcilerinde yüksek iş yüküne neden olabileceğini lütfen unutmayın.",
+    "Limit" : "Sınır",
+    "This allows to configure how many users should be processed in one background job run." : "Bu seçenek, bir arka plan işleminde kaç kullanıcının işlenebileceğini yapılandırır.",
+    "Sanitize filenames" : "Dosya adlarını sadeleştir",
+    "(starting)" : "(başlatılıyor)",
     "Fill template fields" : "Kalıp alanlarını doldur",
-    "Submitting fields …" : "Alanlar gönderiliyor…",
+    "Submitting fields …" : "Alanlar gönderiliyor…",
     "Submit" : "Gönder",
     "Choose a file or folder to transfer" : "Sahipliği aktarılacak bir dosya ya da klasör seçin",
     "Transfer" : "Sahipliği aktar",
@@ -153,6 +219,7 @@ OC.L10N.register(
     "Do not show this dialog again." : "Bu ileti bir daha görüntülenmesin.",
     "Select file or folder to link to" : "Bağlantı verilecek dosya ya da klasörü seçin",
     "Choose {file}" : "{file} seçin",
+    "Files settings" : "Dosyalar ayarları",
     "Share" : "Paylaş",
     "Shared by link" : "Bağlantı ile paylaşılmış",
     "Shared" : "Paylaşılan",
@@ -165,83 +232,52 @@ OC.L10N.register(
     "Error during upload: {message}" : "Yükleme sırasında sorun çıktı: {message}",
     "Error during upload, status code {status}" : "Yüklenirken sorun çıktı, durum kodu {status}",
     "Unknown error during upload" : "Yükleme sırasında bilinmeyen bir sorun çıktı",
-    "\"{displayName}\" action executed successfully" : "\"{displayName}\" işlemi tamamlandı",
     "Loading current folder" : "Geçerli klasör yükleniyor",
     "Retry" : "Yeniden dene",
     "No files in here" : "Burada herhangi bir dosya yok",
     "Upload some content or sync with your devices!" : "Bir şeyler yükleyin ya da aygıtlarınızla eşitleyin!",
     "Go back" : "Geri dön",
-    "Filter file names …" : "Dosya adlarını süz…",
     "Views" : "Görünümler",
-    "Files settings" : "Dosyalar ayarları",
-    "Your files" : "Dosyalarınız",
-    "Open in files" : "Dosyalar uygulamasında aç",
-    "File cannot be accessed" : "Dosyaya erişilemedi",
-    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Dosya bulunamadı ya da görüntüleme izniniz olmayabilir. Gönderenden paylaşmasını isteyin",
-    "Clipboard is not available" : "Pano kullanılamıyor",
-    "WebDAV URL copied to clipboard" : "WebDAV adresi panoya kopyalandı",
-    "Sort favorites first" : "Sık kullanılanlar üstte sıralansın",
-    "Sort folders before files" : "Klasörler dosyaların üzerinde sıralansın",
-    "Show hidden files" : "Gizli dosyaları görüntüle",
-    "Crop image previews" : "Görsel ön izlemeleri kırpılsın",
-    "Enable the grid view" : "Tablo görünümü kullanılsın",
-    "Enable folder tree" : "Klasör ağacını aç",
-    "Additional settings" : "Ek ayarlar",
-    "WebDAV" : "WebDAV",
-    "WebDAV URL" : "WebDAV adresi",
-    "Copy to clipboard" : "Panoya kopyala",
-    "Use this address to access your Files via WebDAV" : "Dosyalarınıza WebDAV üzerinden erişmek için bu adresi kullanın",
-    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "İki adımlı doğrulamayı kullanıma aldıysanız buraya tıklayarak yeni bir uygulama parolası oluşturmalısınız.",
-    "Warnings" : "Uyarılar",
-    "Prevent warning dialogs from open or reenable them." : "Uyarı pencerelerinin görüntülenmesini açın ya da kapatın.",
-    "Show a warning dialog when changing a file extension." : "Dosya uzantısı değiştirilirken uyarı penceresi görüntülensin.",
-    "Keyboard shortcuts" : "Kısayol tuşları",
-    "Speed up your Files experience with these quick shortcuts." : "Şu kısayol tuşlarını kullanarak Dosyalar deneyiminizi hızlandırabilirsiniz.",
-    "Open the actions menu for a file" : "Bir dosyanın işlemler menüsünü açar",
-    "Rename a file" : "Bir dosyayı yeniden adlandırır",
-    "Delete a file" : "Bir dosyayı siler",
-    "Favorite or remove a file from favorites" : "Bir dosyayı sık kullanılanlara ekler ya da kaldırır",
-    "Manage tags for a file" : "Bir dosyanın etiketlerini yönetir",
-    "Selection" : "Seçim",
-    "Select all files" : "Tüm dosyaları seçer",
-    "Deselect all files" : "Tüm dosyaları bırakır",
-    "Select or deselect a file" : "Bir dosyayı seçer ya da bırakır",
-    "Select a range of files" : "Bir dosya grubunu seçer",
-    "Navigation" : "Gezinme",
-    "Navigate to the parent folder" : "Üst klasöre gider",
-    "Navigate to the file above" : "Üstteki dosyaya gider",
-    "Navigate to the file below" : "Aşağıdaki dosyaya gider",
-    "Navigate to the file on the left (in grid mode)" : "Soldaki dosyaya gider (ızgara görünümünde)",
-    "Navigate to the file on the right (in grid mode)" : "Sağdaki dosyaya gider (ızgara görünümünde)",
-    "View" : "Görüntüle",
-    "Toggle the grid view" : "Izgara görünümünü açar ya da kapatır",
-    "Open the sidebar for a file" : "Bir dosyanın yan çubuğunu açar",
-    "Show those shortcuts" : "Bu kısayolları görüntüler",
     "You" : "Siz",
     "Shared multiple times with different people" : "Farklı kişilerle birkaç kez paylaşılmış",
+    "Unable to change the favorite state of the file" : "Dosyanın sık kullanılan durumu değiştirilemedi",
     "Error while loading the file data" : "Dosya verileri yüklenirken sorun çıktı",
     "Owner" : "Sahibi",
     "Remove from favorites" : "Sık kullanılanlardan kaldır",
     "Add to favorites" : "Sık kullanılanlara ekle",
     "Tags" : "Etiketler",
+    "Your files" : "Dosyalarınız",
+    "Open in files" : "Dosyalar uygulamasında aç",
+    "File cannot be accessed" : "Dosyaya erişilemedi",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Dosya bulunamadı ya da görüntüleme izniniz olmayabilir. Gönderenden paylaşmasını isteyin",
+    "No search results for “{query}”" : "“{query}” için bir arama sonucu bulunamadı",
+    "Search for files" : "Dosya ara",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Dosyaların tüm istemcilerle eşitlenebilmesi için dosya adlarının kısıtlanmasını sağlar. Varsayılan olarak POSIX içinde geçerli olan tüm dosya adlarına (Linux veya macOS) izin verilir.",
+    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Windows uyumlu dosya adları açıldıktan sonra, var olan dosyalar artık değiştirilemez. Ancak sahipleri tarafından geçerli yeni adlarla yeniden adlandırılabilir.",
+    "Failed to toggle Windows filename support" : "Windows dosya adları desteğinin durumu değiştirilemedi",
+    "Files compatibility" : "Dosyalar uygulaması uyumluluğu",
+    "Enforce Windows compatibility" : "Windows uyumluluğu zorunlu kılınsın",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Ayrılmış adlar veya özel karakterler kullanmak gibi Windows sistemlerinde geçerli olmayan dosya adlarını engeller. Ancak büyük/küçük harf duyarlılığı uyumluluğunu zorunlu kılmaz.",
     "Blank" : "Boş",
     "Unable to create new file from template" : "Kalıptan yeni dosya eklenemedi",
     "Pick a template for {name}" : "{name} için bir kalıp seçin",
     "Create a new file with the selected template" : "Seçilmiş kalıp ile yeni bir dosya ekle",
     "Creating file" : "Dosya ekleniyor",
     "Save as {displayName}" : "{displayName} olarak kaydet",
-    "Save as …" : "Farklı kaydet…",
-    "Converting files …" : "Dosyalar dönüştürülüyor…",
+    "Save as …" : "Farklı kaydet…",
+    "Converting files …" : "Dosyalar dönüştürülüyor…",
     "Failed to convert files: {message}" : "Dosyalar dönüştürülemedi: {message}",
     "All files failed to be converted" : "Tüm dosyalar dönüştürülemedi",
     "One file could not be converted: {message}" : "Bir dosya dönüştürülemedi: {message}",
-    "Files successfully converted" : "Dosyalar dönüştürüldü",
+    "_%n file could not be converted_::_%n files could not be converted_" : ["%n dosya dönüştürülemedi","%n dosya dönüştürülemedi"],
+    "_%n file converted_::_%n files converted_" : ["%n dosya dönüştürüldü","%n dosya dönüştürüldü"],
+    "Files converted" : "Dosyalar dönüştürüldü",
     "Failed to convert files" : "Dosyalar dönüştürülemedi",
-    "Converting file …" : "Dosya dönüştürülüyor…",
+    "Converting file …" : "Dosya dönüştürülüyor…",
     "File successfully converted" : "Dosya dönüştürüldü",
     "Failed to convert file: {message}" : "Dosya dönüştürülemedi: {message}",
     "Failed to convert file" : "Dosya dönüştürülemedi",
-    "Deletion cancelled" : "Silme iptal edildi",
+    "Delete" : "Sil",
     "Leave this share" : "Bu paylaşımdan ayrıl",
     "Leave these shares" : "Bu paylaşımlardan ayrıl",
     "Disconnect storage" : "Depolama bağlantısını kes",
@@ -252,17 +288,21 @@ OC.L10N.register(
     "Delete files" : "Dosyaları sil",
     "Delete folder" : "Klasörü sil",
     "Delete folders" : "Klasörleri sil",
-    "Delete" : "Sil",
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["{count} ögeyi kalıcı olarak silmek üzeresiniz","{count} ögeyi kalıcı olarak silmek üzeresiniz"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["{count} ögeyi silmek üzeresiniz","{count} ögeyi silmek üzeresiniz"],
     "Confirm deletion" : "Silmeyi onaylayın",
     "Cancel" : "İptal",
-    "Moving \"{source}\" to \"{destination}\" …" : "\"{source}\", \"{destination}\" hedefine taşınıyor…",
-    "Copying \"{source}\" to \"{destination}\" …" : "\"{source}\", \"{destination}\" hedefine kopyalanıyor…",
+    "Download" : "İndir",
+    "The requested file is not available." : "İstenilen dosya kullanılamıyor.",
+    "The requested files are not available." : "İstenilen dosyalar kullanılamıyor.",
+    "Add or remove favorite" : "Sık kullanılanlara ekle ya da kaldır",
+    "Moving \"{source}\" to \"{destination}\" …" : "\"{source}\", \"{destination}\" üzerine taşınıyor…",
+    "Copying \"{source}\" to \"{destination}\" …" : "\"{source}\", \"{destination}\" üzerine kopyalanıyor…",
+    "Destination is not a folder" : "Hedef bir klasör değil",
+    "This file/folder is already in that directory" : "Dosya ya da klasör bu klasörde zaten var",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Bir dosyayı ya da klasörü kendi üzerine veya kendisinin alt klasörüne taşıyamazsınız",
     "(copy)" : "(kopya)",
     "(copy %n)" : "(%n kopyası)",
-    "Move cancelled" : "Taşıma iptal edildi",
     "A file or folder with that name already exists in this folder" : "Bu klasörde aynı adlı bir dosya ya da klasör zaten var",
     "The files are locked" : "Dosyalar kilitli",
     "The file does not exist anymore" : "Dosya artık yok",
@@ -273,18 +313,16 @@ OC.L10N.register(
     "Move" : "Taşı",
     "Move or copy operation failed" : "Taşıma ya da kopyalama yapılamadı",
     "Move or copy" : "Taşı ya da kopyala",
-    "Cancelled move or copy of \"{filename}\"." : "\"{filename}\" dosyasını taşıma ya da kopyalama işlemi iptal edildi",
-    "Cancelled move or copy operation" : "Taşıma ya da kopyalama işlemi iptal edildi",
     "Open folder {displayName}" : "{displayName} klasörünü aç",
     "Open in Files" : "Dosyalar uygulamasında aç",
+    "Open locally" : "Yerel olarak aç",
+    "Failed to redirect to client" : "İstemciye yönlendirilemedi",
     "Open file locally" : "Dosyayı yerel olarak aç",
-    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Dosya artık aygıtınızda açılmalıdır. Açılmazsa lütfen masaüstü uygulamasının kurulu olduğundan emin olun.",
+    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Dosya artık aygıtınızda açılmalıdır. Açılmazsa lütfen bilgisayar uygulamasının kurulu olduğundan emin olun.",
     "Retry and close" : "Yeniden deneyip kapat",
     "Open online" : "Çevrim içi aç",
-    "Failed to redirect to client" : "İstemciye yönlendirilemedi",
-    "Open locally" : "Yerel olarak aç",
     "Rename" : "Yeniden adlandır",
-    "Open details" : "Ayrıntıları aç",
+    "Details" : "Ayrıntılar",
     "View in folder" : "Klasörde görüntüle",
     "Today" : "Bugün",
     "Last 7 days" : "Önceki 7 gün",
@@ -297,15 +335,15 @@ OC.L10N.register(
     "PDFs" : "PDF dosyaları",
     "Folders" : "Klasörler",
     "Audio" : "Ses",
-    "Photos and images" : "Fotoğraflar ve görseller",
+    "Images" : "Görseller",
     "Videos" : "Görüntüler",
-    "New folder creation cancelled" : "Yeni klasör oluşturma işlemi iptal edildi",
     "Created new folder \"{name}\"" : "\"{name}\" yeni klasörü oluşturuldu",
     "Unable to initialize the templates directory" : "Kalıp klasörü hazırlanamadı",
     "Create templates folder" : "Kalıplar klasörü oluştur",
     "Templates" : "Kalıplar",
     "New template folder" : "Yeni kalıp klasörü",
     "In folder" : "Klasörde",
+    "Search in all files" : "Tüm dosyalarda ara",
     "Search in folder: {folder}" : "Şu klasörde ara: {folder}",
     "One of the dropped files could not be processed" : "Bırakılan dosyalardan biri işlenemedi",
     "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Tarayıcınız dosya sistemi API uygulamasını desteklemiyor. Klasörler yüklenemeyecek",
@@ -320,15 +358,16 @@ OC.L10N.register(
     "Files moved successfully" : "Dosyalar taşındı",
     "Conflicts resolution skipped" : "Çakışma çözümleme atlandı",
     "Upload cancelled" : "Yükleme iptal edildi",
+    "Could not rename \"{oldName}\", it does not exist any more" : "\"{oldName}\" adı artık olmadığından değiştirilemedi. ",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{newName}\" adı \"{dir}\" klasöründe zaten kullanılmış. Lütfen başka bir ad seçin.",
+    "Could not rename \"{oldName}\"" : "\"{oldName}\" adı değiştirilemedi",
     "This operation is forbidden" : "Bu işleme izin verilmiyor",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Bu klasör yazılabilir değil. Lütfen günlük kayıtlarına bakın ya da BT yöneticiniz ile görüşün",
+    "This folder is unavailable, please try again later or contact the administration" : "Bu klasör kullanılamıyor. Lütfen bir süre sonra yeniden deneyin ya da BT yöneticiniz ile görüşün",
     "Storage is temporarily not available" : "Depolama geçici olarak kullanılamıyor",
     "Unexpected error: {error}" : "Beklenmeyen bir sorun çıktı: {error}",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} klasör","{folderCount} klasör"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} dosya","{fileCount} dosya"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 dosya ve {folderCount} klasör","1 dosya ve {folderCount} klasör"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} dosya ve 1 klasör","{fileCount} dosya ve 1 klasör"],
-    "{fileCount} files and {folderCount} folders" : "{fileCount} dosya ve {folderCount} klasör",
+    "_%n file_::_%n files_" : ["%n dosya","%n dosya"],
+    "_%n folder_::_%n folders_" : ["%n klasör","%n klasör"],
+    "_%n hidden_::_%n hidden_" : ["%n gizli","%n gizli"],
     "Filename must not be empty." : "Dosya adı boş olamaz.",
     "\"{char}\" is not allowed inside a filename." : "Dosya adlarında \"{char}\" kullanılamaz.",
     "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" ayrılmış bir ad olduğundan dosya adlarında kullanılamaz.",
@@ -337,10 +376,8 @@ OC.L10N.register(
     "List of favorite files and folders." : "Sık kullanılan dosya ve klasör listesi.",
     "No favorites yet" : "Henüz sık kullanılan bir öge yok",
     "Files and folders you mark as favorite will show up here" : "Sık kullanılanlara eklediğiniz dosya ve klasörler burada görüntülenir",
-    "All files" : "Tüm dosyalar",
     "List of your files and folders." : "Dosya ve klasörlerinizin listesi",
-    "All folders" : "Tüm klasörler",
-    "Personal files" : "Kişisel dosyalar",
+    "Folder tree" : "Klasör ağacı",
     "List of your files and folders that are not shared." : "Paylaşılmayan dosya ve klasörlerinizin listesi.",
     "No personal files found" : "Herhangi bir kişisel dosya bulunamadı",
     "Files that are not shared will show up here." : "Paylaşımayan dosyalar burada görüntülenir.",
@@ -348,111 +385,67 @@ OC.L10N.register(
     "List of recently modified files and folders." : "Son değiştirilen dosya ve klasörlerin listesi.",
     "No recently modified files" : "Yakınlarda değiştirilmiş bir dosya yok",
     "Files and folders you recently modified will show up here." : "Son zamanlarda değiştirdiğiniz dosya ve klasörler burada görüntülenir.",
+    "Search" : "Ara",
+    "Search results within your files." : "Dosyalarınızda arama sonuçları.",
     "No entries found in this folder" : "Bu klasörde herhangi bir kayıt bulunamadı",
     "Select all" : "Tümünü seç",
     "Upload too large" : "Yükleme boyutu çok büyük",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Yüklemeye çalıştığınız dosyalar bu sunucuya yüklenmesine izin verilen en büyük dosya boyutunu aşıyor.",
-    "File could not be found" : "Dosya bulunamadı",
-    "Download" : "İndir",
-    "Show list view" : "Liste görünümüne geç",
-    "Show grid view" : "Tablo görünümüne geç",
-    "Close" : "Kapat",
-    "Could not create folder \"{dir}\"" : "\"{dir}\" klasörü oluşturulamadı",
-    "This will stop your current uploads." : "Bu işlem geçerli yüklemeleri durduracak.",
-    "Upload cancelled." : "Yükleme iptal edildi.",
-    "Processing files …" : "Dosyalar işleniyor …",
-    "…" : "…",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "{filename} bir klasör ya da 0 bayt boyutunda olduğundan yüklenemedi",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Yeterli boş alan yok. Yüklemek istediğiniz boyut {size1} ancak yalnızca {size2} boş alan var",
-    "Target folder \"{dir}\" does not exist any more" : "\"{dir}\" hedef klasörü artık yok",
-    "An unknown error has occurred" : "Bilinmeyen bir sorun çıktı",
-    "File could not be uploaded" : "Dosya yüklenemedi",
-    "Uploading …" : "Yükleniyor …",
-    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
-    "Uploading … ({currentNumber}/{total})" : "Yükleniyor… ({currentNumber}/{total})",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} / {totalSize} ({bitrate})",
-    "Uploading that item is not supported" : "Bu ögenin yüklenmesi desteklenmiyor",
-    "Error when assembling chunks, status code {status}" : "Kümeler oluşturulurken sorun çıktı, durum kodu {status}",
-    "Choose target folder" : "Hedef klasörü seçin",
-    "Set reminder" : "Anımsatıcı ayarla",
+    "%1$s (renamed)" : "%1$s (yeniden adlandırıldı)",
+    "renamed file" : "dosyayı yeniden adlandırdı",
+    "Upload (max. %s)" : "Yükle (en büyük: %s)",
+    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Windows uyumlu dosya adları açıldıktan sonra, var olan dosyalar artık değiştirilemez. Ancak sahipleri tarafından geçerli yeni adlarla yeniden adlandırılabilir.",
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Bu ayarı açtıktan sonra dosyaları otomatik olarak da aktarılabilir. Lütfen occ komutuyla ilgili belgelere bakın.",
+    "\"{displayName}\" failed on some elements" : "\"{displayName}\" bazı bileşenlerde tamamlanamadı",
+    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" toplu işlemi tamamlandı",
+    "\"{displayName}\" action failed" : "\"{displayName}\" işlemi tamamlanamadı",
+    "Submitting fields …" : "Alanlar gönderiliyor…",
+    "\"{displayName}\" action executed successfully" : "\"{displayName}\" işlemi tamamlandı",
+    "Filter file names …" : "Dosya adlarını süz…",
+    "Clipboard is not available" : "Pano kullanılamıyor",
+    "WebDAV URL copied to clipboard" : "WebDAV adresi panoya kopyalandı",
+    "Enable the grid view" : "Tablo görünümü kullanılsın",
+    "Enable folder tree" : "Klasör ağacını aç",
+    "WebDAV" : "WebDAV",
+    "Copy to clipboard" : "Panoya kopyala",
+    "Use this address to access your Files via WebDAV" : "Dosyalarınıza WebDAV üzerinden erişmek için bu adresi kullanın",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "İki adımlı doğrulamayı açtıysanız buraya tıklayarak yeni bir uygulama parolası oluşturmalısınız.",
+    "Prevent warning dialogs from open or reenable them." : "Uyarı pencerelerinin görüntülenmesini açın ya da kapatın.",
+    "Show a warning dialog when changing a file extension." : "Dosya uzantısı değiştirilirken uyarı penceresi görüntülensin.",
+    "Keyboard shortcuts" : "Kısayol tuşları",
+    "Speed up your Files experience with these quick shortcuts." : "Şu kısayol tuşlarını kullanarak Dosyalar deneyiminizi hızlandırabilirsiniz.",
+    "Open the actions menu for a file" : "Bir dosyanın işlemler menüsünü açar",
+    "Rename a file" : "Bir dosyayı yeniden adlandırır",
+    "Delete a file" : "Bir dosyayı siler",
+    "Favorite or remove a file from favorites" : "Bir dosyayı sık kullanılanlara ekler ya da kaldırır",
+    "Manage tags for a file" : "Bir dosyanın etiketlerini yönetir",
+    "Deselect all files" : "Tüm dosyaları bırakır",
+    "Select or deselect a file" : "Bir dosyayı seçer ya da bırakır",
+    "Select a range of files" : "Bir dosya grubunu seçer",
+    "Navigate to the parent folder" : "Üst klasöre gider",
+    "Navigate to the file above" : "Üstteki dosyaya gider",
+    "Navigate to the file below" : "Aşağıdaki dosyaya gider",
+    "Navigate to the file on the left (in grid mode)" : "Soldaki dosyaya gider (ızgara görünümünde)",
+    "Navigate to the file on the right (in grid mode)" : "Sağdaki dosyaya gider (ızgara görünümünde)",
+    "Toggle the grid view" : "Izgara görünümünü açar ya da kapatır",
+    "Open the sidebar for a file" : "Bir dosyanın kenar çubuğunu açar",
+    "Save as …" : "Farklı kaydet…",
+    "Converting files …" : "Dosyalar dönüştürülüyor…",
+    "Converting file …" : "Dosya dönüştürülüyor…",
+    "Deletion cancelled" : "Silme iptal edildi",
     "Edit locally" : "Yerel olarak düzenle",
-    "Open" : "Aç",
-    "Could not load info for file \"{file}\"" : "\"{file}\" dosyasının bilgileri alınamadı",
-    "Details" : "Ayrıntılar",
-    "Please select tag(s) to add to the selection" : "Seçime eklemek için etiketleri seçin",
-    "Apply tag(s) to selection" : "Etiketleri seçime uygula",
-    "Select directory \"{dirName}\"" : "\"{dirName}\" klasörünü seçin",
-    "Select file \"{fileName}\"" : "\"{fileName}\" dosyasını seçin",
-    "Unable to determine date" : "Tarih belirlenemedi",
-    "Could not move \"{file}\", target exists" : "\"{file}\" taşınamadı, hedef zaten var",
-    "Could not move \"{file}\"" : "\"{file}\" taşınamadı",
-    "copy" : "kopya",
-    "Could not copy \"{file}\", target exists" : "\"{file}\" dosyası kopyalanamadı, hedef zaten var",
-    "Could not copy \"{file}\"" : "\"{file}\" kopyalanamadı",
-    "Copied {origin} inside {destination}" : "{origin} dosyası, {destination} içine kopyalandı",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} ve diğer {nbfiles} dosya, {destination} içine kopyalandı",
-    "{newName} already exists" : "{newName} zaten var",
-    "Could not rename \"{fileName}\", it does not exist any more" : "\"{fileName}\" yeniden adlandırılamadı, artık yok",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{targetName}\" adı \"{dir}\" klasöründe zaten var. Lütfen farklı bir ad seçin.",
-    "Could not rename \"{fileName}\"" : "\"{fileName}\" yeniden adlandırılamadı",
-    "Could not create file \"{file}\"" : "\"{file}\" dosyası oluşturulamadı",
-    "Could not create file \"{file}\" because it already exists" : "\"{file}\" dosyası zaten var olduğundan oluşturulamadı",
-    "Could not create folder \"{dir}\" because it already exists" : "\"{dir}\" klasörü zaten var olduğundan oluşturulamadı",
-    "Could not fetch file details \"{file}\"" : "\"{file}\" dosyasının ayrıntıları alınamadı",
-    "Error deleting file \"{fileName}\"." : "\"{fileName}\" dosyası silinirken sorun çıktı.",
-    "No search results in other folders for {tag}{filter}{endtag}" : "{tag}{filter}{endtag} için diğer klasörlerde herhangi bir arama sonucu yok",
-    "Enter more than two characters to search in other folders" : "Diğer klasörlerde aramak için iki karakterden fazla yazın",
-    "_%n folder_::_%n folders_" : ["%n klasör","%n klasör"],
-    "_%n file_::_%n files_" : ["%n dosya","%n dosya"],
-    "{dirs} and {files}" : "{dirs} ve {files}",
-    "_including %n hidden_::_including %n hidden_" : ["%n gizli ile birlikte","%n gizli ile birlikte"],
-    "You do not have permission to upload or create files here" : "Buraya dosya yükleme ya da ekleme izniniz yok",
-    "_Uploading %n file_::_Uploading %n files_" : ["%n dosya yükleniyor","%n dosya yükleniyor"],
-    "New" : "Yeni",
-    "New file/folder menu" : "Yeni dosya/klasör menüsü",
-    "Select file range" : "Dosya aralığını seçin",
-    "{used}%" : "%{used}",
-    "{used} used" : "{used} kullanılmış",
-    "\"{name}\" is an invalid file name." : "\"{name}\" geçersiz bir dosya adı.",
-    "File name cannot be empty." : "Dosya adı boş olamaz.",
-    "\"/\" is not allowed inside a file name." : "Dosya adında \"/\" kullanılamaz.",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\" dosya türüne izin verilmiyor",
-    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "{owner} için boş depolama alanı kalmadı. Artık dosyalar güncellenmeyecek ya da eşitlenmeyecek!",
-    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "\"{mountPoint}\" grup klasöründe boş alan kalmadı. Artık güncellenemeyecek ya da eşitlenemeyecek!",
-    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "\"{mountPoint}\" dış depolamasında boş alan kalmadı. Artık güncellenemeyecek ya da eşitlenemeyecek!",
-    "Your storage is full, files cannot be updated or synced anymore!" : "Boş depolama alanınız kalmadı. Artık dosyalar güncellenmeyecek ya da eşitlenmeyecek!",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "{owner} boş depolama alanı bitmek üzere ({usedSpacePercent}%).",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "\"{mountPoint}\" grup klasöründeki boş alan bitmek üzere ({usedSpacePercent}%).",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "\"{mountPoint}\" dış depolamasındaki boş alan bitmek üzere ({usedSpacePercent}%).",
-    "Your storage is almost full ({usedSpacePercent}%)." : "Boş depolama alanınız bitmek üzere ({usedSpacePercent}%).",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["\"{filter}\" ile eşleşiyor","\"{filter}\" ile eşleşiyor"],
-    "Direct link was copied (only works for people who have access to this file/folder)" : "Doğrudan bağlantı kopyalandı (yalnızca bu dosya ya da klasöre erişim izni olan kişiler kullanabilir)",
-    "Path" : "Yol",
-    "_%n byte_::_%n bytes_" : ["%n bayt","%n bayt"],
-    "Favorited" : "Sık kullanılanlara eklendi",
-    "Copy direct link (only works for people who have access to this file/folder)" : "Doğrudan bağlantıyı kopyala (yalnızca bu dosya ya da klasöre erişim izni olan kişiler için)",
-    "Upload file" : "Dosya yükle",
-    "Not favorited" : "Sık kullanılanlarda değil",
-    "An error occurred while trying to update the tags" : "Etiketler güncellenirken bir sorun çıktı",
-    "You don't have permission to upload or create files here." : "Buraya dosya yükleme ya da ekleme izniniz yok.",
-    "Storage informations" : "Depolama bilgileri",
-    "Choose file" : "Dosya seçin",
-    "Go to the previous folder" : "Önceki klasöre git",
-    "Open the files app settings" : "Dosyalar uygulaması ayarlarını aç",
-    "Unable to change the favourite state of the file" : "Dosyanın sık kullanılan durumu değiştirilemedi",
-    "Edit file locally" : "Dosyayı yerel olarak düzenle",
-    "Edit online" : "Çevrim içi düzenle",
-    "Create new templates folder" : "Yeni kalıp klasörü oluştur",
-    "List of favorites files and folders." : "Sık kullanılan dosya ve klasör listesi.",
-    "Personal Files" : "Kişisel dosyalar",
-    "Text file" : "Metin dosyası",
-    "New text file.txt" : "Yeni metin dosyası.txt",
-    "Favored" : "Sık kullanılanlara eklenmiş",
-    "Favor" : "Sık kullanılanlara ekle",
-    "Not favored" : "Sık kullanılanlara eklenmemiş",
-    "Submitting fields…" : "Alanlar gönderiliyor…",
-    "Filter filenames…" : "Dosya adlarını süz…",
-    "{count} files could not be converted" : "{count} dosya dönüştürülemedi",
-    "{count} files successfully converted" : "{count} dosya dönüştürüldü"
+    "Moving \"{source}\" to \"{destination}\" …" : "\"{source}\", \"{destination}\" hedefine taşınıyor…",
+    "Copying \"{source}\" to \"{destination}\" …" : "\"{source}\", \"{destination}\" hedefine kopyalanıyor…",
+    "Move cancelled" : "Taşıma iptal edildi",
+    "Cancelled move or copy of \"{filename}\"." : "\"{filename}\" dosyasını taşıma ya da kopyalama işlemi iptal edildi",
+    "Cancelled move or copy operation" : "Taşıma ya da kopyalama işlemi iptal edildi",
+    "Open details" : "Ayrıntıları aç",
+    "Photos and images" : "Fotoğraflar ve görseller",
+    "New folder creation cancelled" : "Yeni klasör oluşturma işlemi iptal edildi",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Bu klasör yazılabilir değil. Lütfen günlük kayıtlarına bakın ya da BT yöneticiniz ile görüşün",
+    "All folders" : "Tüm klasörler",
+    "Search everywhere …" : "Her yerde ara…",
+    "Search here …" : "Burada ara…",
+    "Preparing …" : "Hazırlanıyor…"
 },
 "nplurals=2; plural=(n > 1);");
