@@ -13,9 +13,11 @@ OC.L10N.register(
     "_1 remaining download allowed_::_{count} remaining downloads allowed_" : ["1 íoslódáil fágtha ceadaithe","{count} íosluchtú fágtha ceadaithe","{count} íosluchtú fágtha ceadaithe","{count} íosluchtú fágtha ceadaithe","{count} íosluchtú fágtha ceadaithe"],
     "Download limit" : "Teorainn a íoslódáil",
     "Configure the default download limit for external shares." : "Cumraigh an teorainn íoslódála réamhshocraithe do scaireanna seachtracha.",
+    "Default download limit for external shares" : "Teorainn íoslódála réamhshocraithe le haghaidh scaireanna seachtracha",
     "Set default download limit" : "Socraigh teorainn íoslódála réamhshocraithe",
     "You have reached the maximum amount of downloads allowed" : "Tá an t-uasmhéid íoslódálacha ceadaithe agat",
     "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "Tá líon teoranta íoslódálacha ag an sciar seo. An bhfuil tú cinnte gur mhaith leat íosluchtú nua a spreagadh?",
-    "Failed to set default download limit" : "Theip ar an teorainn íoslódála réamhshocraithe a shocrú"
+    "Failed to set default download limit" : "Theip ar an teorainn íoslódála réamhshocraithe a shocrú",
+    "Failed to remove default download limit" : "Theip ar an teorainn íoslódála réamhshocraithe a bhaint"
 },
 "nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
