@@ -20,6 +20,7 @@ use Sabre\DAV\Server;
 use Sabre\DAV\ServerPlugin;
 use Sabre\HTTP\RequestInterface;
 use Sabre\HTTP\ResponseInterface;
+use Sabre\Uri;
 
 class TrashbinPlugin extends ServerPlugin {
 	public const TRASHBIN_FILENAME = '{http://nextcloud.org/ns}trashbin-filename';
@@ -104,8 +105,8 @@ class TrashbinPlugin extends ServerPlugin {
 			return $node->getFileId();
 		});
 
-		$propFind->handle(FilesPlugin::HAS_PREVIEW_PROPERTYNAME, function () use ($node) {
-			return $this->previewManager->isAvailable($node->getFileInfo());
+		$propFind->handle(FilesPlugin::HAS_PREVIEW_PROPERTYNAME, function () use ($node): string {
+			return $this->previewManager->isAvailable($node->getFileInfo()) ? 'true' : 'false';
 		});
 
 		$propFind->handle(FilesPlugin::MOUNT_TYPE_PROPERTYNAME, function () {
@@ -146,7 +147,8 @@ class TrashbinPlugin extends ServerPlugin {
 	public function beforeMove(string $sourcePath, string $destinationPath): bool {
 		try {
 			$node = $this->server->tree->getNodeForPath($sourcePath);
-			$destinationNodeParent = $this->server->tree->getNodeForPath(dirname($destinationPath));
+			[$destinationDir, ] = Uri\split($destinationPath);
+			$destinationNodeParent = $this->server->tree->getNodeForPath($destinationDir);
 		} catch (\Sabre\DAV\Exception $e) {
 			\OCP\Server::get(LoggerInterface::class)
 				->error($e->getMessage(), ['app' => 'files_trashbin', 'exception' => $e]);
@@ -164,9 +166,9 @@ class TrashbinPlugin extends ServerPlugin {
 		}
 		$restoreFolder = dirname($fileInfo->getOriginalLocation());
 		$freeSpace = $this->view->free_space($restoreFolder);
-		if ($freeSpace === FileInfo::SPACE_NOT_COMPUTED ||
-			$freeSpace === FileInfo::SPACE_UNKNOWN ||
-			$freeSpace === FileInfo::SPACE_UNLIMITED) {
+		if ($freeSpace === FileInfo::SPACE_NOT_COMPUTED
+			|| $freeSpace === FileInfo::SPACE_UNKNOWN
+			|| $freeSpace === FileInfo::SPACE_UNLIMITED) {
 			return true;
 		}
 		$filesize = $fileInfo->getSize();
