@@ -70,7 +70,7 @@ class TrashItem implements ITrashItem {
 		return $this->fileInfo->getPath();
 	}
 
-	public function getMimetype() {
+	public function getMimetype(): string {
 		return $this->fileInfo->getMimetype();
 	}
 
