@@ -5,7 +5,7 @@ OC.L10N.register(
     "Nextcloud announcement" : "Nextcloud-Ankündigung",
     "Read more" : "Weiterlesen",
     "Disable announcements" : "Ankündigungen ausschalten",
-    "(These announcements are only shown to administrators)" : "(Diese Ankündigungen werden nur Administratoren angezeigt)",
+    "(These announcements are only shown to administrators)" : "(Diese Ankündigungen werden nur der Administration angezeigt)",
     "Nextcloud announcements brings the latest news of Nextcloud into your notifications" : "\"Nextcloud announcements\" zeigt Nextcloud-Neuigkeiten in den Benachrichtigungen an"
 },
 "nplurals=2; plural=(n != 1);");
