@@ -1,4 +1,5 @@
 <?php
+
 /**
  * SPDX-FileCopyrightText: 2016 Nextcloud GmbH and Nextcloud contributors
  * SPDX-License-Identifier: AGPL-3.0-or-later
@@ -18,36 +19,25 @@ use OCP\IGroupManager;
 use OCP\IUser;
 use OCP\Notification\IManager as INotificationManager;
 use phpseclib\File\X509;
+use Psr\Log\LoggerInterface;
 
 class Crawler extends TimedJob {
 	public const FEED_URL = 'https://pushfeed.nextcloud.com/feed';
 
-	/** @var string */
-	protected $appName;
-	/** @var IConfig */
-	protected $config;
-	/** @var IGroupManager */
-	protected $groupManager;
-	/** @var INotificationManager */
-	protected $notificationManager;
-	/** @var IClientService */
-	protected $clientService;
 
 	/** @var array<array-key, bool> */
 	protected $notifyUsers = [];
 
-	public function __construct(string $appName,
+	public function __construct(
 		ITimeFactory $time,
-		IConfig $config,
-		IGroupManager $groupManager,
-		INotificationManager $notificationManager,
-		IClientService $clientService) {
+		protected string $appName,
+		protected IConfig $config,
+		protected IGroupManager $groupManager,
+		protected INotificationManager $notificationManager,
+		protected IClientService $clientService,
+		protected LoggerInterface $logger,
+	) {
 		parent::__construct($time);
-		$this->appName = $appName;
-		$this->config = $config;
-		$this->groupManager = $groupManager;
-		$this->notificationManager = $notificationManager;
-		$this->clientService = $clientService;
 
 		// Run once per day
 		$interval = 24 * 60 * 60;
@@ -61,6 +51,10 @@ class Crawler extends TimedJob {
 
 
 	protected function run(mixed $argument): void {
+		if ($this->config->getSystemValueBool('has_internet_connection', true) === false) {
+			$this->logger->info('This instance does not have Internet connection to access the Nextcloud feed platform.', ['app' => $this->appName]);
+			return;
+		}
 		try {
 			$feedBody = $this->loadFeed();
 			$rss = simplexml_load_string($feedBody);
@@ -123,8 +117,7 @@ class Crawler extends TimedJob {
 	 */
 	protected function loadFeed() {
 		$signature = $this->readFile('.signature');
-
-		if (!$signature) {
+		if ($signature === '' || $signature === null) {
 			throw new \Exception('Invalid signature fetched from the server');
 		}
 
@@ -160,6 +153,9 @@ class Crawler extends TimedJob {
 		}
 
 		$feedBody = $this->readFile('.rss');
+		if ($feedBody === null) {
+			throw new \Exception('Feed body is empty');
+		}
 
 		// Check if the signature actually matches the downloaded content
 		$certificate = openssl_get_publickey(file_get_contents(__DIR__ . '/../../appinfo/certificate.crt'));
@@ -179,24 +175,27 @@ class Crawler extends TimedJob {
 	}
 
 	/**
-	 * @param string $file
-	 * @return string
 	 * @throws \Exception
 	 */
-	protected function readFile($file) {
+	protected function readFile(string $file): ?string {
 		$client = $this->clientService->newClient();
 		$response = $client->get(self::FEED_URL . $file);
 		if ($response->getStatusCode() !== Http::STATUS_OK) {
 			throw new \Exception('Could not load file');
 		}
-		return $response->getBody();
+		$body = $response->getBody();
+		if (is_resource($body)) {
+			$content = stream_get_contents($body);
+			return $content !== false ? $content : null;
+		}
+		return $body;
 	}
 
 	/**
 	 * Get the list of users to notify
 	 * @return string[]
 	 */
-	protected function getUsersToNotify() {
+	protected function getUsersToNotify(): array {
 		if (!empty($this->notifyUsers)) {
 			return array_keys($this->notifyUsers);
 		}
