@@ -21,6 +21,9 @@ OC.L10N.register(
     "Mark selection as favorite" : "تحديد المفضلة",
     "Add selection to favorites" : "إضافة ما تمّ تحديده إلى المفضلة",
     "Remove selection from favorites" : "حذف ما تمّ تحديده من المفضلة",
+    "This name is already in use." : "هذا الاسم سبق استعماله.",
+    "\"{char}\" is not allowed inside a filename." : "\"{char}\" غير مسموح به في اسم الملف.",
+    "Invalid filename." : "اسم ملف غير صحيح.",
     "Name of the album" : "اسم الألبوم",
     "Location of the album" : "موقع الألبوم",
     "Back" : "عودة",
@@ -39,8 +42,6 @@ OC.L10N.register(
     "Add people or groups who can edit your album" : "إضِف الأشخاص أو المجموعات الذين يحق لهم تعديل ألبومك",
     "Search people or groups" : "البحث عن أشخاص أو مجموعات",
     "No recommendations. Start typing." : "لا توجد توصيات. ابدأ بالكتابة.",
-    "Group" : "مجموعة",
-    "Remove {collaboratorLabel} from the collaborators list" : "حذف {collaboratorLabel} من قائمة المتعاونين",
     "Copy the public link" : "إنسَخ الرابط العمومي",
     "Public link copied!" : "تمّ نسخ الرابط العمومي",
     "Copy public link" : "نسخ الرابط العام",
@@ -67,22 +68,18 @@ OC.L10N.register(
     "The destination folder is owned by {owner}" : "المجلد الوجهة يملكه {owner}",
     "There are no photos or videos yet!" : "لا توجد أي صور أو مقاطع فيديو حتى الآن!",
     "_{years} year ago_::_{years} years ago_" : ["سنوات {years} مضت","سنة {years} مضت","سنوات {years} مضت","سنوات {years} مضت","سنوات {years} مضت","سنوات {years} مضت"],
-    "Enable squared photos view" : "تفعيل عرض الصور المربعة",
     "Delete source directory" : "إحذف الدليل المصدر",
     "Pick folder" : "إختَر مُجلّداً",
     "Select a source folder for your media" : "إختَر المجلد المصدر لوسائطك ",
+    "Media folders" : "مجلدات الوسائط",
+    "Choose the folders from where photos and videos are shown." : "إختَر المجلد الذي تُعرض منه الصور و المقاطع",
     "All folders" : "كل المجلدات",
     "Add a Photos source for the timelines" : "إضافة مصادر الصور إلى الخطوط الزمنية",
     "Add folder" : "إضافة مجلد",
-    "Select the default upload location for your media" : "إختَر موضع الرفع التلقائي للوسائط",
     "Home" : "الرئيسية",
-    "Choose default Photos upload and Albums location" : "اختر افتراضي رفع الصور وموقع الألبومات",
-    "Choose a different folder" : "إختَر مجلداً مختلفاً",
-    "View" : "عرض",
-    "Media folders" : "مجلدات الوسائط",
-    "Choose the folders from where photos and videos are shown." : "إختَر المجلد الذي تُعرض منه الصور و المقاطع",
+    "Select the default upload location for your media" : "إختَر موضع الرفع التلقائي للوسائط",
     "Upload folder" : "مجلد الرفع",
-    "Choose the folder where photos and albums are uploaded to." : "إختَر المجلد الذي تُرفع إليه الصور و الألبومات",
+    "General" : "عامٌّ",
     "_%n photo_::_%n photos_" : ["%n صور","%n صورة","%n صور","%n صور","%n صور","%n صور"],
     "Unselect all" : "إلغاء الاختيار للكل",
     "Add photos to this album" : "إضِف صوراً إلى هذا الألبوم",
@@ -114,7 +111,7 @@ OC.L10N.register(
     "This might take some time depending on the size of your photo library." : "يمكن أن يستغرق هذا بعض الوقت و ذلك بحسب حجم مكتبة الصور",
     "Recognized people will show up here" : "الأشخاص الذين تمّ التعرُّف عليهم سيظهرون هنا",
     "This folder does not exist" : "هذا المجلد غير موجود",
-    "Loading folders …" : "تحميل مجلدات ...",
+    "Loading folders…" : "جارٍ تحميل المجلدات…",
     "No photos in here" : "لا توجد صور هنا",
     "Taken on {date} at {time}" : "أُخِذت يوم {date} الساعة {time}",
     "This place does not have any photos or videos yet!" : "هذا المكان ليس له أي صور أو مقاطع فيديو حتى الآن!",
@@ -149,6 +146,8 @@ OC.L10N.register(
     "Failed to delete {fileBaseName}" : "تعذّر حذف {fileBaseName}",
     "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "تعذر تغيير تسمية {currentCollectionFileName} إلى {newCollectionFileName}",
     "Failed to delete {collectionFileName}" : "تعذّر حذف {collectionFileName}",
+    "Cancel" : "Cancel",
+    "Confirm" : "تأكيد",
     "Failed to rename {oldName} to {faceName}" : "تعذر تغيير تسمية {oldName} إلى {faceName}",
     "Failed to delete {faceName}" : "تعذّر حذف{faceName}",
     "Failed to delete {fileId}" : "تعذّر حذف {fileId}",
@@ -156,9 +155,16 @@ OC.L10N.register(
     "Failed to set favorite state for {fileId}" : "تعذّر تعيين الحالة المُفضَّلة لـ{fileId}",
     "Failed to set favorite state for {fileName}" : "تعذّر تعيين الحالة المُفضَّلة لـ{fileName}",
     "Could not load photos folder" : "تعذّر رفع مجلد الصِّور",
+    "Group" : "مجموعة",
+    "Remove {collaboratorLabel} from the collaborators list" : "حذف {collaboratorLabel} من قائمة المتعاونين",
     "Back to {folder}" : "العودة إلى {folder} ",
     "Share this folder" : "مشاركة هذا المجلد",
-    "One of the source folders does not exists" : "أحد المجلدات المصدرية غير موجود",
+    "Enable squared photos view" : "تفعيل عرض الصور المربعة",
+    "Choose default Photos upload and Albums location" : "اختر افتراضي رفع الصور وموقع الألبومات",
+    "Choose a different folder" : "إختَر مجلداً مختلفاً",
+    "View" : "عرض",
+    "Choose the folder where photos and albums are uploaded to." : "إختَر المجلد الذي تُرفع إليه الصور و الألبومات",
+    "Loading folders …" : "تحميل مجلدات ...",
     "Add" : "إضافة"
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
