@@ -39,8 +39,6 @@ OC.L10N.register(
     "Add people or groups who can edit your album" : "Amiesta a persones u grupos que puedan editar l'álbum",
     "Search people or groups" : "Buscar persones o grupos",
     "No recommendations. Start typing." : "Nun hai nenguna recomendación. Comienza a escribir.",
-    "Group" : "Grupu",
-    "Remove {collaboratorLabel} from the collaborators list" : "Quitar «{collaboratorLabel}» de la llista de collaboradores",
     "Copy the public link" : "Copiar l'enllaz públicu",
     "Public link copied!" : "¡Copióse l'enllaz públicu!",
     "Copy public link" : "Copiar l'enllaz públicu",
@@ -52,36 +50,31 @@ OC.L10N.register(
     "No picture for this day" : "Nun hai nenguna semeya pa esti día",
     "Picture taken on this day will show up here." : "Equí apaecen les semeyes feches nesti día.",
     "More photos from this day" : "Más semeyes d'esti día",
+    "_%n photos_::_%n photos_" : ["%n semeya","%n semeyes"],
     "_%n unassigned photo_::_%n unassigned photos_" : ["%n semeya ensin asignar","%n semeyes ensin asignar"],
     "Favorite" : "Meter en Favoritos",
     "Favorite image, open the full size \"{name}\" image" : "Imaxe favorita, abrir la imaxe «{name}» a tamañu completu",
     "Open the full size \"{name}\" image" : "Abrir la imaxe «{name}» a tamañu completu",
     "Select image {imageName}" : "Seleicionar la imaxe «{imageName}»",
     "Open the \"{name}\" folder" : "Abrir la carpeta «{name}»",
-    "Back to {folder}" : "Volver a «{folder}»",
     "Go back" : "Dir p'atrás",
-    "Share this folder" : "Compartir esta carpeta",
     "Dates" : "Dates",
     "Jump to specific date in list" : "Saltar a una data específica de la llista",
     "Jump to {date}" : "Saltar a «{date}»",
     "Add to {destination}" : "Amestar a {destination}",
     "There are no photos or videos yet!" : "¡Nun hai nenguna semeya nin nengún videu!",
     "_{years} year ago_::_{years} years ago_" : ["hai {years} añu","hai {years} años"],
-    "Enable squared photos view" : "Activar la vista de semeyes en cuadráu",
     "Delete source directory" : "Desaniciar el direutoriu d'orixe",
     "Select a source folder for your media" : "Seleiciona una carpeta d'orixe pa los elementos multimedia",
+    "Media folders" : "Carpetes multimedia",
+    "Choose the folders from where photos and videos are shown." : "Escueyi les carpetes de les que s'amuesen les semeyes y vídeos.",
     "All folders" : "Toles carpetes",
     "Add a Photos source for the timelines" : "Amestar una fonte de semeyes pa les llinies de tiempu",
     "Add folder" : "Amestar una carpeta",
-    "Select the default upload location for your media" : "Seleiciona la llocalización de xuba predeterminada pa los elementos multimedia",
     "Home" : "Aniciu",
-    "Choose default Photos upload and Albums location" : "Escueyi la llocalización pa los álbumes y la xuba de semeyes",
-    "Choose a different folder" : "Escueyi una carpeta diferente",
-    "View" : "Ver",
-    "Media folders" : "Carpetes multimedia",
-    "Choose the folders from where photos and videos are shown." : "Escueyi les carpetes de les que s'amuesen les semeyes y vídeos.",
+    "Select the default upload location for your media" : "Seleiciona la llocalización de xuba predeterminada pa los elementos multimedia",
     "Upload folder" : "Carpeta de xuba",
-    "Choose the folder where photos and albums are uploaded to." : "Escueyu la carpeta a onde se xuben les semeyes y los álbumes.",
+    "General" : "Xeneral",
     "_%n photo_::_%n photos_" : ["%n semeya","%n semeyes"],
     "Unselect all" : "Deseleicionar too",
     "Add photos to this album" : "Amestar semeyes a esti álbum",
@@ -113,7 +106,6 @@ OC.L10N.register(
     "This might take some time depending on the size of your photo library." : "Quiciabes esta operación tarde tiempu según el tamañu de la biblioteca de semeyes.",
     "Recognized people will show up here" : "Equí apaecen les persones que se reconozan",
     "This folder does not exist" : "Esta carpeta nun esiste",
-    "Loading folders …" : "Cargando les carpetes…",
     "No photos in here" : "Equí nun hai nenguna semeya",
     "Taken on {date} at {time}" : "Fízose'l {date} a la hora {time}",
     "This place does not have any photos or videos yet!" : "¡Esti llugar nun tien nenguna semeya nin nengún videu!",
@@ -129,7 +121,6 @@ OC.L10N.register(
     "Delete selection" : "Desaniciar la seleición",
     "No photos or videos in here" : "Equí nun hai nenguna semeya nin nengún videu",
     "Unassigned faces" : "Cares ensin asignar",
-    "_%n photos_::_%n photos_" : ["%n semeya","%n semeyes"],
     "Failed to fetch collection." : "Nun se pue dir en cata de la coleición.",
     "Failed to fetch collections list." : "Nun se pue dir en cata de la llista de les coleiciones",
     "Failed to fetch faces list." : "Nun se pue dir en cata de la llista de cares",
@@ -141,10 +132,22 @@ OC.L10N.register(
     "Tagged photos" : "Semeyes etiquetaes",
     "Tagged photo {title}" : "Semeya etiqueta «{title}»",
     "{title}'s face" : "Cara de: {title}",
+    "Last week" : "La selmana anterior",
     "{startDate} to {endDate}" : "{startDate} hasta'l {endDate}",
     "Details" : "Detalles",
+    "Cancel" : "Cancel",
+    "Confirm" : "Confirmar",
     "Could not load photos folder" : "Nun se puen cargar la carpeta de semeyes",
-    "One of the source folders does not exists" : "Nun esiste una de les carpetes d'orixe",
+    "Group" : "Grupu",
+    "Remove {collaboratorLabel} from the collaborators list" : "Quitar «{collaboratorLabel}» de la llista de collaboradores",
+    "Back to {folder}" : "Volver a «{folder}»",
+    "Share this folder" : "Compartir esta carpeta",
+    "Enable squared photos view" : "Activar la vista de semeyes en cuadráu",
+    "Choose default Photos upload and Albums location" : "Escueyi la llocalización pa los álbumes y la xuba de semeyes",
+    "Choose a different folder" : "Escueyi una carpeta diferente",
+    "View" : "Ver",
+    "Choose the folder where photos and albums are uploaded to." : "Escueyu la carpeta a onde se xuben les semeyes y los álbumes.",
+    "Loading folders …" : "Cargando les carpetes…",
     "Add" : "Amestar"
 },
 "nplurals=2; plural=(n != 1);");
