@@ -21,6 +21,9 @@ OC.L10N.register(
     "Mark selection as favorite" : "Imposta selezione come preferiti",
     "Add selection to favorites" : "Aggiungi selezione ai preferiti",
     "Remove selection from favorites" : "Rimuovi selezione dai preferiti",
+    "This name is already in use." : "Questo nome è già utilizzato.",
+    "\"{char}\" is not allowed inside a filename." : "\"{char}\" non è consentito in un nome di file.",
+    "Invalid filename." : "Nome di file non valido.",
     "Name of the album" : "Nome dell'album",
     "Location of the album" : "Posizione dell'album",
     "Back" : "Indietro",
@@ -39,8 +42,6 @@ OC.L10N.register(
     "Add people or groups who can edit your album" : "Aggiungi persone o gruppi che possono modificare il tuo album",
     "Search people or groups" : "Cerca persone o gruppi",
     "No recommendations. Start typing." : "Nessun consiglio. Inizia a scrivere.",
-    "Group" : "Gruppo",
-    "Remove {collaboratorLabel} from the collaborators list" : "Rimuovi {collaboratorLabel} dall'elenco dei collaboratori",
     "Copy the public link" : "Copia il collegamento pubblico",
     "Public link copied!" : "Collegamento pubblico copiato",
     "Copy public link" : "Copia collegamento pubblico",
@@ -52,15 +53,18 @@ OC.L10N.register(
     "No picture for this day" : "Non ci sono foto in questo giorno",
     "Picture taken on this day will show up here." : "Le foto di questo giorno appariranno qui.",
     "More photos from this day" : "Più foto di questo giorno",
+    "_%n photos_::_%n photos_" : ["%n foto","%n foto","%n foto"],
     "_%n unassigned photo_::_%n unassigned photos_" : ["%n foto non assegnata","%n foto non assegnate","%n foto non assegnate"],
     "Favorite" : "Preferito",
     "Favorite image, open the full size \"{name}\" image" : "Immagine preferita, apri l'immagine \"{name}\" a dimensione intera",
     "Open the full size \"{name}\" image" : "Apri l'immagine \"{name}\" a dimensione piena",
     "Select image {imageName}" : "Seleziona immagine {imageName}",
     "Open the \"{name}\" folder" : "Apri la cartella \"{name}\"",
-    "Back to {folder}" : "Torna a {folder}",
     "Go back" : "Indietro",
-    "Share this folder" : "Condividi questa cartella",
+    "Select a custom date range" : "Seleziona un intervallo di date personalizzate",
+    "Select a date range" : "Seleziona un intervallo di date",
+    "Date range" : "Intervallo di date",
+    "Select filters" : "Seleziona filtri",
     "Dates" : "Date",
     "Jump to specific date in list" : "Vai alla data specifica nella lista",
     "Jump to {date}" : "Vai a {date}",
@@ -68,22 +72,19 @@ OC.L10N.register(
     "The destination folder is owned by {owner}" : "La cartella di destinazione è di proprietà di {owner}",
     "There are no photos or videos yet!" : "Non ci sono foto o video ancora",
     "_{years} year ago_::_{years} years ago_" : ["{years} anno fa","{years} anni fa","{years} anni fa"],
-    "Enable squared photos view" : "Abilita vista foto quadrate",
+    "Squared photos view" : "Vista foto quadrate",
     "Delete source directory" : "Rimuovi la cartella sorgente",
     "Pick folder" : "Scegli cartella",
     "Select a source folder for your media" : "Seleziona una cartella sorgente per i tuoi media",
+    "Media folders" : "Cartelle dei media",
+    "Choose the folders from where photos and videos are shown." : "Scegli le cartelle da dove foto e video vengono mostrati",
     "All folders" : "Tutte le cartelle",
     "Add a Photos source for the timelines" : "Aggiungi una sorgente Foto per le timelines",
     "Add folder" : "Aggiungi cartella",
-    "Select the default upload location for your media" : "Seleziona la locazione di upload di default per i tuoi media",
     "Home" : "Home",
-    "Choose default Photos upload and Albums location" : "Scegli il percorso predefinito di caricamento di foto e album",
-    "Choose a different folder" : "Scegli una cartella diversa",
-    "View" : "Visualizza",
-    "Media folders" : "Cartelle dei media",
-    "Choose the folders from where photos and videos are shown." : "Scegli le cartelle da dove foto e video vengono mostrati",
+    "Select the default upload location for your media" : "Seleziona la locazione di upload di default per i tuoi media",
     "Upload folder" : "Cartella di upload",
-    "Choose the folder where photos and albums are uploaded to." : "Scegli la cartella dove foto ed album verranno caricati",
+    "General" : "Generale",
     "_%n photo_::_%n photos_" : ["%n foto","%n foto","%n foto"],
     "Unselect all" : "Deseleziona tutto",
     "Add photos to this album" : "Aggiungi foto a questo album",
@@ -115,7 +116,7 @@ OC.L10N.register(
     "This might take some time depending on the size of your photo library." : "Potrebbe richiedere del tempo a seconda della dimensione della raccolta di foto.",
     "Recognized people will show up here" : "Le persone riconosciute appariranno qui",
     "This folder does not exist" : "Questa cartella non esiste",
-    "Loading folders …" : "Caricamento cartelle …",
+    "Loading folders…" : "Caricamento cartelle…",
     "No photos in here" : "Nessuna foto qui",
     "Taken on {date} at {time}" : "Scattata il {date} alle {time}",
     "This place does not have any photos or videos yet!" : "Questo luogo non ha ancora foto o video!",
@@ -129,12 +130,12 @@ OC.L10N.register(
     "Photos with tags will show up here" : "Le foto con i tag saranno mostrate qui",
     "Popular tags" : "Etichette popolari",
     "All tags" : "Tutte le etichette",
+    "Create new album from filters" : "Crea un nuovo album dai filtri",
     "One of the source folders does not exist" : "Una delle cartelle di origine non esiste",
     "Add to album" : "Aggiungi all'album",
     "Delete selection" : "Elimina selezione",
     "No photos or videos in here" : "Nessuna foto o video qui",
     "Unassigned faces" : "Volti non assegnati",
-    "_%n photos_::_%n photos_" : ["%n foto","%n foto","%n foto"],
     "Failed to fetch collection." : "Recupero della categoria non riuscito.",
     "Failed to fetch collections list." : "Recupero della lista di collezioni non riuscito.",
     "Failed to fetch faces list." : "Recupero della lista di volti non riuscito.",
@@ -147,8 +148,24 @@ OC.L10N.register(
     "Tagged photos" : "Foto con tag",
     "Tagged photo {title}" : "Foto etichettata {title}",
     "{title}'s face" : "Volto di {title}",
+    "Last week" : "Ultima settimana",
+    "Last Month" : "Il mese scorso",
+    "Custom…" : "Personalizzato…",
     "{startDate} to {endDate}" : "{startDate} a {endDate}",
     "Details" : "Dettagli",
+    "Failed to add {fileBaseName} to collection {collectionFileName}" : "Impossibile aggiungere {fileBaseName}alla raccolta {collectionFileName}",
+    "Failed to delete {fileBaseName}" : "Impossibile eliminare {fileBaseName}",
+    "Failed to create {collectionFileName}" : "Impossibile creare {collectionFileName}",
+    "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "Impossibile rinominare {currentCollectionFileName} in {newCollectionFileName}",
+    "Failed to update properties of {collectionFileName} with {properties}" : "Impossibile aggiornare le proprietà di {collectionFileName} con {properties}",
+    "Delete collection" : "Elimina collezione",
+    "Leave shared album" : "Lascia gli album condivisi",
+    "Are you sure you want to delete {collectionName}? This action cannot be undone." : "Vuoi veramente eliminare {collectionName}? Questa azione non può essere annullata.",
+    "Failed to delete {collectionFileName}" : "Impossibile eliminare {collectionFileName}",
+    "Cancel" : "Cancel",
+    "Confirm" : "Conferma",
+    "Failed to move {fileBaseName} to person {faceName}" : "Impossibile spostare {fileBaseName} alla persona{faceName}",
+    "Failed to remove {fileBaseName}" : "Impossibile rimuovere {fileBaseName}",
     "Failed to rename {oldName} to {faceName}" : "Impossibile rinominare {oldName} in {faceName}",
     "Failed to delete {faceName}" : "Impossibile eliminare {faceName}",
     "Failed to delete {fileId}" : "Impossibile eliminare {fileId}",
@@ -156,7 +173,16 @@ OC.L10N.register(
     "Failed to set favorite state for {fileId}" : "Impossibile impostare lo stato preferito per {fileId}",
     "Failed to set favorite state for {fileName}" : "Impossibile impostare lo stato preferito per {fileName}",
     "Could not load photos folder" : "Non è stato possibile caricare la cartella foto",
-    "One of the source folders does not exists" : "Una delle cartelle sorgenti non esiste",
+    "Group" : "Gruppo",
+    "Remove {collaboratorLabel} from the collaborators list" : "Rimuovi {collaboratorLabel} dall'elenco dei collaboratori",
+    "Back to {folder}" : "Torna a {folder}",
+    "Share this folder" : "Condividi questa cartella",
+    "Enable squared photos view" : "Abilita vista foto quadrate",
+    "Choose default Photos upload and Albums location" : "Scegli il percorso predefinito di caricamento di foto e album",
+    "Choose a different folder" : "Scegli una cartella diversa",
+    "View" : "Visualizza",
+    "Choose the folder where photos and albums are uploaded to." : "Scegli la cartella dove foto ed album verranno caricati",
+    "Loading folders …" : "Caricamento cartelle …",
     "Add" : "Aggiungi"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
