@@ -21,6 +21,9 @@ OC.L10N.register(
     "Mark selection as favorite" : "Merk utvalget som favoritt",
     "Add selection to favorites" : "Legg til utvalg i favoritter",
     "Remove selection from favorites" : "Fjern utvalg fra favoritter",
+    "This name is already in use." : "Navnet er allerede i bruk.",
+    "\"{char}\" is not allowed inside a filename." : "\"{char}\" er ikke tillatt i et filnavn.",
+    "Invalid filename." : "Ugyldig filnavn.",
     "Name of the album" : "Navn på albumet",
     "Location of the album" : "Plassering av albumet",
     "Back" : "Tilbake",
@@ -64,21 +67,17 @@ OC.L10N.register(
     "Add to {destination}" : "Legg til i {destination}",
     "There are no photos or videos yet!" : "Det er ingen bilder eller videoer ennå!",
     "_{years} year ago_::_{years} years ago_" : ["{years} år siden","{years} år siden"],
-    "Enable squared photos view" : "Aktiver visning med kvadratiske bilder",
     "Delete source directory" : "Slett kildekatalog",
     "Select a source folder for your media" : "Velg en kildemappe for mediene dine",
+    "Media folders" : "Mediemapper",
+    "Choose the folders from where photos and videos are shown." : "Velg mappene der bilder og videoer vises.",
     "All folders" : "Alle mapper",
     "Add a Photos source for the timelines" : "Legg til en fotokilde for tidslinjene",
     "Add folder" : "Legg til mappe",
-    "Select the default upload location for your media" : "Velg standard opplastingssted for mediene dine",
     "Home" : "Hjem",
-    "Choose default Photos upload and Albums location" : "Velg standard bildeopplasting og albumplassering",
-    "Choose a different folder" : "Velg en annen mappe",
-    "View" : "Vis",
-    "Media folders" : "Mediemapper",
-    "Choose the folders from where photos and videos are shown." : "Velg mappene der bilder og videoer vises.",
+    "Select the default upload location for your media" : "Velg standard opplastingssted for mediene dine",
     "Upload folder" : "Opplastingsmappe",
-    "Choose the folder where photos and albums are uploaded to." : "Velg mappen der bilder og album lastes opp.",
+    "General" : "Generell",
     "_%n photo_::_%n photos_" : ["%n bilde","%n bilder"],
     "Unselect all" : "Fravelg alle",
     "Add photos to this album" : "Legg til bilder i dette albumet",
@@ -141,13 +140,19 @@ OC.L10N.register(
     "Last week" : "Forrige uke",
     "{startDate} to {endDate}" : "{startDate} til {endDate}",
     "Details" : "Detaljer",
+    "Cancel" : "Cancel",
+    "Confirm" : "Bekreft",
     "Could not load photos folder" : "Kunne ikke laste bildemappen",
     "Group" : "Gruppe",
     "Remove {collaboratorLabel} from the collaborators list" : "Fjern {collaboratorLabel} fra samarbeidspartnerlisten",
     "Back to {folder}" : "Tilbake til {folder}",
     "Share this folder" : "Del denne mappen",
+    "Enable squared photos view" : "Aktiver visning med kvadratiske bilder",
+    "Choose default Photos upload and Albums location" : "Velg standard bildeopplasting og albumplassering",
+    "Choose a different folder" : "Velg en annen mappe",
+    "View" : "Vis",
+    "Choose the folder where photos and albums are uploaded to." : "Velg mappen der bilder og album lastes opp.",
     "Loading folders …" : "Laster inn mapper…",
-    "One of the source folders does not exists" : "En av kildemappene finnes ikke",
     "Add" : "Legg til"
 },
 "nplurals=2; plural=(n != 1);");
