@@ -21,6 +21,9 @@ OC.L10N.register(
     "Mark selection as favorite" : "Oznacz wybrane jako ulubione",
     "Add selection to favorites" : "Dodaj wybrane do ulubionych",
     "Remove selection from favorites" : "Usuń wybrane z ulubionych",
+    "This name is already in use." : "Ta nazwa jest już używana.",
+    "\"{char}\" is not allowed inside a filename." : "„{char}” nie jest dozwolone w nazwie pliku.",
+    "Invalid filename." : "Nieprawidłowa nazwa pliku.",
     "Name of the album" : "Nazwa albumu",
     "Location of the album" : "Lokalizacja albumu",
     "Back" : "Poprzednia",
@@ -69,22 +72,18 @@ OC.L10N.register(
     "The destination folder is owned by {owner}" : "Katalog docelowy jest własnością {owner}",
     "There are no photos or videos yet!" : "Nie ma jeszcze zdjęć ani filmów!",
     "_{years} year ago_::_{years} years ago_" : ["{years} rok temu","{years} lata temu","{years} lat temu","{years} lat temu"],
-    "Enable squared photos view" : "Włącz zdjęcia w widoku kwadratowym",
     "Delete source directory" : "Usuń katalog źródłowy",
     "Pick folder" : "Wybierz katalog",
     "Select a source folder for your media" : "Wybierz katalog źródłowy dla multimediów",
+    "Media folders" : "Katalogi multimediów",
+    "Choose the folders from where photos and videos are shown." : "Wybierz katalogi, z których będą wyświetlane zdjęcia i filmy.",
     "All folders" : "Wszystkie katalogi",
     "Add a Photos source for the timelines" : "Dodaj źródło zdjęć do osi czasu",
     "Add folder" : "Dodaj katalog",
-    "Select the default upload location for your media" : "Wybierz domyślną lokalizację przesyłania multimediów",
     "Home" : "Strona główna",
-    "Choose default Photos upload and Albums location" : "Wybierz domyślną lokalizację wysyłania zdjęć i albumów",
-    "Choose a different folder" : "Wybierz inny katalog",
-    "View" : "Podgląd",
-    "Media folders" : "Katalogi multimediów",
-    "Choose the folders from where photos and videos are shown." : "Wybierz katalogi, z których będą wyświetlane zdjęcia i filmy.",
+    "Select the default upload location for your media" : "Wybierz domyślną lokalizację przesyłania multimediów",
     "Upload folder" : "Prześlij katalog",
-    "Choose the folder where photos and albums are uploaded to." : "Wybierz katalog, do którego przesyłane są zdjęcia i albumy.",
+    "General" : "Ogólne",
     "_%n photo_::_%n photos_" : ["%n zdjęcie","%n zdjęcia","%n zdjęć","%n zdjęć"],
     "Unselect all" : "Odznacz wszystko",
     "Add photos to this album" : "Dodaj zdjęcia do tego albumu",
@@ -159,6 +158,8 @@ OC.L10N.register(
     "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "Nie udało się zmienić nazwy {currentCollectionFileName} na {newCollectionFileName}",
     "Failed to update properties of {collectionFileName} with {properties}" : "Nie udało się zaktualizować właściwości {collectionFileName} o {properties}",
     "Failed to delete {collectionFileName}" : "Nie udało się usunąć {collectionFileName}",
+    "Cancel" : "Anuluj",
+    "Confirm" : "Potwierdź",
     "Failed to move {fileBaseName} to person {faceName}" : "Nie udało się przenieść {fileBaseName} do osoby {faceName}",
     "Failed to remove {fileBaseName}" : "Nie udało się usunąć {fileBaseName}",
     "Failed to rename {oldName} to {faceName}" : "Nie udało się zmienić nazwy {oldName} na {faceName}",
@@ -172,8 +173,12 @@ OC.L10N.register(
     "Remove {collaboratorLabel} from the collaborators list" : "Usuń {collaboratorLabel} z listy współpracowników",
     "Back to {folder}" : "Powrót do {folder}",
     "Share this folder" : "Udostępnij ten katalog",
+    "Enable squared photos view" : "Włącz zdjęcia w widoku kwadratowym",
+    "Choose default Photos upload and Albums location" : "Wybierz domyślną lokalizację wysyłania zdjęć i albumów",
+    "Choose a different folder" : "Wybierz inny katalog",
+    "View" : "Podgląd",
+    "Choose the folder where photos and albums are uploaded to." : "Wybierz katalog, do którego przesyłane są zdjęcia i albumy.",
     "Loading folders …" : "Wczytywanie katalogów …",
-    "One of the source folders does not exists" : "Jeden z katalogów źródłowych nie istnieje",
     "Add" : "Dodaj"
 },
 "nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
