@@ -3,6 +3,7 @@ OC.L10N.register(
     {
     "Public link" : "Javna povezava",
     "Photos" : "Fotografije",
+    "On This Day" : "Na današnji dan",
     "Your memories under your control" : "Spomini pod vašim nadzorom",
     "All media" : "Vsi viri",
     "Videos" : "Video posnetki",
@@ -20,6 +21,9 @@ OC.L10N.register(
     "Mark selection as favorite" : "Označi izbor kot priljubljene",
     "Add selection to favorites" : "Dodaj izbor med priljubljene",
     "Remove selection from favorites" : "Odstrani izbor iz priljubljenih",
+    "This name is already in use." : "Vpisano uporabniško ime je že v uporabi",
+    "\"{char}\" is not allowed inside a filename." : "Znak \"{char}\" ni dovoljen v imenu datotek.",
+    "Invalid filename." : "Neveljavno ime datoteke",
     "Name of the album" : "Ime albuma",
     "Location of the album" : "Mesto albuma",
     "Back" : "Nazaj",
@@ -38,30 +42,43 @@ OC.L10N.register(
     "Add people or groups who can edit your album" : "Dodaj osebe in skupine, ki lahko urejajo album",
     "Search people or groups" : "Iskanje oseb in skupin",
     "No recommendations. Start typing." : "Ni priporočil; začnite z vpisovanjem",
-    "Group" : "Skupina",
-    "Remove {collaboratorLabel} from the collaborators list" : "Odstrani {collaboratorLabel} s seznama sodelujočih",
     "Copy the public link" : "Kopiraj javno povezavo",
     "Public link copied!" : "Povezava je kopirana!",
     "Copy public link" : "Kopiraj javno povezavo",
     "Delete the public link" : "Izbriši javno povezavo",
+    "Create public link share" : "Ustvari povezavo za javno deljenje",
     "Share via public link" : "V souporabi z javno povezavo",
     "This collection does not exist" : "Zbirka ne obstaja.",
     "An error occurred" : "Prišlo je do napake.",
+    "No picture for this day" : "Za ta dan ni slik",
+    "Picture taken on this day will show up here." : "Slike zajete na ta dan se bodo prikazale tukaj",
+    "More photos from this day" : "Več fotografij za ta dan",
+    "_%n photos_::_%n photos_" : ["%n fotografija","%n fotografiji","%n fotografije","%n fotografij"],
+    "_%n unassigned photo_::_%n unassigned photos_" : ["%n neoznačena fotografija","%n neoznačeni fotografiji","%n neoznačenih fotografij","%n neoznačenih fotografij"],
     "Favorite" : "Priljubljeno",
     "Open the full size \"{name}\" image" : "Odpri sliko »{name}« v polni velikosti",
     "Select image {imageName}" : "Izbor slike {imageName}",
-    "Back to {folder}" : "Nazaj v mapo {folder}",
+    "Open the \"{name}\" folder" : "Odpri \"{name}\" mapo",
     "Go back" : "Skoči nazaj",
-    "Share this folder" : "Omogoči souporabo mape",
     "Dates" : "Datumi",
+    "Jump to specific date in list" : "Skoči na specifičen dan na seznamu",
+    "Jump to {date}" : "Skoči na {date}",
     "Add to {destination}" : "Dodaj k {cilju}",
+    "The destination folder is owned by {owner}" : "Ciljna mapa je v lasti {owner}",
     "There are no photos or videos yet!" : "Ni še naloženih fotografij in posnetkov!",
     "_{years} year ago_::_{years} years ago_" : ["pred {years} letom","pred {years} letoma","pred {years} leti","pred {years} leti"],
-    "Enable squared photos view" : "Omogoči kvadratne prikaze slik",
+    "Delete source directory" : "Izbriši izborno mapo",
+    "Pick folder" : "Izberi mapo",
+    "Select a source folder for your media" : "Izberite izvorno mapo za vaš medij",
+    "Media folders" : "Medijske mape",
+    "Choose the folders from where photos and videos are shown." : "Izberite mape, od koder bodo prikazane fotografije in videi",
     "All folders" : "Vse mape",
+    "Add a Photos source for the timelines" : "Dodajte vir fotografij za časovnico",
     "Add folder" : "Dodaj mapo",
     "Home" : "Začetna stran",
-    "View" : "Poglej",
+    "Select the default upload location for your media" : "Izberite privzeto mesto nalaganja za vaš medij",
+    "Upload folder" : "Naloži mapo",
+    "General" : "Splošno",
     "_%n photo_::_%n photos_" : ["%n fotografija","%n fotografiji","%n fotografije","%n fotografij"],
     "Unselect all" : "Odstrani izbor",
     "Add photos to this album" : "Dodaj fotografije v ta album",
@@ -73,6 +90,7 @@ OC.L10N.register(
     "Download selected files" : "Prejmi izbrane datoteke",
     "Remove selection from album" : "Odstrani izbor iz albuma",
     "This album does not have any photos or videos yet!" : "V ta album ni še naloženih fotografij in posnetkov!",
+    "Add photos to {albumName}" : "Dodaj fotografije v {albumName}",
     "Manage collaborators" : "Upravljanje s sodelujočimi",
     "Save collaborators for this album." : "Shrani sodelujoče za izbran album",
     "Cover photo for album {albumName}" : "Naslovna fotografija za album {albumName}",
@@ -86,19 +104,33 @@ OC.L10N.register(
     "Name of this person" : "Ime osebe",
     "Save." : "Shrani.",
     "Merge person" : "Združi podatke osebe",
+    "Move to different person" : "Premakni k drugi osebi",
+    "_Move photo to a different person_::_Move photos to a different person_" : ["Premakni sliko k drugi osebi","Premakni sliki k drugi osebi","Premakni slike k drugi osebi","Premakni fotografije k drugi osebi"],
+    "_Remove photo from person_::_Remove photos from person_" : ["Odstrani sliko od osebe","Odstrani sliki od osebe","Odstrani slike od osebe","Odstrani fotografijo od osebe"],
+    "This might take some time depending on the size of your photo library." : "To lahko vzame nekaj časa, odvisno od velikosti albuma fotografij",
+    "Recognized people will show up here" : "Prepoznane osebe se bodo prikazale tukaj",
     "This folder does not exist" : "Ta mapa ne obstaja",
-    "Loading folders …" : "Poteka nalaganje map …",
+    "Loading folders…" : "Poteka nalaganje map …",
     "No photos in here" : "Na tem mestu še ni fotografij",
+    "Taken on {date} at {time}" : "Zajeto {date} ob {time}",
+    "This place does not have any photos or videos yet!" : "Ta prostor še nima nobene fotografije ali videa!",
+    "Add photos to this place" : "Dodaj fotografije v ta prostor",
+    "Cover photo for place {placeName}" : "Naslovna fotografija za prostor {placeName}",
+    "Cover photo for shared album {albumName}" : "Naslovna fotografija za deljen album {albumName}",
     "No photos with this tag yet" : "Ni še fotografij, označenih s to oznako.",
     "No tags yet" : "Ni še dodane nobene oznake",
     "Photos with tags will show up here" : "Na tem mestu bodo prikazane fotografije z oznakami.",
     "Popular tags" : "Priljubljene oznake",
+    "All tags" : "Vse oznake",
+    "One of the source folders does not exist" : "Ena od izvornih map ne obstaja",
     "Add to album" : "Dodaj album",
     "Delete selection" : "Izbriši izbor",
     "No photos or videos in here" : "Ni še nobenih slik in posnetkov",
-    "_%n photos_::_%n photos_" : ["%n fotografija","%n fotografiji","%n fotografije","%n fotografij"],
+    "Unassigned faces" : "Nedodeljeni obrazi",
+    "Failed to fetch collection." : "Spodletelo pridobivanje zbirk.",
     "Failed to fetch collections list." : "Pridobivanje seznama zbirk je spodletelo.",
     "Failed to fetch faces list." : "Pridobivanje seznama obrazov je spodletelo.",
+    "Error fetching files" : "Napaka pri pridobivanju datotek",
     "All your media" : "Vsi viri",
     "Album {title}" : "Album {title}",
     "Shared Albums" : "Albumi v souporabi",
@@ -107,9 +139,28 @@ OC.L10N.register(
     "Tagged photos" : "Označene fotografije",
     "Tagged photo {title}" : "Označena fotografija {title}",
     "{title}'s face" : "{title}: obraz",
+    "Last week" : "Zadnji teden",
+    "{startDate} to {endDate}" : "od {startDate} do {endDate}",
     "Details" : "Podrobnosti",
-    "Failed to delete {fileId}." : "Brisanje polja {fileId} je spodletelo.",
-    "Failed to delete {fileName}." : "Brisanje datoteke {fileName} je spodletelo.",
+    "Failed to delete {fileBaseName}" : "Spodletelo brisanje {fileBaseName}",
+    "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "Spodletelo preimenovanje {currentCollectionFileName} v {newCollectionFileName}",
+    "Failed to delete {collectionFileName}" : "Spodletelo brisanje {collectionFileName}",
+    "Cancel" : "Prekliči",
+    "Confirm" : "Potrdi",
+    "Failed to rename {oldName} to {faceName}" : "Spodletelo preimenovanje {oldName} v {faceName}",
+    "Failed to delete {faceName}" : "Spodletelo brisanje {faceName}",
+    "Failed to delete {fileId}" : "Spodletelo brisanje {fileId}",
+    "Failed to delete {fileName}" : "Spodletelo brisanje {fileName}",
+    "Could not load photos folder" : "Ni mogoče naložiti mape fotografij",
+    "Group" : "Skupina",
+    "Remove {collaboratorLabel} from the collaborators list" : "Odstrani {collaboratorLabel} s seznama sodelujočih",
+    "Back to {folder}" : "Nazaj v mapo {folder}",
+    "Share this folder" : "Omogoči souporabo mape",
+    "Enable squared photos view" : "Omogoči kvadratne prikaze slik",
+    "Choose a different folder" : "Izberite drugo mapo",
+    "View" : "Poglej",
+    "Choose the folder where photos and albums are uploaded to." : "Izberi mapo, kamor se bodo naložile fotografije in albumi",
+    "Loading folders …" : "Poteka nalaganje map …",
     "Add" : "Dodaj"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
