@@ -72,22 +72,19 @@ OC.L10N.register(
     "The destination folder is owned by {owner}" : "目标文件夹所有者为 {owner}",
     "There are no photos or videos yet!" : "还没有照片或视频！",
     "_{years} year ago_::_{years} years ago_" : ["{years} 年前"],
-    "Enable squared photos view" : "启用平铺照片视图",
+    "Squared photos view" : "方形照片视图",
     "Delete source directory" : "删除源目录",
     "Pick folder" : "选择文件夹",
     "Select a source folder for your media" : "为你的媒体文件选择一个源文件夹",
+    "Media folders" : "多媒体文件夹",
+    "Choose the folders from where photos and videos are shown." : "选择显示照片和视频的文件夹。",
     "All folders" : "所有文件夹",
     "Add a Photos source for the timelines" : "为时间轴添加一个照片源",
     "Add folder" : "添加文件夹",
-    "Select the default upload location for your media" : "选择你的媒体文件默认上传位置",
     "Home" : "首页",
-    "Choose default Photos upload and Albums location" : "选择预设照片上传与相册位置",
-    "Choose a different folder" : "选择一个不同的文件夹",
-    "View" : "查看",
-    "Media folders" : "多媒体文件夹",
-    "Choose the folders from where photos and videos are shown." : "选择显示照片和视频的文件夹。",
+    "Select the default upload location for your media" : "选择你的媒体文件默认上传位置",
     "Upload folder" : "上传文件夹",
-    "Choose the folder where photos and albums are uploaded to." : "选择照片和相册上传的文件夹。",
+    "General" : "常规",
     "_%n photo_::_%n photos_" : ["%n张照片"],
     "Unselect all" : "取消全选",
     "Add photos to this album" : "添加照片至此相册",
@@ -161,7 +158,12 @@ OC.L10N.register(
     "Failed to create {collectionFileName}" : "无法创建 {collectionFileName}",
     "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "无法将 {currentCollectionFileName} 重命名为 {newCollectionFileName}",
     "Failed to update properties of {collectionFileName} with {properties}" : "无法使用 {properties} 更新 {collectionFileName} 的属性",
+    "Delete collection" : "删除收藏",
+    "Leave shared album" : "离开共享相册",
+    "Are you sure you want to delete {collectionName}? This action cannot be undone." : "是否确定要删除 {collectionName}？此操作无法撤销。",
     "Failed to delete {collectionFileName}" : "无法删除 {collectionFileName}",
+    "Cancel" : "取消",
+    "Confirm" : "确认",
     "Failed to move {fileBaseName} to person {faceName}" : "无法将 {fileBaseName} 移至人物 {faceName}",
     "Failed to remove {fileBaseName}" : "无法移除 {fileBaseName}",
     "Failed to rename {oldName} to {faceName}" : "无法将 {oldName} 重命名为 {faceName}",
@@ -174,9 +176,13 @@ OC.L10N.register(
     "Group" : "群组",
     "Remove {collaboratorLabel} from the collaborators list" : "将 {collaboratorLabel} 移除协作者列表",
     "Back to {folder}" : "返回 {folder}",
-    "Share this folder" : "共享此文件夹",
+    "Share this folder" : "分享此文件夹",
+    "Enable squared photos view" : "启用方形照片视图",
+    "Choose default Photos upload and Albums location" : "选择预设照片上传与相册位置",
+    "Choose a different folder" : "选择一个不同的文件夹",
+    "View" : "查看",
+    "Choose the folder where photos and albums are uploaded to." : "选择照片和相册上传的文件夹。",
     "Loading folders …" : "正在加载文件夹……",
-    "One of the source folders does not exists" : "其中一个源文件夹不存在",
     "Add" : "添加"
 },
 "nplurals=1; plural=0;");
