@@ -72,22 +72,19 @@ OC.L10N.register(
     "The destination folder is owned by {owner}" : "目標資料夾為 {owner} 擁有",
     "There are no photos or videos yet!" : "還沒有照片或視像！",
     "_{years} year ago_::_{years} years ago_" : ["{years} 年前"],
-    "Enable squared photos view" : "啟用方形照片顯示",
+    "Squared photos view" : "方形照片檢視",
     "Delete source directory" : "刪除來源目錄",
     "Pick folder" : "挑選資料夾",
     "Select a source folder for your media" : "選擇您媒體的來源資料夾",
+    "Media folders" : "媒體資料夾",
+    "Choose the folders from where photos and videos are shown." : "選擇顯示照片與影片的資料夾。",
     "All folders" : "所有資料夾",
     "Add a Photos source for the timelines" : "添加時間軸的照片來源",
     "Add folder" : "添加資料夾",
-    "Select the default upload location for your media" : "選擇媒體的默認上傳位置",
     "Home" : "主頁",
-    "Choose default Photos upload and Albums location" : "選擇默認照片上傳及相簿位置",
-    "Choose a different folder" : "選擇其他資料夾",
-    "View" : "檢視",
-    "Media folders" : "媒體資料夾",
-    "Choose the folders from where photos and videos are shown." : "選擇顯示照片與影片的資料夾。",
+    "Select the default upload location for your media" : "選擇媒體的默認上傳位置",
     "Upload folder" : "上傳資料夾",
-    "Choose the folder where photos and albums are uploaded to." : "選擇照片與相簿上傳到的資料夾。",
+    "General" : "一般",
     "_%n photo_::_%n photos_" : ["%n 張照片"],
     "Unselect all" : "取消全選",
     "Add photos to this album" : "添加照片至此相簿",
@@ -161,7 +158,12 @@ OC.L10N.register(
     "Failed to create {collectionFileName}" : "無法創建 {collectionFileName}",
     "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "重新命名 {currentCollectionFileName} 為 {newCollectionFileName} 失敗",
     "Failed to update properties of {collectionFileName} with {properties}" : "無法使用 {properties} 更新 {collectionFileName} 的屬性",
+    "Delete collection" : "刪除收藏",
+    "Leave shared album" : "離開已分享的相簿",
+    "Are you sure you want to delete {collectionName}? This action cannot be undone." : "您確定您想要刪除 {collectionName} 嗎？此動作無法還原。",
     "Failed to delete {collectionFileName}" : "刪除 {collectionFileName} 失敗",
+    "Cancel" : "取消",
+    "Confirm" : "確認",
     "Failed to move {fileBaseName} to person {faceName}" : "無法將 {fileBaseName} 移動至人物 {faceName}",
     "Failed to remove {fileBaseName}" : "無法移除 {fileBaseName}",
     "Failed to rename {oldName} to {faceName}" : "重新命名 {oldName} 為 {faceName} 失敗",
@@ -175,6 +177,11 @@ OC.L10N.register(
     "Remove {collaboratorLabel} from the collaborators list" : "從協作者清單中移除 {collaboratorLabel}",
     "Back to {folder}" : "回到 {folder}",
     "Share this folder" : "分享這個資料夾",
+    "Enable squared photos view" : "啟用方形照片顯示",
+    "Choose default Photos upload and Albums location" : "選擇默認照片上傳及相簿位置",
+    "Choose a different folder" : "選擇其他資料夾",
+    "View" : "檢視",
+    "Choose the folder where photos and albums are uploaded to." : "選擇照片與相簿上傳到的資料夾。",
     "Loading folders …" : "載入資料夾 …",
     "Add" : "添加"
 },
