@@ -6,6 +6,10 @@ OC.L10N.register(
     "Shows recommended files" : "Aangeraden bestanden tonen",
     "Shows recommended files for quick access of files and folders with recent activity" : "Laat de aangeraden bestanden zien voor snelle toegang tot bestanden en mappen",
     "No recommendations yet" : "Nog geen aanbevelingen",
+    "Last updated {timeAgo}" : "Laatst bijgewerkt {timeAgo}",
+    "Shared with you {timeAgo}" : "Gedeeld met jou {timeAgo}",
+    "Last commented on {timeAgo}" : "Laatst becommentarieerd {timeAgo}",
+    "Path name {path}" : "Padnaam {path}",
     "Show recommendations" : "Toon aanbevelingen",
     "Recently commented" : "Recent gereageerd",
     "Recently edited" : "Recent bewerkt",
