@@ -1,16 +1,6 @@
 OC.L10N.register(
     "settings",
     {
-    "Private" : "Privado",
-    "Only visible to people matched via phone number integration through Talk on mobile" : "Solo visible para las personas que coinciden a través de la integración del número de teléfono mediante Talk en dispositivos móviles",
-    "Local" : "Local",
-    "Only visible to people on this instance and guests" : "Solo visible para las personas en esta instancia y los invitados",
-    "Federated" : "Federado",
-    "Only synchronize to trusted servers" : "Solo sincronizar con servidores de confianza",
-    "Published" : "Publicado",
-    "Synchronize to trusted servers and the global and public address book" : "Sincronizar con servidores de confianza y la libreta de direcciones global y pública",
-    "Verify" : "Verificar",
-    "Verifying …" : "Verificando ...",
     "Unable to change password" : "No fue posible cambiar la contraseña",
     "Very weak password" : "Contraseña muy débil",
     "Weak password" : "Contraseña débil",
@@ -114,6 +104,8 @@ OC.L10N.register(
     "Background jobs" : "Trabajos en segundo plano",
     "Unlimited" : "Ilimitado",
     "Verifying" : "Verificando",
+    "Verifying …" : "Verificando ...",
+    "Verify" : "Verificar",
     "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Su directorio de datos y sus archivos probablemente sean accesibles desde Internet. El archivo .htaccess no está funcionando. Se recomienda encarecidamente que configure su servidor web de manera que el directorio de datos ya no sea accesible, o mueva el directorio de datos fuera de la raíz del documento del servidor web.",
     "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "A la base de datos le faltan algunas columnas opcionales. Debido a que agregar columnas en tablas grandes puede llevar tiempo, no se agregaron automáticamente cuando pueden ser opcionales. Al ejecutar \"occ db:add-missing-columns\", se pueden agregar manualmente esas columnas faltantes mientras la instancia sigue funcionando. Una vez que se agregan las columnas, algunas características pueden mejorar la capacidad de respuesta o la usabilidad.",
     "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "A la base de datos le faltan algunas claves principales. Debido a que agregar claves principales en tablas grandes puede llevar tiempo, no se agregaron automáticamente. Al ejecutar \"occ db:add-missing-primary-keys\", se pueden agregar manualmente esas claves principales faltantes mientras la instancia sigue funcionando.",
@@ -147,8 +139,6 @@ OC.L10N.register(
     "Enforce password protection" : "Forzar protección de contraseñas",
     "Enforce expiration date" : "Forzar fecha de expiración",
     "Set default expiration date for shares to other servers" : "Establecer fecha de vencimiento predeterminada para los compartidos con otros servidores",
-    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Si se habilita el autocompletado \"mismo grupo\" y \"integración de números de teléfono\", es suficiente una coincidencia en cualquiera de los dos para mostrar el usuario.",
-    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Permitir autocompletado al ingresar el nombre completo o la dirección de correo electrónico (ignorando la falta de coincidencia en la libreta de direcciones y estar en el mismo grupo)",
     "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Mostrar texto de descargo de responsabilidad en la página de carga de enlaces públicos (solo se muestra cuando la lista de archivos está oculta)",
     "This text will be shown on the public link upload page when the file list is hidden." : "Este texto se mostrará en la página de carga de la liga pública cuando la lista de archivos esté oculta. ",
     "Default share permissions" : "Permisos predeterminados para compartir",
@@ -177,6 +167,8 @@ OC.L10N.register(
     "No apps found for your version" : "No se encontraron aplicaciones para tu versión",
     "_%n app has an update available_::_%n apps have an update available_" : ["%n aplicación tiene una actualización disponible","%n aplicaciones tienen una actualización disponible","%n aplicaciones tienen una actualización disponible"],
     "_Update_::_Update all_" : ["Actualizar","Actualizar todo","Actualizar todo"],
+    "Group name" : "Nombre del grupo",
+    "Loading groups…" : "Cargando grupos...",
     "Loading" : "Cargando",
     "Daemon" : "Demonio",
     "Type" : "Tipo",
@@ -194,8 +186,6 @@ OC.L10N.register(
     "Limit app usage to groups" : "Limitar el uso de aplicaciones a grupos",
     "No results" : "No hay resultados",
     "Update to {version}" : "Actualizar a {version}",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión mínima de Nextcloud asignada. Esto será un error en el futuro.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión máxima de Nextcloud asignada. Esto será un error en el futuro.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Esta aplicación no puede ser instalada porque las siguientes dependencias no están satisfechas:",
     "Author" : "Autor",
     "Categories" : "Categorías",
@@ -240,6 +230,7 @@ OC.L10N.register(
     "Cron (Recommended)" : "Cron (recomendado)",
     "Unable to update profile default setting" : "No se pudo actualizar la configuración predeterminada del perfil",
     "Profile" : "Perfil",
+    "Password confirmation is required" : "Se requiere la confirmación de la contraseña",
     "Unable to update server side encryption config" : "No se pudo actualizar la configuración de cifrado en el servidor",
     "Server-side encryption" : "Encripción del lado del servidor",
     "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "La encripción del lado del servidor hace posible encriptar archivos que serán cargados a este servidor. Esto trae consigo algunas limitaciónes como penalizaciones en el desemeño, asi que habilítalo sólo si es necesario. ",
@@ -256,10 +247,9 @@ OC.L10N.register(
     "This is the final warning: Do you really want to enable encryption?" : "Esta es la advertencia final: ¿Realmente deseas habilitar la encripción?",
     "Submit" : "Enviar",
     "Rename group" : "Renombrar grupo",
-    "Remove group" : "Eliminar grupo",
+    "Delete group" : "Eliminar grupo",
     "Current password" : "Contraseña actual",
     "New password" : "Nueva contraseña",
-    "Change password" : "Cambiar contraseña",
     "Choose your profile picture" : "Elige tu foto de perfil",
     "Please select a valid png or jpg file" : "Selecciona un archivo válido PNG o JPG",
     "Error setting profile picture" : "Error al establecer la foto de perfil",
@@ -276,6 +266,9 @@ OC.L10N.register(
     "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Ten en cuenta que puede tomar hasta 24 horas para que tu foto de perfil se actualice en todos lados.",
     "You are a member of the following groups:" : "Eres miembro de los siguientes grupos:",
     "Your full name" : "Tu nombre completo",
+    "Unable to update primary email address" : "No se pudo actualizar la dirección de correo electrónico principal",
+    "Unable to delete additional email address" : "No se pudo eliminar la dirección de correo electrónico adicional",
+    "No email address set" : "No se ha establecido la dirección de correo electrónico",
     "Email options" : "Opciones de correo electrónico",
     "Remove primary email" : "Eliminar correo electrónico principal",
     "Delete email" : "Eliminar correo electrónico",
@@ -284,20 +277,17 @@ OC.L10N.register(
     "Set as primary email" : "Establecer como correo electrónico principal",
     "Additional email address {index}" : "Dirección de correo electrónico adicional {index}",
     "Unable to delete primary email address" : "No se pudo eliminar la dirección de correo electrónico principal",
-    "Unable to update primary email address" : "No se pudo actualizar la dirección de correo electrónico principal",
     "Unable to add additional email address" : "No se pudo agregar la dirección de correo electrónico adicional",
     "Unable to update additional email address" : "No se pudo actualizar la dirección de correo electrónico adicional",
-    "Unable to delete additional email address" : "No se pudo eliminar la dirección de correo electrónico adicional",
     "Primary email for password reset and notifications" : "Correo electrónico principal para restablecimiento de contraseña y notificaciones",
-    "No email address set" : "No se ha establecido la dirección de correo electrónico",
     "Your handle" : "Nombre de usuario/a",
     "Your headline" : "Título",
+    "No language set" : "No se ha configurado ningún idioma",
     "Unable to update language" : "No se pudo actualizar el idioma",
     "Help translate" : "Ayuda a traducir",
-    "No language set" : "No se ha configurado ningún idioma",
+    "No locale set" : "No se ha configurado ninguna configuración regional",
     "Unable to update locale" : "No se pudo actualizar la configuración regional",
     "Week starts on {firstDayOfWeek}" : "La semana comienza el {firstDayOfWeek}",
-    "No locale set" : "No se ha configurado ninguna configuración regional",
     "Your city" : "Tu ciudad",
     "Your organisation" : "Tu organización",
     "Your phone number" : "Su número telefónico",
@@ -306,6 +296,7 @@ OC.L10N.register(
     "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Se respeta la configuración más restrictiva de visibilidad o alcance en tu perfil. Por ejemplo, si la visibilidad está configurada en \"Mostrar a todos\" y el alcance está configurado en \"Privado\", se respeta \"Privado\".",
     "Unable to update visibility of {displayId}" : "No se pudo actualizar la visibilidad de {displayId}",
     "Your role" : "Tu cargo",
+    "Timezone" : "Zona horaria",
     "Your website" : "Tu sitio web",
     "Unable to update {property}" : "No se pudo actualizar {property}",
     "No {property} set" : "Ningún {property} establecido",
@@ -313,17 +304,18 @@ OC.L10N.register(
     "Unable to update federation scope of the primary {property}" : "No se pudo actualizar el alcance de federación del {property} principal",
     "Unable to update federation scope of additional {property}" : "No se pudo actualizar el alcance de federación del {property} adicional",
     "Add additional email" : "Agregar correo electrónico adicional",
-    "Add" : "Agregar",
+    "Add" : "Guardar",
     "Create" : "Crear",
     "Change" : "Cambiar",
     "Delete" : "Borrar",
     "Reshare" : "Recompartir",
+    "School" : "Escuela",
     "Default language" : "Idioma predeterminado",
     "Common languages" : "Idiomas comunes",
     "Other languages" : "Otros idiomas",
     "Password change is disabled because the master key is disabled" : "El cambio de contraseña está deshabilitado porque la clave maestra está deshabilitada",
     "Manager" : "Administrador",
-    "Display name" : "Nombre a desplegar",
+    "Display name" : "Nombre para mostrar",
     "Either password or email is required" : "Se requiere una contraseña o un correo electrónico",
     "Password (required)" : "Contraseña (requerida)",
     "Email (required)" : "Correo electrónico (requerido)",
@@ -343,7 +335,6 @@ OC.L10N.register(
     "{size} used" : "{size} usado",
     "Delete account" : "Borrar cuenta",
     "Resend welcome email" : "Reenviar correo de bienvenida",
-    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "En caso de pérdida del dispositivo o salida de la organización, esto puede borrar de forma remota los datos de Nextcloud de todos los dispositivos asociados con {userid}. Solo funciona si los dispositivos están conectados a Internet.",
     "Remote wipe of devices" : "Borrado remoto de dispositivos",
     "Wipe {userid}'s devices" : "Borrar dispositivos de {userid}",
     "Wiped {userid}'s devices" : "Se borraron los dispositivos de {userid}",
@@ -355,7 +346,7 @@ OC.L10N.register(
     "Email was successfully changed" : "Se cambió correctamente el correo electrónico",
     "Welcome mail sent!" : "¡Correo de bienvenida enviado!",
     "Set the language" : "Establecer el idioma",
-    "Done" : "Terminado",
+    "Done" : "Hecho",
     "Edit" : "Editar",
     "Visibility" : "Visibilidad",
     "Show storage path" : "Mostrar ruta de almacenamiento",
@@ -369,17 +360,21 @@ OC.L10N.register(
     "Passwordless authentication requires a secure connection." : "La autenticación sin contraseña requiere una conexión segura.",
     "Add WebAuthn device" : "Agregar dispositivo WebAuthn",
     "Please authorize your WebAuthn device." : "Autoriza tu dispositivo WebAuthn.",
-    "Adding your device …" : "Agregando tu dispositivo ...",
     "Unnamed device" : "Dispositivo sin nombre",
     "Passwordless Authentication" : "Autenticación sin contraseña",
     "Set up your account for passwordless authentication following the FIDO2 standard." : "Configura tu cuenta para la autenticación sin contraseña siguiendo el estándar FIDO2.",
     "No devices configured." : "No hay dispositivos configurados.",
     "The following devices are configured for your account:" : "Los siguientes dispositivos están configurados para tu cuenta:",
     "Your browser does not support WebAuthn." : "Tu navegador no admite WebAuthn.",
+    "Security & setup warnings" : "Advertencias de seguridad y configuración",
+    "Try again" : "Reintentar",
+    "All checks passed." : "Pasaron todas las verificaciones. ",
+    "There are some errors regarding your setup." : "Hay algunos errores en tu configuración.",
+    "There are some warnings regarding your setup." : "Hay algunas advertencias en tu configuración.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Como administrador, puedes hacer ajustes finos al comportamiento de compartir. Por favor consulta la documentación para más información. ",
     "You need to enable the File sharing App." : "Debes habilitar la aplicación Compartir archivos.",
+    "Apply" : "Aplicar",
     "Admins" : "Administradores",
-    "Group name" : "Nombre del grupo",
     "Sending…" : "Enviando...",
     "Email sent" : "Correo electrónico enviado",
     "Location" : "Ubicación",
@@ -395,7 +390,15 @@ OC.L10N.register(
     "Website" : "Sitio web",
     "Profile visibility" : "Visibilidad del perfil",
     "Locale" : "Configuración regional",
+    "Private" : "Privado",
+    "Only visible to people matched via phone number integration through Talk on mobile" : "Solo visible para las personas que coinciden a través de la integración del número de teléfono mediante Talk en dispositivos móviles",
     "Not available as this property is required for core functionality including file sharing and calendar invitations" : "No disponible, ya que esta propiedad es necesaria para la funcionalidad básica, incluyendo el intercambio de archivos y las invitaciones de calendario.",
+    "Local" : "Local",
+    "Only visible to people on this instance and guests" : "Solo visible para las personas en esta instancia y los invitados",
+    "Federated" : "Federado",
+    "Only synchronize to trusted servers" : "Solo sincronizar con servidores de confianza",
+    "Published" : "Publicado",
+    "Synchronize to trusted servers and the global and public address book" : "Sincronizar con servidores de confianza y la libreta de direcciones global y pública",
     "Your apps" : "Tus aplicaciones",
     "Active apps" : "Aplicaciones activas",
     "Disabled apps" : "Aplicaciones deshabilitadas",
@@ -407,7 +410,6 @@ OC.L10N.register(
     "Download and enable" : "Descargar y habilitar",
     "Disable" : "Deshabilitar",
     "The app will be downloaded from the App Store" : "La aplicación se descargará desde la App Store",
-    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Esta aplicación no está marcada como compatible con tu versión de Nextcloud. Si continúas, aún podrás instalar la aplicación. Ten en cuenta que es posible que la aplicación no funcione como se espera.",
     "Unknown" : "Desconocido",
     "Never" : "Nunca",
     "An error occurred during the request. Unable to proceed." : "Ocurrió un error durante la solicitud. No se puede continuar.",
@@ -439,14 +441,6 @@ OC.L10N.register(
     "SMTP Password" : "Contraseña SMTP",
     "Save" : "Guardar",
     "Test and verify email settings" : "Probar y verificar la configuración del correo electrónico",
-    "Security & setup warnings" : "Advertencias de seguridad y configuración",
-    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Es importante para la seguridad y el rendimiento de tu instancia que todo esté configurado correctamente. Para ayudarte con eso, realizamos algunas comprobaciones automáticas. Consulta la documentación enlazada para obtener más información.",
-    "All checks passed." : "Pasaron todas las verificaciones. ",
-    "There are some errors regarding your setup." : "Hay algunos errores en tu configuración.",
-    "There are some warnings regarding your setup." : "Hay algunas advertencias en tu configuración.",
-    "Checking for system and security issues." : "Comprobando problemas del sistema y de seguridad.",
-    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Por favor, revisa las <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">guías de instalación ↗</a> y verifica si hay errores o advertencias en el <a href=\"%2$s\">registro</a>.",
-    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Verifica la seguridad de tu Nextcloud con nuestro <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">escáner de seguridad ↗</a>.",
     "Reasons to use Nextcloud in your organization" : "Razones para usar Nextcloud en tu organización",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Desarrollado por la  {communityopen}comunidad Nextcloud {linkclose}, el {githubopen}código fuente {linkclose} está licenciado bajo  {licenseopen}AGPL{linkclose}.",
     "Like our Facebook page" : "Da un Like a nuestra página de Facebook",
@@ -456,34 +450,14 @@ OC.L10N.register(
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Esta versión comunitaria de Nextcloud no cuenta con soporte y las notificaciones instantáneas no están disponibles.",
     "Use a second factor besides your password to increase security for your account." : "Utiliza un segundo factor además de tu contraseña para aumentar la seguridad de tu cuenta.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Si utilizas aplicaciones de terceros para conectarte a Nextcloud, asegúrate de crear y configurar una contraseña de aplicación para cada una antes de habilitar la autenticación de segundo factor.",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "A la base de datos le faltan algunos índices. Debido a que agregar índices en tablas grandes puede llevar tiempo, no se agregaron automáticamente. Al ejecutar \"occ db:add-missing-indices\", se pueden agregar manualmente esos índices faltantes mientras la instancia sigue funcionando. Una vez que se agregan los índices, las consultas a esas tablas suelen ser mucho más rápidas.",
-    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "Se está utilizando la versión \"%s\" de MariaDB. Nextcloud 21 y versiones posteriores no admiten esta versión y requieren MariaDB 10.2 o superior.",
-    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "Se está utilizando la versión \"%s\" de MySQL. Nextcloud 21 y versiones posteriores no admiten esta versión y requieren MySQL 8.0 o MariaDB 10.2 o superior.",
-    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "Se está utilizando la versión \"%s\" de PostgreSQL. Nextcloud 21 y versiones posteriores no admiten esta versión y requieren PostgreSQL 9.6 o superior.",
-    "Set default expiration date for shares" : "Establecer fecha de vencimiento predeterminada para los compartidos",
-    "Allow username autocompletion in share dialog and allow access to the system address book" : "Permitir autocompletado de nombre de usuario en el cuadro de diálogo de compartir y permitir acceso a la libreta de direcciones del sistema",
-    "Your biography" : "Tu biografía",
-    "You are using <strong>{usage}</strong>" : "Estás usando <strong>{usage}</strong>",
-    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Estás usando <strong>{usage}</strong> de <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
-    "Set user manager" : "Establecer al usuario como administrador",
-    "Username will be autogenerated" : "El nombre de usuario se generará automáticamente",
-    "Username (required)" : "Nombre de usuario (requerido)",
-    "New user" : "Nuevo usuario",
-    "Groups (required)" : "Grupos (requeridos)",
-    "Set user groups" : "Establecer grupos de usuario",
-    "Administered groups" : "Grupos administrados",
-    "Set user as admin for …" : "Establecer al usuario como administrador de ...",
-    "Set user quota" : "Establecer cuota de usuario",
-    "Add new user" : "Agregar nuevo usuario",
-    "_{userCount} user …_::_{userCount} users …_" : ["{userCount} usuario ...","{userCount} usuarios ...","{userCount} usuarios ..."],
-    "_{userCount} user_::_{userCount} users_" : ["{userCount} usuario","{userCount} usuarios","{userCount} usuarios"],
-    "Loading users …" : "Cargando usuarios...",
-    "Username" : "Usuario",
-    "User backend" : "Backend del usuario",
-    "User actions" : "Acciones de usuario",
-    "Add user to group" : "Agregar usuario al grupo",
-    "Server error while trying to add WebAuthn device" : "Error del servidor al intentar agregar el dispositivo WebAuthn",
-    "Name your device" : "Nombra tu dispositivo",
-    "Follow us on Twitter" : "Síguenos en Twitter"
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión mínima de Nextcloud asignada. Esto será un error en el futuro.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión máxima de Nextcloud asignada. Esto será un error en el futuro.",
+    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "En caso de pérdida del dispositivo o salida de la organización, esto puede borrar de forma remota los datos de Nextcloud de todos los dispositivos asociados con {userid}. Solo funciona si los dispositivos están conectados a Internet.",
+    "Adding your device …" : "Agregando tu dispositivo ...",
+    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Esta aplicación no está marcada como compatible con tu versión de Nextcloud. Si continúas, aún podrás instalar la aplicación. Ten en cuenta que es posible que la aplicación no funcione como se espera.",
+    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Es importante para la seguridad y el rendimiento de tu instancia que todo esté configurado correctamente. Para ayudarte con eso, realizamos algunas comprobaciones automáticas. Consulta la documentación enlazada para obtener más información.",
+    "Checking for system and security issues." : "Comprobando problemas del sistema y de seguridad.",
+    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Por favor, revisa las <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">guías de instalación ↗</a> y verifica si hay errores o advertencias en el <a href=\"%2$s\">registro</a>.",
+    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Verifica la seguridad de tu Nextcloud con nuestro <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">escáner de seguridad ↗</a>."
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
