@@ -1,16 +1,6 @@
 OC.L10N.register(
     "settings",
     {
-    "Private" : "Privat",
-    "Only visible to people matched via phone number integration through Talk on mobile" : "Endast synlig för personer matchade via telefonnummer integration via Talk i mobilen",
-    "Local" : "Lokal",
-    "Only visible to people on this instance and guests" : "Endast synlig för personer på denna instansen och gäster",
-    "Federated" : "Federerad",
-    "Only synchronize to trusted servers" : "Synkronisera endast med betrodda servrar",
-    "Published" : "Publicerad",
-    "Synchronize to trusted servers and the global and public address book" : "Synkronisera med betrodda servrar och den globala och offentliga adressboken",
-    "Verify" : "Verifiera",
-    "Verifying …" : "Verifierar ...",
     "Unable to change password" : "Kunde inte ändra lösenord",
     "Very weak password" : "Väldigt svagt lösenord",
     "Weak password" : "Svagt lösenord",
@@ -109,7 +99,7 @@ OC.L10N.register(
     "Administration" : "Administration",
     "Users" : "Användare",
     "Additional settings" : "Övriga inställningar",
-    "Artificial Intelligence" : "Artificiell intelligens",
+    "Assistant" : "Assistent",
     "Administration privileges" : "Administreringsprivilegier",
     "Groupware" : "Grupprogram",
     "Overview" : "Översikt",
@@ -119,6 +109,7 @@ OC.L10N.register(
     "Calendar" : "Kalender",
     "Personal info" : "Personlig information",
     "Mobile & desktop" : "Mobil & skrivbord",
+    "Artificial Intelligence" : "Artificiell intelligens",
     "Email server" : "E-postserver",
     "Mail Providers" : "E-postleverantörer",
     "Mail provider enables sending emails directly through the user's personal email account. At present, this functionality is limited to calendar invitations. It requires Nextcloud Mail 4.1 and an email account in Nextcloud Mail that matches the user's email address in Nextcloud." : "E-postleverantörer gör det möjligt att skicka e-post direkt via användarens personliga e-postkonto. För närvarande är denna funktionalitet begränsad till kalenderinbjudningar. Det kräver Nextcloud Mail 4.1 och ett e-postkonto i Nextcloud Mail som matchar användarens e-postadress i Nextcloud.",
@@ -129,6 +120,8 @@ OC.L10N.register(
     "Background jobs" : "Bakgrundsjobb",
     "Unlimited" : "Obegränsat",
     "Verifying" : "Verifiera",
+    "Verifying …" : "Verifierar ...",
+    "Verify" : "Verifiera",
     "Allowed admin IP ranges" : "Tillåten IP-rymd för administratörer",
     "Configuration key \"%1$s\" expects an array (%2$s found). Admin IP range validation will not be applied." : "Konfigurationsnyckel \"%1$s\" förväntar sig en array (%2$s hittades). Validering av IP-intervall för administratörer tillämpas inte.",
     "Configuration key \"%1$s\" contains invalid IP range(s): \"%2$s\"" : "Konfigurationsnyckel \"%1$s\" innehåller ogiltiga IP-intervall: \"%2$s\"",
@@ -176,6 +169,8 @@ OC.L10N.register(
     "Old server-side-encryption" : "Gammal serverkryptering",
     "Disabled" : "Inaktiverad",
     "The old server-side-encryption format is enabled. We recommend disabling this." : "Det gamla krypteringsformatet på servern är aktiverat. Vi rekommenderar att du inaktiverar detta.",
+    "Logging level" : "Loggnivå",
+    "Logging level configured correctly." : "Loggnivå är korrekt konfigurerad.",
     "Maintenance window start" : "Underhållsfönster startar",
     "Server has no maintenance window start time configured. This means resource intensive daily background jobs will also be executed during your main usage time. We recommend to set it to a time of low usage, so users are less impacted by the load caused from these heavy tasks." : "Servern har ingen konfigurerad starttid för underhållsfönster. Detta innebär att resurskrävande dagliga bakgrundsjobb också kommer att köras under din huvudsakliga användningstid. Vi rekommenderar att du ställer in det till en tid med låg användning, så att användarna påverkas mindre av belastningen som orsakas av dessa tunga uppgifter.",
     "Maintenance window to execute heavy background jobs is between {start}:00 UTC and {end}:00 UTC" : "Underhållsfönstret för att utföra tunga bakgrundsjobb är mellan {start}:00 UTC och {end}:00 UTC",
@@ -225,7 +220,6 @@ OC.L10N.register(
     "Profile information" : "Profilinformation",
     "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Profilbild, fullständigt namn, e-post, telefonnummer, adress, webbplats, Twitter, organisation, roll, rubrik, biografi och om din profil är aktiverad",
     "Nextcloud settings" : "Nextcloud-inställningar",
-    "Task:" : "Uppgift:",
     "Enable" : "Aktivera",
     "Machine translation" : "Maskinöversättning",
     "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "Maskinöversättning kan implementeras av olika appar. Här kan du definiera prioritet för de maskinöversättningsappar som du har installerade.",
@@ -234,6 +228,7 @@ OC.L10N.register(
     "None of your currently installed apps provide image generation functionality" : "Ingen av dina för närvarande installerade appar tillhandahåller bildgenereringsfunktioner",
     "Text processing" : "Textbehandling",
     "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Textbearbetningsuppgifter kan implementeras av olika appar. Här kan du ställa in vilken app som ska användas för vilken uppgift.",
+    "Task:" : "Uppgift:",
     "Here you can decide which group can access certain sections of the administration settings." : "Här kan du bestämma vilken grupp som har tillgång till vissa delar av administrationsinställningarna.",
     "Unable to modify setting" : "Kunde inte ändra inställning.",
     "None" : "Ingen",
@@ -251,6 +246,9 @@ OC.L10N.register(
     "Enforce password protection" : "Tillämpa lösenordskydd",
     "Exclude groups from password requirements" : "Exkludera grupper från lösenordskrav",
     "Exclude groups from creating link shares" : "Exkludera grupper från att skapa länkdelningar",
+    "Allow users to set custom share link tokens" : "Tillåt användare att anpassa delningslänkar",
+    "Shares with custom tokens will continue to be accessible after this setting has been disabled" : "Delningar med anpassade länkar kommer fortsätta vara tillgängliga även efter att denna inställning avaktiverats",
+    "Shares with guessable tokens may be accessed easily" : "Delningar med länkar som går att gissa blir lättillgängliga",
     "Limit sharing based on groups" : "Begränsa delning baserat på grupper",
     "Allow sharing for everyone (default)" : "Tillåt delning för alla (standard)",
     "Exclude some groups from sharing" : "Uteslut vissa grupper från att dela",
@@ -269,13 +267,12 @@ OC.L10N.register(
     "Set default expiration date for shares via link or mail" : "Ställ in standardutgångsdatum för delningar via länk eller e-post",
     "Default expiration time of shares in days" : "Standardutgångstid för delningar i dagar",
     "Privacy settings for sharing" : "Sekretessinställningar för delning",
-    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Om komplettering för \"samma grupp\" och \"telefonnummerintegration\" är aktiverade räcker det med en matchning i en av dem för att visa användaren.",
-    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Tillåt autokomplettering när du anger hela namnet eller e-postadressen (ignorera saknad telefonboksmatchning och att vara i samma grupp)",
     "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Visa friskrivningstext på offentliga uppladdningssidan (visas endast när fil-listan är gömd)",
     "Disclaimer text" : "Friskrivningstext",
     "This text will be shown on the public link upload page when the file list is hidden." : "Denna text kommer att visa på den offentliga uppladdnings-sidan när fil-listan är gömd.",
     "Default share permissions" : "Standardrättigheter för delning",
     "Two-Factor Authentication" : "Tvåfaktorsautentisering",
+    "Two-factor authentication can be enforced for all accounts and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Tvåfaktorsautentisering kan krävas för alla konton eller specifika grupper. Om de inte har någon tvåfaktorsautentisering konfigurerad kommer de inte kunna logga in.",
     "Enforce two-factor authentication" : "Påtvinga tvåfaktorsautentisering",
     "Limit to groups" : "Begränsa till grupper",
     "Enforcement of two-factor authentication can be set for certain groups only." : "Påtvingad tvåfaktorsautentisering kan bara aktiveras för vissa grupper.",
@@ -284,6 +281,7 @@ OC.L10N.register(
     "Two-factor authentication is not enforced for members of the following groups." : "Tvåfaktorsautentisering är inte påtvingad för medlemmar i följande grupper.",
     "Excluded groups" : "Exkluderade grupper",
     "Save changes" : "Spara ändringar",
+    "Default" : "Förvald",
     "Show details for {appName} app" : "Visa detaljer för appen {appName}",
     "Update to {update}" : "Uppdatera till {update}",
     "Remove" : "Ta bort",
@@ -302,11 +300,14 @@ OC.L10N.register(
     "No apps found for your version" : "Inga appar funna för din version",
     "_%n app has an update available_::_%n apps have an update available_" : ["%n app har en uppdatering tillgänglig","%n appar har en uppdatering tillgänglig"],
     "_Update_::_Update all_" : ["Uppdatera","Uppdatera alla"],
+    "Failed to load groups" : "Kunde inte läsa in grupper",
     "Failed to create group" : "Det gick inte att skapa gruppen",
     "Creating group…" : "Skapar grupp...",
     "Create group" : "Skapa grupp",
     "Group name" : "Gruppnamn",
     "Please enter a valid group name" : "Ange ett giltigt gruppnamn",
+    "Search groups…" : "Sök grupper…",
+    "List of groups. This list is not fully populated for performance reasons. The groups will be loaded as you navigate or search through the list." : "Grupplista. Denna lista är inte fullständigt inläst av prestandaskäl. Grupperna kommer att laddas när du navigerar eller söker i listan.",
     "Loading groups…" : "Hämtar grupper...",
     "Nothing to show" : "Inget att visa",
     "Could not load section content from app store." : "Det gick inte att ladda avsnittsinnehåll från app store.",
@@ -334,8 +335,6 @@ OC.L10N.register(
     "Limit app usage to groups" : "Begränsa appanvändning till grupper",
     "No results" : "Inga resultat",
     "Update to {version}" : "Uppdatera till {version}",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Denna app har ingen lägsta Nextcloud-version tilldelad. Detta kommer att innebära ett problem i framtiden.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Denna app har ingen minimum Nextcloud-version tilldelad. Detta kommer att innebära ett problem i framtiden.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Denna applikation kan inte installeras då följande beroenden inte är uppfyllda: %s",
     "Latest updated" : "Senast uppdaterad",
     "Author" : "Upphovsman",
@@ -399,10 +398,11 @@ OC.L10N.register(
     "Unable to update profile default setting" : "Det gick inte att uppdatera profilens standardinställning",
     "Profile" : "Profil",
     "Enable or disable profile by default for new accounts." : "Aktivera eller inaktivera profil som standard för nya konton.",
+    "Password confirmation is required" : "Lösenordsbekräftelse krävs",
     "Failed to save setting" : "Kunde inte spara inställning",
     "Unable to update server side encryption config" : "Kunde inte uppdatera serversidans krypteringskonfiguration",
     "Server-side encryption" : "Serverkryptering",
-    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Kryptering från servern möjliggör kryptering av filer som är uppladdade till servern. Detta innebär vissa begränsningar som prestandaförluster, så aktivera bara om det behövs.",
+    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Kryptering på servern-sidan möjliggör kryptering av filer som är uppladdade till servern. Detta innebär vissa begränsningar som prestandaförluster, så aktivera bara om det behövs.",
     "Enable server-side encryption" : "Aktivera kryptering på server.",
     "No encryption module loaded, please enable an encryption module in the app menu." : "Ingen krypteringsmodul inläst, aktivera krypteringsmodulen i applikationsmenyn.",
     "Select default encryption module:" : "Välj krypteringsmodul:",
@@ -414,15 +414,12 @@ OC.L10N.register(
     "Be aware that encryption always increases the file size." : "OBS! Observera att kryptering alltid ökar filstorleken",
     "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Det är alltid en god ide att skapa regelbundna säkerhetskopior av din data, om kryptering används var säker på att även krypteringsnycklarna säkerhetskopieras tillsammans med din data.",
     "This is the final warning: Do you really want to enable encryption?" : "Detta är en slutgiltig varning: Vill du verkligen aktivera kryptering?",
-    "Failed to remove group \"{group}\"" : "Det gick inte att ta bort gruppen \"{group}\"",
     "Please confirm the group removal" : "Bekräfta borttagning av gruppen",
-    "You are about to remove the group \"{group}\". The accounts will NOT be deleted." : "Du håller på att ta bort gruppen \"{group}\". Kontona kommer INTE att raderas.",
     "Submit" : "Skicka",
     "Rename group" : "Byt namn på grupp",
-    "Remove group" : "Ta bort grupp",
     "Current password" : "Nuvarande lösenord",
     "New password" : "Nytt lösenord",
-    "Change password" : "Ändra lösenord",
+    "Change password" : "Byt lösenord",
     "Choose your profile picture" : "Välj din profilbild",
     "Please select a valid png or jpg file" : "Välj en giltig png- eller jpg-fil",
     "Error setting profile picture" : "Fel vid inställning av profilbild",
@@ -444,6 +441,9 @@ OC.L10N.register(
     "You are using {s}{usage}{/s} of {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})" : "Du använder {s}{usage}{/s} av {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})",
     "You are a member of the following groups:" : "Du är medlem i följande grupper:",
     "Your full name" : "Ditt fullständiga namn",
+    "Unable to update primary email address" : "Kunde inte uppdatera primär e-postadress",
+    "Unable to delete additional email address" : "Kunde inte ta bort ytterligare e-postadress",
+    "No email address set" : "Ingen e-postadress angiven",
     "Email options" : "E-postinställningar",
     "Options for additional email address {index}" : "Alternativ för ytterligare e-postadress {index}",
     "Remove primary email" : "Ta bort primär e-postadress",
@@ -453,25 +453,22 @@ OC.L10N.register(
     "Set as primary email" : "Välj som primär e-post",
     "Additional email address {index}" : "Ytterligare e-postadress {index}",
     "Unable to delete primary email address" : "Kunde inte ta bort primär e-postadress",
-    "Unable to update primary email address" : "Kunde inte uppdatera primär e-postadress",
     "Unable to add additional email address" : "Kunde inte lägga till ytterligare e-postadress",
     "Unable to update additional email address" : "Kunde inte uppdatera ytterligare e-postadress",
-    "Unable to delete additional email address" : "Kunde inte ta bort ytterligare e-postadress",
     "Primary email for password reset and notifications" : "Primär e-postadress för notifikationer och återställning av lösenord",
-    "No email address set" : "Ingen e-postadress angiven",
     "Your handle" : "Ditt kontonamn",
     "Derived from your locale ({weekDayName})" : "Härledd från din plats ({weekDayName})",
     "Unable to update first day of week" : "Kunde inte uppdatera första veckodagen",
     "Day to use as the first day of week" : "Dag att använda som första veckodag",
     "Your headline" : "Din rubrik",
+    "No language set" : "Inget språk angivet",
     "Unable to update language" : "Kunde inte uppdatera språk",
     "Languages" : "Språk",
     "Help translate" : "Hjälp till med översättningarna",
-    "No language set" : "Inget språk angivet",
+    "No locale set" : "Inget språk angivet",
     "Unable to update locale" : "Det gick inte att uppdatera språk",
     "Locales" : "Platser",
     "Week starts on {firstDayOfWeek}" : "Veckan börjar med {firstDayOfWeek}",
-    "No locale set" : "Inget språk angivet",
     "Your city" : "Din stad",
     "Your organisation" : "Din organisation",
     "Your phone number" : "Ditt telefonnummer",
@@ -483,7 +480,9 @@ OC.L10N.register(
     "she/her" : "hon/henne",
     "he/him" : "han/honom",
     "they/them" : "de/dem",
+    "Your pronouns. E.g. {pronounsExample}" : "Dina pronomen. T.ex. {pronounsExample}",
     "Your role" : "Din roll",
+    "Timezone" : "Tidszon",
     "Your X (formerly Twitter) handle" : "Ditt användarnamn på X (tidigare Twitter)",
     "Your website" : "Din webbsida",
     "Invalid value" : "Ogiltigt värde",
@@ -498,17 +497,18 @@ OC.L10N.register(
     "Change" : "Ändra",
     "Delete" : "Radera",
     "Reshare" : "Dela vidare",
+    "School" : "Skola",
     "Default language" : "Standardspråk",
     "Common languages" : "Vanliga språk",
     "Other languages" : "Andra språk",
     "Password change is disabled because the master key is disabled" : "Lösenordsbyte är inaktiverat eftersom huvudnyckeln är inaktiverad",
     "No accounts" : "Inga konton",
-    "Loading accounts …" : "Laddar konton ...",
     "List of accounts. This list is not fully rendered for performance reasons. The accounts will be rendered as you navigate through the list." : "Lista över konton. Denna lista är inte helt återgiven av prestandaskäl. Konton kommer att renderas när du navigerar genom listan.",
     "Manager" : "Chef",
     "Set line manager" : "Ange linjechef",
     "Account name will be autogenerated" : "Kontonamn kommer att autogenereras",
     "Account name (required)" : "Kontonamn (obligatoriskt)",
+    "Failed to search groups" : "Kunde inte söka efter grupper",
     "New account" : "Nytt konto",
     "Display name" : "Visningsnamn",
     "Either password or email is required" : "Antingen lösenord eller e-post krävs",
@@ -519,13 +519,11 @@ OC.L10N.register(
     "Member of the following groups" : "Medlem i följande grupper",
     "Set account groups" : "Ställ in kontogrupper",
     "Admin of the following groups" : "Administratör för följande grupper",
-    "Set account as admin for …" : "Ange konto som administratör för ...",
-    "Quota" : "Lagringsutrymme",
+    "Quota" : "Kvot",
     "Set account quota" : "Ställ in kvot för konto",
     "Language" : "Språk",
     "Set default language" : "Ställ in standardspråk",
     "Add new account" : "Lägg till nytt konto",
-    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} konto …","{userCount} konton …"],
     "_{userCount} account_::_{userCount} accounts_" : ["{userCount} konto","{userCount} konton"],
     "Total rows summary" : "Sammanfattning antal rader",
     "Scroll to load more rows" : "Bläddra för att ladda fler rader",
@@ -542,19 +540,20 @@ OC.L10N.register(
     "Disable account" : "Inaktivera konto",
     "Enable account" : "Aktivera konto",
     "Resend welcome email" : "Skicka om välkomstmeddelande via e-post",
-    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Om användaren förlorar sin enhet eller lämnar organisationen, kan all Nextcloud-data fjärrensas från alla enheter associerade med {userid}. Fungerar bara om enheterna är anslutna till internet.",
     "Remote wipe of devices" : "Fjärrensning av enheter",
     "Wipe {userid}'s devices" : "Rensa enheter för {userid}",
     "Wiped {userid}'s devices" : "Rensade enheter för {userid}",
+    "Failed to load groups with details" : "Kunde inte läsa in grupper med detaljer",
     "Failed to update line manager" : "Kunde inte uppdatera linjechef",
     "Fully delete {userid}'s account including all their personal files, app data, etc." : "Fullständig radering av konto för {userid} inklusive alla personliga filer, appdata etc.",
     "Account deletion" : "Radering av konto",
     "Delete {userid}'s account" : "Ta bort konto för {userid}",
     "Display name was successfully changed" : "Visningsnamnet har ändrats",
+    "Password can't be empty" : "Lösenord får inte vara tomt",
     "Password was successfully changed" : "Lösenordet har ändrats",
+    "Email can't be empty" : "E-post får inte vara tomt",
     "Email was successfully changed" : "E-postadressen har ändrats",
     "Welcome mail sent!" : "Välkomstmeddelande skickat via e-post!",
-    "Loading account …" : "Laddar konto ...",
     "Change display name" : "Ändra visningsnamn",
     "Set new password" : "Ange nytt lösenord",
     "You do not have permissions to see the details of this account" : "Du har inte behörighet att se detaljerna för detta konto.",
@@ -564,7 +563,7 @@ OC.L10N.register(
     "Select account quota" : "Välj kvot för konto",
     "Set the language" : "Ställ in språk",
     "Toggle account actions menu" : "Växla menyn med kontoåtgärder",
-    "Done" : "Färdig",
+    "Done" : "Klar",
     "Edit" : "Redigera",
     "Account management settings" : "Inställningar kontohantering",
     "Visibility" : "Synlighet",
@@ -585,20 +584,26 @@ OC.L10N.register(
     "Passwordless authentication requires a secure connection." : "Lösenordsfri autentisering kräver en säker anslutning.",
     "Add WebAuthn device" : "Lägg till WebAuthn-enhet",
     "Please authorize your WebAuthn device." : "Godkänn din WebAuthn-enhet.",
-    "Adding your device …" : "Lägger till din enhet ....",
     "Unnamed device" : "Namnlös enhet",
     "Passwordless Authentication" : "Lösenordsfri autentisering",
     "Set up your account for passwordless authentication following the FIDO2 standard." : "Ställ in ditt konto för lösenordsfri autentisering som följer FIDO2-standarden.",
     "No devices configured." : "Inga enheter konfigurerade.",
     "The following devices are configured for your account:" : "Följande enheter är konfigurerade för ditt konto:",
     "Your browser does not support WebAuthn." : "Din webbläsare stödjer inte WebAuthn.",
-    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Som administratör kan du fininställa delningsbeteendet. Vänligen se dokumentationen för mer information.",
+    "Security & setup warnings" : "Säkerhet & systemvarningar",
+    "Try again" : "Försök igen",
+    "All checks passed." : "Alla kontroller lyckades!",
+    "There are some errors regarding your setup." : "Det finns några fel angående din inställning.",
+    "There are some warnings regarding your setup." : "Det finns några varningar angående din inställning.",
+    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Som administratör kan du finjustera delningsbeteendet. Vänligen se dokumentationen för mer information.",
     "You need to enable the File sharing App." : "Du måste aktivera fildelnings-appen.",
     "App Store" : "App Store",
     "Loading app list" : "Laddar applista",
     "Loading categories" : "Laddar kategorier",
     "Developer documentation ↗" : "Utvecklardokumentation ↗",
     "Version {version}, {license}-licensed" : "Version {version}, {license}-licensierad",
+    "Version {version}" : "Version {version}",
+    "Apply" : "Tillämpa",
     "All accounts" : "Alla konton",
     "Admins" : "Administratörer",
     "Account group: {group}" : "Kontogrupp: {group}",
@@ -618,12 +623,21 @@ OC.L10N.register(
     "Pronouns" : "Pronomen",
     "Role" : "Roll",
     "X (formerly Twitter)" : "X (tidigare Twitter)",
+    "Bluesky" : "Bluesky",
     "Website" : "Webbplats",
     "Profile visibility" : "Profilsynlighet",
     "Locale" : "Plats",
     "First day of week" : "Första dagen i veckan",
+    "Private" : "Privat",
+    "Only visible to people matched via phone number integration through Talk on mobile" : "Endast synlig för personer matchade via telefonnummer integration via Talk i mobilen",
     "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Inte tillgänglig då denna inställning krävs för essentiell funktionalitet såsom fildelning och kalenderinbjudningar",
+    "Local" : "Lokal",
+    "Only visible to people on this instance and guests" : "Endast synlig för personer på denna instansen och gäster",
+    "Federated" : "Federerad",
+    "Only synchronize to trusted servers" : "Synkronisera endast med betrodda servrar",
     "Not available as federation has been disabled for your account, contact your system administration if you have any questions" : "Ej tillgängligt eftersom federation har inaktiverats för ditt konto, kontakta din systemadministratör om du har några frågor",
+    "Published" : "Publicerad",
+    "Synchronize to trusted servers and the global and public address book" : "Synkronisera med betrodda servrar och den globala och offentliga adressboken",
     "Discover" : "Upptäck",
     "Your apps" : "Dina appar",
     "Active apps" : "Aktiva appar",
@@ -639,7 +653,6 @@ OC.L10N.register(
     "Disable" : "Inaktivera",
     "Allow untested app" : "Tillåt otestad app",
     "The app will be downloaded from the App Store" : "Appen kommer hämtas från appbutiken",
-    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Den här appen är inte markerad som kompatibel med din Nextcloud-version. Om du fortsätter kan du fortfarande installera appen. Observera att appen kanske inte fungerar som förväntat.",
     "Unknown" : "Okänd",
     "Never" : "Aldrig",
     "Could not register device: Network error" : "Kunde inte registrera enheten: Nätverksfel",
@@ -681,14 +694,6 @@ OC.L10N.register(
     "SMTP Password" : "SMTP-lösenord",
     "Save" : "Spara",
     "Test and verify email settings" : "Testa och verifiera e-postinställningar",
-    "Security & setup warnings" : "Säkerhet & systemvarningar",
-    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Det är viktigt för säkerhet och prestanda av din instans att allt är korrekt konfigurerat. För att hjälpa dig med det gör vi några automatiska kontroller. Se den länkade dokumentationen för mer information.",
-    "All checks passed." : "Alla kontroller lyckades!",
-    "There are some errors regarding your setup." : "Det finns några fel angående din inställning.",
-    "There are some warnings regarding your setup." : "Det finns några varningar angående din inställning.",
-    "Checking for system and security issues." : "Kontrollerar system och säkerhetsproblem.",
-    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Vänligen dubbelkolla <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installationsguiderna ↗</a>, och leta efter eventuella fel eller varningar i <a href=\"%2$s\">loggen</a>.",
-    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Kontrollera säkerheten av din Nextcloud-instans med <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">vår säkerhetsgenomsökning ↗</a>.",
     "Reasons to use Nextcloud in your organization" : "Anledningar att använda Nextcloud i din organisation",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Utvecklat av {communityopen}Nextcloud-gemenskapen{linkclose}, {githubopen}källkoden{linkclose}  är licensierad enligt {licenseopen}AGPL-standard{linkclose}.",
     "Like our Facebook page" : "Gilla vår Facebook-sida",
@@ -700,45 +705,18 @@ OC.L10N.register(
     "Use a second factor besides your password to increase security for your account." : "Använd en andra faktor utöver ditt lösenord för att öka säkerheten för ditt konto.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Om du använder tredje-parts applikationer för att ansluta till Nextcloud vänligen skapa och konfigurera ett applösenord för varje innan två-faktor autentisering aktiveras.",
     "Logged in account must be a subadmin" : "Inloggat konto måste vara en underadministratör",
-    "Missing optional index \"%s\" in table \"%s\"." : "Saknar valfri index \"%s\" i tabellen \"%s\".",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Databasen saknar några index. Dessa adderas inte automatsikt då indexering av stora tabeller kan ta tid. Med kommandot  \"occ db:add-missing-indices\" kan de saknade indices läggas till manuellt utan att instansen behöver stoppas. Indexerade tabeller ger oftast mycket snabbare svar.",
-    "File locking" : "Fillåsning",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems." : "Transaktionsbaserad fillåsning är inaktiverad, detta kan leda till problem med konflikter. Aktivera \"filelocking.enabled\" i config.php för att undvika dessa problem.",
-    "The PHP memory limit is below the recommended value of %s." : "Minnesgränsen för PHP är under det rekommenderade värdet på %s.",
-    "You are currently running PHP %s. PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to one of the officially supported PHP versions provided by the PHP Group as soon as possible." : "Du kör för närvarande PHP %s. PHP 8.0 är nu föråldrat i Nextcloud 27. Nextcloud 28 kan kräva minst PHP 8.1. Vänligen uppgradera till en av de officiellt stödda PHP-versionerna som tillhandahålls av PHP Group så snart som möjligt.",
-    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "MariaDB version \"%s\" används. Nextcloud 21 och högre stöder inte denna version och kräver MariaDB 10.2 eller högre.",
-    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "MySQL-versionen \"%s\" används. Nextcloud 21 och högre stöder inte denna version och kräver MySQL 8.0 eller MariaDB 10.2 eller högre.",
-    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "PostgreSQL-versionen \"%s\" används. Nextcloud 21 och högre stöder inte denna version och kräver PostgreSQL 9.6 eller högre.",
-    "Speech-To-Text" : "Tal-till-text",
-    "Speech-To-Text can be implemented by different apps. Here you can set which app should be used." : "Tal-till-text kan implementeras av olika appar. Här kan du ställa in vilken app som ska användas.",
-    "None of your currently installed apps provide Speech-To-Text functionality" : "Ingen av dina installerade appar tillhandahåller tal-till-text-funktionalitet",
-    "None of your currently installed apps provide Text processing functionality" : "Ingen av dina installerade appar tillhandahåller textbearbetningsfunktioner",
-    "Set default expiration date for shares" : "Ställ in standardutgångsdatum för delningar",
-    "Allow username autocompletion in share dialog and allow access to the system address book" : "Tillåt autokomplettering av användarnamn i delningsdialogen och tillåt åtkomst till systemets adressbok",
-    "Your biography" : "Din biografi",
-    "You are using <strong>{usage}</strong>" : "Du använder <strong>{usage}</strong>",
-    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Du använder <strong>{usage}</strong> av <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
-    "Set user manager" : "Ställ in användarhanterare",
-    "Username will be autogenerated" : "Användarnamn kommer att autogenereras",
-    "Username (required)" : "Användarnamn (obligatoriskt)",
-    "New user" : "Ny användare",
-    "Groups (required)" : "Grupper (obligatoriskt)",
-    "Set user groups" : "Ställ in användargrupper",
-    "Administered groups" : "Administrerade grupper",
-    "Set user as admin for …" : "Ange användare som administratör för...",
-    "Set user quota" : "Ställ in användarkvot",
-    "Add new user" : "Lägg till ny användare",
-    "_{userCount} user …_::_{userCount} users …_" : ["{userCount} användare …","{userCount} användare …"],
-    "_{userCount} user_::_{userCount} users_" : ["{userCount} användare","{userCount} användare"],
-    "Loading users …" : "Laddar användare …",
-    "Username" : "Användarnamn",
-    "User backend" : "Användarbackend",
-    "User actions" : "Användaråtgärder",
-    "Add user to group" : "Lägg till användare i grupp",
-    "Server error while trying to add WebAuthn device" : "Serverfel när du försökte lägga till en WebAuthn-enhet",
-    "Name your device" : "Namnge din enhet",
-    "Active accounts" : "Aktiva konton",
-    "Follow us on Twitter" : "Följ oss på Twitter",
-    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "För att denna kontroll ska kunna köra måste du se till att webbservern kan ansluta till sig själv. Den måste alltså kunna finna och ansluta till minst en av sina \"trusted_domains\" eller \"overwrite.cli.url\":en. Detta misslyckande kan vara resultatet av en DNS missmatch på serversidan eller utgående brandväggs-regler."
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Denna app har ingen lägsta Nextcloud-version tilldelad. Detta kommer att innebära ett problem i framtiden.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Denna app har ingen minimum Nextcloud-version tilldelad. Detta kommer att innebära ett problem i framtiden.",
+    "Loading accounts …" : "Laddar konton ...",
+    "Set account as admin for …" : "Ange konto som administratör för ...",
+    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} konto …","{userCount} konton …"],
+    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Om användaren förlorar sin enhet eller lämnar organisationen, kan all Nextcloud-data fjärrensas från alla enheter associerade med {userid}. Fungerar bara om enheterna är anslutna till internet.",
+    "Loading account …" : "Laddar konto ...",
+    "Adding your device …" : "Lägger till din enhet ....",
+    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Den här appen är inte markerad som kompatibel med din Nextcloud-version. Om du fortsätter kan du fortfarande installera appen. Observera att appen kanske inte fungerar som förväntat.",
+    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Det är viktigt för säkerhet och prestanda av din instans att allt är korrekt konfigurerat. För att hjälpa dig med det gör vi några automatiska kontroller. Se den länkade dokumentationen för mer information.",
+    "Checking for system and security issues." : "Kontrollerar system och säkerhetsproblem.",
+    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Vänligen dubbelkolla <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installationsguiderna ↗</a>, och leta efter eventuella fel eller varningar i <a href=\"%2$s\">loggen</a>.",
+    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Kontrollera säkerheten av din Nextcloud-instans med <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">vår säkerhetsgenomsökning ↗</a>."
 },
 "nplurals=2; plural=(n != 1);");
