@@ -56,7 +56,6 @@ OC.L10N.register(
     "Failed to delete tag" : "No s'ha pogut suprimir l'etiqueta",
     "Create or edit tags" : "Creeu o editeu etiquetes",
     "Search for a tag to edit" : "Cerqueu l'etiqueta que voleu editar",
-    "Collaborative tags …" : "Etiquetes col·laboratives…",
     "No tags to select" : "No hi ha cap etiqueta per seleccionar",
     "Tag name" : "Nom de l'etiqueta",
     "Tag level" : "Nivell de l'etiqueta",
@@ -64,8 +63,7 @@ OC.L10N.register(
     "Update" : "Actualitza",
     "Delete" : "Suprimeix",
     "Reset" : "Reinicialitza",
-    "Loading …" : "S'està carregant…",
-    "_{tag1} will be set and {tag2} will be removed from 1 file._::_{tag1} will be set and {tag2} will be removed from {count} files._" : ["S'establirà {tag1} i s'eliminarà {tag2} d'1 fitxer.","S'establirà {tag1} i s'eliminarà {tag2} de {count} fitxers."],
+    "_{tag1} will be set and {tag2} will be removed from 1 file._::_{tag1} will be set and {tag2} will be removed from {count} files._" : ["S'establirà {tag1} i s'eliminarà {tag2} d'1 fitxer.","S'establirà {tag1} i s'eliminaran {tag2} de {count} fitxers."],
     "_{tag} will be set to 1 file._::_{tag} will be set to {count} files._" : ["{tag} s'establirà en 1 fitxer.","{tag} s'establirà en {count} fitxers."],
     "_{tag} will be removed from 1 file._::_{tag} will be removed from {count} files._" : ["{tag} s'eliminarà d'1 fitxer.","{tag} s'eliminarà de {count} fitxers."],
     "_{tags} and {lastTag} will be set to 1 file._::_{tags} and {lastTag} will be set to {count} files._" : ["{tags} i {lastTag} s'establiran en 1 fitxer.","{tags} i {lastTag} s'establiran en {count} fitxers."],
@@ -74,29 +72,25 @@ OC.L10N.register(
     "{displayName} (restricted)" : "{displayName} (restringit)",
     "Only admins can create new tags" : "Només els administradors poden crear etiquetes noves",
     "Failed to apply tags changes" : "No s'han pogut aplicar els canvis d'etiquetes",
-    "File tags modification canceled" : "S'ha cancel·lat la modificació de les etiquetes del fitxer",
-    "Manage tags" : "Gestiona les etiquetes",
+    "Manage tags" : "Administrar les etiquetes",
     "Applying tags changes…" : "S'estan aplicant els canvis d'etiquetes…",
     "Search or create tag" : "Cerca o crea una etiqueta",
     "Search tag" : "Etiqueta de cerca",
     "Change tag color" : "Canvia el color de l'etiqueta",
     "Create new tag" : "Crea una etiqueta nova",
-    "Select or create tags to apply to all selected files" : "Seleccioneu o creeu etiquetes per aplicar-les a tots els fitxers seleccionats",
-    "Select tags to apply to all selected files" : "Seleccioneu les etiquetes per aplicar a tots els fitxers seleccionats",
     "Cancel" : "Cancel·la",
-    "Apply changes" : "Aplica els canvis",
-    "Failed to load tags" : "No s'han pogut carregar les etiquetes",
+    "Apply" : "Aplica",
     "Failed to load selected tags" : "No s'han pogut carregar les etiquetes seleccionades",
+    "Failed to load tags" : "No s'han pogut carregar les etiquetes",
     "Failed to select tag" : "No s'ha pogut seleccionar l'etiqueta",
     "System admin disabled tag creation. You can only use existing ones." : "L'administrador del sistema ha desactivat la creació d'etiquetes. Només podeu utilitzar els existents.",
-    "Loading collaborative tags …" : "S'estan carregant les etiquetes col·laboratives…",
     "Search or create collaborative tags" : "Cerqueu o creeu etiquetes col·laboratives",
     "No tags to select, type to create a new tag" : "No hi ha cap etiqueta per seleccionar, escriviu per a crear una etiqueta nova",
-    "Unable to update setting" : "No es pot actualitzar la configuració",
+    "Unable to update setting" : "No es pot actualitzar el paràmetre",
     "System tag creation is now restricted to administrators" : "La creació d'etiquetes del sistema ara està restringida als administradors",
     "System tag creation is now allowed for everybody" : "La creació d'etiquetes del sistema ara està permesa per a tothom",
     "System tag management" : "Gestió d'etiquetes del sistema",
-    "If enabled, only administrators can create and edit tags. Accounts can still assign and remove them from files." : "Si està activat, només els administradors poden crear i editar etiquetes. Els comptes encara poden assignar-los i eliminar-los dels fitxers.",
+    "If enabled, only administrators can create and edit tags. Accounts can still assign and remove them from files." : "Si està habilitat, només els administradors poden crear i editar etiquetes. Els comptes encara poden assignar-los i eliminar-los dels fitxers.",
     "Restrict tag creation and editing to administrators" : "Restringeix la creació i edició d'etiquetes als administradors",
     "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Les etiquetes col·laboratives estan disponibles per a tots els usuaris. Els usuaris poden veure les etiquetes restringides, però no les poden assignar. Les etiquetes invisibles són per a ús intern, perquè els usuaris no poden ni veure-les ni assignar-les.",
     "Assigned collaborative tags" : "Etiquetes col·laboratives assignades",
@@ -111,7 +105,12 @@ OC.L10N.register(
     "Failed to load tags for file" : "No s'han pogut carregar les etiquetes del fitxer",
     "Failed to set tag for file" : "No s'ha pogut definit l'etiqueta per al fitxer",
     "Failed to delete tag for file" : "No s'ha pogut suprimir l'etiqueta del fitxer",
-    "This file has the tag {tag}" : "Aquest fitxer té l'etiqueta {tag}",
-    "This file has the tags {firstTags} and {lastTag}" : "Aquest fitxer té les etiquetes {firstTags} i {lastTag}"
+    "Collaborative tags …" : "Etiquetes col·laboratives…",
+    "Loading …" : "S'està carregant…",
+    "File tags modification canceled" : "S'ha cancel·lat la modificació de les etiquetes del fitxer",
+    "Select or create tags to apply to all selected files" : "Seleccioneu o creeu etiquetes per aplicar-les a tots els fitxers seleccionats",
+    "Select tags to apply to all selected files" : "Seleccioneu les etiquetes per aplicar a tots els fitxers seleccionats",
+    "Apply changes" : "Aplica els canvis",
+    "Loading collaborative tags …" : "S'estan carregant les etiquetes col·laboratives…"
 },
 "nplurals=2; plural=(n != 1);");
