@@ -4,20 +4,21 @@ OC.L10N.register(
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Mae'r ffeil lwythwyd i fyny'n fwy na chyfarwyddeb MAX_FILE_SIZE bennwyd yn y ffurflen HTML",
     "No file was uploaded" : "Ni lwythwyd ffeil i fyny",
     "Missing a temporary folder" : "Plygell dros dro yn eisiau",
-    "Translate" : "Cyfieithu",
     "Saved" : "Wedi'u cadw",
     "Keyboard shortcuts" : "Llwybrau byr bysellfwrdd",
     "Bold" : "Trwm",
     "Italic" : "Italig",
     "Link" : "Dolen",
     "Undo" : "Dadwneud",
+    "Cancel" : "Cancel",
     "URL" : "URL",
+    "Save" : "Cadw",
+    "Translate" : "Cyfieithu",
     "to" : "at",
     "Upload" : "Llwytho i fyny",
     "Edit" : "Golygu",
     "Source code" : "Cod ffynhonnell",
     "Details" : "Manylion",
-    "Info" : "Info",
-    "Warning" : "Rhybudd"
+    "Choose" : "Dewisa"
 },
 "nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
