@@ -22,15 +22,6 @@ OC.L10N.register(
     "Text" : "テキスト",
     "📝 Collaborative document editing" : "📝 共同文書編集",
     "** 📝 Collaborative document editing!**\n\n- **📝 Focused writing:** No distractions, only the formatting you need.\n- **🙋 Work together:** Share and collaborate with friends and colleagues, no matter if they use Nextcloud or not!\n- **💾 Open format:** Files are saved as [Markdown](https://en.wikipedia.org/wiki/Markdown), so you can edit them from any other text app too.\n- **✊ Strong foundation:** We use [🐈 tiptap](https://tiptap.scrumpy.io) which is based on [🦉 ProseMirror](https://prosemirror.net) – huge thanks to them!" : "**📝共同文書編集！**\n\n- **📝 集中執筆：集中モードで、必要なフォーマットだけ。\n- **🙋 一緒に仕事をする：**友達や同僚と、Nextcloudを使っていようとなかろうと、共有して共同作業しよう！\n- **💾 オープンフォーマット:** ファイルは[Markdown](https://en.wikipedia.org/wiki/Markdown)として保存されるので、他のテキストアプリからも編集できます。\n- **✊ 強固な基盤：**私たちは[🦉 ProseMirror](https://prosemirror.net)をベースにした[🐈 tiptap](https://tiptap.scrumpy.io)を使用しています - 本当にありがとうございます！",
-    "Insert result" : "結果を挿入する",
-    "Nextcloud Assistant result copied" : "Nextcloud アシスタントの結果をコピーしました",
-    "Could not copy result to clipboard" : "結果をコピーできませんでした",
-    "Nextcloud Assistant" : "Nextcloud アシスタント",
-    "Translate" : "翻訳",
-    "Show assistant results" : "アシスタントの結果を表示する",
-    "Assistant results" : "アシスタントの結果",
-    "Show result" : "結果を表示する",
-    "Delete task" : "タスクを削除",
     "Overwrite the file and save the current changes" : "ファイルを上書きし現在の変更を保存します",
     "Discard the current changes and load the latest version" : "現在の変更を破棄し、最新バージョンをロードします",
     "Reload" : "再読み込み",
@@ -41,24 +32,32 @@ OC.L10N.register(
     "This file is opened read-only as it is currently locked by {user}." : "このファイルは現在 {user} によってロックされているため、読み取り専用で開かれました",
     "Close outline view" : "目次の表示を閉じる",
     "Outline" : "目次",
+    "Insert below" : "下に挿入",
+    "Click for options, hold to drag" : "クリックしてオプションを選択、押したままドラッグ",
+    "Not connected. Cannot update guest name." : "接続されていません。ゲスト名を更新できません。",
+    "Failed to update the guest name." : "ゲスト名の更新に失敗しました。",
     "Enter your name so other people can see who is editing" : "編集中の人が誰なのか他のユーザに分かるように、名前を入力してください",
-    "Edit guest name" : "ゲスト名を編集",
+    "Enter your name" : "あなたの名前を入力",
     "Guest" : "ゲスト",
-    "Save guest name" : "ゲスト名を保存",
+    "submit" : "送信",
+    "you" : "あなた",
+    "edit" : "編集",
     "Uploading multiple attachments failed." : "複数の添付ファイルのアップロードに失敗しました。",
     "Uploading attachment failed: {error}" : "添付ファイルのアップロードに失敗しました: {error}",
     "Uploading attachment failed." : "添付ファイルのアップロードに失敗しました。",
     "Insert an attachment" : "添付ファイルを挿入する",
     "Failed to insert from Files" : "ファイルからの挿入に失敗しました",
     "Failed to create attachment" : "添付ファイルの作成に失敗しました",
+    "Offline since {time}." : "{time}以降オフラインです。",
+    "Not connected to the cloud." : "クラウドに接続されていません。",
     "Preview options" : "プレビューオプション",
     "Text only" : "テキストのみ",
     "Show link preview" : "リンクのプレビューを表示",
     "Open in new tab" : "新しいタブで開く",
+    "Copy link" : "リンクをコピー",
     "Remove link" : "リンクを削除",
     "Active people" : "ファイルを開いているユーザー",
     "guest" : "ゲスト",
-    "Open the Smart Picker" : "スマートピッカーを開く",
     "Offline" : "オフライン",
     "Offline, changes will be saved when online" : "オフラインです。変更はオンラインになった時に保存されます",
     "Saving …" : "保存中 ...",
@@ -115,13 +114,13 @@ OC.L10N.register(
     "Redo" : "やり直し",
     "Toggle outline" : "アウトラインを切り替える",
     "Alt" : "Alt",
-    "Cannot copy, please copy the link manually" : "コピーできませんでした。手動でリンクをコピーしてください。",
-    "Copy link to clipboard" : "リンクをクリップボードにコピーする",
     "Open link" : "リンクを開く",
     "Edit link" : "リンクを編集",
     "Save changes" : "変更を保存",
     "Cancel" : "キャンセル",
     "URL" : "URL",
+    "Save" : "保存する",
+    "Disabled because you are currently offline." : "現在オフラインのため無効です。",
     "Attachments cannot be created or uploaded because this file is shared from another cloud." : "このファイルは別のクラウドから共有されているため、添付ファイルの作成やアップロードはできません。",
     "Upload from computer" : "コンピュータからアップロード",
     "Insert from Files" : "アップロード済のファイルを挿入",
@@ -129,7 +128,17 @@ OC.L10N.register(
     "Link to file or folder" : "ファイルやフォルダーへのリンク",
     "Link to website" : "ウェブサイトへのリンク",
     "Update link" : "リンクの更新",
+    "Open the Smart Picker" : "スマートピッカーを開く",
     "{menuItemName}, \"{selectedSubMenuItemName}\" is selected" : "{menuItemName}, \"{selectedSubMenuItemName}\" が選択されました",
+    "Insert result" : "結果を挿入する",
+    "Nextcloud Assistant result copied" : "Nextcloud アシスタントの結果をコピーしました",
+    "Could not copy result to clipboard" : "結果をコピーできませんでした",
+    "Translate" : "翻訳",
+    "Show assistant results" : "アシスタントの結果を表示する",
+    "Assistant results" : "アシスタントの結果",
+    "Nextcloud Assistant" : "Nextcloud アシスタント",
+    "Show result" : "結果を表示する",
+    "Delete task" : "タスクを削除",
     "_%n word_::_%n words_" : ["%n語"],
     "_%n char_::_%n chars_" : ["%n文字"],
     "Remaining actions" : "残りのアクション",
@@ -217,17 +226,9 @@ OC.L10N.register(
     "Could not copy to the clipboard" : "クリップボードにコピーできませんでした",
     "Front matter" : "Front matter",
     "Link to this section" : "このセクションへのリンク",
-    "Use current version" : "現在のバージョンを使用",
-    "Use the saved version" : "保存済みのバージョンを使用",
-    "Document has been changed outside of the editor. The changes cannot be applied" : "ドキュメントがエディター外で変更されました。変更を適用できません",
-    "Document could not be loaded. Please check your internet connection." : "ドキュメントを読み込めませんでした。インターネット接続を確認してください。",
-    "Document idle for {timeout} minutes, click to continue editing" : "ドキュメントが{timeout}分間アイドル状態です。クリックして編集を続行します",
-    "Detect language" : "言語を検出する",
-    "Callouts" : "コールアウト",
-    "Info" : "情報",
-    "Success" : "完了",
-    "Warning" : "警告",
-    "Danger" : "危険",
-    "Start writing, or try '/' to add, '@' to mention…" : "書き始めるか、「/」で追加、「@」でメンション...。"
+    "Edit guest name" : "ゲスト名を編集",
+    "Save guest name" : "ゲスト名を保存",
+    "Cannot copy, please copy the link manually" : "コピーできませんでした。手動でリンクをコピーしてください。",
+    "Copy link to clipboard" : "リンクをクリップボードにコピーする"
 },
 "nplurals=1; plural=0;");
