@@ -19,17 +19,18 @@ OC.L10N.register(
     "Readme" : "Прочитај",
     "Text" : "Текст",
     "📝 Collaborative document editing" : "📝 Колаборативно уредување на документи",
-    "Translate" : "Преведи",
-    "Delete task" : "Избриши задача",
     "Reconnect" : "Повторно поврзување",
     "This file is opened read-only as it is currently locked by {user}." : "Оваа датотека е отворена како за читање и истата е заклучена од {user}.",
     "Close outline view" : "Затвори преглед",
     "Outline" : "Преглед",
     "Enter your name so other people can see who is editing" : "Напишете го вашето име за да можат другите корисници да знаат кој уредува",
-    "Edit guest name" : "Промени име на гостин",
+    "Enter your name" : "Внесете го вашето име",
     "Guest" : "Гостин",
-    "Save guest name" : "Зачувај име на гостин",
+    "submit" : "испрати",
+    "you" : "ти",
+    "edit" : "уреди",
     "Insert an attachment" : "Вметни прилог",
+    "Copy link" : "Копирај линк",
     "Active people" : "Активни луѓе",
     "guest" : "гостин",
     "Offline" : "Исклучен",
@@ -44,6 +45,7 @@ OC.L10N.register(
     "Style" : "Стил",
     "Syntax" : "Синтакса",
     "Keyboard shortcuts" : "Кратенки преку тастатура",
+    "Enter" : "Ентер",
     "Shift" : "Shift",
     "Bold" : "Болд",
     "Bold text" : "Болдиран текст",
@@ -60,22 +62,26 @@ OC.L10N.register(
     "Some code" : "Некој код",
     "Link" : "Линк",
     "Insert emoji" : "Вметни емотикон",
+    "Action" : "Акција",
     "Undo" : "Назад",
     "Redo" : "Напред",
     "Alt" : "Alt",
-    "Cannot copy, please copy the link manually" : "Неможе да се копира, копирајте го линкот рачно",
+    "Open link" : "Отвори линк",
     "Save changes" : "Зачувај ги промените",
     "Cancel" : "Откажи",
     "URL" : "Адреса",
+    "Save" : "Сними",
     "Upload from computer" : "Прикачи од компјутер",
     "Insert from Files" : "Вметни од датотеките",
     "Formatting help" : "Помош за форматирање",
-    "Select file or folder to link to" : "Изберете датотека или папка за линк до",
+    "Translate" : "Преведи",
+    "Delete task" : "Избриши задача",
     "Editor actions" : "Акции на уредникот",
     "Select language" : "Изберете јазик",
     "to" : "до",
     "Replace" : "Преклопи",
     "No emoji found" : "Не се пронајдени емотикони",
+    "Upload" : "Прикачи",
     "Edit" : "Уреди",
     "Source code" : "Изворен код",
     "Failed to load" : "Неуспешно вчитување",
@@ -97,15 +103,12 @@ OC.L10N.register(
     "Command" : "Команда",
     "Ctrl" : "Ctrl",
     "Option" : "Опции",
-    "Use current version" : "Користи ја моменталната верзија",
-    "Use the saved version" : "Користи ја зачуваната верзија",
-    "Document idle for {timeout} minutes, click to continue editing" : "Документот е неактивен {timeout} минути, кликни за да продолжиш со уредување",
-    "Show author colors" : "Прикажи ги боите на авторот",
-    "Author colors are only shown until everyone has closed the document." : "Боите на авторот се прикажуваат само кога сите ќе го затворат документот.",
-    "Info" : "Инфо",
-    "Success" : "Успешно",
-    "Warning" : "Предупредување",
-    "Control" : "Контрола",
-    "Add notes, lists or links …" : "Додади белешки, листи или линкови ..."
+    "Select file or folder to link to" : "Изберете датотека или папка за линк до",
+    "Choose" : "Избери",
+    "Choose {file}" : "Избери {file}",
+    "Add folder description" : "Додади опис на папката",
+    "Edit guest name" : "Промени име на гостин",
+    "Save guest name" : "Зачувај име на гостин",
+    "Cannot copy, please copy the link manually" : "Неможе да се копира, копирајте го линкот рачно"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
