@@ -4,10 +4,14 @@ OC.L10N.register(
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Saiz fail yang dimuatnaik melebihi MAX_FILE_SIZE yang ditetapkan dalam borang HTML",
     "No file was uploaded" : "Tiada fail dimuatnaik",
     "Missing a temporary folder" : "Direktori sementara hilang",
+    "Saved" : "Disimpan",
+    "Cancel" : "Cancel",
+    "URL" : "URL",
+    "Save" : "Simpan",
     "Translate" : "Translate",
     "to" : "kepada",
-    "Info" : "Info",
-    "Warning" : "Amaran",
-    "Edit" : "Sunting"
+    "Upload" : "Muat naik",
+    "Edit" : "Sunting",
+    "Done" : "Selesai"
 },
 "nplurals=1; plural=0;");
