@@ -119,6 +119,9 @@ OC.L10N.register(
     "Save changes" : "保存更改",
     "Cancel" : "取消",
     "URL" : "URL",
+    "Edit block formula" : "編輯區塊公式",
+    "Edit inline formula" : "編輯行內公式",
+    "LaTeX formula" : "LaTeX 公式",
     "Save" : "保存",
     "Disabled because you are currently offline." : "因為您目前離線，所以已停用。",
     "Attachments cannot be created or uploaded because this file is shared from another cloud." : "無法創建或上傳附件，因為此檔案來自另一個雲端分享。",
@@ -204,6 +207,8 @@ OC.L10N.register(
     "Increase indentation" : "增加縮排",
     "Decrease indentation" : "減少縮排",
     "Blocks" : "區塊",
+    "Inline math" : "行內數學",
+    "Block math" : "區塊數學",
     "Info callout" : "資訊標記",
     "Success callout" : "成功標記",
     "Warning callout" : "警告標記",
