@@ -50,7 +50,7 @@ OC.L10N.register(
     "The default light appearance." : "Das helle Standarddesign.",
     "Legal notice" : "Impressum",
     "Privacy policy" : "Datenschutzerklärung",
-    "Adjust the Nextcloud theme" : "Passe das Design von Nextcloud an",
+    "Adjust the Nextcloud theme" : "Passen Sie das Design von Nextcloud an",
     "Name" : "Name",
     "Web link" : "Internet-Link",
     "a safe home for all your data" : "Ein sicheres Zuhause für Ihre Daten",
@@ -95,16 +95,16 @@ OC.L10N.register(
     "Select background" : "Hintergrund wählen",
     "No background has been selected" : "Es wurde kein Hintergrund ausgewählt",
     "Custom background" : "Benutzerdefinierter Hintergrund",
-    "Plain background" : "Einfacher Hintergrund",
+    "Plain background" : "Einfarbiger Hintergrund",
     "Default background" : "Standardhintergrund",
     "Theme selection is enforced" : "Designauswahl wird erzwungen",
     "Could not set the app order" : "Die App-Reihenfolge konnte nicht festgelegt werden",
-    "Could not reset the app order" : "Standard App-Reihenfolge konnte nicht zurückgesetzt werden",
+    "Could not reset the app order" : "Standard-App-Reihenfolge konnte nicht zurückgesetzt werden",
     "Navigation bar settings" : "Einstellungen der Navigationsleiste",
     "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Sie können die App-Reihenfolge für die Navigationsleiste konfigurieren. Der erste Eintrag ist die Standard-App, die nach der Anmeldung oder beim Klicken auf das Logo geöffnet wird.",
     "The default app can not be changed because it was configured by the administrator." : "Die Standard-App kann nicht geändert werden, da sie von der Administration konfiguriert wurde.",
     "The app order was changed, to see it in action you have to reload the page." : "Die App-Reihenfolge wurde geändert. Um die Änderungen zu sehen, müssen Sie die Seite neu laden.",
-    "Reset default app order" : "Standard App-Reihenfolge zurücksetzen",
+    "Reset default app order" : "Standard-App-Reihenfolge zurücksetzen",
     "Could not set primary color" : "Primärfarbe konnte nicht festgelegt werden",
     "Reset primary color" : "Primärfarbe zurücksetzen",
     "Could not set global default apps" : "Globale Standard-Apps konnten nicht festgelegt werden",
@@ -119,12 +119,7 @@ OC.L10N.register(
     "Reset to default" : "Auf Standard zurücksetzen ",
     "Upload" : "Hochladen",
     "Remove background image" : "Hintergrundbild entfernen",
-    "Color" : "Farbe",
     "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Der barrierefreie Zugang ist für uns sehr wichtig. Wir halten uns an Webstandards und prüfen, ob alles auch ohne Maus und unterstützende Software wie Screenreader nutzbar ist. Wir streben die Einhaltung der {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 auf AA-Niveau an, mit dem kontrastreichen Design sogar auf AAA-Niveau.",
-    ". Unable to apply the setting." : ". Fehler beim Anwenden der Einstellung.",
-    "Background" : "Hintergrund",
-    "Set a custom background" : "Einen benutzerdefinierten Hintergrund setzen",
-    "Change color" : "Farbe ändern",
-    "No background" : "Kein Hintergrund"
+    ". Unable to apply the setting." : ". Fehler beim Anwenden der Einstellung."
 },
 "nplurals=2; plural=(n != 1);");
