@@ -10,6 +10,7 @@ OC.L10N.register(
     "Out of office" : "Fora do escritório",
     "Working remotely" : "Em trabalho remoto",
     "In a call" : "Em uma chamada",
+    "Be right back" : "Volto já",
     "User status" : "Status do usuário",
     "Clear status after" : "Limpar status após",
     "Emoji for your status message" : "Emoji para sua mensagem de status",
@@ -23,27 +24,28 @@ OC.L10N.register(
     "There was an error saving the status" : "Ocorreu um erro ao salvar o status",
     "There was an error clearing the status" : "Ocorreu um erro ao limpar o status",
     "There was an error reverting the status" : "Ocorreu um erro ao reverter o status",
-    "Set status" : "Definir status",
-    "Online status" : "Status online",
+    "Online status" : "Status on-line",
     "Status message" : "Mensagem de status",
     "Set absence period" : "Definir período de ausência",
     "Set absence period and replacement" : "Definir período de ausência e substituição",
     "Your status was set automatically" : "Seu status foi definido automaticamente",
     "Clear status message" : "Limpar mensagem de status",
     "Set status message" : "Definir mensagem de status",
-    "Don't clear" : "Não limpe",
-    "Today" : "Hoje",
-    "This week" : "Esta semana",
-    "Online" : "Online",
+    "Online" : "On-line",
     "Away" : "Fora",
+    "Busy" : "Ocupado",
     "Do not disturb" : "Não perturbe",
     "Invisible" : "Invisível",
-    "Offline" : "Offline",
+    "Offline" : "Off-line",
+    "Set status" : "Definir status",
     "There was an error saving the new status" : "Ocorreu um erro ao salvar o novo status",
+    "Don't clear" : "Não limpe",
     "30 minutes" : "30 minutos",
     "1 hour" : "1 hora",
     "4 hours" : "4 horas",
+    "Today" : "Hoje",
+    "This week" : "Esta semana",
     "Mute all notifications" : "Silenciar todas as notificações",
-    "Appear offline" : "Aparecer offline"
+    "Appear offline" : "Aparecer off-line"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
