@@ -27,21 +27,21 @@ OC.L10N.register(
     "%s accessed %s" : "%s rochtain %s",
     "%s renamed %s" : "%s athainmnithe %s",
     "%s copied %s" : "%s chóipeáil %s",
-    "%s assigned %s to %s" : "%s sannta %s do %s",
+    "%1$s assigned %2$s to %3$s" : "%1$s sannta %2$s do %3$s",
     "Operation #%s does not exist" : "Níl oibríocht # %s ann",
-    "Entity %s does not exist" : "Níl aonán %s ann",
     "Entity %s is invalid" : "Tá aonán %s neamhbhailí",
+    "Entity %s does not exist" : "Níl aonán %s ann",
     "No events are chosen." : "Ní roghnaítear aon imeachtaí.",
     "Entity %s has no event %s" : "Níl imeacht %s ag eintiteas %s",
-    "Operation %s does not exist" : "Níl oibríocht %s ann",
-    "Operation %s is invalid" : "Tá oibríocht %s neamhbhailí",
-    "At least one check needs to be provided" : "Ní mór seiceáil amháin ar a laghad a sholáthar",
     "The provided operation data is too long" : "Tá na sonraí oibríochta a chuirtear ar fáil ró-fhada",
+    "Operation %s is invalid" : "Tá oibríocht %s neamhbhailí",
+    "Operation %s does not exist" : "Níl oibríocht %s ann",
+    "At least one check needs to be provided" : "Ní mór seiceáil amháin ar a laghad a sholáthar",
     "Invalid check provided" : "Cuireadh seiceáil neamhbhailí ar fáil",
-    "Check %s does not exist" : "Seiceáil nach bhfuil %s ann",
-    "Check %s is invalid" : "Seiceáil go bhfuil %s neamhbhailí",
-    "Check %s is not allowed with this entity" : "Seiceáil nach bhfuil %s ceadaithe leis an eintiteas seo",
     "The provided check value is too long" : "Tá an luach seiceála a chuirtear ar fáil ró-fhada",
+    "Check %s is invalid" : "Seiceáil go bhfuil %s neamhbhailí",
+    "Check %s does not exist" : "Seiceáil nach bhfuil %s ann",
+    "Check %s is not allowed with this entity" : "Seiceáil nach bhfuil %s ceadaithe leis an eintiteas seo",
     "Check #%s does not exist" : "Seiceáil nach bhfuil # %s ann",
     "Check %s is invalid or does not exist" : "Seiceáil go bhfuil %s neamhbhailí nó níl sé ann",
     "Flow" : "Sreabhadh",
@@ -56,7 +56,6 @@ OC.L10N.register(
     "PDF documents" : "Doiciméid PDF",
     "Video" : "Físeán",
     "Custom MIME type" : "Cineál MIME saincheaptha",
-    "Custom mimetype" : "Cineál MIME saincheaptha",
     "Select a file type" : "Roghnaigh cineál comhaid",
     "e.g. httpd/unix-directory" : "m.sh. httpd/unix-directory",
     "Please enter a valid time span" : "Cuir isteach réise ama bailí le do thoil",
@@ -71,7 +70,7 @@ OC.L10N.register(
     "Select a user agent" : "Roghnaigh gníomhaire úsáideora",
     "Select groups" : "Roghnaigh grúpaí",
     "Groups" : "Grúpaí",
-    "Type to search for group …" : "Clóscríobh chun grúpa a chuardach…",
+    "Type to search for group …" : "Clóscríobh chun grúpa a chuardach …",
     "Select a trigger" : "Roghnaigh truicear",
     "At least one event must be selected" : "Ní mór imeacht amháin ar a laghad a roghnú",
     "Add new flow" : "Cuir sreabhadh nua leis",
@@ -120,6 +119,7 @@ OC.L10N.register(
     "Request user agent" : "Iarr gníomhaire úsáideora",
     "Group membership" : "Ballraíocht ghrúpa",
     "is member of" : "ina bhall de",
-    "is not member of" : "nach ball de"
+    "is not member of" : "nach ball de",
+    "Type to search for group …" : "Clóscríobh chun grúpa a chuardach…"
 },
 "nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
