@@ -21,27 +21,27 @@ OC.L10N.register(
     "File copied" : "Ficheiro copiado",
     "Tag assigned" : "Etiqueta asignada",
     "Someone" : "Someone",
-    "%s created %s" : "%s creado %s",
-    "%s modified %s" : "%s modificado %s",
-    "%s deleted %s" : "%s eliminado %s",
-    "%s accessed %s" : "%s accedido %s",
-    "%s renamed %s" : "%s renomeado %s",
-    "%s copied %s" : "%s copiado %s",
-    "%s assigned %s to %s" : "%s asignado %s a %s",
+    "%s created %s" : "%s creou %s",
+    "%s modified %s" : "%s modificou %s",
+    "%s deleted %s" : "%s eliminou %s",
+    "%s accessed %s" : "%s accedeu a %s",
+    "%s renamed %s" : "%s renomeou %s",
+    "%s copied %s" : "%s copiou %s",
+    "%1$s assigned %2$s to %3$s" : "%1$s asignou %2$s a %3$s",
     "Operation #%s does not exist" : "Non existe a operación nº %s ",
-    "Entity %s does not exist" : "Non existe a entidade %s",
     "Entity %s is invalid" : "A entidade %s é incorrecta",
+    "Entity %s does not exist" : "Non existe a entidade %s",
     "No events are chosen." : "Non foi escollido ningún evento.",
     "Entity %s has no event %s" : "A entidade %s non ten ningún evento %s",
-    "Operation %s does not exist" : "Non existe a operación %s",
-    "Operation %s is invalid" : "A operación %s é incorrecta",
-    "At least one check needs to be provided" : "É necesario fornecer polo menos unha comprobación",
     "The provided operation data is too long" : "Os datos de operación fornecidos son demasiado longos",
+    "Operation %s is invalid" : "A operación %s é incorrecta",
+    "Operation %s does not exist" : "Non existe a operación %s",
+    "At least one check needs to be provided" : "É necesario fornecer polo menos unha comprobación",
     "Invalid check provided" : "Forneceuse unha confirmación incorrecta",
-    "Check %s does not exist" : "Non existe a proba %s",
-    "Check %s is invalid" : "A proba %s é incorrecta",
-    "Check %s is not allowed with this entity" : "A proba %s non está permitida con esta entidade",
     "The provided check value is too long" : "O valor de comprobación fornecido é demasiado longo",
+    "Check %s is invalid" : "A proba %s é incorrecta",
+    "Check %s does not exist" : "Non existe a proba %s",
+    "Check %s is not allowed with this entity" : "A proba %s non está permitida con esta entidade",
     "Check #%s does not exist" : "Non existe a proba nº %s ",
     "Check %s is invalid or does not exist" : "A proba %s é incorrecta ou non existe",
     "Flow" : "Fluxo",
@@ -56,7 +56,6 @@ OC.L10N.register(
     "PDF documents" : "Documentos PDF",
     "Video" : "Vídeo",
     "Custom MIME type" : "Tipo MIME personalizado",
-    "Custom mimetype" : "Tipo MIME personalizado",
     "Select a file type" : "Seleccione un tipo de ficheiro",
     "e.g. httpd/unix-directory" : "p. ex.: httpd/unix-directory",
     "Please enter a valid time span" : "Introduza un intervalo de tempo válido",
@@ -71,7 +70,7 @@ OC.L10N.register(
     "Select a user agent" : "Seleccionar un axente de usuario",
     "Select groups" : "Seleccionar grupos",
     "Groups" : "Grupos",
-    "Type to search for group …" : "Escriba para buscar por grupo…",
+    "Type to search for group …" : "Escriba para buscar por grupo…",
     "Select a trigger" : "Seleccione un activador",
     "At least one event must be selected" : "Ten que seleccionar polo menos un evento",
     "Add new flow" : "Engadir un novo fluxo",
@@ -120,6 +119,7 @@ OC.L10N.register(
     "Request user agent" : "Cliente usado para a solicitude",
     "Group membership" : "Pertenza ao grupo",
     "is member of" : "é membro de",
-    "is not member of" : "non é membro de"
+    "is not member of" : "non é membro de",
+    "Type to search for group …" : "Escriba para buscar por grupo…"
 },
 "nplurals=2; plural=(n != 1);");
