@@ -27,14 +27,13 @@ OC.L10N.register(
     "%s accessed %s" : "%s пристапи %s",
     "%s renamed %s" : "%s преименува %s",
     "%s copied %s" : "%s копираше %s",
-    "%s assigned %s to %s" : "%s пристапи %s до %s",
     "Operation #%s does not exist" : "Операцијата #%s не постои",
-    "Entity %s does not exist" : "Субјектот %s не постои",
     "Entity %s is invalid" : "Субјектот %s е невалиден",
+    "Entity %s does not exist" : "Субјектот %s не постои",
     "No events are chosen." : "Не е избран настан.",
     "Entity %s has no event %s" : "Субјектот %s нема настан %s",
-    "Operation %s does not exist" : "Операцијата %s не постои",
     "Operation %s is invalid" : "Операцијата %s е невалидна",
+    "Operation %s does not exist" : "Операцијата %s не постои",
     "Flow" : "Проток",
     "Select a filter" : "Изберете филтер",
     "Select a comparator" : "Изберете компаратор",
@@ -45,7 +44,6 @@ OC.L10N.register(
     "Office documents" : "Office документи",
     "PDF documents" : "PDF документи",
     "Video" : "Видео",
-    "Custom mimetype" : "Прилагоден тип на датотеки",
     "Select a file type" : "Изберете вид на датотека",
     "e.g. httpd/unix-directory" : "Пр. httpd/unix-directory",
     "Please enter a valid time span" : "Внесете валиден времески осег",
