@@ -27,23 +27,24 @@ OC.L10N.register(
     "%s accessed %s" : "1%s acedido 1%s",
     "%s renamed %s" : "1%s renomeado 1%s",
     "%s copied %s" : "1%s copiado 1%s",
-    "%s assigned %s to %s" : "1%s atribuido 1%s para 1%s",
     "Operation #%s does not exist" : "Operação #1%s não existe",
-    "Entity %s does not exist" : "Entidade %s não existe",
     "Entity %s is invalid" : "Entidade %s é inválida",
+    "Entity %s does not exist" : "Entidade %s não existe",
     "No events are chosen." : "Não são escolhidos eventos.",
     "Entity %s has no event %s" : "Entidade %s não tem evento %s",
     "Operation %s is invalid" : "Operação %s é inválida",
-    "Check %s does not exist" : "Validação %s não existe",
     "Check %s is invalid" : "Validação %s é inválida",
+    "Check %s does not exist" : "Validação %s não existe",
     "Check %s is invalid or does not exist" : "Verifique%sé inválido ou não existe",
     "Flow" : "Fluxo",
     "Nextcloud workflow engine" : "Motor de fluxo de trabalho da Nextcloud",
     "Select a filter" : "Selecionar um filtro",
     "Select a comparator" : "Selecionar um comparador",
     "Remove filter" : "Remover filtro",
+    "Audio" : "Áudio",
     "Folder" : "Pasta",
     "Images" : "Imagens",
+    "Video" : "Vídeo",
     "Files WebDAV" : "Ficheiros WebDAV",
     "Android client" : "Cliente de Android",
     "iOS client" : "Cliente de iOS",
@@ -55,6 +56,7 @@ OC.L10N.register(
     "and" : "e",
     "Cancel" : "Cancelar",
     "Delete" : "Apagar",
+    "Show less" : "Mostrar menos",
     "matches" : "corresponde",
     "does not match" : "não corresponde",
     "is" : "é",
