@@ -27,21 +27,21 @@ OC.L10N.register(
     "%s accessed %s" : "%s 存取了 %s",
     "%s renamed %s" : "%s 重新命名了 %s",
     "%s copied %s" : "%s 複製了 %s",
-    "%s assigned %s to %s" : "%s 指派了 %s 給 %s",
+    "%1$s assigned %2$s to %3$s" : "%1$s 指派了 %2$s 給 %3$s",
     "Operation #%s does not exist" : "操作 #%s 不存在",
-    "Entity %s does not exist" : "實體 %s 不存在",
     "Entity %s is invalid" : "實體 %s 無效",
+    "Entity %s does not exist" : "實體 %s 不存在",
     "No events are chosen." : "未選擇事件。",
     "Entity %s has no event %s" : "實體 %s 沒有事件 %s",
-    "Operation %s does not exist" : "操作 %s 不存在",
-    "Operation %s is invalid" : "操作 #%s 無效",
-    "At least one check needs to be provided" : "至少需要提供一次檢查",
     "The provided operation data is too long" : "提供的操作資料過長",
+    "Operation %s is invalid" : "操作 #%s 無效",
+    "Operation %s does not exist" : "操作 %s 不存在",
+    "At least one check needs to be provided" : "至少需要提供一次檢查",
     "Invalid check provided" : "提供無效的檢查",
-    "Check %s does not exist" : "檢查 %s 不存在",
-    "Check %s is invalid" : "檢查 %s 無效",
-    "Check %s is not allowed with this entity" : "不允許對此實體進行檢查 %s",
     "The provided check value is too long" : "提供的檢查值過長",
+    "Check %s is invalid" : "檢查 %s 無效",
+    "Check %s does not exist" : "檢查 %s 不存在",
+    "Check %s is not allowed with this entity" : "不允許對此實體進行檢查 %s",
     "Check #%s does not exist" : "檢查 #%s 不存在",
     "Check %s is invalid or does not exist" : "檢查 %s 無效或不存在",
     "Flow" : "流程",
@@ -56,7 +56,6 @@ OC.L10N.register(
     "PDF documents" : "PDF 文件",
     "Video" : "影片",
     "Custom MIME type" : "自訂 MIME 類型",
-    "Custom mimetype" : "自訂 mimetype",
     "Select a file type" : "選取檔案類型",
     "e.g. httpd/unix-directory" : "例如：httpd/unix-directory",
     "Please enter a valid time span" : "請輸入有效的時間範圍",
