@@ -1,4 +1,5 @@
 <?php
+
 /**
  * SPDX-FileCopyrightText: 2017 Nextcloud GmbH and Nextcloud contributors
  * SPDX-License-Identifier: AGPL-3.0-or-later
@@ -17,8 +18,11 @@ use OCP\AppFramework\Http\Attribute\FrontpageRoute;
 use OCP\AppFramework\Http\Attribute\NoAdminRequired;
 use OCP\AppFramework\Http\Attribute\NoCSRFRequired;
 use OCP\AppFramework\Http\Attribute\OpenAPI;
+use OCP\AppFramework\Http\Attribute\PasswordConfirmationRequired;
 use OCP\AppFramework\Http\Attribute\PublicPage;
 use OCP\AppFramework\Http\Attribute\UseSession;
+use OCP\AppFramework\Http\ContentSecurityPolicy;
+use OCP\AppFramework\Http\RedirectResponse;
 use OCP\AppFramework\Http\Response;
 use OCP\AppFramework\Http\StandaloneTemplateResponse;
 use OCP\AppFramework\Utility\ITimeFactory;
@@ -62,7 +66,7 @@ class ClientFlowLoginController extends Controller {
 	}
 
 	private function getClientName(): string {
-		$userAgent = $this->request->getHeader('USER_AGENT');
+		$userAgent = $this->request->getHeader('user-agent');
 		return $userAgent !== '' ? $userAgent : 'unknown';
 	}
 
@@ -106,8 +110,8 @@ class ClientFlowLoginController extends Controller {
 				$this->appName,
 				'error',
 				[
-					'errors' =>
-					[
+					'errors'
+					=> [
 						[
 							'error' => 'Access Forbidden',
 							'hint' => 'Invalid request',
@@ -124,7 +128,7 @@ class ClientFlowLoginController extends Controller {
 		);
 		$this->session->set(self::STATE_NAME, $stateToken);
 
-		$csp = new Http\ContentSecurityPolicy();
+		$csp = new ContentSecurityPolicy();
 		if ($client) {
 			$csp->addAllowedFormActionDomain($client->getRedirectUri());
 		} else {
@@ -177,7 +181,7 @@ class ClientFlowLoginController extends Controller {
 			$clientName = $client->getName();
 		}
 
-		$csp = new Http\ContentSecurityPolicy();
+		$csp = new ContentSecurityPolicy();
 		if ($client) {
 			$csp->addAllowedFormActionDomain($client->getRedirectUri());
 		} else {
@@ -212,6 +216,7 @@ class ClientFlowLoginController extends Controller {
 
 	#[NoAdminRequired]
 	#[UseSession]
+	#[PasswordConfirmationRequired(strict: false)]
 	#[FrontpageRoute(verb: 'POST', url: '/login/flow')]
 	public function generateAppPassword(
 		string $stateToken,
@@ -313,7 +318,7 @@ class ClientFlowLoginController extends Controller {
 			new AppPasswordCreatedEvent($generatedToken)
 		);
 
-		return new Http\RedirectResponse($redirectUri);
+		return new RedirectResponse($redirectUri);
 	}
 
 	#[PublicPage]
@@ -342,7 +347,7 @@ class ClientFlowLoginController extends Controller {
 		}
 
 		$redirectUri = 'nc://login/server:' . $this->getServerPath() . '&user:' . urlencode($user) . '&password:' . urlencode($password);
-		return new Http\RedirectResponse($redirectUri);
+		return new RedirectResponse($redirectUri);
 	}
 
 	private function getServerPath(): string {
