@@ -153,6 +153,13 @@ OC.L10N.register(
     "Cannot install this app" : "Nun se pue instalar esta aplicación",
     "Skip" : "Saltar",
     "Install recommended apps" : "Instalar les aplicaciones aconseyaes",
+    "Online" : "En llinia",
+    "Away" : "Ausente",
+    "Busy" : "Ocupáu",
+    "Do not disturb" : "Nun molestar",
+    "Mute all notifications" : "Desactivar tolos avisos",
+    "Invisible" : "Invisible",
+    "Appear offline" : "Apaecer desconectáu",
     "Avatar of {displayName}" : "Avatar de: {displayName}",
     "Settings menu" : "Menú de configuración",
     "Search contacts" : "Buscar contautos",
@@ -343,7 +350,6 @@ OC.L10N.register(
     "Error fetching contact actions" : "Hebo un error al dir en cata de les aiciones del contautu",
     "Non-existing tag #{tag}" : "Etiqueta inesistente #{tag}",
     "Restricted" : "Restrinxóse",
-    "Invisible" : "Invisible",
     "Delete" : "Desaniciar",
     "Rename" : "Renomar",
     "Collaborative tags" : "Etiquetes collaboratives",
