@@ -18,15 +18,15 @@ OC.L10N.register(
     "Unknown filetype" : "Nekonata dosiertipo",
     "An error occurred. Please contact your admin." : "Eraro okazis. Bonvolu kontakti vian administranton.",
     "Invalid image" : "Nevalida bildo",
-    "No temporary profile picture available, try again" : "Neniu provizora profilbildo disponeblas, bv. reprovi",
-    "No crop data provided" : "Neniu stucdatumo provizita",
-    "No valid crop data provided" : "Neniu valida stucdatumo provizita",
-    "Crop is not square" : "Stuca elekto ne estas kvadrata",
     "State token does not match" : "Stata ĵetono ne kongruas",
     "Invalid app password" : "Nevalida aplikaĵo-pasvorto",
     "Could not complete login" : "Ensaluto ne eblis",
+    "State token missing" : "Mankas ĵetono pri stato",
     "Your login token is invalid or has expired" : "Via ensaluta ĵetono ne validas aŭ senvalidiĝis",
+    "Please use original client" : "Bonvolu uzi la originan klienton",
+    "This community release of Nextcloud is unsupported and push notifications are limited." : "Tiu ĉi komunuma eldonaĵo de Nextcloud ne havas subtenon, kaj puŝajn atentigojn estas limigitaj.",
     "Login" : "Login",
+    "Unsupported email length (>255)" : "Nevalida longeco de retadreso (>255)",
     "Password reset is disabled" : "Pasvorta restarigo malebligita",
     "Could not reset password because the token is expired" : "Ne eblis restarigi pasvorton, ĉar la ĵetono senvalidiĝis",
     "Could not reset password because the token is invalid" : "Ne eblis restarigi pasvorton, ĉar la ĵetono ne validas",
@@ -36,21 +36,25 @@ OC.L10N.register(
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Alklaku la jenan butonon por restarigi vian pasvorton. Si vi ne petis restarigon de via pasvorto, simple ignoru tiun ĉi retmesaĝon.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Alklaku la jenan ligilon por restarigi vian pasvorton. Si vi ne petis restarigon de via pasvorto, simple ignoru tiun ĉi retmesaĝon.",
     "Reset your password" : "Restarigi vian pasvorton ",
+    "The given provider is not available" : "La provizanto menciita ne estas disponebla",
     "Task not found" : "Tasko ne trovita",
     "Internal error" : "Interna eraro",
     "Not found" : "Ne trovita",
+    "Node is locked" : "Nodo estas ŝlosita",
+    "Bad request" : "Malbona peto",
+    "Requested task type does not exist" : "Petita task-tipo ne ekzistas",
     "Image not found" : "Bildo ne trovita",
     "Unable to translate" : "Ne eblas traduki",
-    "Nextcloud Server" : "Nextcloud-servilo",
-    "Some of your link shares have been removed" : "Kelkaj el viaj kunhavigaj ligiloj estis forigitaj",
-    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Pro sekuriga problemo, ni forigu kelkajn el viaj kunhavigaj ligiloj. Bv. vidi la ligilon por plia informo.",
-    "Learn more ↗" : "Scii pli ↗",
-    "Preparing update" : "Preparo de  la ĝisdatigo",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Ripara stadio:",
     "Repair info:" : "Ripara informo:",
     "Repair warning:" : "Ripara averto:",
     "Repair error:" : "Ripara eraro:",
+    "Nextcloud Server" : "Nextcloud-servilo",
+    "Some of your link shares have been removed" : "Kelkaj el viaj kunhavigaj ligiloj estis forigitaj",
+    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Pro sekuriga problemo, ni forigu kelkajn el viaj kunhavigaj ligiloj. Bv. vidi la ligilon por plia informo.",
+    "Learn more ↗" : "Scii pli ↗",
+    "Preparing update" : "Preparo de  la ĝisdatigo",
     "Turned on maintenance mode" : "Reĝimo de prizorgado ŝaltita.",
     "Turned off maintenance mode" : "Reĝimo de prizorgado malŝaltita.",
     "Maintenance mode is kept active" : "Reĝimo de prizorgado pluas",
@@ -66,16 +70,7 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (nekongrua)",
     "The following apps have been disabled: %s" : "La jenaj aplikaĵoj estis malŝatitaj: %s",
     "Already up to date" : "Jam aktuala",
-    "Error occurred while checking server setup" : "Eraro dum kontrolo de servila agordo",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "Por pliaj detaloj, vidu la {linkstart}dokumentaron ↗{linkend}.",
-    "unknown text" : "nekonata teksto",
-    "Hello world!" : "Saluton, mondo!",
-    "sunny" : "suna",
-    "Hello {name}, the weather is {weather}" : "Saluton {name}, la vetero estas {weather}",
-    "Hello {name}" : "Saluton {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Jen via serĉ-rezultoj<script>alert(1)</script></strong>",
-    "new" : "nova",
-    "_download %n file_::_download %n files_" : ["elŝuti %n dosieron","elŝuti %n dosierojn"],
+    "Unknown" : "Nekonata",
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Ĝisdatigo estas farata; forirado de la paĝo povas kelkfoje interrompi la agon.",
     "Update to {version}" : "Ĝisdatigi al {version}",
     "An error occurred." : "Eraro okazis.",
@@ -93,7 +88,6 @@ OC.L10N.register(
     "Pick start date" : "Elekti komencan daton",
     "Pick end date" : "Elekti finan daton",
     "Search in date range" : "Serĉi en data periodo",
-    "Searching …" : "Serĉado ...",
     "Start typing to search" : "Ektajpu por serĉi",
     "No matching results" : "Neniuj kongruaj rezultoj",
     "Today" : "Hodiaŭ",
@@ -107,7 +101,6 @@ OC.L10N.register(
     "Filter in current view" : "Filtrilo en ĉi vido",
     "Search in" : "Serĉi en",
     "Log in" : "Ensaluti",
-    "Logging in …" : "Ensaluti...",
     "Log in to {productName}" : "Saluti al {productName}",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Ni eltrovis plurajn nevalidajn provojn ensaluti el via IP-adreso. Do, oni prokrastis vian sekvantan ensaluton dum ĝis 30 sekundoj.",
     "Account name or email" : "Kontonomo aŭ retpoŝta adreso",
@@ -117,29 +110,26 @@ OC.L10N.register(
     "Please try again or contact your administrator." : "Bonvolu provi ree aŭ kontakti vian administranton.",
     "Password" : "Pasvorto",
     "Your account is not setup for passwordless login." : "Via konto ne estas agordita por uzi senpasvortan ensaluton.",
-    "Passwordless authentication is not supported in your browser." : "Senpasvorta aŭtentigo ne eblas per via retumilo.",
     "Your connection is not secure" : "La konekto ne sekuras",
     "Passwordless authentication is only available over a secure connection." : "Senpasvorta aŭtentigo eblas nur pere de sekura konekto.",
+    "Passwordless authentication is not supported in your browser." : "Senpasvorta aŭtentigo ne eblas per via retumilo.",
     "Reset password" : "Restarigi pasvorton",
-    "Couldn't send reset email. Please contact your administrator." : "Ne eblas sendi retpoŝton pri restarigo. Bonvolu kontakti vian administranton.",
     "Back to login" : "Antaŭen al ensaluto",
+    "Couldn't send reset email. Please contact your administrator." : "Ne eblas sendi retpoŝton pri restarigo. Bonvolu kontakti vian administranton.",
     "New password" : "Nova pasvorto",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Viaj dosieroj estas ĉifritaj. Ne estos eble rehavi viajn datumojn post la restarigo de via pasvorto. Se vi ne tute certas pri kio fari, bonvolu pridemandi vian administranton, antaŭ ol daŭrigi.  Ĉu vi ja volas daŭrigi?",
     "I know what I'm doing" : "Mi scias, kion mi faras",
     "Resetting password" : "Restarigo de la pasvorto",
     "Recommended apps" : "Rekomendataj aplikaĵoj",
-    "Loading apps …" : "Ŝargado de aplikaĵoj...",
     "App download or installation failed" : "Elŝuto aŭ instalado de la aplikaĵo malsukcesis",
     "Cannot install this app" : "La instalado de tiu aplikaĵo ne eblas",
     "Skip" : "Preterpasi",
-    "Installing apps …" : "Instalado de aplikaĵoj...",
     "Install recommended apps" : "Instali rekomendatajn aplikaĵojn",
+    "Busy" : "Okupita",
+    "Invisible" : "Nevidebla",
     "Avatar of {displayName}" : "Avataro de {displayName}",
     "Settings menu" : "Menuo de agordo",
-    "Loading your contacts …" : "Ŝargo de viaj kontaktoj...",
-    "Looking for {term} …" : "Serĉo de {term}…",
     "Reset search" : "Restarigi serĉon",
-    "Search contacts …" : "Serĉi kontaktojn…",
     "Could not load your contacts" : "Ne eblis ŝargi viajn kontaktojn",
     "No contacts found" : "Neniu kontakto troviĝis",
     "Install the Contacts app" : "Instali la Kontakto-aplikaĵon",
@@ -148,6 +138,24 @@ OC.L10N.register(
     "Forgot password?" : "Ĉu vi forgesis vian pasvorton?",
     "Back" : "Antaŭen",
     "More actions" : "Pliaj agoj",
+    "Security warning" : "Sekureca averto",
+    "Storage & database" : "Konservejo kaj datumbazo",
+    "Data folder" : "Datuma dosierujo",
+    "Install and activate additional PHP modules to choose other database types." : "Instalu kaj aktivigu pliajn PHP-modulojn por elekti aliajn datumbazajn specojn..",
+    "For more details check out the documentation." : "Por pli detaloj, vidu la dokumentaron.",
+    "Performance warning" : "Rendimenta averto",
+    "You chose SQLite as database." : "Vi elektis datumbazon „SQLite“.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite estu nur uzita por minimuma kaj programista servilo. Por produkta medio, ni rekomendas uzi alian tipon de datumbazo.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Se vi uzas klientojn por sinkronigi dosierojn, oni ne rekomendas datumbazon SQLite.",
+    "Database user" : "Datumbaza uzanto",
+    "Database password" : "Datumbaza pasvorto",
+    "Database name" : "Datumbaza nomo",
+    "Database tablespace" : "Datumbaza tabelospaco",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Bv. entajpi la pordan numeron kune kun la gastiga nomo (ekzemple: localhost:5432).",
+    "Database host" : "Datumbaza gastigo",
+    "Install" : "Instali",
+    "Need help?" : "Ĉu necesas helpo?",
+    "See the documentation" : "Vidi la dokumentaron",
     "{name} version {version} and above" : "{name} versio {version} kaj supre",
     "This browser is not supported" : "La retumilo ne estas subtenata",
     "Continue with this unsupported browser" : "Daŭrigi per tiu ne subtenata retumilo",
@@ -171,7 +179,6 @@ OC.L10N.register(
     "(all selected)" : "(ĉiuj elektitaj)",
     "({count} selected)" : "({count} elektitaj)",
     "Error loading file exists template" : "Eraris ŝargo de ŝablono pri ekzistanta dosiero",
-    "Saving …" : "Konservado...",
     "seconds ago" : "sekundoj antaŭe",
     "Connection to server lost" : "Konekto al servilo perdita",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problemo dum ŝargo de paĝo, reŝargo en %n sekundo","Problemo dum ŝargo de paĝo, reŝargo en %n sekundoj"],
@@ -186,29 +193,15 @@ OC.L10N.register(
     "Type to search for existing projects" : "Entajpi por serĉi jam ekzistantajn projektojn",
     "New in" : "Nova en",
     "View changelog" : "Vidi ŝanĝoprotokolon",
-    "Very weak password" : "Tre malforta pasvorto",
-    "Weak password" : "Malforta pasvorto",
-    "So-so password" : "Mezbona pasvorto",
-    "Good password" : "Bona pasvorto",
-    "Strong password" : "Forta pasvorto",
-    "No action available" : "Neniu ago disponebla",
-    "Error fetching contact actions" : "Eraro dum serĉo de kontakt-agoj",
     "Close \"{dialogTitle}\" dialog" : "Fermi la dialogon \"{dialogTitle}\"",
-    "Non-existing tag #{tag}" : "Ne ekzistas etikedo #{tag}",
-    "Restricted" : "Limigita",
-    "Invisible" : "Nevidebla",
-    "Delete" : "Forigi",
-    "Rename" : "Alinomi",
-    "Collaborative tags" : "Kunlaboraj etikedoj",
-    "No tags found" : "Neniu etikedo troviĝis ",
     "Personal" : "Persona",
     "Accounts" : "Kontoj",
     "Admin" : "Administranto",
     "Help" : "Helpo",
     "Access forbidden" : "Aliro estas malpermesata",
+    "Back to %s" : "Antaŭen al %s",
     "Page not found" : "Paĝo ne trovita",
     "The page could not be found on the server or you may not be allowed to view it." : "La paĝo ne povis esti trovita en la servilo aŭ vi eble ne rajtas vidi ĝin.",
-    "Back to %s" : "Antaŭen al %s",
     "Too many requests" : "Tro da petoj",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Estis tro multaj petoj de via reto. Reprovu poste aŭ kontaktu vian administranton se tio estas eraro.",
     "Error" : "Eraro",
@@ -225,31 +218,6 @@ OC.L10N.register(
     "File: %s" : "Dosiero: %s",
     "Line: %s" : "Linio: %s",
     "Trace" : "Spuro",
-    "Security warning" : "Sekureca averto",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Via datumdosierujo kaj dosieroj estas probable elireblaj el la interreto, ĉar la dosiero „.htaccess“ ne funkcias.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Por pli da informoj pri kielo agordi vian retservilon, bv. vidi la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentaron</a>.",
-    "Show password" : "Montri pasvorton",
-    "Toggle password visibility" : "Ŝanĝi videblecon de pasvorto",
-    "Storage & database" : "Konservejo kaj datumbazo",
-    "Data folder" : "Datuma dosierujo",
-    "Configure the database" : "Agordi la datumbazon",
-    "Only %s is available." : "Nur %s disponeblas.",
-    "Install and activate additional PHP modules to choose other database types." : "Instalu kaj aktivigu pliajn PHP-modulojn por elekti aliajn datumbazajn specojn..",
-    "For more details check out the documentation." : "Por pli detaloj, vidu la dokumentaron.",
-    "Database account" : "Datumbaza konto",
-    "Database password" : "Datumbaza pasvorto",
-    "Database name" : "Datumbaza nomo",
-    "Database tablespace" : "Datumbaza tabelospaco",
-    "Database host" : "Datumbaza gastigo",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Bv. entajpi la pordan numeron kune kun la gastiga nomo (ekzemple: localhost:5432).",
-    "Performance warning" : "Rendimenta averto",
-    "You chose SQLite as database." : "Vi elektis datumbazon „SQLite“.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite estu nur uzita por minimuma kaj programista servilo. Por produkta medio, ni rekomendas uzi alian tipon de datumbazo.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Se vi uzas klientojn por sinkronigi dosierojn, oni ne rekomendas datumbazon SQLite.",
-    "Install" : "Instali",
-    "Installing …" : "Instalante…",
-    "Need help?" : "Ĉu necesas helpo?",
-    "See the documentation" : "Vidi la dokumentaron",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Ŝajnas, ke vi provas reinstali vian Nextcloud. Sed la dosiero CAN_INSTALL (angle por „eblo instali“) mankas en via dosierujo „config“. Bv. krei dosieron CAN_INSTALL ene de via dosierujo „config“ por daŭrigi.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Ne eblis forigi la dosieron „CAN_INSTALL“ el via dosierujo „config“. Bv. forigi ĝin permane.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Tiu aplikaĵo bezonas Ĝavoskripton („Javascript“) por funkcii. Bonvolu {linkstart}ŝalti Ĝavoskripton{linkend} kaj poste reŝargi la paĝon.",
@@ -304,10 +272,44 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "La servilo %s estas nun en reĝimo de prizorgado, tio eble daŭros longatempe.",
     "This page will refresh itself when the instance is available again." : "Tiu ĉi paĝo aktualiĝos mem, kiam la servilo redisponeblos.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontaktu vian administranton, se tiu ĉi mesaĝo daŭras aŭ aperas neatendite.",
-    "Currently open" : "Aktuale malfermita",
-    "Edit Profile" : "Modifi profilon",
-    "Error loading message template: {error}" : "Eraro dum ŝargo de mesaĝa ŝablono: {error}",
-    "Profile not found" : "Profilo ne troviĝis",
-    "The profile does not exist." : "La profilo ne ekzistas."
+    "Error occurred while checking server setup" : "Eraro dum kontrolo de servila agordo",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "Por pliaj detaloj, vidu la {linkstart}dokumentaron ↗{linkend}.",
+    "unknown text" : "nekonata teksto",
+    "Hello world!" : "Saluton, mondo!",
+    "sunny" : "suna",
+    "Hello {name}, the weather is {weather}" : "Saluton {name}, la vetero estas {weather}",
+    "Hello {name}" : "Saluton {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Jen via serĉ-rezultoj<script>alert(1)</script></strong>",
+    "new" : "nova",
+    "_download %n file_::_download %n files_" : ["elŝuti %n dosieron","elŝuti %n dosierojn"],
+    "Searching …" : "Serĉado ...",
+    "Logging in …" : "Ensaluti...",
+    "Loading apps …" : "Ŝargado de aplikaĵoj...",
+    "Installing apps …" : "Instalado de aplikaĵoj...",
+    "Loading your contacts …" : "Ŝargo de viaj kontaktoj...",
+    "Looking for {term} …" : "Serĉo de {term}…",
+    "Search contacts …" : "Serĉi kontaktojn…",
+    "Saving …" : "Konservado...",
+    "Very weak password" : "Tre malforta pasvorto",
+    "Weak password" : "Malforta pasvorto",
+    "So-so password" : "Mezbona pasvorto",
+    "Good password" : "Bona pasvorto",
+    "Strong password" : "Forta pasvorto",
+    "No action available" : "Neniu ago disponebla",
+    "Error fetching contact actions" : "Eraro dum serĉo de kontakt-agoj",
+    "Non-existing tag #{tag}" : "Ne ekzistas etikedo #{tag}",
+    "Restricted" : "Limigita",
+    "Delete" : "Forigi",
+    "Rename" : "Alinomi",
+    "Collaborative tags" : "Kunlaboraj etikedoj",
+    "No tags found" : "Neniu etikedo troviĝis ",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Via datumdosierujo kaj dosieroj estas probable elireblaj el la interreto, ĉar la dosiero „.htaccess“ ne funkcias.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Por pli da informoj pri kielo agordi vian retservilon, bv. vidi la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentaron</a>.",
+    "Show password" : "Montri pasvorton",
+    "Toggle password visibility" : "Ŝanĝi videblecon de pasvorto",
+    "Configure the database" : "Agordi la datumbazon",
+    "Only %s is available." : "Nur %s disponeblas.",
+    "Database account" : "Datumbaza konto",
+    "Installing …" : "Instalante…"
 },
 "nplurals=2; plural=(n != 1);");
