@@ -18,10 +18,6 @@ OC.L10N.register(
     "Unknown filetype" : "Tipo de archivo desconocido",
     "An error occurred. Please contact your admin." : "Se presentó un error. Por favor contacta a tu adminsitrador. ",
     "Invalid image" : "Imagen inválida",
-    "No temporary profile picture available, try again" : "No hay una imagen de perfil temporal disponible, por favor inténtalo de nuevo",
-    "No crop data provided" : "No se han proporcionado datos del recorte",
-    "No valid crop data provided" : "No se han proporcionado datos válidos del recorte",
-    "Crop is not square" : "El recorte no es cuadrado",
     "State token does not match" : "La ficha de estado no corresponde",
     "Invalid app password" : "Contraseña de la aplicación no válida",
     "Could not complete login" : "No se pudo completar el inicio de sesión",
@@ -70,16 +66,6 @@ OC.L10N.register(
     "The following apps have been disabled: %s" : "Las siguientes aplicaciones se han desactivado: %s",
     "Already up to date" : "Ya está actualizado",
     "Unknown" : "Desconocido",
-    "Error occurred while checking server setup" : "Se presentó un error al verificar la configuración del servidor",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "Para obtener más detalles, consulte la {linkstart}documentación ↗{linkend}.",
-    "unknown text" : "texto desconocido",
-    "Hello world!" : "¡Hola mundo!",
-    "sunny" : "soleado",
-    "Hello {name}, the weather is {weather}" : "Hola {name}, el clima es {weather}",
-    "Hello {name}" : "Hola {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Estos son los resultados de tu búsqueda <script>alert(1)</script></strong>",
-    "new" : "nuevo",
-    "_download %n file_::_download %n files_" : ["Descargar %n archivos","Descargar %n archivos","Descargar %n archivos"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "La actualización está en curso, abandonar esta página puede interrumpir el proceso en algunos ambientes. ",
     "Update to {version}" : "Actualizar a {version}",
     "An error occurred." : "Se presentó un error.",
@@ -95,16 +81,15 @@ OC.L10N.register(
     "Yes" : "Sí",
     "Failed to add the public link to your Nextcloud" : "Se presentó una falla al agregar el enlace público a tu Nextcloud",
     "Create share" : "Crear compartición",
-    "Searching …" : "Buscando...",
     "Start typing to search" : "Empieza a escribir para buscar",
     "Today" : "Hoy",
+    "Last 7 days" : "Últimos 7 días",
     "Last year" : "Último año",
     "Places" : "Lugares",
     "People" : "Personas",
     "Results" : "Resultados",
     "Load more results" : "Cargar más resultados",
     "Log in" : "Ingresar",
-    "Logging in …" : "Iniciando sesión ...",
     "Log in to {productName}" : "Iniciar sesión en {productName}",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Hemos detectado múltiples intentos de inicio de sesión desde tu IP. Por lo tanto tu siguiente incio de sesión se retrasará hasta 30 segundos. ",
     "Account name or email" : "Nombre de cuenta o correo electrónico",
@@ -134,20 +119,22 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Documentos colaborativos, hojas de cálculo y presentaciones, basados en Collabora Online.",
     "Distraction free note taking app." : "Aplicación de toma de notas sin distracciones.",
     "Recommended apps" : "Aplicaciones recomendadas",
-    "Loading apps …" : "Cargando aplicaciones...",
     "Could not fetch list of apps from the App Store." : "No se pudo obtener la lista de aplicaciones desde la Tienda de aplicaciones.",
     "App download or installation failed" : "Error al descargar o instalar la aplicación",
     "Cannot install this app because it is not compatible" : "No se puede instalar esta aplicación porque no es compatible",
     "Cannot install this app" : "No se puede instalar esta aplicación",
     "Skip" : "Omitir",
-    "Installing apps …" : "Instalando aplicaciones...",
     "Install recommended apps" : "Instalar aplicaciones recomendadas",
+    "Online" : "En línea",
+    "Away" : "Ausente",
+    "Busy" : "Ocupado",
+    "Do not disturb" : "No molestar",
+    "Mute all notifications" : "Silenciar todas las notificaciones",
+    "Invisible" : "Invisible",
+    "Appear offline" : "Aparecer como desconectado",
     "Settings menu" : "Menú de Configuraciones",
-    "Loading your contacts …" : "Cargando sus contactos ... ",
-    "Looking for {term} …" : "Buscando {term} ...",
     "Search contacts" : "Buscar contactos",
     "Reset search" : "Reestablecer búsqueda",
-    "Search contacts …" : "Buscar contactos ...",
     "Could not load your contacts" : "No fue posible cargar tus contactos",
     "No contacts found" : "No se encontraron contactos",
     "Show all contacts" : "Mostrar todos los contactos",
@@ -159,7 +146,6 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Se produjo un error al buscar {type}",
     "Search starts once you start typing and results may be reached with the arrow keys" : "La búsqueda comienza una vez que empiezas a escribir y los resultados se pueden alcanzar con las teclas de flecha",
     "Search for {name} only" : "Buscar solo {name}",
-    "Loading more results …" : "Cargando más resultados ...",
     "Forgot password?" : "¿Olvidaste tu contraseña?",
     "Back to login form" : "Volver al formulario de inicio de sesión",
     "Back" : "Atrás",
@@ -180,7 +166,6 @@ OC.L10N.register(
     "Database tablespace" : "Espacio de tablas en la base de datos",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Por favor especifica el número de puerto así como el nombre del servidor (ejem., localhost:5432).",
     "Database host" : "Servidor de base de datos",
-    "Installing …" : "Instalando...",
     "Install" : "Instalar",
     "Need help?" : "¿Necesitas ayuda?",
     "See the documentation" : "Ver la documentación",
@@ -189,7 +174,6 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Tu navegador no es compatible. Por favor, actualízalo a una versión más nueva o una compatible.",
     "Continue with this unsupported browser" : "Continuar con este navegador no compatible",
     "Supported versions" : "Versiones compatibles",
-    "Search {types} …" : "Buscar {types} ...",
     "Choose" : "Seleccionar",
     "Copy" : "Copiar",
     "Move" : "Mover",
@@ -206,7 +190,7 @@ OC.L10N.register(
     "(all selected)" : "(todos seleccionados)",
     "({count} selected)" : "({count} seleccionados)",
     "Error loading file exists template" : "Se presentó un error al cargar la plantilla de existe archivo ",
-    "Saving …" : "Saving …",
+    "Saving …" : "Guardando...",
     "seconds ago" : "hace segundos",
     "Connection to server lost" : "Se ha perdido la conexión con el servidor",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Se presentó un error al cargar la página, recargando en %n segundo","Se presentó un error al cargar la página, recargando en %n segundos","Se presentó un error al cargar la página, recargando en %n segundos"],
@@ -221,16 +205,7 @@ OC.L10N.register(
     "Type to search for existing projects" : "Escribe para buscar proyectos existentes",
     "New in" : "Nuevo en",
     "View changelog" : "Ver registro de cambios",
-    "No action available" : "No hay acciones disponibles",
-    "Error fetching contact actions" : "Se presentó un error al traer las acciónes de contatos",
     "Close \"{dialogTitle}\" dialog" : "Cerrar diálogo \"{dialogTitle}\"",
-    "Non-existing tag #{tag}" : "Etiqueta #{tag} no-existente",
-    "Restricted" : "Restringido",
-    "Invisible" : "Invisible",
-    "Delete" : "Borrar",
-    "Rename" : "Renombrar",
-    "Collaborative tags" : "Etiquetas colaborativas",
-    "No tags found" : "No se encontraron etiquetas",
     "Personal" : "Personal",
     "Accounts" : "Cuentas",
     "Admin" : "Administración",
@@ -310,24 +285,45 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Esta instancia %s se encuentra actualmente en modo mantenimiento, que podría tomar algo de tiempo. ",
     "This page will refresh itself when the instance is available again." : "Esta página se actualizará automáticamente cuando la instancia esté disponible nuevamente.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacta a tu administrador del sistema si este mensaje persiste o se presentó de manera inesperada.",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chat, videollamadas, uso compartido de pantalla, reuniones en línea y videoconferencias, en tu navegador y con aplicaciones móviles.",
-    "You have not added any info yet" : "No has agregado ninguna información todavía",
-    "{user} has not added any info yet" : "{user} no ha agregado ninguna información aún",
-    "Error opening the user status modal, try hard refreshing the page" : "Error al abrir el modal de estado del usuario, intenta actualizar la página",
-    "Edit Profile" : "Editar perfil",
-    "The headline and about sections will show up here" : "El titular y la sección Acerca de se mostrarán aquí",
+    "Error occurred while checking server setup" : "Se presentó un error al verificar la configuración del servidor",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "Para obtener más detalles, consulte la {linkstart}documentación ↗{linkend}.",
+    "unknown text" : "texto desconocido",
+    "Hello world!" : "¡Hola mundo!",
+    "sunny" : "soleado",
+    "Hello {name}, the weather is {weather}" : "Hola {name}, el clima es {weather}",
+    "Hello {name}" : "Hola {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Estos son los resultados de tu búsqueda <script>alert(1)</script></strong>",
+    "new" : "nuevo",
+    "_download %n file_::_download %n files_" : ["Descargar %n archivos","Descargar %n archivos","Descargar %n archivos"],
+    "Searching …" : "Buscando...",
+    "Logging in …" : "Iniciando sesión ...",
+    "Loading apps …" : "Cargando aplicaciones...",
+    "Installing apps …" : "Instalando aplicaciones...",
+    "Loading your contacts …" : "Cargando sus contactos ... ",
+    "Looking for {term} …" : "Buscando {term} ...",
+    "Search contacts …" : "Buscar contactos ...",
+    "Loading more results …" : "Cargando más resultados ...",
+    "Search {types} …" : "Buscar {types} ...",
+    "Saving …" : "Saving …",
     "Very weak password" : "Contraseña muy débil",
     "Weak password" : "Contraseña débil",
     "So-so password" : "Contraseña aceptable",
     "Good password" : "Buena contraseña",
     "Strong password" : "Contraseña fuerte",
-    "Profile not found" : "Perfil no encontrado",
-    "The profile does not exist." : "El perfil no existe.",
+    "No action available" : "No hay acciones disponibles",
+    "Error fetching contact actions" : "Se presentó un error al traer las acciónes de contatos",
+    "Non-existing tag #{tag}" : "Etiqueta #{tag} no-existente",
+    "Restricted" : "Restringido",
+    "Delete" : "Borrar",
+    "Rename" : "Renombrar",
+    "Collaborative tags" : "Etiquetas colaborativas",
+    "No tags found" : "No se encontraron etiquetas",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Tu directorio de datos y sus archivos probablemente sean accesibles desde Internet ya que el archivo .htaccess no funciona.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Para más información de como configurar correctaemente tu servidor, por favor consulta la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentación</a>.",
     "Show password" : "Mostrar contraseña",
     "Toggle password visibility" : "Alternar visibilidad de contraseña",
     "Configure the database" : "Configurar la base de datos",
-    "Only %s is available." : "Sólo %s está disponible."
+    "Only %s is available." : "Sólo %s está disponible.",
+    "Installing …" : "Instalando..."
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
