@@ -18,15 +18,12 @@ OC.L10N.register(
     "Unknown filetype" : "Fitxategi mota ezezaguna",
     "An error occurred. Please contact your admin." : "Errore bat gertatu da, jarri zure administratzailearekin harremanetan.",
     "Invalid image" : "Baliogabeko irudia",
-    "No temporary profile picture available, try again" : "Ez dago behin-behineko profil irudirik erabilgarri, saiatu berriro",
-    "No crop data provided" : "Ez da mozketa daturik eman",
-    "No valid crop data provided" : "Ez da baliozko mozketa daturik eman",
-    "Crop is not square" : "Mozketa ez da karratua",
     "State token does not match" : "Egoera-tokena ez dator bat",
     "Invalid app password" : "Aplikazio pasahitz baliogabea",
     "Could not complete login" : "Ezin izan da saioa hasi",
     "State token missing" : "Egoera-tokena falta da",
     "Your login token is invalid or has expired" : "Zure saio-hasierako tokena baliogabea da edo iraungi da",
+    "Please use original client" : "Erabili jatorrizko bezeroa",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "Nextcloud komunitate bertsio honek ez du laguntza-zerbitzurik eta push jakinarazpenak mugatuak dira.",
     "Login" : "Hasi saioa",
     "Unsupported email length (>255)" : "E-posta luzera onartezina (>255)",
@@ -43,6 +40,7 @@ OC.L10N.register(
     "Task not found" : "Ez da eginkizuna aurkitu",
     "Internal error" : "Barne errorea",
     "Not found" : "Ez da aurkitu",
+    "Node is locked" : "Nodoa blokeatuta dago",
     "Bad request" : "Eskaera txarra",
     "Requested task type does not exist" : "Eskatutako eginkizun mota ez da existitzen",
     "Necessary language model provider is not available" : "Beharrezko lengoaia-modelo hornitzailea ez dago eskuragarri",
@@ -51,6 +49,11 @@ OC.L10N.register(
     "No translation provider available" : "Ez dago itzulpen-hornitzailerik erabilgarri",
     "Could not detect language" : "Ezin izan da hizkuntza hauteman",
     "Unable to translate" : "Ezin izan da itzuli",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair step:" : "Konponketa pausoa:",
+    "Repair info:" : "Konponketa informazioa:",
+    "Repair warning:" : "Konponketa abisua:",
+    "Repair error:" : "Konponketa errorea:",
     "Nextcloud Server" : "Nextcloud zerbitzaria",
     "Some of your link shares have been removed" : "Zure esteka partekatzeetako batzuk kendu dira",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Segurtasun errore baten ondorioz zure esteka partekatze batzuk kendu ditugu. Ikusi esteka informazio gehiagorako.",
@@ -58,11 +61,6 @@ OC.L10N.register(
     "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Sartu zure harpidetza-gakoa laguntza-aplikazioan kontuen muga handitzeko. Horrek Nextcloud Enterprise-k eskaintzen dituen abantaila gehigarri guztiak ere ematen dizkizu eta oso gomendagarria da enpresetan funtzionatzeko.",
     "Learn more ↗" : "Informazio gehiago ↗",
     "Preparing update" : "Eguneratzea prestatzen",
-    "[%d / %d]: %s" : "[%d / %d]: %s",
-    "Repair step:" : "Konponketa pausoa:",
-    "Repair info:" : "Konponketa informazioa:",
-    "Repair warning:" : "Konponketa abisua:",
-    "Repair error:" : "Konponketa errorea:",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "Mesedez, erabili komando-lerroko eguneratzailea, arakatzailearen bidez eguneratzea desgaituta dagoelako zure config.php-n.",
     "Turned on maintenance mode" : "Mantentze modua aktibatu da",
     "Turned off maintenance mode" : "Mantentze modua desaktibatu da",
@@ -79,16 +77,125 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (bateraezina)",
     "The following apps have been disabled: %s" : "Hurrengo aplikazioak desgaitu dira: %s",
     "Already up to date" : "Eguneratuta dago dagoeneko",
-    "Error occurred while checking server setup" : "Errorea gertatu da zerbitzariaren konfigurazioa egiaztatzean",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "Xehetasun gehiago lortzeko, ikusi {linkstart}dokumentazioa ↗{linkend}.",
-    "unknown text" : "testu ezezaguna",
-    "Hello world!" : "Kaixo mundua!",
-    "sunny" : "eguzkitsua",
-    "Hello {name}, the weather is {weather}" : "Kaixo {name}, eguraldia {weather} da",
-    "Hello {name}" : "Kaixo {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Hauek dira zure bilaketaren emaitzak:<script>alert(1)</script></strong>",
-    "new" : "berria",
-    "_download %n file_::_download %n files_" : ["deskargatu fitxategi %n","deskargatu %n fitxategi"],
+    "Windows Command Script" : "Windows Command script-a",
+    "Electronic book document" : "Liburu elektronikoko dokumentua",
+    "TrueType Font Collection" : "TrueType letra bilduma",
+    "Web Open Font Format" : "Web Open Font formatua",
+    "GPX geographic data" : "GPX datu geografikoa",
+    "Gzip archive" : "Gzip fitxategia",
+    "Adobe Illustrator document" : "Adobe Illustrator dokumentua",
+    "Java source code" : "Java iturburu kodea",
+    "JavaScript source code" : "JavaScript iturburu kodea",
+    "JSON document" : "JSON dokumentua",
+    "Microsoft Access database" : "Microsoft Access datu-basea",
+    "Microsoft OneNote document" : "Microsoft OneNote dokumentua",
+    "Microsoft Word document" : "Microsoft Word dokumentua",
+    "Unknown" : "Ezezaguna",
+    "PDF document" : "PDF dokumentua",
+    "PostScript document" : "PostScript dokumentua",
+    "RSS summary" : "RSS laburpena",
+    "Android package" : "Android paketea",
+    "KML geographic data" : "KML datu geografikoa",
+    "KML geographic compressed data" : "KML datu geografiko konprimatua",
+    "Lotus Word Pro document" : "Lotus Word Pro dokumentua",
+    "Excel spreadsheet" : "Excel kalkulu-orria",
+    "Excel add-in" : "Excel gehigarria",
+    "Excel 2007 binary spreadsheet" : "Excel 2007 kalkulu-orri bitarra",
+    "Excel spreadsheet template" : "Excel kalkulu-orriko txantiloia",
+    "Outlook Message" : "Outlook mezua",
+    "PowerPoint presentation" : "PowerPoint aurkezpena",
+    "PowerPoint add-in" : "PowerPoint gehigarria",
+    "PowerPoint presentation template" : "PowerPoint aurkezpen txantiloia",
+    "Word document" : "Word dokumentua",
+    "ODF formula" : "ODF formula",
+    "ODG drawing" : "ODG marrazketa",
+    "ODG drawing (Flat XML)" : "ODG marrazketa (Flat XML)",
+    "ODG template" : "ODG txantiloia",
+    "ODP presentation" : "ODP aurkezpena",
+    "ODP presentation (Flat XML)" : "ODP aurkezpena (Flat XML)",
+    "ODP template" : "ODP txantiloia",
+    "ODS spreadsheet" : "ODS kalkulu-orria",
+    "ODS spreadsheet (Flat XML)" : "ODS kalkulu-orria (Flat XML)",
+    "ODS template" : "ODS txantiloia",
+    "ODT document" : "ODT dokumentua",
+    "ODT document (Flat XML)" : "ODT dokumentua (Flat XML)",
+    "ODT template" : "ODT txantiloia",
+    "PowerPoint 2007 presentation" : "PowerPoint 2007 aurkezpena",
+    "PowerPoint 2007 show" : "PowerPoint 2007 ikuskizuna",
+    "PowerPoint 2007 presentation template" : "PowerPoint 2007 aurkezpen txantiloia",
+    "Excel 2007 spreadsheet" : "Excel 2007 kalkulu-orria",
+    "Excel 2007 spreadsheet template" : "Excel 2007 kalkulu-orri txantiloia",
+    "Word 2007 document" : "Word 2007 dokumentua",
+    "Word 2007 document template" : "Word 2007 dokumentu txantiloia",
+    "Microsoft Visio document" : "Microsoft Visio dokumentua",
+    "WordPerfect document" : "WordPerfect dokumentua",
+    "7-zip archive" : "7-zip fitxategia",
+    "Blender scene" : "Blender eszena",
+    "Bzip2 archive" : "Bzip2 fitxategia",
+    "Debian package" : "Debian paketea",
+    "FictionBook document" : "FictionBook dokumentua",
+    "Unknown font" : "Letra mota ezezaguna",
+    "Krita document" : "Krita dokumentua",
+    "Mobipocket e-book" : "Mobipocket liburu elektronikoa",
+    "Windows Installer package" : "Windows Installer paketea",
+    "Perl script" : "Perl script-a",
+    "PHP script" : "PHP script-a",
+    "Tar archive" : "Tar fitxategia",
+    "XML document" : "XML dokumentua",
+    "YAML document" : "YAML dokumentua",
+    "Zip archive" : "Zip fitxategia",
+    "Zstandard archive" : "Zstandard fitxategia",
+    "AAC audio" : "AAC audioa",
+    "FLAC audio" : "FLAC audioa",
+    "MPEG-4 audio" : "MPEG-4 audioa",
+    "MP3 audio" : "MP3 audioa",
+    "Ogg audio" : "Ogg audioa",
+    "RIFF/WAVe standard Audio" : "RIFF/WAVe audio estandarra",
+    "WebM audio" : "WebM audioa",
+    "MP3 ShoutCast playlist" : "MP3 ShoutCast erreprodukzio-zerrenda",
+    "Windows BMP image" : "Windows BMP irudia",
+    "Better Portable Graphics image" : "Better Portable Graphics irudia",
+    "EMF image" : "EMF irudia",
+    "GIF image" : "GIF irudia",
+    "HEIC image" : "HEIC irudia",
+    "HEIF image" : "HEIF irudia",
+    "JPEG-2000 JP2 image" : "JPEG-2000 JP2 irudia",
+    "JPEG image" : "JPEG irudia",
+    "PNG image" : "PNG irudia",
+    "SVG image" : "SVG irudia",
+    "Truevision Targa image" : "Truevision Targa irudia",
+    "TIFF image" : "TIFF irudia",
+    "WebP image" : "WebP irudia",
+    "Digital raw image" : "Digital raw irudia",
+    "Windows Icon" : "Windows Ikonoa",
+    "Email message" : "Email mezua",
+    "VCS/ICS calendar" : "VCS/ICS egutegia",
+    "CSS stylesheet" : "CSS estilo-orria",
+    "CSV document" : "CSV dokumentua",
+    "HTML document" : "HTML dokumentua",
+    "Markdown document" : "Markdown dokumentua",
+    "Org-mode file" : "Org-mode fitxategia",
+    "Plain text document" : "Testu soileko dokumentua ",
+    "Rich Text document" : "Testu aberatseko dokumentua",
+    "Electronic business card" : "Negozio-txartel elektronikoa",
+    "C++ source code" : "C++ iturburu kodea",
+    "LDIF address book" : "LDIF helbide liburua",
+    "NFO document" : "NFO dokumentua",
+    "PHP source" : "PHP iturburua",
+    "Python script" : "Python script-a",
+    "ReStructuredText document" : "ReStructuredText dokumentua",
+    "3GPP multimedia file" : "3GPP multimedia fitxategia",
+    "MPEG video" : "MPEG bideoa",
+    "DV video" : "DV bideoa",
+    "MPEG-2 transport stream" : "MPEG-2 igorpena",
+    "MPEG-4 video" : "MPEG-4 bideoa",
+    "Ogg video" : "Ogg bideoa",
+    "QuickTime video" : "QuickTime bideoa",
+    "WebM video" : "WebM bideoa",
+    "Flash video" : "Flash bideoa",
+    "Matroska video" : "Matroska bideoa",
+    "Windows Media video" : "Windows Media bideoa",
+    "AVI video" : "AVI bideoa",
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Eguneratzea abian da, orri hau utziz gero prozesua eten liteke ingurune batzuetan.",
     "Update to {version}" : "Eguneratu {version} bertsiora",
     "An error occurred." : "Errore bat gertatu da.",
@@ -109,7 +216,7 @@ OC.L10N.register(
     "Federated user" : "Erabiltzaile federatua",
     "user@your-nextcloud.org" : "erabiltzaile@zure-nextcloud.org",
     "Create share" : "Sortu partekatzea",
-    "Direct link copied to clipboard" : "Esteka zuzena arbelera kopiatuta",
+    "Direct link copied" : "Esteka zuzena kopiatu da",
     "Please copy the link manually:" : "Mesedez kopiatu esteka eskuz:",
     "Custom date range" : "Data-tarte pertsonalizatua",
     "Pick start date" : "Aukeratu hasiera-data",
@@ -118,7 +225,6 @@ OC.L10N.register(
     "Search in current app" : "Bilatu aplikazio honetan",
     "Clear search" : "Garbitu bilaketa",
     "Search everywhere" : "Bilatu nonahi",
-    "Searching …" : "Bilatzen…",
     "Start typing to search" : "Hasi idazten bilatzeko",
     "No matching results" : "Ez dago bilaketaren emaitzarik",
     "Today" : "Gaur",
@@ -133,11 +239,11 @@ OC.L10N.register(
     "Search people" : "Bilatu pertsonak",
     "People" : "Jendea",
     "Filter in current view" : "Iragazi uneko ikuspegian",
+    "Search connected services" : "Bilatu konektatutako zerbitzuak",
     "Results" : "Emaitzak",
     "Load more results" : "Kargatu emaitza gehiago ",
     "Search in" : "Bilatu hemen",
     "Log in" : "Hasi saioa",
-    "Logging in …" : "Saioa hasten...",
     "Log in to {productName}" : "Hasi saioa {productName}-(e)n",
     "Wrong login or password." : "Erabiltzaile edo pasahitz okerra.",
     "This account is disabled" : "Kontu hau desgaituta dago",
@@ -146,8 +252,8 @@ OC.L10N.register(
     "Account name" : "Kontuaren izena",
     "Server side authentication failed!" : "Zerbitzari aldeko autentifikazioak huts egin du!",
     "Please contact your administrator." : "Mesedez jarri harremanetan zure administratzailearekin.",
-    "Temporary error" : "Aldi baterako errorea",
-    "Please try again." : "Mesedez saiatu berriro.",
+    "Session error" : "Saio errorea",
+    "It appears your session token has expired, please refresh the page and try again." : "Zure saio-tokena iraungita dagoela dirudi, mesedez freskatu orria eta saiatu berriro.",
     "An internal error occurred." : "Barne-errore bat gertatu da.",
     "Please try again or contact your administrator." : "Saiatu berriro edo jarri harremanetan zure administratzailearekin.",
     "Password" : "Pasahitza",
@@ -174,21 +280,22 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Dokumentu, kalkulu-orri eta aurkezpen kolaboratiboak, Collabora Online-en sortuak.",
     "Distraction free note taking app." : "Distrakziorik gabeko oharrak hartzeko aplikazioa.",
     "Recommended apps" : "Gomendatutako aplikazioak",
-    "Loading apps …" : "Aplikazioak kargatzen...",
     "Could not fetch list of apps from the App Store." : "Ezin izan da aplikazioen zerrenda eskuratu aplikazioen dendatik.",
     "App download or installation failed" : "Huts egin du aplikazioaren deskarga edo instalazioak",
     "Cannot install this app because it is not compatible" : "Ezin da aplikazio hau instalatu ez delako bateragarria",
     "Cannot install this app" : "Ezin da aplikazio hau instalatu",
     "Skip" : "Saltatu",
-    "Installing apps …" : "Aplikazioak instalatzen...",
     "Install recommended apps" : "Instalatu gomendatutako aplikazioak",
+    "Online" : "Linean",
+    "Away" : "Kanpoan",
+    "Busy" : "Lanpetua",
+    "Do not disturb" : "Ez molestatu",
+    "Mute all notifications" : "Isilarazi jakinarazpen guztiak",
+    "Invisible" : "Ikusezina",
     "Avatar of {displayName}" : "{displayName}-(r)en avatarra",
     "Settings menu" : "Ezarpenen menua",
-    "Loading your contacts …" : "Zure kontaktuak kargatzen...",
-    "Looking for {term} …" : "{term} bilatzen...",
     "Search contacts" : "Bilatu kontaktuak",
     "Reset search" : "Berrezarri bilaketa",
-    "Search contacts …" : "Bilatu kontaktuak...",
     "Could not load your contacts" : "Ezin izan dira zure kontaktuak kargatu",
     "No contacts found" : "Ez da kontakturik aurkitu",
     "Show all contacts" : "Erakutsi kontaktu guztiak",
@@ -200,16 +307,36 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Errorea gertatu da {type} bilatzean",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Bilaketa idazten hasten zarenean hasten da eta emaitzak gezi-teklen bidez lor daitezke",
     "Search for {name} only" : "Biatu {name} bakarrik",
-    "Loading more results …" : "Emaitza gehiago kargatzen ...",
     "Forgot password?" : "Pasahitza ahaztu duzu?",
     "Back to login form" : "Itzuli saio hasierara",
     "Back" : "Atzera",
     "Login form is disabled." : "Saioa hasteko inprimakia desgaituta dago.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud saioa hasteko inprimakia desgaituta dago. Erabili saioa hasteko beste aukera eskuragarri badago edo jarri harremanetan zure administrazioarekin.",
     "More actions" : "Ekintza gehiago",
+    "User menu" : "Erabiltzailearen menua",
+    "Your guest name: {user}" : "Zure gonbidatu izena: {user}",
+    "You are currently not identified." : "Une honetan identifikatu gabe zaude.",
+    "Set public name" : "Ezarri izen publikoa",
+    "Change public name" : "Aldatu izen publikoa",
+    "Password is too weak" : "Pasahitza oso ahula da",
+    "Password is weak" : "Pasahitza ahula da",
+    "Password is average" : "Pasahitzak tarteko indarra du",
+    "Password is strong" : "Pasahitza segurua da",
+    "Password is very strong" : "Pasahitza oso segurua da",
+    "Password is extremely strong" : "Pasahitza erabat segurua da",
+    "Unknown password strength" : "Pasahitzaren segurtasun maila ezezaguna",
+    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Litekeena da zure datuen direktorioa eta fitxategiak Internetetik atzitzea, <code>.htaccess</code> f fitxategiak ez duelako funtzionatzen. ",
+    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Jakiteko zure zerbitzaria nola konfiguratu zuzen, {linkStart}begiratu dokumentazioa{linkEnd}",
+    "Autoconfig file detected" : "Autoconfig fitxategia atzeman da",
+    "The setup form below is pre-filled with the values from the config file." : "Beheko konfigurazio formularioa konfigurazio fitxategiko balioekin aurrez betetzen da.",
     "Security warning" : "Segurtasun abisua",
+    "Create administration account" : "Sortu administrazio kontua",
+    "Administration account name" : "Administrazio kontuaren izena",
+    "Administration account password" : "Administrazio kontuaren pasahitza",
     "Storage & database" : "Biltegia eta datu-basea",
     "Data folder" : "Datuen karpeta",
+    "Database configuration" : "Datu-basearen ezarpenak",
+    "Only {firstAndOnlyDatabase} is available." : "Soilik {firstAndOnlyDatabase} dago eskuragarri",
     "Install and activate additional PHP modules to choose other database types." : "Instalatu eta aktibatu PHP modulu osagarriak, beste datu-base mota batzuk aukeratzeko.",
     "For more details check out the documentation." : "Xehetasun gehiago nahi izanez gero, begiratu dokumentazioa.",
     "Performance warning" : "Errendimendu abisua",
@@ -222,7 +349,7 @@ OC.L10N.register(
     "Database tablespace" : "Datu-basearen taula-lekua",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Zehaztu ataka, makinaren izenarekin batera (adb. localhost:5432).",
     "Database host" : "Datu-basearen ostalaria",
-    "Installing …" : "Instalatzen ...",
+    "localhost" : "localhost",
     "Install" : "Instalatu",
     "Need help?" : "Laguntza behar duzu?",
     "See the documentation" : "Ikusi dokumentazioa",
@@ -231,7 +358,6 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Zure nabigatzailea ez da onartzen. Mesedez, eguneratu bertsio berriago batera edo onartzen den batera.",
     "Continue with this unsupported browser" : "Jarraitu onartzen ez den arakatzaile honekin",
     "Supported versions" : "Onartutako bertsioak",
-    "Search {types} …" : "Bilatu  {types} …",
     "Choose {file}" : "Aukeratu {file}",
     "Choose" : "Aukeratu",
     "Copy to {target}" : "Kopiatu hona: {target}",
@@ -251,7 +377,7 @@ OC.L10N.register(
     "(all selected)" : "(denak hautatuta)",
     "({count} selected)" : "({count} hautatuta)",
     "Error loading file exists template" : "Errorea fitxategia existitzen da txantiloia kargatzean",
-    "Saving …" : "Gordetzen …",
+    "Saving …" : "Gordetzen  ...",
     "seconds ago" : "segundo lehenago",
     "Connection to server lost" : "Zerbitzariarekiko konexioa eten da",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Arazoa orria kargatzerakoan, segundo %n barru berriz kargatuko da","Arazoa orria kargatzerakoan,  %n segundo barru berriz kargatuko da"],
@@ -266,26 +392,18 @@ OC.L10N.register(
     "Type to search for existing projects" : "Hasi idazten, dauden proiektuak bilatzeko",
     "New in" : "Berria hemen:",
     "View changelog" : "Ikusi aldaketen egunkaria",
-    "No action available" : "Ez dago ekintzarik eskuragarri",
-    "Error fetching contact actions" : "Errorea kontaktu-ekintzak eskuratzean",
     "Close \"{dialogTitle}\" dialog" : "Itxi \"{dialogTitle}\" elkarrizketa",
     "Email length is at max (255)" : "Posta elektronikoaren luzera gehienez (255) da",
-    "Non-existing tag #{tag}" : "#{tag} ez da existitzen",
-    "Restricted" : "Mugatua",
-    "Invisible" : "Ikusezina",
-    "Delete" : "Ezabatu",
-    "Rename" : "Berrizendatu",
-    "Collaborative tags" : "Elkarlaneko etiketak",
-    "No tags found" : "Ez da etiketarik aurkitu",
     "Clipboard not available, please copy manually" : "Arbela ez dago eskuragarri, mesedez kopiatu eskuz",
     "Personal" : "Pertsonala",
     "Accounts" : "Kontuak",
     "Admin" : "Admin",
     "Help" : "Laguntza",
     "Access forbidden" : "Sarrera debekatuta",
+    "You are not allowed to access this page." : "Ez daukazu baimenik orri hau ikusteko.",
+    "Back to %s" : "Itzuli %s(e)ra",
     "Page not found" : "Orria ez da aurkitu",
     "The page could not be found on the server or you may not be allowed to view it." : "Ezin izan da orria aurkitu edo ez duzu ikusteko baimenik.",
-    "Back to %s" : "Itzuli %s(e)ra",
     "Too many requests" : "Eskaera gehiegi",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Eskaera gehiegi zeuden zure saretik. Saiatu beranduago edo kontaktatu zure administrailearekin hau errorea bada.",
     "Error" : "Errorea",
@@ -304,7 +422,7 @@ OC.L10N.register(
     "Line: %s" : "Lerroa: %s",
     "Trace" : "Aztarna",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Badirudi zure Nextcloud berrinstalatu nahian ari zarela. Hala ere CAN_INSTALL fitxategia falta da zure config direktorioan. Mesedez sor ezazu CAN_INSTALL fitxategia zure config karpetan jarraitu ahal izateko.",
-    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Ezin izan da CAN_INSTALL fitxategia config karpetatik ezabatu. Mesedez ezaba ezazu fitxategi hau eskuz.",
+    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Ezin izan da CAN_INSTALL fitxategia config karpetatik kendu. Mesedez kendu ezazu fitxategi hau eskuz.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Aplikazio honek JavaScript eskatzen du ondo funtzionatzeko. Mesedez {linkstart}JavaScript gaitu{linkend} eta webgunea birkargatu.",
     "Skip to main content" : "Salto eduki nagusira",
     "Skip to navigation of app" : "Salto aplikazioaren nabigaziora",
@@ -361,23 +479,40 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "%s instantzia hau mantentze moduan dago une honetan, honek denbora tarte bat iraun dezake.",
     "This page will refresh itself when the instance is available again." : "Instantzia berriz ere erabilgarri dagoenean orri hau freskatuko da.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Jarri harremanetan zure sistema administratzailearekin mezu honek irauten badu edo ezustean agertu bada.",
-    "Currently open" : "Irekita une honetan",
-    "Login with username or email" : "Hasi saioa erabiltzaile-izen edo e-postarekin",
-    "Login with username" : "Hasi saioa erabiltzaile-izenarekin",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Txata, bideo-deiak, pantaila partekatzea, lineako bilerak eta web konferentziak - zure nabigatzailean eta mugikorrerako aplikazioekin.",
-    "You have not added any info yet" : "Oraindik ez duzu informaziorik gehitu",
-    "{user} has not added any info yet" : "{user}-(e)k ez du oraindik informaziorik gehitu",
-    "Error opening the user status modal, try hard refreshing the page" : "Errorea erabiltzailen egoera leihoa irekitzean, saiatu orria guztiz freskatzen",
-    "Edit Profile" : "Editatu profila",
-    "The headline and about sections will show up here" : "Izenburua eta 'Niri buruz' atalak hemen agertuko dira",
-    "Error loading message template: {error}" : "Errorea mezu txantiloia kargatzean: {error}",
+    "Error occurred while checking server setup" : "Errorea gertatu da zerbitzariaren konfigurazioa egiaztatzean",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "Xehetasun gehiago lortzeko, ikusi {linkstart}dokumentazioa ↗{linkend}.",
+    "unknown text" : "testu ezezaguna",
+    "Hello world!" : "Kaixo mundua!",
+    "sunny" : "eguzkitsua",
+    "Hello {name}, the weather is {weather}" : "Kaixo {name}, eguraldia {weather} da",
+    "Hello {name}" : "Kaixo {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Hauek dira zure bilaketaren emaitzak:<script>alert(1)</script></strong>",
+    "new" : "berria",
+    "_download %n file_::_download %n files_" : ["deskargatu fitxategi %n","deskargatu %n fitxategi"],
+    "Direct link copied to clipboard" : "Esteka zuzena arbelera kopiatuta",
+    "Searching …" : "Bilatzen…",
+    "Logging in …" : "Saioa hasten...",
+    "Loading apps …" : "Aplikazioak kargatzen...",
+    "Installing apps …" : "Aplikazioak instalatzen...",
+    "Loading your contacts …" : "Zure kontaktuak kargatzen...",
+    "Looking for {term} …" : "{term} bilatzen...",
+    "Search contacts …" : "Bilatu kontaktuak...",
+    "Loading more results …" : "Emaitza gehiago kargatzen ...",
+    "Search {types} …" : "Bilatu  {types} …",
+    "Saving …" : "Gordetzen …",
     "Very weak password" : "Pasahitz oso ahula",
     "Weak password" : "Pasahitz ahula",
     "So-so password" : "Hala moduzko pasahitza",
     "Good password" : "Pasahitz ona",
     "Strong password" : "Pasahitz sendoa",
-    "Profile not found" : "Profila ez da aurkitu",
-    "The profile does not exist." : "Profila ez da existitzen",
+    "No action available" : "Ez dago ekintzarik eskuragarri",
+    "Error fetching contact actions" : "Errorea kontaktu-ekintzak eskuratzean",
+    "Non-existing tag #{tag}" : "#{tag} ez da existitzen",
+    "Restricted" : "Mugatua",
+    "Delete" : "Ezabatu",
+    "Rename" : "Berrizendatu",
+    "Collaborative tags" : "Elkarlaneko etiketak",
+    "No tags found" : "Ez da etiketarik aurkitu",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Zure datuen karpeta eta fitxategiak interneten bidez eskuragarri egon daitezke .htaccess fitxategia ez delako funtzionatzen ari.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Zerbitzaria behar bezala konfiguratzeari buruzko informazio gehiagorako, mesedez begira ezazu <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentazioa</a>.",
     "<strong>Create an admin account</strong>" : "<strong>Sortu administratzaile kontu bat</strong>",
@@ -387,6 +522,7 @@ OC.L10N.register(
     "Toggle password visibility" : "Txandakatu pasahitzaren ikusgaitasuna",
     "Configure the database" : "Konfiguratu datu-basea",
     "Only %s is available." : "Soilik %s dago eskuragarri.",
-    "Database account" : "Datu-basearen kontua"
+    "Database account" : "Datu-basearen kontua",
+    "Installing …" : "Instalatzen ..."
 },
 "nplurals=2; plural=(n != 1);");
