@@ -18,15 +18,12 @@ OC.L10N.register(
     "Unknown filetype" : "Cineál comhaid anaithnid",
     "An error occurred. Please contact your admin." : "Tharla earráid. Déan teagmháil le do riarthóir le do thoil.",
     "Invalid image" : "Íomhá neamhbhailí",
-    "No temporary profile picture available, try again" : "Níl aon phictiúr próifíle sealadach ar fáil, bain triail eile as",
-    "No crop data provided" : "Níor soláthraíodh aon sonraí bairr",
-    "No valid crop data provided" : "Níor soláthraíodh aon sonraí bailí bairr",
-    "Crop is not square" : "Níl an barr cearnach",
     "State token does not match" : "Ní hionann an comhartha stáit",
     "Invalid app password" : "Pasfhocal feidhmchláir neamhbhailí",
     "Could not complete login" : "Níorbh fhéidir logáil isteach a chríochnú",
     "State token missing" : "Comhartha stáit in easnamh",
     "Your login token is invalid or has expired" : "Tá do chomhartha logáil isteach neamhbhailí nó imithe in éag",
+    "Please use original client" : "Bain úsáid as an gcliant bunaidh le do thoil",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "Ní thacaítear leis an scaoileadh pobail seo de Nextcloud agus tá teorainn le fógraí brú.",
     "Login" : "Logáil isteach",
     "Unsupported email length (>255)" : "Fad ríomhphoist nach dtacaítear leis (>255)",
@@ -43,7 +40,9 @@ OC.L10N.register(
     "Task not found" : "Níor aimsíodh an tasc",
     "Internal error" : "Earráid inmheánach",
     "Not found" : "Ní bhfuarthas",
+    "Node is locked" : "Tá an nód faoi ghlas",
     "Bad request" : "Drochiarratas",
+    "Input text is too long" : "Tá an téacs ionchuir rófhada",
     "Requested task type does not exist" : "Níl an cineál taisc iarrtha ann",
     "Necessary language model provider is not available" : "Níl soláthraí múnla teanga riachtanach ar fáil",
     "No text to image provider is available" : "Níl aon soláthraí téacs go híomhá ar fáil",
@@ -51,6 +50,12 @@ OC.L10N.register(
     "No translation provider available" : "Níl aon soláthraí aistriúcháin ar fáil",
     "Could not detect language" : "Níorbh fhéidir teanga a bhrath",
     "Unable to translate" : "Ní féidir aistriú",
+    "No valid filters provided" : "Níor soláthraíodh aon scagairí bailí",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair step:" : "Céim deisiúcháin:",
+    "Repair info:" : "Eolas deisiúcháin:",
+    "Repair warning:" : "Rabhadh deisiúcháin:",
+    "Repair error:" : "Earráid deisiúcháin:",
     "Nextcloud Server" : "Freastalaí Nextcloud",
     "Some of your link shares have been removed" : "Baineadh cuid de do chuid naisc",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Mar gheall ar fhabht slándála bhí orainn roinnt de do naisc a roinnt. Féach ar an nasc le haghaidh tuilleadh eolais.",
@@ -58,11 +63,6 @@ OC.L10N.register(
     "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Cuir isteach d'eochair síntiúis san aip tacaíochta chun teorainn an chuntais a mhéadú. Tugann sé seo freisin na buntáistí breise go léir a thairgeann Nextcloud Enterprise agus moltar go mór é don oibríocht i gcuideachtaí.",
     "Learn more ↗" : "Tuilleadh eolais ↗",
     "Preparing update" : "Nuashonrú a ullmhú",
-    "[%d / %d]: %s" : "[%d / %d]: %s",
-    "Repair step:" : "Céim deisiúcháin:",
-    "Repair info:" : "Eolas deisiúcháin:",
-    "Repair warning:" : "Rabhadh deisiúcháin:",
-    "Repair error:" : "Earráid deisiúcháin:",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "Bain úsáid as an nuashonróir líne ordaithe toisc go bhfuil nuashonrú trí bhrabhsálaí díchumasaithe i do config.php.",
     "Turned on maintenance mode" : "Cuireadh modh cothabhála ar siúl",
     "Turned off maintenance mode" : "Modh cothabhála múchta",
@@ -79,16 +79,125 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (neamh-chomhoiriúnach)",
     "The following apps have been disabled: %s" : "Díchumasaíodh na haipeanna seo a leanas:%s",
     "Already up to date" : "Cheana féin suas chun dáta",
-    "Error occurred while checking server setup" : "Tharla earráid agus socrú an fhreastalaí á sheiceáil",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "Le haghaidh tuilleadh sonraí féach an {linkstart}doiciméadú ↗{linkend}.",
-    "unknown text" : "téacs anaithnid",
-    "Hello world!" : "Dia duit, a dhomhan!",
-    "sunny" : "Grianmhar",
-    "Hello {name}, the weather is {weather}" : "Dia duit {name}, tá an aimsir {weather}",
-    "Hello {name}" : "Dia duit {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Seo iad do thorthaí cuardaigh<script>foláireamh(1)</script></strong>",
-    "new" : "nua",
-    "_download %n file_::_download %n files_" : ["íoslódáil %n comhad","íoslódáil %n comhaid","íoslódáil %n comhaid","íoslódáil %n comhaid","íoslódáil %n comhaid"],
+    "Windows Command Script" : "Script Ordú Windows",
+    "Electronic book document" : "Doiciméad leabhar leictreonach",
+    "TrueType Font Collection" : "Bailiúchán Clónna TrueType",
+    "Web Open Font Format" : "Formáid Cló Oscailte Gréasáin",
+    "GPX geographic data" : "Sonraí geografacha GPX",
+    "Gzip archive" : "Cartlann Gzip",
+    "Adobe Illustrator document" : "Doiciméad Adobe Illustrator",
+    "Java source code" : "Cód foinse Java",
+    "JavaScript source code" : "Cód foinse JavaScript",
+    "JSON document" : "Doiciméad JSON",
+    "Microsoft Access database" : "Bunachar sonraí Microsoft Access",
+    "Microsoft OneNote document" : "Doiciméad Microsoft OneNote",
+    "Microsoft Word document" : "Doiciméad Microsoft Word",
+    "Unknown" : "Anaithnid",
+    "PDF document" : "Doiciméad PDF",
+    "PostScript document" : "Doiciméad PostScript",
+    "RSS summary" : "Achoimre RSS",
+    "Android package" : "Pacáiste Android",
+    "KML geographic data" : "Sonraí geografacha KML",
+    "KML geographic compressed data" : "Sonraí comhbhrúite geografacha KML",
+    "Lotus Word Pro document" : "Doiciméad Lotus Word Pro",
+    "Excel spreadsheet" : "Scarbhileog Excel",
+    "Excel add-in" : "Breiseán Excel",
+    "Excel 2007 binary spreadsheet" : "Scarbhileog dhénártha Excel 2007",
+    "Excel spreadsheet template" : "Teimpléad scarbhileog Excel",
+    "Outlook Message" : "Teachtaireacht Outlook",
+    "PowerPoint presentation" : "Cur i láthair PowerPoint",
+    "PowerPoint add-in" : "Breiseán PowerPoint",
+    "PowerPoint presentation template" : "Teimpléad cur i láthair PowerPoint",
+    "Word document" : "Doiciméad Word",
+    "ODF formula" : "Foirmle ODF",
+    "ODG drawing" : "Líníocht ODG",
+    "ODG drawing (Flat XML)" : "Líníocht ODG (XML Cothrom)",
+    "ODG template" : "Teimpléad ODG",
+    "ODP presentation" : "Cur i láthair ODP",
+    "ODP presentation (Flat XML)" : "Cur i láthair ODP (XML Cothrom)",
+    "ODP template" : "Teimpléad ODP",
+    "ODS spreadsheet" : "Scarbhileog ODS",
+    "ODS spreadsheet (Flat XML)" : "Scarbhileog ODS (XML Cothrom)",
+    "ODS template" : "Teimpléad ODS",
+    "ODT document" : "Doiciméad ODT",
+    "ODT document (Flat XML)" : "Doiciméad ODT (XML Cothrom)",
+    "ODT template" : "Teimpléad ODT",
+    "PowerPoint 2007 presentation" : "Cur i láthair PowerPoint 2007",
+    "PowerPoint 2007 show" : "Taispeántas PowerPoint 2007",
+    "PowerPoint 2007 presentation template" : "Teimpléad cur i láthair PowerPoint 2007",
+    "Excel 2007 spreadsheet" : "Scarbhileog Excel 2007",
+    "Excel 2007 spreadsheet template" : "Teimpléad scarbhileog Excel 2007",
+    "Word 2007 document" : "Doiciméad Word 2007",
+    "Word 2007 document template" : "Teimpléad doiciméad Word 2007",
+    "Microsoft Visio document" : "Doiciméad Microsoft Visio",
+    "WordPerfect document" : "Doiciméad WordPerfect",
+    "7-zip archive" : "Cartlann 7-zip",
+    "Blender scene" : "Radharc cumascóra",
+    "Bzip2 archive" : "Cartlann Bzip2",
+    "Debian package" : "Pacáiste Debian",
+    "FictionBook document" : "Doiciméad FictionBook",
+    "Unknown font" : "Cló anaithnid",
+    "Krita document" : "Doiciméad Krita",
+    "Mobipocket e-book" : "Ríomhleabhar Mobipocket",
+    "Windows Installer package" : "Pacáiste Suiteálaí Windows",
+    "Perl script" : "Script Perl",
+    "PHP script" : "Script PHP",
+    "Tar archive" : "Cartlann Tar",
+    "XML document" : "Doiciméad XML",
+    "YAML document" : "Doiciméad YAML",
+    "Zip archive" : "Cartlann zip",
+    "Zstandard archive" : "Cartlann Zstandard",
+    "AAC audio" : "Fuaim AAC",
+    "FLAC audio" : "Fuaim FLAC",
+    "MPEG-4 audio" : "Fuaim MPEG-4",
+    "MP3 audio" : "Fuaim MP3",
+    "Ogg audio" : "Fuaim Ogg",
+    "RIFF/WAVe standard Audio" : "Fuaim chaighdeánach RIFF/WAVe",
+    "WebM audio" : "Fuaim WebM",
+    "MP3 ShoutCast playlist" : "Seinmliosta MP3 ShoutCast",
+    "Windows BMP image" : "Íomhá BMP Windows",
+    "Better Portable Graphics image" : "Íomhá Grafaicí Inaistrithe Níos Fearr",
+    "EMF image" : "Íomhá EMF",
+    "GIF image" : "Íomhá GIF",
+    "HEIC image" : "Íomhá HEIC",
+    "HEIF image" : "Íomhá HEIF",
+    "JPEG-2000 JP2 image" : "Íomhá JPEG-2000 JP2",
+    "JPEG image" : "Íomhá JPEG",
+    "PNG image" : "Íomhá PNG",
+    "SVG image" : "Íomhá SVG",
+    "Truevision Targa image" : "Íomhá Truevision Targa",
+    "TIFF image" : "Íomhá TIFF",
+    "WebP image" : "Íomhá WebP",
+    "Digital raw image" : "Íomhá amh digiteach",
+    "Windows Icon" : "Deilbhín Windows",
+    "Email message" : "Teachtaireacht ríomhphoist",
+    "VCS/ICS calendar" : "Féilire VCS/ICS",
+    "CSS stylesheet" : "Bileog stíle CSS",
+    "CSV document" : "Doiciméad CSV",
+    "HTML document" : "Doiciméad HTML",
+    "Markdown document" : "Doiciméad marcála síos",
+    "Org-mode file" : "Comhad mód eagraíochta",
+    "Plain text document" : "Doiciméad téacs simplí",
+    "Rich Text document" : "Doiciméad Téacs Saibhir",
+    "Electronic business card" : "Cárta gnó leictreonach",
+    "C++ source code" : "Cód foinse C++",
+    "LDIF address book" : "Leabhar seoltaí LDIF",
+    "NFO document" : "Doiciméad NFO",
+    "PHP source" : "Foinse PHP",
+    "Python script" : "Script Python",
+    "ReStructuredText document" : "Doiciméad AthstruchtúrthaTéacs",
+    "3GPP multimedia file" : "Comhad ilmheán 3GPP",
+    "MPEG video" : "Físeán MPEG",
+    "DV video" : "Físeán DV",
+    "MPEG-2 transport stream" : "Sruth iompair MPEG-2",
+    "MPEG-4 video" : "Físeán MPEG-4",
+    "Ogg video" : "Físeán Ogg",
+    "QuickTime video" : "Físeán QuickTime",
+    "WebM video" : "Físeán WebM",
+    "Flash video" : "Físeán Flash",
+    "Matroska video" : "Físeán Matroska",
+    "Windows Media video" : "Físeán Windows Media",
+    "AVI video" : "Físeán AVI",
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Tá an nuashonrú ar siúl, agus d'fhéadfadh go gcuirfí isteach ar an bpróiseas i dtimpeallachtaí áirithe dá bhfágfaí an leathanach seo.",
     "Update to {version}" : "Nuashonraigh go {version}",
     "An error occurred." : "Tharla earráid.",
@@ -109,7 +218,7 @@ OC.L10N.register(
     "Federated user" : "Úsáideoir cónaidhme",
     "user@your-nextcloud.org" : "user@your-nextcloud.org",
     "Create share" : "Cruthaigh sciar",
-    "Direct link copied to clipboard" : "Cóipeáladh nasc díreach chuig an ngearrthaisce",
+    "Direct link copied" : "Nasc díreach cóipeáilte",
     "Please copy the link manually:" : "Cóipeáil an nasc de láimh le do thoil:",
     "Custom date range" : "Raon dáta saincheaptha",
     "Pick start date" : "Roghnaigh dáta tosaithe",
@@ -118,14 +227,16 @@ OC.L10N.register(
     "Search in current app" : "Cuardaigh san aip reatha",
     "Clear search" : "Glan cuardach",
     "Search everywhere" : "Cuardaigh i ngach áit",
-    "Searching …" : "Ag cuardach…",
+    "Searching …" : "Ag cuardach …",
     "Start typing to search" : "Tosaigh ag clóscríobh chun cuardach a dhéanamh",
+    "Minimum search length is {minSearchLength} characters" : "Is é {minSearchLength} carachtar an fad cuardaigh íosta",
     "No matching results" : "Gan torthaí meaitseála",
     "Today" : "Inniu",
     "Last 7 days" : "7 lá seo caite",
     "Last 30 days" : "30 lá anuas",
     "This year" : "An bhliain seo",
     "Last year" : "Anuraidh",
+    "Between {startDate} and {endDate}" : "Idir {startDate} agus {endDate}",
     "Unified search" : "Cuardach aontaithe",
     "Search apps, files, tags, messages" : "Cuardaigh apps, comhaid, clibeanna, teachtaireachtaí",
     "Places" : "Áiteanna",
@@ -133,11 +244,12 @@ OC.L10N.register(
     "Search people" : "Cuardaigh daoine",
     "People" : "Daoine",
     "Filter in current view" : "Scag san amharc reatha",
+    "Search connected services" : "Cuardaigh seirbhísí nasctha",
     "Results" : "Torthaí",
     "Load more results" : "Íoslódáil níos mó torthaí",
     "Search in" : "Cuardaigh isteach",
     "Log in" : "Logáil isteach",
-    "Logging in …" : "Ag logáil isteach…",
+    "Logging in …" : "Ag logáil isteach …",
     "Log in to {productName}" : "Logáil isteach ar {productName}",
     "Wrong login or password." : "Logáil isteach mícheart nó pasfhocal.",
     "This account is disabled" : "Tá an cuntas seo díchumasaithe",
@@ -146,11 +258,12 @@ OC.L10N.register(
     "Account name" : "Ainm chuntais",
     "Server side authentication failed!" : "Theip ar fhíordheimhniú taobh an fhreastalaí!",
     "Please contact your administrator." : "Déan teagmháil le do riarthóir.",
-    "Temporary error" : "Earráid shealadach",
-    "Please try again." : "Arís, le d'thoil.",
+    "Session error" : "Earráid seisiúin",
+    "It appears your session token has expired, please refresh the page and try again." : "Is cosúil go bhfuil do chomhartha seisiúin imithe in éag, athnuaigh an leathanach agus bain triail eile as.",
     "An internal error occurred." : "Tharla earráid inmheánach.",
     "Please try again or contact your administrator." : "Bain triail eile as nó déan teagmháil le do riarthóir.",
     "Password" : "Pasfhocal",
+    "Remember me" : "Cuimhnigh orm",
     "Log in with a device" : "Logáil isteach le gléas",
     "Login or email" : "Logáil isteach nó ríomhphost",
     "Your account is not setup for passwordless login." : "Níl do chuntas socraithe le haghaidh logáil isteach gan pasfhocal.",
@@ -174,21 +287,28 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Doiciméid chomhoibríocha, scarbhileoga agus cur i láthair, tógtha ar Collabora Online.",
     "Distraction free note taking app." : "Clár chun nótaí a tharraingt saor in aisce,.",
     "Recommended apps" : "Aipeanna molta",
-    "Loading apps …" : "Aipeanna á lódáil…",
+    "Loading apps …" : "Ag lódáil aipeanna …",
     "Could not fetch list of apps from the App Store." : "Níorbh fhéidir liosta aipeanna a fháil ón App Store.",
     "App download or installation failed" : "Theip ar íoslódáil nó suiteáil an aip",
     "Cannot install this app because it is not compatible" : "Ní féidir an aip seo a shuiteáil toisc nach bhfuil sé comhoiriúnach",
     "Cannot install this app" : "Ní féidir an aip seo a shuiteáil",
     "Skip" : "Scipeáil",
-    "Installing apps …" : "Aipeanna á suiteáil…",
+    "Installing apps …" : "Ag suiteáil aipeanna …",
     "Install recommended apps" : "Suiteáil aipeanna molta",
+    "Online" : "Ar líne",
+    "Away" : "Amach",
+    "Busy" : "Gnóthach",
+    "Do not disturb" : "Ná cur as",
+    "Mute all notifications" : "Balbhaigh gach fógra",
+    "Invisible" : "Dofheicthe",
+    "Appear offline" : "Le feiceáil as líne",
     "Avatar of {displayName}" : "Avatar de {displayName}",
     "Settings menu" : "Roghchlár socruithe",
-    "Loading your contacts …" : "Do theagmhálaithe á lódáil…",
-    "Looking for {term} …" : "Ag lorg {term} …",
+    "Loading your contacts …" : "Ag lódáil do theagmhálaithe …",
+    "Looking for {term} …" : "Ag lorg {term} …",
     "Search contacts" : "Cuardaigh teagmhálaithe",
     "Reset search" : "Athshocraigh cuardach",
-    "Search contacts …" : "Cuardaigh teagmhálaithe…",
+    "Search contacts …" : "Cuardaigh teagmhálaithe …",
     "Could not load your contacts" : "Níorbh fhéidir do theagmhálaithe a lódáil",
     "No contacts found" : "Níor aimsíodh aon teagmhálaí",
     "Show all contacts" : "Taispeáin gach teagmháil",
@@ -200,13 +320,18 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Tharla earráid agus {type} á chuardach",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Tosaíonn an cuardach nuair a thosaíonn tú ag clóscríobh agus is féidir na torthaí a bhaint amach leis na heochracha saigheada",
     "Search for {name} only" : "Déan cuardach ar {name} amháin",
-    "Loading more results …" : "Tuilleadh torthaí á lódáil…",
+    "Loading more results …" : "Tuilleadh torthaí á lódáil …",
     "Forgot password?" : "Dearmad ar pasfhocal?",
     "Back to login form" : "Ar ais go dtí an fhoirm logáil isteach",
     "Back" : "Ar ais",
     "Login form is disabled." : "Tá an fhoirm logáil isteach díchumasaithe.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Tá foirm logáil isteach Nextcloud díchumasaithe. Úsáid rogha logáil isteach eile má tá sé ar fáil nó déan teagmháil le do lucht riaracháin.",
     "More actions" : "Tuilleadh gníomhartha",
+    "User menu" : "Roghchlár úsáideora",
+    "Your guest name: {user}" : "Ainm d'aoi: {user}",
+    "You are currently not identified." : "Níl aitheantas tugtha duit faoi láthair.",
+    "Set public name" : "Socraigh ainm poiblí",
+    "Change public name" : "Athraigh ainm poiblí",
     "Password is too weak" : "Tá pasfhocal ró-lag",
     "Password is weak" : "Tá pasfhocal lag",
     "Password is average" : "Is pasfhocal meánach",
@@ -225,6 +350,7 @@ OC.L10N.register(
     "Storage & database" : "Stóráil agus bunachar sonraí",
     "Data folder" : "Fillteán sonraí",
     "Database configuration" : "Cumraíocht bunachar sonraí",
+    "Database type" : "Cineál bunachar sonraí",
     "Only {firstAndOnlyDatabase} is available." : "Níl ach {firstAndOnlyDatabase} ar fáil.",
     "Install and activate additional PHP modules to choose other database types." : "Suiteáil agus gníomhachtaigh modúil PHP breise chun cineálacha bunachar sonraí eile a roghnú.",
     "For more details check out the documentation." : "Le haghaidh tuilleadh sonraí féach ar an doiciméadú.",
@@ -232,6 +358,7 @@ OC.L10N.register(
     "You chose SQLite as database." : "Roghnaigh tú SQLite mar bhunachar sonraí.",
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "Níor cheart SQLite a úsáid ach amháin le haghaidh cásanna íosta agus forbartha. Le haghaidh táirgeadh molaimid inneall bunachar sonraí difriúil.",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Má úsáideann tú cliaint chun comhaid a shioncronú, ní miste go mór úsáid SQLite.",
+    "Database connection" : "Nasc bunachar sonraí",
     "Database user" : "Úsáideoir bunachar sonraí",
     "Database password" : "Pasfhocal bunachar sonraí",
     "Database name" : "Ainm bunachar sonraí",
@@ -239,7 +366,7 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Sonraigh le do thoil uimhir an phoirt mar aon le hainm an óstaigh (m.sh., localhost: 5432).",
     "Database host" : "Óstach bunachar sonraí",
     "localhost" : "áitiúil-óstach",
-    "Installing …" : "Suiteáil…",
+    "Installing …" : "Ag suiteáil …",
     "Install" : "Suiteáil",
     "Need help?" : "Teastaionn Cabhair?",
     "See the documentation" : "Féach ar an doiciméadú",
@@ -248,7 +375,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Ní thacaítear le do bhrabhsálaí. Uasghrádaigh go leagan níos nuaí nó go leagan a dtacaítear leis le do thoil.",
     "Continue with this unsupported browser" : "Lean ar aghaidh leis an mbrabhsálaí seo nach dtacaítear leis",
     "Supported versions" : "Leaganacha tacaithe",
-    "Search {types} …" : "Cuardaigh {types} …",
+    "Search {types} …" : "Cuardaigh {types} …",
     "Choose {file}" : "Roghnaigh {file}",
     "Choose" : "Roghnaigh",
     "Copy to {target}" : "Cóipeáil chuig {target}",
@@ -268,7 +395,7 @@ OC.L10N.register(
     "(all selected)" : "(roghnaithe go léir)",
     "({count} selected)" : "({count} roghnaithe)",
     "Error loading file exists template" : "Earráid agus an comhad á lódáil tá an teimpléad ann",
-    "Saving …" : "Shábháil …",
+    "Saving …" : "Shábháil …",
     "seconds ago" : "soicind ó shin",
     "Connection to server lost" : "Ceangal leis an bhfreastalaí caillte",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Fadhb le lódáil an leathanaigh, á athlódáil i %n soicind ","Fadhb le lódáil an leathanaigh, á athlódáil i %n soicind ","Fadhb le lódáil an leathanaigh, á athlódáil i %n soicind ","Fadhb le lódáil an leathanaigh, á athlódáil i %n soicind ","Fadhb le lódáil an leathanaigh, á athlódáil i %n soicind "],
@@ -283,26 +410,18 @@ OC.L10N.register(
     "Type to search for existing projects" : "Clóscríobh chun tionscadail atá ann cheana a chuardach",
     "New in" : "Nua isteach",
     "View changelog" : "Féach ar loga na n-athruithe",
-    "No action available" : "Níl aon ghníomh ar fáil",
-    "Error fetching contact actions" : "Earráid agus gníomhartha teagmhála á bhfáil",
     "Close \"{dialogTitle}\" dialog" : "Dún dialóg \"{dialogTitle}\".",
     "Email length is at max (255)" : "Tá fad an ríomhphoist ag uasmhéid (255)",
-    "Non-existing tag #{tag}" : "Clib nach bhfuil ann #{tag}",
-    "Restricted" : "Srianta",
-    "Invisible" : "Dofheicthe",
-    "Delete" : "Scrios",
-    "Rename" : "Athainmnigh",
-    "Collaborative tags" : "Clibeanna comhoibríocha",
-    "No tags found" : "Níor aimsíodh clibeanna",
     "Clipboard not available, please copy manually" : "Níl an gearrthaisce ar fáil, cóipeáil de láimh",
     "Personal" : "Pearsanta",
     "Accounts" : "Cuntais",
     "Admin" : "Riarachán",
     "Help" : "Cabhrú",
     "Access forbidden" : "Rochtain toirmiscthe",
+    "You are not allowed to access this page." : "Níl cead agat rochtain a fháil ar an leathanach seo.",
+    "Back to %s" : "Ar ais go dtí %s",
     "Page not found" : "Ní bhfuarthas an leathanach",
     "The page could not be found on the server or you may not be allowed to view it." : "Níorbh fhéidir an leathanach a fháil ar an bhfreastalaí nó b'fhéidir nach bhfuil cead agat é a fheiceáil.",
-    "Back to %s" : "Ar ais go dtí %s",
     "Too many requests" : "An iomarca iarratas",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Tháinig an iomarca iarratas ó do líonra. Bain triail eile as ar ball nó déan teagmháil le do riarthóir más earráid é seo.",
     "Error" : "Earráid",
@@ -378,23 +497,40 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Tá an cás %s seo i mód cothabhála faoi láthair, agus seans go dtógfaidh sé sin tamall.",
     "This page will refresh itself when the instance is available again." : "Athnóidh an leathanach seo é féin nuair a bheidh an t-ásc ar fáil arís.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Déan teagmháil le riarthóir do chórais má leanann an teachtaireacht seo nó má thaispeánfar gan choinne.",
-    "Currently open" : "Oscailte faoi láthair",
-    "Login with username or email" : "Logáil isteach le hainm úsáideora nó ríomhphost",
-    "Login with username" : "Logáil isteach leis an ainm úsáideora",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Comhrá, físghlaonna, comhroinnt scáileáin, cruinnithe ar líne agus comhdháil gréasáin – i do bhrabhsálaí agus le haipeanna móibíleacha.",
-    "You have not added any info yet" : "Níl aon fhaisnéis curtha agat fós",
-    "{user} has not added any info yet" : "Níor chuir {user} aon fhaisnéis leis fós",
-    "Error opening the user status modal, try hard refreshing the page" : "Earráid agus an modh stádas úsáideora á oscailt, déan iarracht an leathanach a athnuachan go dian",
-    "Edit Profile" : "Cuir Próifíl in Eagar",
-    "The headline and about sections will show up here" : "Taispeánfar an ceannlíne agus na hailt faoi anseo",
-    "Error loading message template: {error}" : "Earráid agus teimpléad na teachtaireachta á lódáil: {error}",
+    "Error occurred while checking server setup" : "Tharla earráid agus socrú an fhreastalaí á sheiceáil",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "Le haghaidh tuilleadh sonraí féach an {linkstart}doiciméadú ↗{linkend}.",
+    "unknown text" : "téacs anaithnid",
+    "Hello world!" : "Dia duit, a dhomhan!",
+    "sunny" : "Grianmhar",
+    "Hello {name}, the weather is {weather}" : "Dia duit {name}, tá an aimsir {weather}",
+    "Hello {name}" : "Dia duit {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Seo iad do thorthaí cuardaigh<script>foláireamh(1)</script></strong>",
+    "new" : "nua",
+    "_download %n file_::_download %n files_" : ["íoslódáil %n comhad","íoslódáil %n comhaid","íoslódáil %n comhaid","íoslódáil %n comhaid","íoslódáil %n comhaid"],
+    "Direct link copied to clipboard" : "Cóipeáladh nasc díreach chuig an ngearrthaisce",
+    "Searching …" : "Ag cuardach…",
+    "Logging in …" : "Ag logáil isteach…",
+    "Loading apps …" : "Aipeanna á lódáil…",
+    "Installing apps …" : "Aipeanna á suiteáil…",
+    "Loading your contacts …" : "Do theagmhálaithe á lódáil…",
+    "Looking for {term} …" : "Ag lorg {term} …",
+    "Search contacts …" : "Cuardaigh teagmhálaithe…",
+    "Loading more results …" : "Tuilleadh torthaí á lódáil…",
+    "Search {types} …" : "Cuardaigh {types} …",
+    "Saving …" : "Shábháil …",
     "Very weak password" : "Pasfhocal an-lag",
     "Weak password" : "Pasfhocal lag",
     "So-so password" : "mar sin-sin pasfhocal",
     "Good password" : "pasfhocal maith",
     "Strong password" : "Pasfhocal láidir",
-    "Profile not found" : "Próifíl gan aimsiú",
-    "The profile does not exist." : "Níl an phróifíl ann.",
+    "No action available" : "Níl aon ghníomh ar fáil",
+    "Error fetching contact actions" : "Earráid agus gníomhartha teagmhála á bhfáil",
+    "Non-existing tag #{tag}" : "Clib nach bhfuil ann #{tag}",
+    "Restricted" : "Srianta",
+    "Delete" : "Scrios",
+    "Rename" : "Athainmnigh",
+    "Collaborative tags" : "Clibeanna comhoibríocha",
+    "No tags found" : "Níor aimsíodh clibeanna",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Is dócha go bhfuil do eolaire sonraí agus comhaid inrochtana ón idirlíon toisc nach n-oibríonn an comhad .htaccess.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Chun tuilleadh faisnéise a fháil faoi conas do fhreastalaí a chumrú i gceart, féach ar an <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">doiciméad</a>le do thoil. ",
     "<strong>Create an admin account</strong>" : "<strong>Cruthaigh cuntas riaracháin</strong>",
@@ -404,6 +540,7 @@ OC.L10N.register(
     "Toggle password visibility" : "Scoránaigh infheictheacht pasfhocail",
     "Configure the database" : "Cumraigh an bunachar sonraí",
     "Only %s is available." : "Níl ach %s ar fáil.",
-    "Database account" : "Cuntas bunachar sonraí"
+    "Database account" : "Cuntas bunachar sonraí",
+    "Installing …" : "Suiteáil…"
 },
 "nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
