@@ -18,10 +18,6 @@ OC.L10N.register(
     "Unknown filetype" : "Tipe berkas tidak dikenal",
     "An error occurred. Please contact your admin." : "Terjadi kesalahan. Silakan hubungi admin Anda.",
     "Invalid image" : "Gambar tidak valid",
-    "No temporary profile picture available, try again" : "Tidak ada gambar profil sementara yang tersedia, coba lagi",
-    "No crop data provided" : "Tidak ada data krop tersedia",
-    "No valid crop data provided" : "Tidak ada data valid untuk dipangkas",
-    "Crop is not square" : "Pangkas ini tidak persegi",
     "State token does not match" : "Token yang digunakan tidak cocok",
     "Invalid app password" : "Kata sandi aplikasi tidak valid",
     "Could not complete login" : "Tidak dapat menyelesaikan log masuk",
@@ -32,20 +28,20 @@ OC.L10N.register(
     "Could not reset password because the token is invalid" : "Tidak dapat mengatur ulang kata sandi karena token tidak valid",
     "%s password reset" : "%s kata sandi disetel ulang",
     "Password reset" : "Setel ulang kata sandi",
-    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Klik tombol berikut untuk menyetel ulang kata sandi Anda. Jika Anda tidak melakukan permintaan setel ulang kata sandi, abaikan surel ini.",
-    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Klik tautan berikut untuk menyetel ulang kata sandi Anda. Jika Anda tidak melakukan permintaan setel ulang kata sandi, abaikan surel ini.",
+    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Klik tombol berikut untuk menyetel ulang kata sandi Anda. Jika Anda tidak melakukan permintaan setel ulang kata sandi, abaikan email ini.",
+    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Klik tautan berikut untuk menyetel ulang kata sandi Anda. Jika Anda tidak melakukan permintaan setel ulang kata sandi, abaikan email ini.",
     "Reset your password" : "Setel ulang kata sandi Anda",
     "Internal error" : "Kesalahan internal",
-    "Nextcloud Server" : "Server Nextcloud",
-    "Some of your link shares have been removed" : "Beberapa tautan berbagi Anda telah dihapus",
-    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Dikarenakan isu bug keamanan, kami perlu menghapus beberapa tautan berbagi Anda. Silakan lihat tautan berikut untuk informasi lebih lanjut.",
-    "Learn more ↗" : "Pelajari lebih lanjut ↗",
-    "Preparing update" : "Mempersiapkan pembaruan",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Langkah perbaikan:",
     "Repair info:" : "Info perbaikan:",
     "Repair warning:" : "Peringatan perbaikan:",
     "Repair error:" : "Galat perbaikan:",
+    "Nextcloud Server" : "Server Nextcloud",
+    "Some of your link shares have been removed" : "Beberapa tautan berbagi Anda telah dihapus",
+    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Dikarenakan isu bug keamanan, kami perlu menghapus beberapa tautan berbagi Anda. Silakan lihat tautan berikut untuk informasi lebih lanjut.",
+    "Learn more ↗" : "Pelajari lebih lanjut ↗",
+    "Preparing update" : "Mempersiapkan pembaruan",
     "Turned on maintenance mode" : "Hidupkan mode perawatan",
     "Turned off maintenance mode" : "Matikan mode perawatan",
     "Maintenance mode is kept active" : "Mode Pemeliharaan masih aktif",
@@ -61,15 +57,8 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (tidak kompatibel)",
     "The following apps have been disabled: %s" : "Aplikasi berikut telah dinonaktifkan: %s",
     "Already up to date" : "Sudah yang terbaru",
-    "Error occurred while checking server setup" : "Kesalahan tidak terduga saat memeriksa setelan server",
-    "unknown text" : "teks tidak diketahui",
-    "Hello world!" : "Halo dunia!",
-    "sunny" : "cerah",
-    "Hello {name}, the weather is {weather}" : "Halo {name}, saat ini {weather}",
-    "Hello {name}" : "Halo {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Ini adalah hasil pencarian Anda<script>alert(1)</script></strong>",
-    "new" : "baru",
-    "_download %n file_::_download %n files_" : ["unduh %n berkas"],
+    "Unknown" : "Tidak diketahui",
+    "PNG image" : "Gambar PNG",
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Pembaruan sedang dalam proses, meninggalkan halaman ini mungkin dapat mengganggu proses di beberapa lingkungan.",
     "Update to {version}" : "Perbarui ke {version}",
     "An error occurred." : "Terjadi kesalahan.",
@@ -89,7 +78,6 @@ OC.L10N.register(
     "People" : "Orang",
     "Load more results" : "Muat lebih banyak hasil",
     "Log in" : "Masuk",
-    "Logging in …" : "Log masuk...",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Terdeteksi multipel percobaan log masuk tidak valid dari IP Anda. Pencekalan log masuk berikutnya dilakukan hingga 30 detik.",
     "Server side authentication failed!" : "Otentikasi dari sisi server gagal!",
     "Please contact your administrator." : "Silakan hubungi administrator Anda.",
@@ -98,35 +86,37 @@ OC.L10N.register(
     "Password" : "Kata Sandi",
     "Log in with a device" : "Log masuk dengan perangkat",
     "Your account is not setup for passwordless login." : "Akun Anda tidak diatur untuk masuk tanpa kata sandi.",
-    "Browser not supported" : "Peramban tidak didukung",
-    "Passwordless authentication is not supported in your browser." : "Otentikasi tanpa kata sandi tidak didukung peramban Anda.",
     "Your connection is not secure" : "Koneksi Anda tidak aman",
     "Passwordless authentication is only available over a secure connection." : "Otentikasi tanpa kata sandi hanya tersedia melalui koneksi aman.",
+    "Browser not supported" : "Peramban tidak didukung",
+    "Passwordless authentication is not supported in your browser." : "Otentikasi tanpa kata sandi tidak didukung peramban Anda.",
     "Reset password" : "Setel ulang kata sandi",
-    "Couldn't send reset email. Please contact your administrator." : "Tidak dapat mengirim surel setel ulang. Silakan hubungi administrator Anda.",
-    "Password cannot be changed. Please contact your administrator." : "Kata sandi tidak dapat diubah. Silakan hubungi administrator Anda.",
     "Back to login" : "Kembali ke log masuk",
+    "Couldn't send reset email. Please contact your administrator." : "Tidak dapat mengirim email setel ulang. Silakan hubungi administrator Anda.",
+    "Password cannot be changed. Please contact your administrator." : "Kata sandi tidak dapat diubah. Silakan hubungi administrator Anda.",
     "New password" : "Kata sandi baru",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Berkas Anda terenkripsi. Tidak memungkinkan untuk mendapatkan kembali data Anda setelah kata sandi disetel ulang. Jika tidak yakin, silakan hubungi administrator Anda sebelum melanjutkan. Apa Anda ingin melanjutkan?",
     "I know what I'm doing" : "Saya tahu apa yang saya lakukan",
     "Resetting password" : "Menyetel ulang kata sandi",
     "Schedule work & meetings, synced with all your devices." : "Penjadwalan rapat & pekerjaan, tersinkronisasi dengan gawai Anda.",
     "Keep your colleagues and friends in one place without leaking their private info." : "Simpan info teman dan kolega Anda dalam satu tempat, tanpa membocorkan privat mereka.",
-    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Aplikasi klien surel sederhana, terintegrasi dengan Berkas, Kontak, dan Kalender.",
+    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Aplikasi klien email sederhana, terintegrasi dengan Berkas, Kontak, dan Kalender.",
     "Recommended apps" : "Aplikasi terekomendasi",
-    "Loading apps …" : "Memuat aplikasi ...",
     "Could not fetch list of apps from the App Store." : "Tidak dapat mengambil daftar aplikasi dari App Store.",
     "App download or installation failed" : "Unduh aplikasi atau gagal instalasi",
     "Cannot install this app because it is not compatible" : "Tidak dapat memasang aplikasi ini karena tidak kompatibel",
     "Cannot install this app" : "Tidak dapat memasang aplikasi ini",
     "Skip" : "Lewati",
-    "Installing apps …" : "menginstal aplikasi ...",
     "Install recommended apps" : "Instal aplikasi yang disarankan",
+    "Online" : "Online",
+    "Away" : "Jauh",
+    "Busy" : "Sibuk",
+    "Do not disturb" : "Jangan diganggu",
+    "Mute all notifications" : "Bisukan semua notifikasi",
+    "Invisible" : "Tersembunyi",
+    "Appear offline" : "Tampak offline",
     "Settings menu" : "Menu Pengaturan",
-    "Loading your contacts …" : "Memuat kontak Anda ...",
-    "Looking for {term} …" : "Mencari {term}",
     "Reset search" : "Ulang pencarian",
-    "Search contacts …" : "Cari kontak ...",
     "Could not load your contacts" : "Tidak dapat memuat kontak Anda",
     "No contacts found" : "Kontak tidak ditemukan",
     "Show all contacts" : "Tampilkan semua kontak",
@@ -136,10 +126,26 @@ OC.L10N.register(
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Harap masukkan {minSearchLength} karakter atau lebih untuk mencari"],
     "An error occurred while searching for {type}" : "Terjadi kesalahan saat mencari {type}",
     "Search for {name} only" : "Cari {name} saja",
-    "Loading more results …" : "Memuat hasil lainnya…",
     "Forgot password?" : "Lupa kata sandi?",
     "Back" : "Kembali",
-    "Search {types} …" : "Cari {types} …",
+    "Security warning" : "Peringatan keamanan",
+    "Storage & database" : "Penyimpanan & Basis data",
+    "Data folder" : "Folder data",
+    "Install and activate additional PHP modules to choose other database types." : "Pasang dan aktifkan modul PHP tambahan untuk memilih tipe basis data lainnya.",
+    "For more details check out the documentation." : "Untuk lebih rinci, periksa pada dokumentasi.",
+    "Performance warning" : "Peringatan kinerja",
+    "You chose SQLite as database." : "Anda memilih SQLite sebagai pangkalan data",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite hanya digunakan pada instalasi minimal dan lingkungan pengembangan. Untuk lingkungan produksi dianjurkan menggunakan backend pangkalan data lain.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Jika menggunakan klien untuk sinkronisasi berkas, penggunaan SQLite sangat tidak dianjurkan.",
+    "Database user" : "Pengguna basis data",
+    "Database password" : "Kata sandi basis data",
+    "Database name" : "Nama basis data",
+    "Database tablespace" : "Tablespace basis data",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Harap tentukan nomor port beserta nama host (contoh., localhost:5432).",
+    "Database host" : "Host basis data",
+    "Install" : "Pasang",
+    "Need help?" : "Butuh bantuan?",
+    "See the documentation" : "Lihat dokumentasi",
     "Choose" : "Pilih",
     "Copy" : "Salin",
     "Move" : "Pindah",
@@ -156,7 +162,6 @@ OC.L10N.register(
     "(all selected)" : "(semua terpilih)",
     "({count} selected)" : "({count} terpilih)",
     "Error loading file exists template" : "Kesalahan memuat templat berkas yang sudah ada",
-    "Saving …" : "Menyimpan ...",
     "seconds ago" : "beberapa detik yang lalu",
     "Connection to server lost" : "Koneksi ke server gagal",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Tidak dapat memuat laman, muat ulang dalam %n detik"],
@@ -171,26 +176,13 @@ OC.L10N.register(
     "Type to search for existing projects" : "Ketik untuk mencari proyek eksis",
     "New in" : "Terbaru",
     "View changelog" : "Lihat log pembaruan",
-    "Very weak password" : "Kata sandi sangat lemah",
-    "Weak password" : "Kata sandi lemah",
-    "So-so password" : "Kata sandi lumayan",
-    "Good password" : "Kata sandi baik",
-    "Strong password" : "Kata sandi kuat",
-    "No action available" : "Aksi tidak tersedia",
-    "Error fetching contact actions" : "Galat mengambil aksi kontak",
-    "Non-existing tag #{tag}" : "Tag tidak ada #{tag}",
-    "Restricted" : "Terbatas",
-    "Invisible" : "Tersembunyi",
-    "Delete" : "Hapus",
-    "Rename" : "Ubah nama",
-    "Collaborative tags" : "Tag kolaboratif",
-    "No tags found" : "Tag tidak ditemukan",
     "Personal" : "Pribadi",
+    "Accounts" : "Accounts",
     "Admin" : "Admin",
     "Help" : "Bantuan",
     "Access forbidden" : "Akses ditolak",
-    "Page not found" : "Halaman tidak ditemukan",
     "Back to %s" : "Kembali ke %s",
+    "Page not found" : "Halaman tidak ditemukan",
     "Too many requests" : "Terlalu banyak permintaan",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Ada terlalu banyak permintaan dari jaringan Anda. Coba lagi nanti atau hubungi administrator Anda jika ini adalah kesalahan.",
     "Error" : "Kesalahan",
@@ -207,29 +199,6 @@ OC.L10N.register(
     "File: %s" : "Berkas: %s",
     "Line: %s" : "Baris: %s",
     "Trace" : "Jejak",
-    "Security warning" : "Peringatan keamanan",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Kemungkinan direktori data dan berkas Anda dapat diakses dari internet karena berkas .htaccess tidak berfungsi.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Informasi bagaimana kesesuaian konfigurasi peladen Anda, silakan lihat <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentasi</a>.",
-    "Show password" : "Tampilkan kata sandi",
-    "Storage & database" : "Penyimpanan & Basis data",
-    "Data folder" : "Folder data",
-    "Configure the database" : "Konfigurasikan basis data",
-    "Only %s is available." : "Hanya %s yang tersedia",
-    "Install and activate additional PHP modules to choose other database types." : "Pasang dan aktifkan modul PHP tambahan untuk memilih tipe basis data lainnya.",
-    "For more details check out the documentation." : "Untuk lebih rinci, periksa pada dokumentasi.",
-    "Database password" : "Kata sandi basis data",
-    "Database name" : "Nama basis data",
-    "Database tablespace" : "Tablespace basis data",
-    "Database host" : "Host basis data",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Harap tentukan nomor port beserta nama host (contoh., localhost:5432).",
-    "Performance warning" : "Peringatan kinerja",
-    "You chose SQLite as database." : "Anda memilih SQLite sebagai pangkalan data",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite hanya digunakan pada instalasi minimal dan lingkungan pengembangan. Untuk lingkungan produksi dianjurkan menggunakan backend pangkalan data lain.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Jika menggunakan klien untuk sinkronisasi berkas, penggunaan SQLite sangat tidak dianjurkan.",
-    "Install" : "Pasang",
-    "Installing …" : "Memasang …",
-    "Need help?" : "Butuh bantuan?",
-    "See the documentation" : "Lihat dokumentasi",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Sepertinya Anda coba untuk menginstal ulang Nextcloud. Namun berkas CAN_INSTALL tidak ditemukan pada direktori konfigurasi. Silakan buat berkas tersebut untuk melanjutkan.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Tidak dapat membuang CAN_INSTALL dari direktori konfigurasi. Silakan lakukan secara manual.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Aplikasi ini memerlukan JavaScript untuk dapat beroperasi dengan benar. Mohon {linkstart}aktifkan JavaScript{linkend} dan muat ulang halaman ini.",
@@ -248,8 +217,8 @@ OC.L10N.register(
     "You can close this window." : "Anda dapat menutup jendela ini.",
     "Previous" : "Sebelumnya",
     "This share is password-protected" : "Berbagi ini dilindungi kata sandi",
-    "Please type in your email address to request a temporary password" : "Silakan ketik alamat surel Anda untuk meminta kata sandi sementara",
-    "Email address" : "Alamat surel",
+    "Please type in your email address to request a temporary password" : "Silakan ketik alamat email Anda untuk meminta kata sandi sementara",
+    "Email address" : "Alamat email",
     "Password sent!" : "Kata sandi terkirim!",
     "You are not authorized to request a password for this share" : "Anda tidak diizinkan untuk meminta kata sandi untuk pembagian ini",
     "Two-factor authentication" : "Otentikasi Two-factor",
@@ -283,12 +252,42 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Instansi %s ini sedang dalam modus pemeliharaan, mungkin memerlukan beberapa saat.",
     "This page will refresh itself when the instance is available again." : "Laman ini akan dimuat otomatis saat instalasi kembali tersedia.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Hubungi administrator sistem Anda jika pesan ini terus muncul atau muncul tiba-tiba.",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Mengobrol, panggilan video, berbagi layar, rapat daring, dan konferensi web - melalui peramban dan menggunakan aplikasi pada gawai.",
-    "You have not added any info yet" : "Anda belum menambahkan info apa pun",
-    "{user} has not added any info yet" : "{user} belum menambahkan info apa pun",
-    "Edit Profile" : "Sunting profil",
-    "Error loading message template: {error}" : "Kesalahan memuat templat pesan: {error}",
-    "Profile not found" : "Profil tidak ditemukan",
-    "The profile does not exist." : "Profil tidak ada."
+    "Error occurred while checking server setup" : "Kesalahan tidak terduga saat memeriksa setelan server",
+    "unknown text" : "teks tidak diketahui",
+    "Hello world!" : "Halo dunia!",
+    "sunny" : "cerah",
+    "Hello {name}, the weather is {weather}" : "Halo {name}, saat ini {weather}",
+    "Hello {name}" : "Halo {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Ini adalah hasil pencarian Anda<script>alert(1)</script></strong>",
+    "new" : "baru",
+    "_download %n file_::_download %n files_" : ["unduh %n berkas"],
+    "Logging in …" : "Log masuk...",
+    "Loading apps …" : "Memuat aplikasi ...",
+    "Installing apps …" : "menginstal aplikasi ...",
+    "Loading your contacts …" : "Memuat kontak Anda ...",
+    "Looking for {term} …" : "Mencari {term}",
+    "Search contacts …" : "Cari kontak ...",
+    "Loading more results …" : "Memuat hasil lainnya…",
+    "Search {types} …" : "Cari {types} …",
+    "Saving …" : "Menyimpan ...",
+    "Very weak password" : "Kata sandi sangat lemah",
+    "Weak password" : "Kata sandi lemah",
+    "So-so password" : "Kata sandi lumayan",
+    "Good password" : "Kata sandi baik",
+    "Strong password" : "Kata sandi kuat",
+    "No action available" : "Aksi tidak tersedia",
+    "Error fetching contact actions" : "Galat mengambil aksi kontak",
+    "Non-existing tag #{tag}" : "Tag tidak ada #{tag}",
+    "Restricted" : "Terbatas",
+    "Delete" : "Hapus",
+    "Rename" : "Ubah nama",
+    "Collaborative tags" : "Tag kolaboratif",
+    "No tags found" : "Tag tidak ditemukan",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Kemungkinan direktori data dan berkas Anda dapat diakses dari internet karena berkas .htaccess tidak berfungsi.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Informasi bagaimana kesesuaian konfigurasi peladen Anda, silakan lihat <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentasi</a>.",
+    "Show password" : "Tampilkan kata sandi",
+    "Configure the database" : "Konfigurasikan basis data",
+    "Only %s is available." : "Hanya %s yang tersedia",
+    "Installing …" : "Memasang …"
 },
 "nplurals=1; plural=0;");
