@@ -42,6 +42,7 @@ OC.L10N.register(
     "Not found" : "Non trovato",
     "Node is locked" : "Il nodo è bloccato",
     "Bad request" : "Richiesta errata",
+    "Input text is too long" : "Il testo inserito è troppo lungo",
     "Requested task type does not exist" : "Il tipo di attività richiesto non esiste",
     "Necessary language model provider is not available" : "Il necessario provider di modello per la lingua non è disponibile",
     "No text to image provider is available" : "Nessun fornitore da-testo-a-immagine disponibile",
@@ -262,6 +263,7 @@ OC.L10N.register(
     "An internal error occurred." : "Si è verificato un errore interno.",
     "Please try again or contact your administrator." : "Prova ancora o contatta il tuo amministratore.",
     "Password" : "Password",
+    "Remember me" : "Ricordami",
     "Log in with a device" : "Accedi con un dispositivo",
     "Login or email" : "Nome utente o email",
     "Your account is not setup for passwordless login." : "Il tuo account non è configurato per l'accesso senza password.",
@@ -293,6 +295,13 @@ OC.L10N.register(
     "Skip" : "Salta",
     "Installing apps …" : "Installazione app …",
     "Install recommended apps" : "Installa applicazioni consigliate",
+    "Online" : "In linea",
+    "Away" : "Assente",
+    "Busy" : "Occupato",
+    "Do not disturb" : "Non disturbare",
+    "Mute all notifications" : "Muta tutte le notifiche",
+    "Invisible" : "Invisibile",
+    "Appear offline" : "Appari non in linea",
     "Avatar of {displayName}" : "Avatar di {displayName}",
     "Settings menu" : "Menu delle impostazioni",
     "Loading your contacts …" : "Caricamento dei tuoi contatti …",
@@ -518,7 +527,6 @@ OC.L10N.register(
     "Error fetching contact actions" : "Errore durante il recupero delle azioni dei contatti",
     "Non-existing tag #{tag}" : "Etichetta #{tag} inesistente",
     "Restricted" : "Limitato",
-    "Invisible" : "Invisibile",
     "Delete" : "Elimina",
     "Rename" : "Rinomina",
     "Collaborative tags" : "Etichette collaborative",
