@@ -18,10 +18,6 @@ OC.L10N.register(
     "Unknown filetype" : "不明なファイル形式",
     "An error occurred. Please contact your admin." : "エラーが発生しました。管理者に連絡してください。",
     "Invalid image" : "無効な画像",
-    "No temporary profile picture available, try again" : "一時的なプロファイル用画像が利用できません。もう一度試してください",
-    "No crop data provided" : "クロップデータが提供されていません",
-    "No valid crop data provided" : "有効なクロップデータが提供されていません",
-    "Crop is not square" : "クロップが正方形ではありません",
     "State token does not match" : "状態トークンが一致しません",
     "Invalid app password" : "アプリパスワードが無効です",
     "Could not complete login" : "ログインが完了できませんでした",
@@ -46,6 +42,7 @@ OC.L10N.register(
     "Not found" : "見つかりませんでした",
     "Node is locked" : "ノードがロックされています",
     "Bad request" : "Bad request",
+    "Input text is too long" : "入力テキストが長すぎます",
     "Requested task type does not exist" : "要求されたタスクの種類が存在しません",
     "Necessary language model provider is not available" : "必要な言語モデルプロバイダーが利用できません",
     "No text to image provider is available" : "テキストを画像に変換するプロバイダーはありません",
@@ -53,6 +50,7 @@ OC.L10N.register(
     "No translation provider available" : "利用可能な翻訳プロバイダーがありません",
     "Could not detect language" : "言語を検出できませんでした",
     "Unable to translate" : "翻訳できませんでした",
+    "No valid filters provided" : "有効なフィルターがありません",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "修復ステップ:",
     "Repair info:" : "修復情報:",
@@ -200,14 +198,6 @@ OC.L10N.register(
     "Matroska video" : "Matroskaビデオ",
     "Windows Media video" : "Windows Mediaビデオ",
     "AVI video" : "AVI ビデオ",
-    "unknown text" : "不明なテキスト",
-    "Hello world!" : "Hello world!",
-    "sunny" : "快晴",
-    "Hello {name}, the weather is {weather}" : "こんにちは､ {name}､ 天気は{weather}です",
-    "Hello {name}" : " {name}さん､こんにちは",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>これが検索結果です<script>alert(1)</script></strong>",
-    "new" : "新規",
-    "_download %n file_::_download %n files_" : ["%n個のファイルをダウンロード"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "更新が進行中です。このページを離れると一部の環境では処理が中断されてしまう可能性があります。",
     "Update to {version}" : "{version} にアップデート",
     "An error occurred." : "エラーが発生しました。",
@@ -237,14 +227,16 @@ OC.L10N.register(
     "Search in current app" : "現在のアプリケーションで検索",
     "Clear search" : "検索をクリア",
     "Search everywhere" : "あらゆる場所を検索",
-    "Searching …" : "検索しています…",
+    "Searching …" : "検索しています…",
     "Start typing to search" : "入力して検索を開始します",
+    "Minimum search length is {minSearchLength} characters" : "検索の最小長は{minSearchLength}文字です",
     "No matching results" : "一致する結果はありません",
     "Today" : "今日",
     "Last 7 days" : "7日以内",
     "Last 30 days" : "30日以内",
     "This year" : "今年",
     "Last year" : "去年",
+    "Between {startDate} and {endDate}" : "{startDate}から{endDate}まで",
     "Unified search" : "統合検索",
     "Search apps, files, tags, messages" : "アプリ、ファイル、タグ、メッセージを検索",
     "Places" : "場所",
@@ -257,7 +249,7 @@ OC.L10N.register(
     "Load more results" : "次の結果を読み込む",
     "Search in" : "検索対象",
     "Log in" : "ログイン",
-    "Logging in …" : "ログイン中...",
+    "Logging in …" : "ログイン中...",
     "Log in to {productName}" : "{productName} へログイン",
     "Wrong login or password." : "ログイン名またはパスワードが間違っています。",
     "This account is disabled" : "アカウントが無効化されています",
@@ -271,6 +263,7 @@ OC.L10N.register(
     "An internal error occurred." : "内部エラーが発生しました。",
     "Please try again or contact your administrator." : "もう一度やり直してみるか、管理者にお問い合わせください。",
     "Password" : "パスワード",
+    "Remember me" : "ログイン情報を記憶",
     "Log in with a device" : "デバイスを使ってログインする",
     "Login or email" : "ログイン名またはEメール",
     "Your account is not setup for passwordless login." : "あなたのアカウントはパスワードなしでログインできるように設定されていません。",
@@ -294,21 +287,28 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Collabora Online上に構築された、共同作業ドキュメント、スプレッドシート、およびプレゼンテーション",
     "Distraction free note taking app." : "集中モードメモアプリ",
     "Recommended apps" : "推奨アプリ",
-    "Loading apps …" : "アプリを読み込み中…",
+    "Loading apps …" : "アプリを読み込み中…",
     "Could not fetch list of apps from the App Store." : "App Storeからアプリのリストを取得できませんでした。",
     "App download or installation failed" : "アプリのダウンロードまたはインストールに失敗しました",
     "Cannot install this app because it is not compatible" : "アプリの互換性がないため、インストールできません",
     "Cannot install this app" : "このアプリはインストールできません",
     "Skip" : "スキップ",
-    "Installing apps …" : "アプリをインストールしています…",
+    "Installing apps …" : "アプリをインストールしています…",
     "Install recommended apps" : "推奨アプリをインストール",
+    "Online" : "オンライン",
+    "Away" : "不在",
+    "Busy" : "ビジー",
+    "Do not disturb" : "取り込み中",
+    "Mute all notifications" : "全ての通知をミュートします",
+    "Invisible" : "オフライン",
+    "Appear offline" : "オフライン",
     "Avatar of {displayName}" : "{displayName} のアバター",
     "Settings menu" : "メニュー設定",
-    "Loading your contacts …" : "連絡先を読み込み中...",
-    "Looking for {term} …" : "{term} を確認中 ...",
+    "Loading your contacts …" : "連絡先を読み込み中...",
+    "Looking for {term} …" : "{term} を確認中 ...",
     "Search contacts" : "連絡先を検索",
     "Reset search" : "検索をリセットする",
-    "Search contacts …" : "連絡先を検索...",
+    "Search contacts …" : "連絡先を検索...",
     "Could not load your contacts" : "連絡先を読み込めませんでした",
     "No contacts found" : "連絡先が見つかりません",
     "Show all contacts" : "すべての連絡先を表示",
@@ -320,7 +320,7 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "{type} の検索中にエラーが発生しました",
     "Search starts once you start typing and results may be reached with the arrow keys" : "入力が始まると検索が始まり、矢印キーで検索結果を表示することができます",
     "Search for {name} only" : "{name}のみを検索",
-    "Loading more results …" : "次の結果を読み込み中 ...",
+    "Loading more results …" : "次の結果を読み込み中 ...",
     "Forgot password?" : "パスワードをお忘れですか?",
     "Back to login form" : "ログイン画面に戻る",
     "Back" : "戻る",
@@ -350,6 +350,7 @@ OC.L10N.register(
     "Storage & database" : "ストレージとデータベース",
     "Data folder" : "データフォルダー",
     "Database configuration" : "データベース設定",
+    "Database type" : "データベースの種類",
     "Only {firstAndOnlyDatabase} is available." : "{firstAndOnlyDatabase} のみ有効です。",
     "Install and activate additional PHP modules to choose other database types." : "他のデータベースタイプを選択するためには、追加の PHP モジュールインストールして有効化してください。",
     "For more details check out the documentation." : "詳細は、ドキュメントを確認してください。",
@@ -357,6 +358,7 @@ OC.L10N.register(
     "You chose SQLite as database." : "あなたはSQLiteをデータベースとして選択しました。",
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLiteは小規模もしくは開発用のインスタンスでのみ利用できます。プロダクション環境では他のデータベースをお勧めします。",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "ファイルの同期にクライアントを使用している場合、SQLiteの使用はお勧めできません。",
+    "Database connection" : "データベース接続",
     "Database user" : "データベースのユーザー名",
     "Database password" : "データベースのパスワード",
     "Database name" : "データベース名",
@@ -364,7 +366,7 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "ポート番号をホスト名とともに指定してください(例：localhost：5432)。",
     "Database host" : "データベースのホスト名",
     "localhost" : "localhost",
-    "Installing …" : "インストールしています…",
+    "Installing …" : "インストールしています…",
     "Install" : "インストール",
     "Need help?" : "ヘルプが必要ですか？",
     "See the documentation" : "ドキュメントを確認してください",
@@ -373,7 +375,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "お使いのブラウザーはサポート対象外です。新しいバージョンにアップグレードするかサポートされているブラウザーへ切り替えてください",
     "Continue with this unsupported browser" : "サポート対象外のブラウザーで継続する",
     "Supported versions" : "サポート対象バージョン",
-    "Search {types} …" : "{types} を検索…",
+    "Search {types} …" : "{types} を検索…",
     "Choose {file}" : "{file}を選択",
     "Choose" : "選択",
     "Copy to {target}" : "{target} にコピー",
@@ -393,7 +395,7 @@ OC.L10N.register(
     "(all selected)" : "(すべて選択)",
     "({count} selected)" : "({count} 選択)",
     "Error loading file exists template" : "既存ファイルのテンプレートの読み込みエラー",
-    "Saving …" : "保存中...",
+    "Saving …" : "保存中 …",
     "seconds ago" : "数秒前",
     "Connection to server lost" : "サーバーとの接続が切断されました",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["ページの読み込み中に問題が発生しました。%n秒後に再読み込みします"],
@@ -408,17 +410,8 @@ OC.L10N.register(
     "Type to search for existing projects" : "入力して既存のプロジェクトを検索します",
     "New in" : "新機能",
     "View changelog" : "変更履歴を確認する",
-    "No action available" : "操作できません",
-    "Error fetching contact actions" : "連絡先操作取得エラー",
     "Close \"{dialogTitle}\" dialog" : "\"{dialogTitle}\"ダイアログを閉じる",
     "Email length is at max (255)" : "メールアドレスの長さは 255文字 以下です",
-    "Non-existing tag #{tag}" : "存在しないタグ#{tag}",
-    "Restricted" : "制限付き",
-    "Invisible" : "オフライン",
-    "Delete" : "削除",
-    "Rename" : "名前の変更",
-    "Collaborative tags" : "コラボタグ",
-    "No tags found" : "タグが見つかりません",
     "Clipboard not available, please copy manually" : "クリップボードが使用できません。手動でコピーしてください",
     "Personal" : "個人",
     "Accounts" : "アカウント",
@@ -506,19 +499,38 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "このメッセージが引き続き、または予期せず現れる場合は、システム管理者に問い合わせてください。",
     "Error occurred while checking server setup" : "サーバー設定のチェック中にエラーが発生しました",
     "For more details see the {linkstart}documentation ↗{linkend}." : "詳細については、{linkstart}ドキュメント↗{linkend}を参照してください。",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "チャット、ビデオ通話、画面共有、オンラインミーティング、ウェブ会議 - ブラウザーとモバイルアプリで。",
-    "You have not added any info yet" : "まだ情報が追加されていません",
-    "{user} has not added any info yet" : "{user}が、まだ情報を追加していません",
-    "Error opening the user status modal, try hard refreshing the page" : "ユーザーステータスモーダルを開くときにエラーが発生しました。ページを更新してみてください",
-    "Edit Profile" : "プロフィールを編集",
-    "The headline and about sections will show up here" : "見出しと概要セクションがここに表示されます",
+    "unknown text" : "不明なテキスト",
+    "Hello world!" : "Hello world!",
+    "sunny" : "快晴",
+    "Hello {name}, the weather is {weather}" : "こんにちは､ {name}､ 天気は{weather}です",
+    "Hello {name}" : " {name}さん､こんにちは",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>これが検索結果です<script>alert(1)</script></strong>",
+    "new" : "新規",
+    "_download %n file_::_download %n files_" : ["%n個のファイルをダウンロード"],
+    "Direct link copied to clipboard" : "クリップボードにコピーされた直接リンク",
+    "Searching …" : "検索しています…",
+    "Logging in …" : "ログイン中...",
+    "Loading apps …" : "アプリを読み込み中…",
+    "Installing apps …" : "アプリをインストールしています…",
+    "Loading your contacts …" : "連絡先を読み込み中...",
+    "Looking for {term} …" : "{term} を確認中 ...",
+    "Search contacts …" : "連絡先を検索...",
+    "Loading more results …" : "次の結果を読み込み中 ...",
+    "Search {types} …" : "{types} を検索…",
+    "Saving …" : "保存中...",
     "Very weak password" : "非常に弱いパスワード",
     "Weak password" : "弱いパスワード",
     "So-so password" : "まずまずのパスワード",
     "Good password" : "良好なパスワード",
     "Strong password" : "強いパスワード",
-    "Profile not found" : "プロフィールが見つかりません",
-    "The profile does not exist." : "プロフィールはありません",
+    "No action available" : "操作できません",
+    "Error fetching contact actions" : "連絡先操作取得エラー",
+    "Non-existing tag #{tag}" : "存在しないタグ#{tag}",
+    "Restricted" : "制限付き",
+    "Delete" : "削除",
+    "Rename" : "名前の変更",
+    "Collaborative tags" : "コラボタグ",
+    "No tags found" : "タグが見つかりません",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : ".htaccessファイルが動作していないため、おそらくあなたのデータディレクトリまたはファイルはインターネットからアクセス可能になっています。",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "サーバーを適正に設定する情報は、こちらの<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">ドキュメント</a>を参照してください。",
     "<strong>Create an admin account</strong>" : "<strong>管理者アカウントを作成する</strong>",
@@ -529,6 +541,6 @@ OC.L10N.register(
     "Configure the database" : "データベースを設定してください",
     "Only %s is available." : "%s のみ有効です。",
     "Database account" : "データベースアカウント",
-    "Direct link copied to clipboard" : "クリップボードにコピーされた直接リンク"
+    "Installing …" : "インストールしています…"
 },
 "nplurals=1; plural=0;");
