@@ -18,10 +18,6 @@ OC.L10N.register(
     "Unknown filetype" : "Nežinomas failo tipas",
     "An error occurred. Please contact your admin." : "Įvyko klaida. Susisiekite su savo administratoriumi.",
     "Invalid image" : "Netinkamas paveikslas",
-    "No temporary profile picture available, try again" : "Nėra laikinojo profilio paveikslėlio, bandykite dar kartą",
-    "No crop data provided" : "Nenurodyti apkirpimo duomenys",
-    "No valid crop data provided" : "Pateikti neteisingi apkirpimo duomenys",
-    "Crop is not square" : "Apkirpimo plotas nėra kvadratas",
     "State token does not match" : "Išorinės sistemos leidimai nesutampa su turimais.",
     "Invalid app password" : "Neteisingas programėlės slaptažodis",
     "Could not complete login" : "Nepavyko užbaigti prisijungimo",
@@ -44,14 +40,14 @@ OC.L10N.register(
     "Image not found" : "Paveikslėlis nerastas",
     "Could not detect language" : "Nepavyko aptikti kalbos",
     "Unable to translate" : "Nepavyko išversti",
-    "Nextcloud Server" : "Nextcloud serveris",
-    "Learn more ↗" : "Sužinokite daugiau ↗",
-    "Preparing update" : "Ruošiamas atnaujinimas",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Pataisymo žingsnis:",
     "Repair info:" : "Pataisymo informacija:",
     "Repair warning:" : "Taisymo įspėjimas:",
     "Repair error:" : "Taisymo klaida:",
+    "Nextcloud Server" : "Nextcloud serveris",
+    "Learn more ↗" : "Sužinokite daugiau ↗",
+    "Preparing update" : "Ruošiamas atnaujinimas",
     "Turned on maintenance mode" : "Įjungta techninės priežiūros veiksena",
     "Turned off maintenance mode" : "Išjungta techninės priežiūros veiksena",
     "Maintenance mode is kept active" : "Techninės priežiūros veiksena yra aktyvi",
@@ -67,16 +63,8 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (nesuderinama)",
     "The following apps have been disabled: %s" : "Šios programėlės buvo išjungtos: %s",
     "Already up to date" : "Naudojama naujausia versija",
-    "Error occurred while checking server setup" : "Tikrinant serverio sąranką, įvyko klaida",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "Išsamesnei informacijai, žiūrėkite {linkstart}dokumentaciją ↗{linkend}.",
-    "unknown text" : "nežinomas tekstas",
-    "Hello world!" : "Sveikas, pasauli!",
-    "sunny" : "saulėta",
-    "Hello {name}, the weather is {weather}" : "Sveiki {name}, šiandien yra {weather}",
-    "Hello {name}" : "Sveiki, {name},",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Paieškos rezultatai:<script>alert(1)</script></strong>",
-    "new" : "naujas",
-    "_download %n file_::_download %n files_" : ["atsisiųsti %n failą","atsisiųsti %n failus","atsisiųsti %n failų","atsisiųsti %n failą"],
+    "Unknown" : "Nežinoma",
+    "PNG image" : "PNG paveikslas",
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Vykdomas atnaujinimas, palikus šį puslapį atvertą, kai kuriose aplinkose šis procesas gali būti nutrauktas.",
     "Update to {version}" : "Atnaujinti į versiją {version}",
     "An error occurred." : "Įvyko klaida.",
@@ -93,10 +81,8 @@ OC.L10N.register(
     "Yes" : "Taip",
     "Failed to add the public link to your Nextcloud" : "Nepavyko pridėti viešosios nuorodos į jūsų Nextcloud",
     "Create share" : "Sukurti viešinį",
-    "Direct link copied to clipboard" : "Tiesioginė nuoroda nukopijuota į iškarpinę",
     "Please copy the link manually:" : "Nukopijuokite nuorodą rankiniu būdu:",
     "Clear search" : "Išvalyti paiešką",
-    "Searching …" : "Ieškoma…",
     "Start typing to search" : "Rašykite norėdami atlikti paiešką",
     "Today" : "Šiandien",
     "Last 7 days" : "Paskutinės 7 dienos",
@@ -106,7 +92,6 @@ OC.L10N.register(
     "Results" : "Rezultatai",
     "Load more results" : "Įkelti daugiau rezultatų",
     "Log in" : "Prisijungti",
-    "Logging in …" : "Prisijungiama …",
     "Log in to {productName}" : "Prisijunkite prie {productName}",
     "Wrong login or password." : "Neteisingas prisijungimas ar slaptažodis.",
     "This account is disabled" : "Ši paskyra yra išjungta",
@@ -115,8 +100,6 @@ OC.L10N.register(
     "Account name" : "Paskyros pavadinimas",
     "Server side authentication failed!" : "Autentikacija serveryje nepavyko!",
     "Please contact your administrator." : "Susisiekite su savo administratoriumi.",
-    "Temporary error" : "Laikina klaida",
-    "Please try again." : "Bandykite dar kartą.",
     "An internal error occurred." : "Įvyko vidinė klaida.",
     "Please try again or contact your administrator." : "Pabandykite dar kartą arba susisiekite su savo administratoriumi.",
     "Password" : "Slaptažodis",
@@ -136,19 +119,20 @@ OC.L10N.register(
     "Keep your colleagues and friends in one place without leaking their private info." : "Saugokite savo kolegas bei draugus vienoje vietoje, neatskleisdami jų asmeninės informacjios.",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "Paprasta el. pašto programėlė, tvarkingai integruota su failais, adresatais ir kalendoriumi.",
     "Recommended apps" : "Rekomenduojamos programėlės",
-    "Loading apps …" : "Įkeliamos programėlės…",
     "App download or installation failed" : "Programėlės atsisiuntimas ar įdiegimas patyrė nesėkmę",
     "Cannot install this app because it is not compatible" : "Nepavyksta įdiegti šios programėlės, nes ji yra nesuderinama",
     "Cannot install this app" : "Nepavyksta įdiegti šios programėlės",
     "Skip" : "Praleisti",
-    "Installing apps …" : "Įdiegiamos programėlės…",
     "Install recommended apps" : "Įdiegti rekomenduojamas programėles",
+    "Away" : "Atsitraukęs",
+    "Busy" : "Užimtas laikas",
+    "Do not disturb" : "Netrukdyti",
+    "Mute all notifications" : "Išjungti visus pranešimus",
+    "Invisible" : "Nematomas",
+    "Appear offline" : "Atrodyti atsijungusiu",
     "Settings menu" : "Nustatymų meniu",
-    "Loading your contacts …" : "Įkeliami jūsų adresatai…",
-    "Looking for {term} …" : "Ieškoma {term} ...",
     "Search contacts" : "Ieškoti adresatų",
     "Reset search" : "Atstatyti paiešką",
-    "Search contacts …" : "Ieškoti adresatų…",
     "Could not load your contacts" : "Nepavyko įkelti jūsų adresatų",
     "No contacts found" : "Adresatų nerasta",
     "Show all contacts" : "Rodyti visus adresatus",
@@ -158,7 +142,6 @@ OC.L10N.register(
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Norėdami atlikti paiešką, įveskite {minSearchLength} ar daugiau simbolių","Norėdami atlikti paiešką, įveskite {minSearchLength} ar daugiau simbolių","Norėdami atlikti paiešką, įveskite {minSearchLength} ar daugiau simbolių","Norėdami atlikti paiešką, įveskite {minSearchLength} ar daugiau simbolių"],
     "An error occurred while searching for {type}" : "Ieškant {type}, įvyko klaida",
     "Search for {name} only" : "Ieškoti tik {name}",
-    "Loading more results …" : "Įkeliama daugiau rezultatų…",
     "Forgot password?" : "Pamiršote slaptažodį?",
     "Back" : "Atgal",
     "More actions" : "Daugiau veiksmų",
@@ -176,7 +159,6 @@ OC.L10N.register(
     "Database name" : "Duomenų bazės pavadinimas",
     "Database tablespace" : "Duomenų bazės loginis saugojimas",
     "Database host" : "Duomenų bazės serveris",
-    "Installing …" : "Įdiegiama…",
     "Install" : "Įdiegti",
     "Need help?" : "Reikia pagalbos?",
     "See the documentation" : "Žiūrėkite dokumentaciją",
@@ -184,7 +166,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Jūsų naršyklė yra nepalaikoma. Atnaujinkite į naujesnę versiją arba naudokite palaikomą naršyklę.",
     "Continue with this unsupported browser" : "Tęsti naudojant šią nepalaikomą naršyklę",
     "Supported versions" : "Palaikomos versijos",
-    "Search {types} …" : "Ieškoti {types}…",
+    "Choose {file}" : "Pasirinkti{file}",
     "Choose" : "Pasirinkti",
     "Copy to {target}" : "Kopijuoti į {target}",
     "Copy" : "Kopijuoti",
@@ -203,7 +185,7 @@ OC.L10N.register(
     "(all selected)" : "(visi pažymėti)",
     "({count} selected)" : "({count} pažymėtų)",
     "Error loading file exists template" : "Klaida įkeliant saugykloje esančių rinkmenų ruošinį",
-    "Saving …" : "Įrašoma…",
+    "Saving …" : "Įrašoma…",
     "seconds ago" : "prieš keletą sekundžių",
     "Connection to server lost" : "Ryšys su serveriu nutrūko",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundės","Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundžių","Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundžių","Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundės"],
@@ -218,22 +200,13 @@ OC.L10N.register(
     "Type to search for existing projects" : "Rašykite norėdami ieškoti esamų projektų",
     "New in" : "Nauja",
     "View changelog" : "Rodyti keitinių žurnalą",
-    "No action available" : "Jokie veiksmai negalimi",
-    "Error fetching contact actions" : "Klaida gaunant veiksmus darbui su adresatais",
-    "Non-existing tag #{tag}" : "Neegzistuojanti žymė #{tag}",
-    "Restricted" : "Apribota",
-    "Invisible" : "Nematomas",
-    "Delete" : "Ištrinti",
-    "Rename" : "Pervadinti",
-    "Collaborative tags" : "Bendradarbiavimo žymės",
-    "No tags found" : "Nerasta jokių žymių",
     "Personal" : "Asmeniniai",
     "Accounts" : "Paskyros",
     "Admin" : "Administravimas",
     "Help" : "Pagalba",
     "Access forbidden" : "Prieiga uždrausta",
-    "Page not found" : "Puslapis nerastas",
     "Back to %s" : "Atgal į %s",
+    "Page not found" : "Puslapis nerastas",
     "Too many requests" : "Per daug užklausų",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Iš jūsų tinklo buvo per daug užklausų. Bandykite dar kartą vėliau arba, jeigu tai klaida, susisiekite su savo administratoriumi.",
     "Error" : "Klaida",
@@ -299,24 +272,47 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Šis %s egzempliorius šiuo metu yra techninės priežiūros veiksenoje, kas savo ruožtu gali šiek tiek užtrukti.",
     "This page will refresh itself when the instance is available again." : "Šis puslapis bus įkeltas iš naujo, kai egzempliorius bus ir vėl prieinamas.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Susisiekite su savo sistemos administratoriumi, jei šis pranešimas nedingsta arba, jei jis pasirodė netikėtai.",
-    "You have not added any info yet" : "Jūs kol kas nesate pridėję jokios informacijos",
-    "{user} has not added any info yet" : "Naudotojas {user} kol kas nėra pridėjęs jokios informacijos",
-    "Edit Profile" : "Taisyti profilį",
-    "The headline and about sections will show up here" : "Čia bus rodoma santrauka apie jus bei kita su jumis susijusi informacija",
-    "Error loading message template: {error}" : "Klaida įkeliant žinutės ruošinį: {error}",
+    "Error occurred while checking server setup" : "Tikrinant serverio sąranką, įvyko klaida",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "Išsamesnei informacijai, žiūrėkite {linkstart}dokumentaciją ↗{linkend}.",
+    "unknown text" : "nežinomas tekstas",
+    "Hello world!" : "Sveikas, pasauli!",
+    "sunny" : "saulėta",
+    "Hello {name}, the weather is {weather}" : "Sveiki {name}, šiandien yra {weather}",
+    "Hello {name}" : "Sveiki, {name},",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Paieškos rezultatai:<script>alert(1)</script></strong>",
+    "new" : "naujas",
+    "_download %n file_::_download %n files_" : ["atsisiųsti %n failą","atsisiųsti %n failus","atsisiųsti %n failų","atsisiųsti %n failą"],
+    "Direct link copied to clipboard" : "Tiesioginė nuoroda nukopijuota į iškarpinę",
+    "Searching …" : "Ieškoma…",
+    "Logging in …" : "Prisijungiama …",
+    "Loading apps …" : "Įkeliamos programėlės…",
+    "Installing apps …" : "Įdiegiamos programėlės…",
+    "Loading your contacts …" : "Įkeliami jūsų adresatai…",
+    "Looking for {term} …" : "Ieškoma {term} ...",
+    "Search contacts …" : "Ieškoti adresatų…",
+    "Loading more results …" : "Įkeliama daugiau rezultatų…",
+    "Search {types} …" : "Ieškoti {types}…",
+    "Saving …" : "Įrašoma…",
     "Very weak password" : "Labai silpnas slaptažodis",
     "Weak password" : "Silpnas slaptažodis",
     "So-so password" : "Neblogas slaptažodis",
     "Good password" : "Geras slaptažodis",
     "Strong password" : "Stiprus slaptažodis",
-    "Profile not found" : "Profilis nerastas",
-    "The profile does not exist." : "Profilio nėra.",
+    "No action available" : "Jokie veiksmai negalimi",
+    "Error fetching contact actions" : "Klaida gaunant veiksmus darbui su adresatais",
+    "Non-existing tag #{tag}" : "Neegzistuojanti žyma #{tag}",
+    "Restricted" : "Apribota",
+    "Delete" : "Ištrinti",
+    "Rename" : "Pervadinti",
+    "Collaborative tags" : "Bendradarbiavimo žymos",
+    "No tags found" : "Nerasta jokių žymų",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Jūsų duomenų katalogas ir failai, tikriausiai, yra prieinami per internetą, nes .htaccess failas neveikia.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Išsamesnei informacijai apie tai kaip tinkamai sukonfigūruoti savo serverį, žiūrėkite <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentaciją</a>.",
     "Show password" : "Rodyti slaptažodį",
     "Toggle password visibility" : "Perjungti slaptažodžio matomumą",
     "Configure the database" : "Konfigūruokite duomenų bazę",
     "Only %s is available." : "Yra prieinama tik %s.",
-    "Database account" : "Duomenų bazės paskyra"
+    "Database account" : "Duomenų bazės paskyra",
+    "Installing …" : "Įdiegiama…"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
