@@ -18,10 +18,6 @@ OC.L10N.register(
     "Unknown filetype" : "Ukjent filtype",
     "An error occurred. Please contact your admin." : "Det oppsto en feil. Kontakt din administrator.",
     "Invalid image" : "Ugyldig bilde",
-    "No temporary profile picture available, try again" : "Midlertidig profilbilde ikke tilgjengelig. Prøv igjen",
-    "No crop data provided" : "Ingen beskjæringsinformasjon angitt",
-    "No valid crop data provided" : "Ingen gyldige beskjæringsdata oppgitt",
-    "Crop is not square" : "Beskjæringen er ikke kvadratisk",
     "State token does not match" : "Tilstandsnøkkel samsvarer ikke",
     "Invalid app password" : "Ugyldig programpassord",
     "Could not complete login" : "Kunne ikke fullføre pålogging",
@@ -51,6 +47,12 @@ OC.L10N.register(
     "No translation provider available" : "Ingen tilbyder av oversetting er tilgjengelig",
     "Could not detect language" : "Kunne ikke gjenkjenne srpåk",
     "Unable to translate" : "Ikke i stand til å oversette",
+    "No valid filters provided" : "Ingen gyldige filtre oppgitt.",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair step:" : "Reparasjonstrinn:",
+    "Repair info:" : "Reparasjonsinformasjon:",
+    "Repair warning:" : "Reparasjonsadvarsel:",
+    "Repair error:" : "Reparasjonsfeil:",
     "Nextcloud Server" : "Nextcloud-server",
     "Some of your link shares have been removed" : "Noen av de delte lenkene dine har blitt fjernet",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "På grunn av et sikkerhetsproblem har vi fjernet enkelte av de delte lenkene dine. Vennligst se linken for mer informasjon. ",
@@ -58,11 +60,6 @@ OC.L10N.register(
     "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Skriv inn abonnementsnøkkelen din i støtteappen for å øke brukergrensen. Dette gir deg også alle tilleggsfordeler som Nextcloud Enterprise tilbyr og anbefales på det sterkeste for driften i selskaper.",
     "Learn more ↗" : "Lær mer ↗",
     "Preparing update" : "Forbereder oppdatering",
-    "[%d / %d]: %s" : "[%d / %d]: %s",
-    "Repair step:" : "Reparasjonstrinn:",
-    "Repair info:" : "Reparasjonsinformasjon:",
-    "Repair warning:" : "Reparasjonsadvarsel:",
-    "Repair error:" : "Reparasjonsfeil:",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "Vennligst bruk kommandolinje til å oppdatere.  Oppdatering via nettleser er ikke aktivert i din config.php.",
     "Turned on maintenance mode" : "Vedlikeholdmodus aktivt",
     "Turned off maintenance mode" : "Vedlikeholdmodus er deaktivert",
@@ -79,16 +76,58 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (ikke kompatibel)",
     "The following apps have been disabled: %s" : "Følgende apper har blitt deaktivert: %s",
     "Already up to date" : "Allerede oppdatert",
-    "Error occurred while checking server setup" : "Feil oppsto ved sjekking av server-oppsett",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "For mer informasjon se {linkstart}dokumentasjonen ↗{linkend}.",
-    "unknown text" : "ukjent tekst",
-    "Hello world!" : "Hei, verden!",
-    "sunny" : "solfylt",
-    "Hello {name}, the weather is {weather}" : "Hallo {name}, været er {weather}",
-    "Hello {name}" : "Hallo {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Dette er dine søketreff<script>alert(1)</script></strong>",
-    "new" : "ny",
-    "_download %n file_::_download %n files_" : ["last ned %n fil","last ned %n filer"],
+    "JSON document" : "JSON-dokument",
+    "Microsoft Word document" : "Microsoft Word-dokument",
+    "Unknown" : "Ukjent",
+    "PDF document" : "PDF-dokument",
+    "PowerPoint presentation" : "PowerPoint-presentasjon",
+    "Word document" : "Word-dokument",
+    "ODG template" : "ODG-mal",
+    "ODP presentation" : "ODP-presentasjon",
+    "ODP template" : "ODP-mal",
+    "ODS template" : "ODS-mal",
+    "ODT document" : "ODT-dokument",
+    "ODT template" : "ODT-mal",
+    "WordPerfect document" : "WordPerfect-dokument",
+    "FictionBook document" : "FictionBook-dokument",
+    "Krita document" : "Krita-dokument",
+    "Perl script" : "Perl-skript",
+    "PHP script" : "PHP-skript",
+    "Tar archive" : "Tar-arkiv",
+    "XML document" : "XML-dokument",
+    "YAML document" : "YAML-dokument",
+    "Zip archive" : "Zip-arkiv",
+    "Zstandard archive" : "Zstandard-arkiv",
+    "EMF image" : "EMF-bilde",
+    "GIF image" : "GIF-bilde",
+    "HEIC image" : "HEIC-bilde",
+    "HEIF image" : "HEIF-bilde",
+    "JPEG image" : "JPEG-bilde",
+    "PNG image" : "PNG-bilde",
+    "SVG image" : "SVG-bilde",
+    "TIFF image" : "TIFF-bilde",
+    "WebP image" : "WebP-bilde",
+    "Windows Icon" : "Windows-ikon",
+    "Email message" : "Epostmelding",
+    "CSV document" : "CSV-dokument",
+    "HTML document" : "HTML-dokument",
+    "Markdown document" : "Markdown-dokument",
+    "C++ source code" : "C++-kildekode",
+    "LDIF address book" : "LDIF-adressebok",
+    "NFO document" : "NFO-dokument",
+    "PHP source" : "PHP-kilde",
+    "Python script" : "Python-skript",
+    "ReStructuredText document" : "ReStructuredText-dokument",
+    "MPEG video" : "MPEG-video",
+    "DV video" : "DV-video",
+    "MPEG-4 video" : "MPEG-4-video",
+    "Ogg video" : "Ogg-video",
+    "QuickTime video" : "QuickTime-video",
+    "WebM video" : "WebM-video",
+    "Flash video" : "Flash-video",
+    "Matroska video" : "Mastroka-video",
+    "Windows Media video" : "Windows Media-video",
+    "AVI video" : "AVI-video",
     "The update is in progress, leaving this page might interrupt the process in some environments." : "En oppdatering foregår, lukking av denne siden kan forstyrre prosessen på enkelte systemer.",
     "Update to {version}" : "Oppdater til {version}",
     "An error occurred." : "En feil oppsto.",
@@ -109,7 +148,7 @@ OC.L10N.register(
     "Federated user" : "Forent bruker",
     "user@your-nextcloud.org" : "bruker@din-nextcloud.org",
     "Create share" : "Opprett deling",
-    "Direct link copied to clipboard" : "Direkte lenke kopiert til utklippstavlen",
+    "Direct link copied" : "Direktelenke kopiert",
     "Please copy the link manually:" : "Vennligst kopier lenken manuelt:",
     "Custom date range" : "Egendefinert datoperiode",
     "Pick start date" : "Velg start dato",
@@ -118,14 +157,15 @@ OC.L10N.register(
     "Search in current app" : "Søk i gjeldende app",
     "Clear search" : "Tøm søk",
     "Search everywhere" : "Søk overalt",
-    "Searching …" : "Søker ...",
     "Start typing to search" : "Start å skrive for å søke",
+    "Minimum search length is {minSearchLength} characters" : "Minimum søklengde er {minSearchLength}tegn",
     "No matching results" : "Ingen treff",
     "Today" : "I dag",
     "Last 7 days" : "Siste 7 dager",
     "Last 30 days" : "Siste 30 dager",
     "This year" : "I år",
     "Last year" : "I fjor",
+    "Between {startDate} and {endDate}" : "Mellom {startDate}og {endDate}",
     "Unified search" : "Enhetlig søk",
     "Search apps, files, tags, messages" : "Søk i apper, filer, tagger, meldinger",
     "Places" : "Steder",
@@ -133,11 +173,11 @@ OC.L10N.register(
     "Search people" : "Søk etter personer",
     "People" : "Mennesker",
     "Filter in current view" : "Filter i gjeldende visning",
+    "Search connected services" : "Søk etter tilkoblede tjenester",
     "Results" : "Resultater",
     "Load more results" : "Last flere resultater",
     "Search in" : "Søk i",
     "Log in" : "Logg inn",
-    "Logging in …" : "Logger inn…",
     "Log in to {productName}" : "Logg på {productName}",
     "Wrong login or password." : "Feil pålogging eller passord.",
     "This account is disabled" : "Denne kontoen er deaktivert",
@@ -146,8 +186,7 @@ OC.L10N.register(
     "Account name" : "Kontonavn",
     "Server side authentication failed!" : "Autentisering mislyktes på serveren!",
     "Please contact your administrator." : "Kontakt administratoren din.",
-    "Temporary error" : "Midlertidig feil",
-    "Please try again." : "Vennligst prøv på nytt.",
+    "Session error" : "Sesjonfeil",
     "An internal error occurred." : "En intern feil oppsto",
     "Please try again or contact your administrator." : "Prøv igjen eller kontakt en administrator.",
     "Password" : "Passord",
@@ -174,21 +213,23 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Samarbeidsdokumenter, regneark og presentasjoner, bygget på Collabora Online.",
     "Distraction free note taking app." : "Distraksjonsfri notatapp.",
     "Recommended apps" : "Anbefalte apper",
-    "Loading apps …" : "Laster apper ... ",
     "Could not fetch list of apps from the App Store." : "Kunne ikke hente liste med apper fra appbutikken. ",
     "App download or installation failed" : "Nedlasting eller installasjon av app feilet ",
     "Cannot install this app because it is not compatible" : "Kan ikke installere denne appen fordi den ikke er kompatibel",
     "Cannot install this app" : "Kan ikke installere denne appen",
     "Skip" : "Hopp over",
-    "Installing apps …" : "Installerer apper ... ",
     "Install recommended apps" : "Installer anbefalte apper",
+    "Online" : "Pålogget",
+    "Away" : "Borte",
+    "Busy" : "Opptatt",
+    "Do not disturb" : "Ikke forstyrr",
+    "Mute all notifications" : "Demp alle varslinger",
+    "Invisible" : "Usynlig",
+    "Appear offline" : "Vis som frakoblet",
     "Avatar of {displayName}" : "{displayName} sin Avatar",
     "Settings menu" : "Meny for innstillinger",
-    "Loading your contacts …" : "Laster inn kontaktene dine…",
-    "Looking for {term} …" : "Ser etter {term}…",
     "Search contacts" : "Søk etter kontakter",
     "Reset search" : "Tilbakestill søk",
-    "Search contacts …" : "Søk etter kontakter…",
     "Could not load your contacts" : "Kunne ikke laste inn kontaktene dine",
     "No contacts found" : "Fant ingen kontakter",
     "Show all contacts" : "Vis alle kontakter",
@@ -200,16 +241,32 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Det oppsto en feil ved søk etter {type}",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Søket starter når du begynner å skrive, og resultater kan nås med piltastene",
     "Search for {name} only" : "Søk kun etter {name}",
-    "Loading more results …" : "Laster flere resultater ...",
     "Forgot password?" : "Glemt passord?",
     "Back to login form" : "Tilbake til innloggingsskjema",
     "Back" : "Tilbake",
     "Login form is disabled." : "Innloggingskjemaet er deaktivert.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud-påloggingsskjemaet er deaktivert. Bruk et annet påloggingsalternativ hvis tilgjengelig, eller kontakt administrasjonen din.",
     "More actions" : "Flere handlinger",
+    "User menu" : "Brukermeny",
+    "Your guest name: {user}" : "Ditt gjestenavn: {user}",
+    "You are currently not identified." : "Du er for øyeblikket ikke identifisert.",
+    "Set public name" : "Sett offentlig navn",
+    "Change public name" : "Endre offentlig navn",
+    "Password is too weak" : "Passordet er for svakt",
+    "Password is weak" : "Passordet er svakt",
+    "Password is average" : "Passordet er middels sterkt",
+    "Password is strong" : "Passordet er sterkt",
+    "Password is very strong" : "Passordet er veldig sterkt",
+    "Password is extremely strong" : "Passordet er ekstremt sterkt",
+    "Unknown password strength" : "Ukjent passordstyrke",
+    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Datamappen og filene dine er sannsynligvis tilgjengelig fra Internett fordi <code>.htaccess</code>-filen ikke fungerer.",
+    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "For informasjon om hvordan å konfigurere din server, vennligst {linkStart}se dokumentasjonen{linkEnd}",
     "Security warning" : "Sikkerhetsadvarsel",
+    "Create administration account" : "Opprett administratorkonto",
     "Storage & database" : "Lagring og database",
     "Data folder" : "Datamappe",
+    "Database configuration" : "Databasekonfigurasjon",
+    "Only {firstAndOnlyDatabase} is available." : "Kun {firstAndOnlyDatabase} er tilgjengelig. ",
     "Install and activate additional PHP modules to choose other database types." : "Installer og aktiver flere PHP-moduler for å velge andre databasetyper.",
     "For more details check out the documentation." : "Henvend deg til dokumentasjonen for flere detaljer.",
     "Performance warning" : "Ytelsesadvarsel",
@@ -222,7 +279,6 @@ OC.L10N.register(
     "Database tablespace" : "Database-tabellområde",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Spesifiser portnr. sammen med servernavnet (f.eks., localhost:5432).",
     "Database host" : "Databasevert",
-    "Installing …" : "Installerer ...",
     "Install" : "Installer",
     "Need help?" : "Trenger du hjelp?",
     "See the documentation" : "Se dokumentasjonen",
@@ -231,7 +287,6 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Nettleseren din støttes ikke. Vennligst oppgrader til en nyere versjon eller en støttet versjon.",
     "Continue with this unsupported browser" : "Fortsett med denne nettleseren som ikke støttes",
     "Supported versions" : "Støttede versjoner",
-    "Search {types} …" : "Søk {types} ...",
     "Choose {file}" : "Velg {file}",
     "Choose" : "Velg",
     "Copy to {target}" : "Kopier til {target}",
@@ -251,7 +306,7 @@ OC.L10N.register(
     "(all selected)" : "(alle valgt)",
     "({count} selected)" : "({count} valgt)",
     "Error loading file exists template" : "Feil ved lasting av \"filen eksisterer\"-mal",
-    "Saving …" : "Lagrer...",
+    "Saving …" : "Lagrer ...",
     "seconds ago" : "for få sekunder siden",
     "Connection to server lost" : "Mistet tilkobling til server",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problem ved lasting av side, laster på nytt om %n sekund","Problem ved lasting av side, laster på nytt om %n sekunder"],
@@ -266,26 +321,18 @@ OC.L10N.register(
     "Type to search for existing projects" : "Skriv for å søke etter eksisterende prosjekter",
     "New in" : "Ny i",
     "View changelog" : "Se endringslogg",
-    "No action available" : "Ingen handling tilgjengelig",
-    "Error fetching contact actions" : "Feil ved innhenting av kontakt-handlinger",
     "Close \"{dialogTitle}\" dialog" : "Lukk \"{dialogTitle}\" dialogen",
     "Email length is at max (255)" : "E-postlengden er på maks (255)",
-    "Non-existing tag #{tag}" : "Ikke-eksisterende merkelapp #{tag}",
-    "Restricted" : "Begrenset",
-    "Invisible" : "Usynlig",
-    "Delete" : "Slett",
-    "Rename" : "Gi nytt navn",
-    "Collaborative tags" : "Samarbeidsmerkelapper",
-    "No tags found" : "Ingen emneknagger funnet",
     "Clipboard not available, please copy manually" : "Utklippstavlen ikke tilgjengelig, kopier manuelt",
     "Personal" : "Personlig",
     "Accounts" : "Kontoer",
     "Admin" : "Admin",
     "Help" : "Hjelp",
     "Access forbidden" : "Tilgang nektet",
+    "You are not allowed to access this page." : "Du har ikke tilgang til denne siden.",
+    "Back to %s" : "Tilbake til %s",
     "Page not found" : "Siden ble ikke funnet",
     "The page could not be found on the server or you may not be allowed to view it." : "Siden ble ikke funnet på serveren, eller du har ikke tilgang til den.",
-    "Back to %s" : "Tilbake til %s",
     "Too many requests" : "For mange forespørsler",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Det var for mange forespørsler fra ditt nettverk. Prøv igjen senere eller kontakt din administrator hvis dette er en feil.",
     "Error" : "Feil",
@@ -361,23 +408,40 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Denne %s-instansen er for øyeblikket i vedlikeholdsmodus, noe som kan vare en stund.",
     "This page will refresh itself when the instance is available again." : "Siden vil oppdatere seg selv når instans er tilgjengelig igjen.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontakt systemadministratoren hvis denne meldingen var uventet eller ikke forsvinner.",
-    "Currently open" : "For øyeblikket åpen",
-    "Login with username or email" : "Logg inn med brukernavn eller e-post",
-    "Login with username" : "Logg inn med brukernavn",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatting, videosamtaler, skjermdeling, nettmøter og webkonferanser – i din nettleser og med mobilapper.",
-    "You have not added any info yet" : "Du har ikke lagt inn noe informasjon ennå",
-    "{user} has not added any info yet" : "{user} har ikke lagt inn noe informasjon ennå",
-    "Error opening the user status modal, try hard refreshing the page" : "Feil ved åpning av bruker-status modal, prøv å laste inn siden på nytt med hard refresh",
-    "Edit Profile" : "Endre profil",
-    "The headline and about sections will show up here" : "Overskriften og om-seksjoner vil vises her",
-    "Error loading message template: {error}" : "Feil ved lasting av meldingsmal: {error}",
+    "Error occurred while checking server setup" : "Feil oppsto ved sjekking av server-oppsett",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "For mer informasjon se {linkstart}dokumentasjonen ↗{linkend}.",
+    "unknown text" : "ukjent tekst",
+    "Hello world!" : "Hei, verden!",
+    "sunny" : "solfylt",
+    "Hello {name}, the weather is {weather}" : "Hallo {name}, været er {weather}",
+    "Hello {name}" : "Hallo {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Dette er dine søketreff<script>alert(1)</script></strong>",
+    "new" : "ny",
+    "_download %n file_::_download %n files_" : ["last ned %n fil","last ned %n filer"],
+    "Direct link copied to clipboard" : "Direkte lenke kopiert til utklippstavlen",
+    "Searching …" : "Søker ...",
+    "Logging in …" : "Logger inn…",
+    "Loading apps …" : "Laster apper ... ",
+    "Installing apps …" : "Installerer apper ... ",
+    "Loading your contacts …" : "Laster inn kontaktene dine…",
+    "Looking for {term} …" : "Ser etter {term}…",
+    "Search contacts …" : "Søk etter kontakter…",
+    "Loading more results …" : "Laster flere resultater ...",
+    "Search {types} …" : "Søk {types} ...",
+    "Saving …" : "Lagrer...",
     "Very weak password" : "Veldig svakt passord",
     "Weak password" : "Svakt passord",
     "So-so password" : "Bob-bob-passord",
     "Good password" : "Bra passord",
     "Strong password" : "Sterkt passord",
-    "Profile not found" : "Finner ikke profil",
-    "The profile does not exist." : "Profilen finnes ikke",
+    "No action available" : "Ingen handling tilgjengelig",
+    "Error fetching contact actions" : "Feil ved innhenting av kontakt-handlinger",
+    "Non-existing tag #{tag}" : "Ikke-eksisterende merkelapp #{tag}",
+    "Restricted" : "Begrenset",
+    "Delete" : "Slett",
+    "Rename" : "Gi nytt navn",
+    "Collaborative tags" : "Samarbeidsmerkelapper",
+    "No tags found" : "Ingen emneknagger funnet",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Datamappen og filene dine er sannsynligvis tilgjengelig fra Internett fordi .htaccess-filen ikke fungerer.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "For informasjon om hvordan du skal konfigurere serveren skikkelig, les <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentasjonen</a>.",
     "<strong>Create an admin account</strong>" : "<strong>Opprett en administratorkonto</strong>",
@@ -387,6 +451,7 @@ OC.L10N.register(
     "Toggle password visibility" : "Vis passord av/på",
     "Configure the database" : "Sett opp databasen",
     "Only %s is available." : "Kun %s er tilgjengelig.",
-    "Database account" : "Databasekonto"
+    "Database account" : "Databasekonto",
+    "Installing …" : "Installerer ..."
 },
 "nplurals=2; plural=(n != 1);");
