@@ -18,10 +18,6 @@ OC.L10N.register(
     "Unknown filetype" : "Tipe de fichièr desconegut",
     "An error occurred. Please contact your admin." : "Una error s’es producha. Volgatz ben contactar l’admin.",
     "Invalid image" : "Imatge desconegut",
-    "No temporary profile picture available, try again" : "Cap d’imatge de perfil temporari pas disponible, tornatz ensajar",
-    "No crop data provided" : "Cap de donada de produccion",
-    "No valid crop data provided" : "Cap de donada pas valida pas provesida",
-    "Crop is not square" : "Lo retalhatge es pas carrat",
     "State token does not match" : "Lo geton d’estat correspond pas",
     "Invalid app password" : "Senhal d’aplicacion invalid",
     "Could not complete login" : "Autocomplecion impossibla de l’identificant",
@@ -35,16 +31,16 @@ OC.L10N.register(
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Clicat sul boton seguent per reïnicializar vòstre senhal. S’avètz pas demandat sa reïnicializacion, ignoratz aqueste corrièl.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Clicat sul ligam seguent per reïnicializar vòstre senhal. S’avètz pas demandat sa reïnicializacion, ignoratz aqueste corrièl.",
     "Reset your password" : "Reïnicializatz vòstre senhal",
-    "Nextcloud Server" : "Servidor Nextcloud",
-    "Some of your link shares have been removed" : "D’unes de vòstres ligams de partiment foguèron tirats",
-    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "A causa d’una avaria de seguretat nos calguèt tirar certans de vòstres ligams de partiment. Vejatz lo ligam per mai d’informacions.",
-    "Learn more ↗" : "Ne saber mai ↗",
-    "Preparing update" : "Preparacion de la mesa a jorn",
     "[%d / %d]: %s" : "[%d / %d] : %s",
     "Repair step:" : "Etapa de reparacion :",
     "Repair info:" : "Info de reparacion :",
     "Repair warning:" : "Avertiment de reparacion :",
     "Repair error:" : "Error de reparacion :",
+    "Nextcloud Server" : "Servidor Nextcloud",
+    "Some of your link shares have been removed" : "D’unes de vòstres ligams de partiment foguèron tirats",
+    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "A causa d’una avaria de seguretat nos calguèt tirar certans de vòstres ligams de partiment. Vejatz lo ligam per mai d’informacions.",
+    "Learn more ↗" : "Ne saber mai ↗",
+    "Preparing update" : "Preparacion de la mesa a jorn",
     "Turned on maintenance mode" : "Mòde manteniment aviat",
     "Turned off maintenance mode" : "Mòde manteniment atudat",
     "Maintenance mode is kept active" : "Lo mòde manteniment ten d’èsser actiu",
@@ -59,15 +55,7 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (incompatible)",
     "The following apps have been disabled: %s" : "Las aplicacions seguentas son estadas desactivadas : %s",
     "Already up to date" : "Ja a jorn",
-    "Error occurred while checking server setup" : "Error producha pendent la verificacion de l’installacion del servidor",
-    "unknown text" : "tèxt desconegut",
-    "Hello world!" : "Adieu monde !",
-    "sunny" : "ensolelhat",
-    "Hello {name}, the weather is {weather}" : "Adiu {name}, lo temps es {weather}",
-    "Hello {name}" : "Adiu {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Vaquí vòstres resultats de recèrca<script>alert(1)</script></strong>",
-    "new" : "nòu",
-    "_download %n file_::_download %n files_" : ["telecargar %n fichièr","telecargar %n fichièrs"],
+    "Unknown" : "Desconegut",
     "The update is in progress, leaving this page might interrupt the process in some environments." : "La mesa a jorn es en cors, quitar aquesta pagina poiriá interrompre lo processús dins d’unes environaments.",
     "Update to {version}" : "Metre a jorn a {version}",
     "An error occurred." : "Una error s’es producha.",
@@ -80,14 +68,12 @@ OC.L10N.register(
     "_{count} notification_::_{count} notifications_" : ["{count} notificacion","{count} notificacions"],
     "No" : "No",
     "Yes" : "Yes",
-    "Searching …" : "Recèrca…",
     "Start typing to search" : "Començatz de picar per recercar",
     "Today" : "Uèi",
     "Date" : "Data",
     "People" : "Gent",
     "Load more results" : "Cargar mai de resultats",
     "Log in" : "Connexion",
-    "Logging in …" : "Identificacion…",
     "Log in to {productName}" : "Se connectar a {productName}",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Avèm detectat mantun ensag invalid de connexion a partir de vòstra IP. Per consequent vòstra connexion venenta serà en pausa per 30 segondas.",
     "Account name or email" : "Nom d’utilizaire o email",
@@ -98,14 +84,14 @@ OC.L10N.register(
     "Password" : "Senhal",
     "Log in with a device" : "Connexion amb un periferic",
     "Your account is not setup for passwordless login." : "Vòstre compte es pas parametrat per una autentificacion sens senhal.",
-    "Browser not supported" : "Navegador pas pres en carga",
-    "Passwordless authentication is not supported in your browser." : "L’autentificacion sens senhal es pas presa en cargar per vòstre navegador.",
     "Your connection is not secure" : "Vòstra connexion es pas segura",
     "Passwordless authentication is only available over a secure connection." : "L’autentificacion sens senhal es sonque disponibla via una connexion segura.",
+    "Browser not supported" : "Navegador pas pres en carga",
+    "Passwordless authentication is not supported in your browser." : "L’autentificacion sens senhal es pas presa en cargar per vòstre navegador.",
     "Reset password" : "Reïnicializar senhal",
+    "Back to login" : "Tornar a la connexion",
     "Couldn't send reset email. Please contact your administrator." : "Impossible de mandar lo corrièl de reïnicializacion. Contactatz vòstre administrator.",
     "Password cannot be changed. Please contact your administrator." : "Se pòt pas cambiar lo senhal. Mercés de contactar vòstre administrator.",
-    "Back to login" : "Tornar a la connexion",
     "New password" : "Senhal novèl",
     "I know what I'm doing" : "Sabi çò que fau",
     "Resetting password" : "Reïnicializacion de senhal",
@@ -113,19 +99,21 @@ OC.L10N.register(
     "Keep your colleagues and friends in one place without leaking their private info." : "Gardatz vòstres companhs e amics a un sòl lòc sens divulgar lor vida privada.",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "Aplicacion simpla e simpatica de corrièl integrada a Fichièrs, Contactes e Calendièr.",
     "Recommended apps" : "Aplicacions recomandadas",
-    "Loading apps …" : "Cargament aplicacions…",
     "App download or installation failed" : "Telecargament o installacion de l’aplicacion fracassada",
     "Cannot install this app because it is not compatible" : "Impossibla d’installar aquesta app perque es pas compatibla",
     "Cannot install this app" : "Impossible d’installar aquesta app",
     "Skip" : "Sautar",
-    "Installing apps …" : "Installacion aplicacions…",
     "Install recommended apps" : "Installar las aplicacions recomandadas",
+    "Online" : "En linha",
+    "Away" : "Absent",
+    "Busy" : "Ocupat",
+    "Do not disturb" : "Me desturbes pas",
+    "Mute all notifications" : "Amudir totas las notificacions",
+    "Invisible" : "Invisible",
+    "Appear offline" : "Aparéisser fòra linha",
     "Settings menu" : "Menú paramètres",
-    "Loading your contacts …" : "Cargaments dels contactes…",
-    "Looking for {term} …" : "Recèrca de {term}…",
     "Search contacts" : "Cercar pels contactes",
     "Reset search" : "Escafar la recèrca",
-    "Search contacts …" : "Cercar pels contactes…",
     "Could not load your contacts" : "Cargament impossible de vòstres contactes",
     "No contacts found" : "Cap de contact pas trobat",
     "Install the Contacts app" : "Installar l’aplicacion Contactes",
@@ -133,15 +121,31 @@ OC.L10N.register(
     "No results for {query}" : "Cap de resultat per {query}",
     "An error occurred while searching for {type}" : "Una error s’es producha en cercant {type}",
     "Search for {name} only" : "Cercar sonque {name}",
-    "Loading more results …" : "Cargament de mai de resultats…",
     "Forgot password?" : "Senhal oblidat ?",
     "Back" : "Retorn",
     "Login form is disabled." : "Lo formulari de connexion es desactivat.",
     "More actions" : "Mai d’accions",
+    "Security warning" : "Avertiment de seguretat",
+    "Storage & database" : "Emmagazinatge & basa de donada",
+    "Data folder" : "Dossièr de donadas",
+    "Install and activate additional PHP modules to choose other database types." : "Installatz e activatz los modules PHP complementaris per causir d’autres tipes de basas de donadas.",
+    "For more details check out the documentation." : "Per mai de detalhs consultatz la documentacion.",
+    "Performance warning" : "Avertiment de performança",
+    "You chose SQLite as database." : "Causissètz SQLite coma basa de donadas.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite deu solament èsser utilizat per d’instàncias minimalas e de desvolopament. Per la produccion recomandam un autre sistèma de basa de donadas.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "S’utilizatz los clients per sincronizar de fichièrs, l’utilizacion de SQLite es forçadament descoratjada.",
+    "Database user" : "Utilizaire basa de donadas",
+    "Database password" : "Senhal basa de donadas",
+    "Database name" : "Nom basa de donadas",
+    "Database tablespace" : "Tablespace basa de donadas",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Volgatz especificar lo numèro de pòrt aprèp lo nom d’òste (ex : localhost:5432).",
+    "Database host" : "Òste basa de donadas",
+    "Install" : "Installar",
+    "Need help?" : "Besonh d’ajuda ?",
+    "See the documentation" : "Vejatz la documentacion",
     "{name} version {version} and above" : "{name} version {version} e ulterior",
     "This browser is not supported" : "Aqueste navigador es pas pres en carga",
     "Supported versions" : "Versions presas en carga",
-    "Search {types} …" : "Recèrca {types}…",
     "Choose" : "Causir",
     "Copy" : "Copiar",
     "Move" : "Move",
@@ -157,7 +161,6 @@ OC.L10N.register(
     "Continue" : "Contunhar",
     "(all selected)" : "(totes seleccionats)",
     "({count} selected)" : "({count} seleccionats)",
-    "Saving …" : "Enregistrament…",
     "seconds ago" : "fa qualques segondas",
     "Connection to server lost" : "Connexion al servidor perduda",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problèma de cargar de la pagina, actualizacion d’aquí %n seconda","Problèma de cargar de la pagina, actualizacion d’aquí %n secondas"],
@@ -171,26 +174,13 @@ OC.L10N.register(
     "Connect items to a project to make them easier to find" : "Connectatz d’elements a un projècte per lo rendre mai simples de trobar",
     "New in" : "Nòu dins",
     "View changelog" : "Veire jornal de modificacions",
-    "Very weak password" : "Senhal plan feble",
-    "Weak password" : "Senhal feble",
-    "So-so password" : "Senhal mejan",
-    "Good password" : "Bon senhal",
-    "Strong password" : "Senhal fòrt",
-    "No action available" : "Cap d’accion pas disponibla",
-    "Error fetching contact actions" : "Error en recuperacion las accions contacte",
-    "Non-existing tag #{tag}" : "Etiqueta inexistenta #{tag}",
-    "Restricted" : "Restrencha",
-    "Invisible" : "Invisible",
-    "Delete" : "Suprimir",
-    "Rename" : "Renomenar",
-    "Collaborative tags" : "Etiquetas collaborativas",
-    "No tags found" : "Cap d’etiqueta pas trobada",
     "Personal" : "Personal",
+    "Accounts" : "Accounts",
     "Admin" : "Admin",
     "Help" : "Ajuda",
     "Access forbidden" : "Accès defendut",
-    "Page not found" : "Pagina pas trobada",
     "Back to %s" : "Tornar a %s",
+    "Page not found" : "Pagina pas trobada",
     "Too many requests" : "Tròp de requèstas",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "I a agut tròp de requèstas a partir de vòstre ret. Tornatz ensajar mai tard o contactatz vòstre administrator s’aquò es una error.",
     "Error" : "Error",
@@ -207,30 +197,6 @@ OC.L10N.register(
     "File: %s" : "Fichièr : %s",
     "Line: %s" : "Linha : %s",
     "Trace" : "Traça",
-    "Security warning" : "Avertiment de seguretat",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Vòstre repertòri de donadas e vòstres fichièrs son probablament accessibles a partir d’internet pr’amor que lo fichièr .htaccess fonciona pas.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Per d’informacions per corrèctament configurar vòstre servidor, consultatz la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentacion</a>.",
-    "Show password" : "Mostrar lo senhal",
-    "Toggle password visibility" : "Alternar la visibilitat del senhal",
-    "Storage & database" : "Emmagazinatge & basa de donada",
-    "Data folder" : "Dossièr de donadas",
-    "Configure the database" : "Configurar la basa de donadas",
-    "Only %s is available." : "Sonque %s es disponible.",
-    "Install and activate additional PHP modules to choose other database types." : "Installatz e activatz los modules PHP complementaris per causir d’autres tipes de basas de donadas.",
-    "For more details check out the documentation." : "Per mai de detalhs consultatz la documentacion.",
-    "Database password" : "Senhal basa de donadas",
-    "Database name" : "Nom basa de donadas",
-    "Database tablespace" : "Tablespace basa de donadas",
-    "Database host" : "Òste basa de donadas",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Volgatz especificar lo numèro de pòrt aprèp lo nom d’òste (ex : localhost:5432).",
-    "Performance warning" : "Avertiment de performança",
-    "You chose SQLite as database." : "Causissètz SQLite coma basa de donadas.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite deu solament èsser utilizat per d’instàncias minimalas e de desvolopament. Per la produccion recomandam un autre sistèma de basa de donadas.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "S’utilizatz los clients per sincronizar de fichièrs, l’utilizacion de SQLite es forçadament descoratjada.",
-    "Install" : "Installar",
-    "Installing …" : "Installacion...",
-    "Need help?" : "Besonh d’ajuda ?",
-    "See the documentation" : "Vejatz la documentacion",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Sembla que sètz a reïnstallar vòstre Nextcloud. Pasmens lo fichièr CAN_INSTALL es absent del repertòri config. Volgatz ben crear lo fichièr CAN_INSTALL dins vòstre dossièr config per contunhar.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Supression impossibla de CAN_INSTALL dins lo repertòri config. Mercés de lo tirar manualament.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Aquesta aplicacion requerís JavaScript per foncionar coma cal. {linkstart}Activatz JavaScript{linkend} e recargatz la pagina.",
@@ -282,12 +248,44 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "L’instància %s es actualament en mòde manteniment, pòt trigar.",
     "This page will refresh itself when the instance is available again." : "Aquesta pagina s’actualizarà soleta quand l’instància serà disponibla de nòu.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contactatz l’administrator sistèma s’aqueste messatge ten d’aparéisser o apareis sens rason.",
-    "Currently open" : "Actualament dobèrta",
-    "Login with username or email" : "Connexion amb nom d’utilizaire o email",
-    "Login with username" : "Connexion amb nom d’utilizaire",
-    "Edit Profile" : "Modificar perfil",
-    "Error loading message template: {error}" : "Error de cargament del modèl de messatge : {error}",
-    "Profile not found" : "Perfil pas trobat",
-    "The profile does not exist." : "Lo perfil existís pas."
+    "Error occurred while checking server setup" : "Error producha pendent la verificacion de l’installacion del servidor",
+    "unknown text" : "tèxt desconegut",
+    "Hello world!" : "Adieu monde !",
+    "sunny" : "ensolelhat",
+    "Hello {name}, the weather is {weather}" : "Adiu {name}, lo temps es {weather}",
+    "Hello {name}" : "Adiu {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Vaquí vòstres resultats de recèrca<script>alert(1)</script></strong>",
+    "new" : "nòu",
+    "_download %n file_::_download %n files_" : ["telecargar %n fichièr","telecargar %n fichièrs"],
+    "Searching …" : "Recèrca…",
+    "Logging in …" : "Identificacion…",
+    "Loading apps …" : "Cargament aplicacions…",
+    "Installing apps …" : "Installacion aplicacions…",
+    "Loading your contacts …" : "Cargaments dels contactes…",
+    "Looking for {term} …" : "Recèrca de {term}…",
+    "Search contacts …" : "Cercar pels contactes…",
+    "Loading more results …" : "Cargament de mai de resultats…",
+    "Search {types} …" : "Recèrca {types}…",
+    "Saving …" : "Enregistrament…",
+    "Very weak password" : "Senhal plan feble",
+    "Weak password" : "Senhal feble",
+    "So-so password" : "Senhal mejan",
+    "Good password" : "Bon senhal",
+    "Strong password" : "Senhal fòrt",
+    "No action available" : "Cap d’accion pas disponibla",
+    "Error fetching contact actions" : "Error en recuperacion las accions contacte",
+    "Non-existing tag #{tag}" : "Etiqueta inexistenta #{tag}",
+    "Restricted" : "Restrencha",
+    "Delete" : "Suprimir",
+    "Rename" : "Renomenar",
+    "Collaborative tags" : "Etiquetas collaborativas",
+    "No tags found" : "Cap d’etiqueta pas trobada",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Vòstre repertòri de donadas e vòstres fichièrs son probablament accessibles a partir d’internet pr’amor que lo fichièr .htaccess fonciona pas.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Per d’informacions per corrèctament configurar vòstre servidor, consultatz la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentacion</a>.",
+    "Show password" : "Mostrar lo senhal",
+    "Toggle password visibility" : "Alternar la visibilitat del senhal",
+    "Configure the database" : "Configurar la basa de donadas",
+    "Only %s is available." : "Sonque %s es disponible.",
+    "Installing …" : "Installacion..."
 },
 "nplurals=2; plural=(n > 1);");
