@@ -18,15 +18,12 @@ OC.L10N.register(
     "Unknown filetype" : "Nieznany typ pliku",
     "An error occurred. Please contact your admin." : "Wystąpił błąd. Skontaktuj się z administratorem.",
     "Invalid image" : "Nieprawidłowy obraz",
-    "No temporary profile picture available, try again" : "Brak tymczasowego zdjęcia profilowego, spróbuj ponownie",
-    "No crop data provided" : "Brak danych do przycięcia",
-    "No valid crop data provided" : "Brak prawidłowych danych do przycięcia",
-    "Crop is not square" : "Przycięcie nie jest kwadratowe",
     "State token does not match" : "Token nie pasuje",
     "Invalid app password" : "Nieprawidłowe hasło do aplikacji",
     "Could not complete login" : "Nie można dokończyć logowania",
     "State token missing" : "Brak statusu tokena",
     "Your login token is invalid or has expired" : "Token logowania jest nieprawidłowy lub wygasł",
+    "Please use original client" : "Użyj oryginalnego klienta",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "To wydanie społecznościowe Nextcloud nie jest obsługiwane, a powiadomienia Push są ograniczone.",
     "Login" : "Zaloguj",
     "Unsupported email length (>255)" : "Nieobsługiwana długość wiadomości e-mail (>255)",
@@ -43,6 +40,7 @@ OC.L10N.register(
     "Task not found" : "Nie znaleziono zadania",
     "Internal error" : "Błąd wewnętrzny",
     "Not found" : "Nie znaleziono",
+    "Node is locked" : "Węzeł jest zablokowany",
     "Bad request" : "Złe żądanie",
     "Requested task type does not exist" : "Żądany typ zadania nie istnieje",
     "Necessary language model provider is not available" : "Niezbędny dostawca modelu językowego nie jest dostępny",
@@ -51,6 +49,12 @@ OC.L10N.register(
     "No translation provider available" : "Brak dostępnego dostawcy tłumaczenia",
     "Could not detect language" : "Nie można wykryć języka",
     "Unable to translate" : "Nie można przetłumaczyć",
+    "No valid filters provided" : "Nie podano prawidłowych filtrów",
+    "[%d / %d]: %s" : "[%d/%d]: %s",
+    "Repair step:" : "Krok naprawy:",
+    "Repair info:" : "Informacja o naprawie: ",
+    "Repair warning:" : "Ostrzeżenie naprawy:",
+    "Repair error:" : "Błąd naprawy: ",
     "Nextcloud Server" : "Serwer Nextcloud",
     "Some of your link shares have been removed" : "Niektóre udostępnienia linków zostały usunięte",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Ze względu na błąd bezpieczeństwa musieliśmy usunąć część Twoich udostępnień linków. Zobacz link, aby uzyskać więcej informacji.",
@@ -58,11 +62,6 @@ OC.L10N.register(
     "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Wprowadź klucz subskrypcji w aplikacji pomocy technicznej, aby zwiększyć limit kont. Zapewnia to również wszystkie dodatkowe korzyści oferowane przez Nextcloud dla firm i jest wysoce zalecane dla działania w firmach.",
     "Learn more ↗" : "Dowiedz się więcej ↗",
     "Preparing update" : "Przygotowywanie aktualizacji",
-    "[%d / %d]: %s" : "[%d/%d]: %s",
-    "Repair step:" : "Krok naprawy:",
-    "Repair info:" : "Informacja o naprawie: ",
-    "Repair warning:" : "Ostrzeżenie naprawy:",
-    "Repair error:" : "Błąd naprawy: ",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "Użyj wiersza poleceń do aktualizacji, ponieważ aktualizacja przez przeglądarkę jest wyłączona w Twoim pliku config.php.",
     "Turned on maintenance mode" : "Włączono tryb konserwacji",
     "Turned off maintenance mode" : "Wyłączono tryb konserwacji",
@@ -79,16 +78,125 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (niekompatybilny)",
     "The following apps have been disabled: %s" : "Następujące aplikacje zostały wyłączone: %s",
     "Already up to date" : "Już zaktualizowano",
-    "Error occurred while checking server setup" : "Wystąpił błąd podczas sprawdzania konfiguracji serwera",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "Więcej informacji można znaleźć w {linkstart}dokumentacji ↗{linkend}.",
-    "unknown text" : "nieznany tekst",
-    "Hello world!" : "Witaj świecie!",
-    "sunny" : "słoneczna",
-    "Hello {name}, the weather is {weather}" : "Cześć {name}, dzisiejsza pogoda jest {weather}",
-    "Hello {name}" : "Witaj {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>To są twoje wyniki wyszukiwania<script>alert(1)</script></strong>",
-    "new" : "nowy",
-    "_download %n file_::_download %n files_" : ["pobrano %n plik","pobrano %n pliki","pobrano %n plików","pobrano %n plików"],
+    "Windows Command Script" : "Skrypt poleceń Windows",
+    "Electronic book document" : "Dokument książki elektronicznej",
+    "TrueType Font Collection" : "Kolekcja czcionek TrueType",
+    "Web Open Font Format" : "Format czcionki Web Open (WOFF)",
+    "GPX geographic data" : "Dane geograficzne GPX",
+    "Gzip archive" : "Archiwum Gzip",
+    "Adobe Illustrator document" : "Dokument Adobe Illustrator",
+    "Java source code" : "Kod źródłowy Java",
+    "JavaScript source code" : "Kod źródłowy JavaScript",
+    "JSON document" : "Dokument JOSN",
+    "Microsoft Access database" : "Baza danych Microsoft Access",
+    "Microsoft OneNote document" : "Dokument Microsoft OneNote",
+    "Microsoft Word document" : "Dokument Microsoft Word",
+    "Unknown" : "Nieznany",
+    "PDF document" : "Dokument PDF",
+    "PostScript document" : "Dokument PostScript",
+    "RSS summary" : "Podsumowanie RSS",
+    "Android package" : "Pakiet Android (APK)",
+    "KML geographic data" : "Dane geograficzne KML",
+    "KML geographic compressed data" : "Skompresowane dane geograficzne KML",
+    "Lotus Word Pro document" : "Dokument Lotus Word Pro",
+    "Excel spreadsheet" : "Arkusz kalkulacyjny Excel",
+    "Excel add-in" : "Wtyczka Excel",
+    "Excel 2007 binary spreadsheet" : "Binarny arkusz kalkulacyjny Excel 2007",
+    "Excel spreadsheet template" : "Szablon arkusza kalkulacyjnego Excel",
+    "Outlook Message" : "Wiadomość Outlook",
+    "PowerPoint presentation" : "Prezentacja PowerPoint",
+    "PowerPoint add-in" : "Wtyczka PowerPoint",
+    "PowerPoint presentation template" : "Szablon prezentacji PowerPoint",
+    "Word document" : "Dokument Word",
+    "ODF formula" : "Formuła ODF",
+    "ODG drawing" : "Rysunek ODG",
+    "ODG drawing (Flat XML)" : "Rysunek ODG (płaski XML)",
+    "ODG template" : "Szablon ODG",
+    "ODP presentation" : "Prezentacja ODP",
+    "ODP presentation (Flat XML)" : "Prezentacja ODP (płaski XML)",
+    "ODP template" : "Szablon ODT",
+    "ODS spreadsheet" : "Arkusz kalkulacyjny ODS",
+    "ODS spreadsheet (Flat XML)" : "Arkusz kalkulacyjny ODS (płaski XML)",
+    "ODS template" : "Szablon ODS",
+    "ODT document" : "Dokument ODT",
+    "ODT document (Flat XML)" : "Dokument ODT (płaski XML)",
+    "ODT template" : "Szablon ODT",
+    "PowerPoint 2007 presentation" : "Prezentacja PowerPoint 2007",
+    "PowerPoint 2007 show" : "Pokaz PowerPoint 2007",
+    "PowerPoint 2007 presentation template" : "Szablon prezentacji PowerPoint 2007",
+    "Excel 2007 spreadsheet" : "Arkusz kalkulacyjny Excel 2007",
+    "Excel 2007 spreadsheet template" : "Szablon arkusza kalkulacyjnego Excel 2007",
+    "Word 2007 document" : "Dokument Word 2007",
+    "Word 2007 document template" : "Szablon dokumentu Word 2007",
+    "Microsoft Visio document" : "Dokument Microsoft Visio",
+    "WordPerfect document" : "Dokument WordPerfect ",
+    "7-zip archive" : "Archiwum 7-zip",
+    "Blender scene" : "Scena Blender",
+    "Bzip2 archive" : "Archiwum Bzip2",
+    "Debian package" : "Pakiet Debian (DEB)",
+    "FictionBook document" : "Dokument FictionBook",
+    "Unknown font" : "Nieznana czcionka",
+    "Krita document" : "Dokument Krita",
+    "Mobipocket e-book" : "E-book Mobipocket ",
+    "Windows Installer package" : "Pakiet instalacyjny Windows (MSI)",
+    "Perl script" : "Skrypt Perl",
+    "PHP script" : "Skrypt PHP",
+    "Tar archive" : "Archiwum Tar",
+    "XML document" : "Dokument XML",
+    "YAML document" : "Dokument YAML",
+    "Zip archive" : "Archiwum ZIP",
+    "Zstandard archive" : "Archiwum Zstandard",
+    "AAC audio" : "Dźwięk AAC",
+    "FLAC audio" : "Dźwięk FLAC",
+    "MPEG-4 audio" : "Dźwięk MPEG-4",
+    "MP3 audio" : "Dźwięk MP3",
+    "Ogg audio" : "Dźwięk Ogg",
+    "RIFF/WAVe standard Audio" : "Dźwięk w standardzie RIFF/WAVe",
+    "WebM audio" : "Dźwięk WebM",
+    "MP3 ShoutCast playlist" : "Playlista MP3 ShoutCast",
+    "Windows BMP image" : "Obraz Windows BMP",
+    "Better Portable Graphics image" : "Obraz Better Portable Graphics (BPG)",
+    "EMF image" : "Obraz EMF",
+    "GIF image" : "Obraz GIF",
+    "HEIC image" : "Obraz HEIC ",
+    "HEIF image" : "Obraz HEIF ",
+    "JPEG-2000 JP2 image" : "Obraz JPEG-2000 JP2",
+    "JPEG image" : "Obraz JPEG",
+    "PNG image" : "obraz PNG",
+    "SVG image" : "Obraz SVG",
+    "Truevision Targa image" : "Obraz Truevision Targa (TGA)",
+    "TIFF image" : "Obraz TIFF",
+    "WebP image" : "Obraz WebP",
+    "Digital raw image" : "Cyfrowy obraz w formacie RAW",
+    "Windows Icon" : "Ikona Windows",
+    "Email message" : "Wiadomość email",
+    "VCS/ICS calendar" : "Kalendarz VCS/ICS",
+    "CSS stylesheet" : "Arkusz stylów CSS",
+    "CSV document" : "Dokument CSV",
+    "HTML document" : "Dokument HTML",
+    "Markdown document" : "Dokument Markdown",
+    "Org-mode file" : "Plik w formacie Org-mode",
+    "Plain text document" : "Dokument tekstowy (zwykły tekst)",
+    "Rich Text document" : "Dokument Rich Text (RTF)",
+    "Electronic business card" : "Elektroniczna wizytówka",
+    "C++ source code" : "Kod źródłowy C++",
+    "LDIF address book" : "Książka adresowa LDIF",
+    "NFO document" : "Dokument NFO",
+    "PHP source" : "Źródło PHP",
+    "Python script" : "Skrypt Python",
+    "ReStructuredText document" : "Dokument ReStructuredText",
+    "3GPP multimedia file" : "Plik multimedialny 3GPP",
+    "MPEG video" : "Wideo MPEG",
+    "DV video" : "Wideo DV",
+    "MPEG-2 transport stream" : "Strumień transportowy MPEG-2",
+    "MPEG-4 video" : "Wideo MPEG-4",
+    "Ogg video" : "Wideo Ogg",
+    "QuickTime video" : "Wideo QuickTime",
+    "WebM video" : "Wideo WebM",
+    "Flash video" : "Wideo Flash",
+    "Matroska video" : "Wideo Matroska",
+    "Windows Media video" : "Wideo Windows Media",
+    "AVI video" : "Wideo AVI",
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Trwa aktualizacja. W niektórych przypadkach, opuszczenie tej strony może przerwać ten proces.",
     "Update to {version}" : "Aktualizacja do {version}",
     "An error occurred." : "Wystąpił błąd.",
@@ -109,7 +217,7 @@ OC.L10N.register(
     "Federated user" : "Użytkownik sfederowany",
     "user@your-nextcloud.org" : "uzytkownik@twoj-nextcloud.pl",
     "Create share" : "Utwórz udostępnienie",
-    "Direct link copied to clipboard" : "Bezpośredni odnośnik skopiowany do schowka",
+    "Direct link copied" : "Bezpośredni link skopiowany",
     "Please copy the link manually:" : "Skopiuj odnośnik ręcznie:",
     "Custom date range" : "Własny zakres dat",
     "Pick start date" : "Wybierz datę rozpoczęcia",
@@ -118,14 +226,16 @@ OC.L10N.register(
     "Search in current app" : "Wyszukaj w bieżącej aplikacji",
     "Clear search" : "Wyczyść wyszukiwanie",
     "Search everywhere" : "Szukaj wszędzie",
-    "Searching …" : "Wyszukiwanie…",
+    "Searching …" : "Wyszukiwanie …",
     "Start typing to search" : "Zacznij pisać, aby wyszukać",
+    "Minimum search length is {minSearchLength} characters" : "Minimalna długość wyszukiwania to {minSearchLength} znaków",
     "No matching results" : "Brak pasujących wyników",
     "Today" : "Dzisiaj",
     "Last 7 days" : "Ostatnie 7 dni",
     "Last 30 days" : "Ostatnie 30 dni",
     "This year" : "W tym roku",
     "Last year" : "W zeszłym roku",
+    "Between {startDate} and {endDate}" : "Pomiędzy {startDate} a {endDate}",
     "Unified search" : "Ujednolicone wyszukiwanie",
     "Search apps, files, tags, messages" : "Szukaj aplikacji, plików, tagów, wiadomości",
     "Places" : "Miejsca",
@@ -133,11 +243,12 @@ OC.L10N.register(
     "Search people" : "Szukaj ludzi",
     "People" : "Osoby",
     "Filter in current view" : "Filtruj w bieżącym widoku",
+    "Search connected services" : "Szukaj połączonych usług",
     "Results" : "Wyniki",
     "Load more results" : "Wczytaj więcej wyników",
     "Search in" : "Szukaj w",
     "Log in" : "Zaloguj",
-    "Logging in …" : "Logowanie…",
+    "Logging in …" : "Logowanie ...",
     "Log in to {productName}" : "Zaloguj się do {productName}",
     "Wrong login or password." : "Błędny login lub hasło.",
     "This account is disabled" : "To konto jest wyłączone",
@@ -146,9 +257,12 @@ OC.L10N.register(
     "Account name" : "Nazwa konta",
     "Server side authentication failed!" : "Uwierzytelnianie po stronie serwera nie powiodło się!",
     "Please contact your administrator." : "Skontaktuj się z administratorem",
+    "Session error" : "Błąd sesji",
+    "It appears your session token has expired, please refresh the page and try again." : "Wygląda na to, że Twój token sesji wygasł. Odśwież stronę i spróbuj ponownie.",
     "An internal error occurred." : "Wystąpił błąd wewnętrzny.",
     "Please try again or contact your administrator." : "Spróbuj ponownie lub skontaktuj się z administratorem.",
     "Password" : "Hasło",
+    "Remember me" : "Zapamiętaj mnie",
     "Log in with a device" : "Zaloguj się za pomocą urządzenia",
     "Login or email" : "Nazwa logowania lub e-mail",
     "Your account is not setup for passwordless login." : "Twoje konto nie jest skonfigurowane do logowania bez hasła.",
@@ -172,21 +286,28 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Wspólne dokumenty, arkusze kalkulacyjne i prezentacje oparte na Collabora Online.",
     "Distraction free note taking app." : "Aplikacja do robienia notatek bez rozpraszania uwagi.",
     "Recommended apps" : "Polecane aplikacje",
-    "Loading apps …" : "Wczytywanie aplikacji…",
+    "Loading apps …" : "Wczytywanie aplikacji …",
     "Could not fetch list of apps from the App Store." : "Nie można pobrać listy aplikacji ze sklepu z aplikacjami.",
     "App download or installation failed" : "Pobieranie lub instalacja aplikacji nie powiodła się",
     "Cannot install this app because it is not compatible" : "Nie można zainstalować tej aplikacji, ponieważ nie jest kompatybilna",
     "Cannot install this app" : "Nie można zainstalować tej aplikacji",
     "Skip" : "Pomiń",
-    "Installing apps …" : "Instalowanie aplikacji…",
+    "Installing apps …" : "Instalowanie aplikacji …",
     "Install recommended apps" : "Zainstaluj zalecane aplikacje",
+    "Online" : "Online",
+    "Away" : "Bezczynny",
+    "Busy" : "Brak dostępności",
+    "Do not disturb" : "Nie przeszkadzać",
+    "Mute all notifications" : "Wycisz wszystkie powiadomienia",
+    "Invisible" : "Niewidoczny",
+    "Appear offline" : "Wyglądaj jako offline",
     "Avatar of {displayName}" : "Awatar {displayName}",
     "Settings menu" : "Menu ustawień",
-    "Loading your contacts …" : "Wczytywanie kontaktów…",
-    "Looking for {term} …" : "Szukam {term}…",
+    "Loading your contacts …" : "Wczytywanie kontaktów …",
+    "Looking for {term} …" : "Szukam {term} …",
     "Search contacts" : "Szukaj kontaktów",
     "Reset search" : "Zresetuj wyszukiwanie",
-    "Search contacts …" : "Wyszukiwanie kontaktów…",
+    "Search contacts …" : "Wyszukiwanie kontaktów …",
     "Could not load your contacts" : "Nie można wczytać kontaktów",
     "No contacts found" : "Nie znaleziono kontaktów",
     "Show all contacts" : "Pokaż wszystkie kontakty",
@@ -198,29 +319,53 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Wystąpił błąd podczas wyszukiwania {type}",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Wyszukiwanie rozpoczyna się po rozpoczęciu pisania, a wyniki można uzyskać za pomocą klawiszy strzałek",
     "Search for {name} only" : "Wyszukaj tylko {name}",
-    "Loading more results …" : "Wczytuję więcej wyników…",
+    "Loading more results …" : "Wczytuję więcej wyników …",
     "Forgot password?" : "Zapomniałeś hasła?",
     "Back to login form" : "Powrót do formularza logowania",
     "Back" : "Wstecz",
     "Login form is disabled." : "Formularz logowania jest wyłączony.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Formularz logowania Nextcloud jest wyłączony. Użyj innej opcji logowania, jeśli jest dostępna, lub skontaktuj się z administracją.",
     "More actions" : "Więcej akcji",
+    "User menu" : "Menu użytkownika",
+    "Your guest name: {user}" : "Twoja nazwa gościa: {user}",
+    "You are currently not identified." : "Obecnie nie jesteś zidentyfikowany.",
+    "Set public name" : "Ustaw nazwę publiczną",
+    "Change public name" : "Zmień nazwę publiczną",
+    "Password is too weak" : "Hasło jest za słabe",
+    "Password is weak" : "Hasło jest słabe",
+    "Password is average" : "Hasło jest przeciętne",
+    "Password is strong" : "Hasło jest silne",
+    "Password is very strong" : "Hasło jest bardzo silne",
+    "Password is extremely strong" : "Hasło jest niezwykle silne",
+    "Unknown password strength" : "Nieznana siła hasła",
+    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Prawdopodobnie Twój katalog danych i pliki są dostępne z Internetu, ponieważ plik <code>.htaccess</code> nie działa.",
+    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Aby uzyskać informacje na temat prawidłowej konfiguracji serwera, {linkStart}zapoznaj się z dokumentacją{linkEnd}",
+    "Autoconfig file detected" : "Wykryto plik autokonfiguracjny",
+    "The setup form below is pre-filled with the values from the config file." : "Poniższy formularz konfiguracji jest wstępnie wypełniony wartościami z pliku konfiguracyjnego.",
     "Security warning" : "Ostrzeżenie bezpieczeństwa",
+    "Create administration account" : "Utwórz konto administracyjne",
+    "Administration account name" : "Nazwa konta administracyjnego",
+    "Administration account password" : "Hasło do konta administracyjnego",
     "Storage & database" : "Magazyn i baza danych",
     "Data folder" : "Katalog danych",
+    "Database configuration" : "Konfiguracja bazy danych",
+    "Database type" : "Typ bazy danych",
+    "Only {firstAndOnlyDatabase} is available." : "Dostępne jest tylko {firstAndOnlyDatabase}.",
     "Install and activate additional PHP modules to choose other database types." : "Zainstaluj lub aktywuj dodatkowe moduły PHP, aby uzyskać możliwość wyboru innych typów baz danych.",
     "For more details check out the documentation." : "Aby uzyskać więcej informacji zapoznaj się z dokumentacją.",
     "Performance warning" : "Ostrzeżenie o wydajności",
     "You chose SQLite as database." : "Wybrałeś SQLite jako bazę danych.",
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite powinien być używany tylko dla instancji minimalnych i rozwojowych. Dla rozwiniętej zalecamy inne zaplecze bazy danych.",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Jeśli używasz klientów do synchronizacji plików, używanie SQLite jest bardzo odradzane.",
+    "Database connection" : "Połączenie bazy danych",
     "Database user" : "Użytkownik bazy danych",
     "Database password" : "Hasło do bazy danych",
     "Database name" : "Nazwa bazy danych",
     "Database tablespace" : "Obszar tabel bazy danych",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Podaj numer portu wraz z nazwą hosta (np. localhost: 5432).",
     "Database host" : "Host bazy danych",
-    "Installing …" : "Instalowanie…",
+    "localhost" : "localhost",
+    "Installing …" : "Instalowanie …",
     "Install" : "Zainstaluj",
     "Need help?" : "Potrzebujesz pomocy?",
     "See the documentation" : "Zapoznaj się z dokumentacją",
@@ -229,7 +374,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Twoja przeglądarka nie jest wspierana. Uaktualnij do nowszej lub obsługiwanej wersji.",
     "Continue with this unsupported browser" : "Kontynuuj w tej nieobsługiwanej przeglądarce",
     "Supported versions" : "Obsługiwane wersje",
-    "Search {types} …" : "Wyszukaj {types}…",
+    "Search {types} …" : "Wyszukaj {types} …",
     "Choose {file}" : "Wybierz {file}",
     "Choose" : "Wybierz",
     "Copy to {target}" : "Skopiuj do {target}",
@@ -249,7 +394,7 @@ OC.L10N.register(
     "(all selected)" : "(wybrano wszystkie)",
     "({count} selected)" : "(wybrano {count})",
     "Error loading file exists template" : "Błąd podczas ładowania pliku istniejącego szablonu",
-    "Saving …" : "Zapisywanie…",
+    "Saving …" : "Zapisywanie…",
     "seconds ago" : "przed chwilą",
     "Connection to server lost" : "Utracono połączenie z serwerem",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problem z wczytaniem strony, ponowne wczytanie za %n sekundę","Problem z wczytaniem strony, ponowne wczytanie za %n sekundy","Problem z wczytaniem strony, ponowne wczytanie za %n sekund","Problem z wczytaniem strony, ponowne wczytanie za %n sekund"],
@@ -264,26 +409,18 @@ OC.L10N.register(
     "Type to search for existing projects" : "Wpisz rodzaj, aby wyszukać istniejące projekty",
     "New in" : "Nowość w",
     "View changelog" : "Przeglądaj listę zmian",
-    "No action available" : "Żadna akcja nie jest dostępna",
-    "Error fetching contact actions" : "Błąd podczas pobierania akcji dla kontaktu",
     "Close \"{dialogTitle}\" dialog" : "Zamknij okno \"{dialogTitle}\"",
     "Email length is at max (255)" : "Długość e-maila jest maksymalna (255)",
-    "Non-existing tag #{tag}" : "Etykieta #{tag} nie istnieje",
-    "Restricted" : "Ograniczone",
-    "Invisible" : "Niewidoczny",
-    "Delete" : "Usuń",
-    "Rename" : "Zmień nazwę",
-    "Collaborative tags" : "Etykiety wspólne",
-    "No tags found" : "Nie znaleziono etykiet",
     "Clipboard not available, please copy manually" : "Schowek nie jest dostępny, prosimy skopiować ręcznie",
     "Personal" : "Osobiste",
     "Accounts" : "Konta",
     "Admin" : "Administrator",
     "Help" : "Pomoc",
     "Access forbidden" : "Dostęp zabroniony",
+    "You are not allowed to access this page." : "Nie masz uprawnień do tej strony.",
+    "Back to %s" : "Powrót do %s",
     "Page not found" : "Nie znaleziono strony",
     "The page could not be found on the server or you may not be allowed to view it." : "Strona nie została znaleziona na serwerze lub możesz nie mieć uprawnień do jej przeglądania.",
-    "Back to %s" : "Powrót do %s",
     "Too many requests" : "Zbyt wiele żądań",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Zbyt wiele żądań z Twojej sieci. Spróbuj ponownie później lub skontaktuj się z administratorem, jeśli jest to błąd.",
     "Error" : "Błąd",
@@ -359,23 +496,40 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Ta instancja %s jest obecnie w trybie konserwacji, co może chwilę potrwać.",
     "This page will refresh itself when the instance is available again." : "Strona odświeży się, gdy instancja będzie ponownie dostępna.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Skontaktuj się z administratorem systemu, jeśli ten komunikat będzie się powtarzał lub pojawił się nieoczekiwanie.",
-    "Currently open" : "Obecnie otwarte",
-    "Login with username or email" : "Zaloguj się za pomocą nazwy lub e-mail",
-    "Login with username" : "Zaloguj się za pomocą nazwy użytkownika",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Czat, rozmowy wideo, udostępnianie ekranu, spotkania online i konferencje internetowe - w przeglądarce i aplikacjach mobilnych.",
-    "You have not added any info yet" : "Nie dodałeś jeszcze żadnych informacji",
-    "{user} has not added any info yet" : "{user} nie dodał jeszcze żadnych informacji",
-    "Error opening the user status modal, try hard refreshing the page" : "Błąd podczas otwierania modalnego statusu użytkownika, spróbuj bardziej odświeżyć stronę",
-    "Edit Profile" : "Edytuj profil",
-    "The headline and about sections will show up here" : "Tutaj pojawi się nagłówek i informacje o sekcjach",
-    "Error loading message template: {error}" : "Błąd podczas ładowania szablonu wiadomości: {error}",
+    "Error occurred while checking server setup" : "Wystąpił błąd podczas sprawdzania konfiguracji serwera",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "Więcej informacji można znaleźć w {linkstart}dokumentacji ↗{linkend}.",
+    "unknown text" : "nieznany tekst",
+    "Hello world!" : "Witaj świecie!",
+    "sunny" : "słoneczna",
+    "Hello {name}, the weather is {weather}" : "Cześć {name}, dzisiejsza pogoda jest {weather}",
+    "Hello {name}" : "Witaj {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>To są twoje wyniki wyszukiwania<script>alert(1)</script></strong>",
+    "new" : "nowy",
+    "_download %n file_::_download %n files_" : ["pobrano %n plik","pobrano %n pliki","pobrano %n plików","pobrano %n plików"],
+    "Direct link copied to clipboard" : "Bezpośredni odnośnik skopiowany do schowka",
+    "Searching …" : "Wyszukiwanie…",
+    "Logging in …" : "Logowanie…",
+    "Loading apps …" : "Wczytywanie aplikacji…",
+    "Installing apps …" : "Instalowanie aplikacji…",
+    "Loading your contacts …" : "Wczytywanie kontaktów…",
+    "Looking for {term} …" : "Szukam {term}…",
+    "Search contacts …" : "Wyszukiwanie kontaktów…",
+    "Loading more results …" : "Wczytuję więcej wyników…",
+    "Search {types} …" : "Wyszukaj {types}…",
+    "Saving …" : "Zapisywanie…",
     "Very weak password" : "Bardzo słabe hasło",
     "Weak password" : "Słabe hasło",
     "So-so password" : "Mało skomplikowane hasło",
     "Good password" : "Dobre hasło",
     "Strong password" : "Silne hasło",
-    "Profile not found" : "Nie znaleziono profilu",
-    "The profile does not exist." : "Profil nie istnieje.",
+    "No action available" : "Żadna akcja nie jest dostępna",
+    "Error fetching contact actions" : "Błąd podczas pobierania akcji dla kontaktu",
+    "Non-existing tag #{tag}" : "Etykieta #{tag} nie istnieje",
+    "Restricted" : "Ograniczone",
+    "Delete" : "Usuń",
+    "Rename" : "Zmień nazwę",
+    "Collaborative tags" : "Etykiety wspólne",
+    "No tags found" : "Nie znaleziono etykiet",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Twój katalog danych i pliki są prawdopodobnie dostępne z poziomu internetu, ponieważ plik .htaccess nie działa.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Informacje na temat prawidłowej konfiguracji serwera można znaleźć w <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentacji</a>.",
     "<strong>Create an admin account</strong>" : "<strong>Utwórz konto administratora</strong>",
@@ -385,6 +539,7 @@ OC.L10N.register(
     "Toggle password visibility" : "Przełącz widoczność hasła",
     "Configure the database" : "Skonfiguruj bazę danych",
     "Only %s is available." : "Dostępne jest tylko %s.",
-    "Database account" : "Konto bazy danych"
+    "Database account" : "Konto bazy danych",
+    "Installing …" : "Instalowanie…"
 },
 "nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
