@@ -18,10 +18,6 @@ OC.L10N.register(
     "Unknown filetype" : "Genia de archìviu disconnota",
     "An error occurred. Please contact your admin." : "B'at àpidu un'errore. Cuntata s'amministratzione tua.",
     "Invalid image" : "Immàgine non bàlida",
-    "No temporary profile picture available, try again" : "Peruna foto de profilu temporànea a disponimentu, torra a proare",
-    "No crop data provided" : "Perunu datu frunidu",
-    "No valid crop data provided" : "Perunu datu vàlidu frunidu",
-    "Crop is not square" : "Su retàlliu no est a iscuadra",
     "State token does not match" : "S'istadu de s'autenticadore non currispondet",
     "Invalid app password" : "Crae de aplicatzione non vàlida",
     "Could not complete login" : "Non s'est pòdida cumpletare s'intrada",
@@ -68,14 +64,6 @@ OC.L10N.register(
     "The following apps have been disabled: %s" : "Is aplicatziones in fatu sunt istadas disativadas: %s",
     "Already up to date" : "Giai agiornadu",
     "Unknown" : "Disconnotu",
-    "unknown text" : "testu disconnotu",
-    "Hello world!" : "Salude mundu!",
-    "sunny" : "solianu",
-    "Hello {name}, the weather is {weather}" : "Salude {name}, su tempus est {weather}",
-    "Hello {name}" : "Salude {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Custos sunt is resurtados de sa chirca <script>avisu(1)</script></strong>",
-    "new" : "nou",
-    "_download %n file_::_download %n files_" : ["iscàrriga %n documentu","iscàrriga %narchìvios"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "S'agiornamentu est in cursu, lassende sa pàgina su protzessu si diat pòdere  suspèndere.",
     "Update to {version}" : "Agiorna a {version}",
     "An error occurred." : "B'at àpidu un'errore.",
@@ -96,7 +84,6 @@ OC.L10N.register(
     "Pick start date" : "Sèbera una data de cumintzu",
     "Pick end date" : "Sèbera una data de acabbu",
     "Search in date range" : "Chirca in su perìodu de datas",
-    "Searching …" : "Chirchende …",
     "Start typing to search" : "Cumintza a iscrìere pro chircare",
     "No matching results" : "Nissunu resurtadu",
     "Today" : "Oe ",
@@ -113,7 +100,6 @@ OC.L10N.register(
     "Load more results" : "Càrriga àteros resurtados",
     "Search in" : "Chirca in",
     "Log in" : "Intra",
-    "Logging in …" : "Intrende ...",
     "Log in to {productName}" : "Identìfica·ti in {productName}",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Amus agatadu tentativos meda de atzessu dae s'IP tuo. Duncas s'atzessu tuo imbeniente dd'as a pòdere fàghere intre 30 segundos.",
     "Account name or email" : "Nùmene de su contu o indiritzu de posta",
@@ -140,20 +126,21 @@ OC.L10N.register(
     "Keep your colleagues and friends in one place without leaking their private info." : "Mantene is collegas e is amistades tuas in unu logu chene mustrare is datos privados issoro.",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "Aplicatzione de posta eletrònica simpre e integrada bene cun Archìvios, Cuntatos e Calendàriu.",
     "Recommended apps" : "Aplicatziones racumandadas",
-    "Loading apps …" : "Carrighende aplicatziones ...",
     "Could not fetch list of apps from the App Store." : "No at fatu a recuperare sa lista dae sa butega de is aplicatziones.",
     "App download or installation failed" : "Iscarrigamentu de s'aplicatzione o installatzione faddida",
     "Cannot install this app because it is not compatible" : "Non faghet a installare custa aplicatzione ca no est cumpatìbile",
     "Cannot install this app" : "Non faghet a installare custa aplicatzione",
     "Skip" : "Brinca",
-    "Installing apps …" : "Installende aplicatziones ...",
     "Install recommended apps" : "Installa is aplicatziones racumandadas",
+    "Away" : "Ausente",
+    "Busy" : "Impinnadu",
+    "Do not disturb" : "No istorbes",
+    "Mute all notifications" : "Istuda totu is notìficas",
+    "Invisible" : "Invisìbile",
+    "Appear offline" : "Mustra•ti foras de lìnia",
     "Settings menu" : "Menù de cunfiguratzione",
-    "Loading your contacts …" : "Carrighende is cuntatos...",
-    "Looking for {term} …" : "Chirchende {term} …",
     "Search contacts" : "Chirca cuntatos",
     "Reset search" : "Riprìstina chirca",
-    "Search contacts …" : "Chirca cuntatos ...",
     "Could not load your contacts" : "No at fatu a carrigare is cuntatos",
     "No contacts found" : "Perunu cuntatu agatadu",
     "Show all contacts" : "Mustra totu is cuntatos",
@@ -164,7 +151,6 @@ OC.L10N.register(
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Inserta {longàriaMinChirca} o prus caràteres pro chircare","Inserta·nche {minSearchLength} o prus caràteres pro chircare"],
     "An error occurred while searching for {type}" : "B'at àpidu un'errore in sa chirca de {type}",
     "Search for {name} only" : "Chirca pro {name} ebbia",
-    "Loading more results …" : "Carrighende àteros resurtados ...",
     "Forgot password?" : "As ismentigadu sa crae?",
     "Back to login form" : "Torra a su formulàriu de identificatzione",
     "Back" : "A coa",
@@ -185,7 +171,6 @@ OC.L10N.register(
     "Database tablespace" : "Logu de sa tauledda de sa base de datos",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Ispetzìfica su nùmeru de sa gianna aintru de su nùmene de su retzidore (p.e., retzidorelocale:5432).",
     "Database host" : "Retzidore de sa base de datos",
-    "Installing …" : "Installende ...",
     "Install" : "Installa",
     "Need help?" : "Boles agiudu?",
     "See the documentation" : "Càstia sa documentatzione",
@@ -194,7 +179,6 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Su navigadore tuo no est cumpatìbile. Atualiza·ddu a una versione noa o càmbia a unu navigadore cumpatìbile.",
     "Continue with this unsupported browser" : "Abarra in custu navigadore non cumpatìbile",
     "Supported versions" : "Versiones cumpatìbiles",
-    "Search {types} …" : "Chirca {types} …",
     "Choose {file}" : "Sèbera {file}",
     "Choose" : "Sèbera",
     "Copy to {target}" : "Còpia a {target}",
@@ -214,7 +198,7 @@ OC.L10N.register(
     "(all selected)" : "(totu seletzionadu)",
     "({count} selected)" : "({count} seletzionadu)",
     "Error loading file exists template" : "Errore in su carrigamentu de su modellu de archìviu",
-    "Saving …" : "Sarvende …",
+    "Saving …" : "Sarvende ...",
     "seconds ago" : "segundos a immoe",
     "Connection to server lost" : "Connessione a su serbidore pèrdida",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Si seletzionas ambas is versiones, su documentu copiadu at a tènnere unu nùmeru in agiunta a su nùmene.","Problema in su carrigamentu de sa pàgina, torrende a carrigare intre %n segundos"],
@@ -229,16 +213,7 @@ OC.L10N.register(
     "Type to search for existing projects" : "Iscrie pro chircare is progetos chi ddoe sunt giai",
     "New in" : "Prima borta in",
     "View changelog" : "Càstia su registru de is càmbios",
-    "No action available" : "Peruna atzione a disponimentu",
-    "Error fetching contact actions" : "Errore in su recùperu de is atziones de cuntatu",
     "Close \"{dialogTitle}\" dialog" : "Serra su cuadru de diàlogu \"{dialogTitle}\"",
-    "Non-existing tag #{tag}" : "S'eticheta no esistit #{tag}",
-    "Restricted" : "Limitadu",
-    "Invisible" : "Invisìbile",
-    "Delete" : "Cantzella",
-    "Rename" : "Torra a numenare",
-    "Collaborative tags" : "Etichetas collaborativas",
-    "No tags found" : "Peruna eticheta agatada",
     "Personal" : "Personale",
     "Accounts" : "Accounts",
     "Admin" : "Amministratzione",
@@ -317,21 +292,43 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Cuntata s'amministratzione de sistema si custu messàgiu abarrat o torrat a cumpàrrere.",
     "Error occurred while checking server setup" : "Ddoe at àpidu un'errore in su controllu de sa cunfiguratzione de su serbidore",
     "For more details see the {linkstart}documentation ↗{linkend}." : "Pro àteros detàllios controlla sa {linkstart}documentatzione ↗{linkend}.",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Tzarradas, video mutidas, cumpartzidura de s'ischermu, reuniones in lìnia e vìdeo-cunferèntzias – in su navigadore tuo e cun aplicatziones mòbiles.",
-    "Edit Profile" : "Modìfica su profilu",
-    "The headline and about sections will show up here" : "Is setziones de tìtulu e informatziones ant a èssere ammustradas inoghe",
+    "unknown text" : "testu disconnotu",
+    "Hello world!" : "Salude mundu!",
+    "sunny" : "solianu",
+    "Hello {name}, the weather is {weather}" : "Salude {name}, su tempus est {weather}",
+    "Hello {name}" : "Salude {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Custos sunt is resurtados de sa chirca <script>avisu(1)</script></strong>",
+    "new" : "nou",
+    "_download %n file_::_download %n files_" : ["iscàrriga %n documentu","iscàrriga %narchìvios"],
+    "Searching …" : "Chirchende …",
+    "Logging in …" : "Intrende ...",
+    "Loading apps …" : "Carrighende aplicatziones ...",
+    "Installing apps …" : "Installende aplicatziones ...",
+    "Loading your contacts …" : "Carrighende is cuntatos...",
+    "Looking for {term} …" : "Chirchende {term} …",
+    "Search contacts …" : "Chirca cuntatos ...",
+    "Loading more results …" : "Carrighende àteros resurtados ...",
+    "Search {types} …" : "Chirca {types} …",
+    "Saving …" : "Sarvende …",
     "Very weak password" : "Crae dèbile meda",
     "Weak password" : "Crae dèbile",
     "So-so password" : "Crae aici aici",
     "Good password" : "Crae bona",
     "Strong password" : "Crae bona a beru",
-    "Profile not found" : "Profilu no agatadu",
-    "The profile does not exist." : "Su profilu no esistit.",
+    "No action available" : "Peruna atzione a disponimentu",
+    "Error fetching contact actions" : "Errore in su recùperu de is atziones de cuntatu",
+    "Non-existing tag #{tag}" : "S'eticheta no esistit #{tag}",
+    "Restricted" : "Limitadu",
+    "Delete" : "Cantzella",
+    "Rename" : "Torra a numenare",
+    "Collaborative tags" : "Etichetas collaborativas",
+    "No tags found" : "Peruna eticheta agatada",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Is cartellas de datos e is archìvios tuos fortzis sunt atzessìbiles dae s'internet ca s'archìviu .htaccess no est funtzionende.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Pro informatziones subra de comente cunfigurare su serbidore tuo, càstia in sa <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentatzione</a>.",
     "Show password" : "Mustra crae",
     "Toggle password visibility" : "Càmbia sa visibilidade de sa crae",
     "Configure the database" : "Cunfigura sa base de datos",
-    "Only %s is available." : "%s isceti est a disponimentu."
+    "Only %s is available." : "%s isceti est a disponimentu.",
+    "Installing …" : "Installende ..."
 },
 "nplurals=2; plural=(n != 1);");
