@@ -156,6 +156,11 @@ OC.L10N.register(
     "Cannot install this app" : "ไม่สามารถติดตั้งแอปนี้",
     "Skip" : "ข้าม",
     "Install recommended apps" : "ติดตั้งแอปแนะนำ",
+    "Online" : "ออนไลน์",
+    "Away" : "ไม่อยู่",
+    "Mute all notifications" : "ปิดการแจ้งเตือนทั้งหมด",
+    "Invisible" : "มองไม่เห็น",
+    "Appear offline" : "แสดงเป็นออฟไลน์",
     "Avatar of {displayName}" : "อวาตาร์ของ {displayName}",
     "Settings menu" : "เมนูการตั้งค่า",
     "Search contacts" : "ค้นหารายชื่อ",
@@ -342,7 +347,6 @@ OC.L10N.register(
     "Error fetching contact actions" : "เกิดข้อผิดพลาดในการดึงการกระทำรายชื่อ",
     "Non-existing tag #{tag}" : "แท็ก #{tag} ไม่มีอยู่",
     "Restricted" : "ถูกจำกัด",
-    "Invisible" : "มองไม่เห็น",
     "Delete" : "ลบ",
     "Rename" : "เปลี่ยนชื่อ",
     "Collaborative tags" : "แท็กแบบทำงานร่วมกัน",
