@@ -18,10 +18,6 @@ OC.L10N.register(
     "Unknown filetype" : "Noma'lum fayl turi",
     "An error occurred. Please contact your admin." : "Xatolik yuz berdi. O`z adminingizga murojaat qiling.",
     "Invalid image" : "Noto'g'ri rasm",
-    "No temporary profile picture available, try again" : "Profil rasmi vaqtinchalik mavjud emas, qaytadan urinib ko'ring",
-    "No crop data provided" : "Kerakli maʼlumotlar berilmagan",
-    "No valid crop data provided" : "Kerakli maʼlumotlar xato berilgan",
-    "Crop is not square" : "Kerakli maʼlumotlar moslashtirilmagan",
     "State token does not match" : "Token mos emas",
     "Invalid app password" : "Ilova paroli noto'g'ri",
     "Could not complete login" : "Kirishni yakunlab bo'lmadi",
@@ -51,6 +47,11 @@ OC.L10N.register(
     "No translation provider available" : "Tarjima provayderi mavjud emas",
     "Could not detect language" : "Tilni aniqlab bo'lmadi",
     "Unable to translate" : "Tarjima qilib bo'lmadi",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair step:" : "Ta'mirlash bosqichi:",
+    "Repair info:" : "Repair info:",
+    "Repair warning:" : "Ta'mirlash haqida ogohlantirish:",
+    "Repair error:" : "Ta'mirlash xatosi:",
     "Nextcloud Server" : "Next bulutli Server",
     "Some of your link shares have been removed" : "Sizning havola aktsiyalaringizdan ba'zilari olib tashlandi",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Xavfsizlik xatosi tufayli biz sizning ba'zi havolalaringizni olib tashlashimiz kerak edi. Qo'shimcha ma'lumot olish uchun link qarang.",
@@ -58,11 +59,6 @@ OC.L10N.register(
     "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Hisob cheklovini oshirish uchun obuna kalitini qo'llab-quvvatlash ilovasiga kiriting. Bu sizga Next cloud Enterprise taklif qiladigan va kompaniyalarda ishlash uchun juda tavsiya etiladigan barcha qo'shimcha imtiyozlarni beradi.",
     "Learn more ↗" : "Ko'proq ma'lumot oling. ↗",
     "Preparing update" : "Yangilanish tayyorlanmoqda",
-    "[%d / %d]: %s" : "[%d / %d]: %s",
-    "Repair step:" : "Ta'mirlash bosqichi:",
-    "Repair info:" : "Repair info:",
-    "Repair warning:" : "Ta'mirlash haqida ogohlantirish:",
-    "Repair error:" : "Ta'mirlash xatosi:",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "Iltimos, buyruq satrini yangilashdan foydalaning, chunki config.php da brauzer orqali yangilash o'chirilgan.",
     "Turned on maintenance mode" : "Ta'minot rejimi yoqilgan",
     "Turned off maintenance mode" : "Ta'minot rejimi o'chirilgan",
@@ -79,16 +75,7 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (mos kelmaydigan)",
     "The following apps have been disabled: %s" : "Quyidagi ilovalar o'chirilgan:  %s",
     "Already up to date" : "Allaqachon dolzarb",
-    "Error occurred while checking server setup" : "Serverni sozlashni tekshirishda xatolik yuz berdi",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "Batafsil ma'lumot uchun {linkstart}documentatsiyasini ↗{linkend}qarang.",
-    "unknown text" : "noma'lum matn",
-    "Hello world!" : "Salom dunyo!",
-    "sunny" : "quyoshli",
-    "Hello {name}, the weather is {weather}" : "Salom {name}, Ob-havo hozir {weather}",
-    "Hello {name}" : "Salom {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Bu sizning qidiruv natijalaringiz<script>ogohlantirish(1)</script></strong>",
-    "new" : "yangi",
-    "_download %n file_::_download %n files_" : ["fayllarni yuklash %n "],
+    "Unknown" : "Noma'lum",
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Yangilanish davom etmoqda, bu sahifani tark etish ba'zi muhitlarda jarayonni to'xtatishi mumkin.",
     "Update to {version}" : " {version}ni yangilash",
     "An error occurred." : "Xatolik yuz berdi.",
@@ -109,7 +96,6 @@ OC.L10N.register(
     "Federated user" : "Korporativ foydalanuvchi",
     "user@your-nextcloud.org" : "user@your-nextcloud.org",
     "Create share" : "Tarqatish yaratish",
-    "Direct link copied to clipboard" : "Klipbordga nusxa olish",
     "Please copy the link manually:" : "Iltimos, havolani qo'lda nusxalash:",
     "Custom date range" : "Maxsus sana oralig'i",
     "Pick start date" : "Boshlanish sanasini tanlang",
@@ -118,7 +104,6 @@ OC.L10N.register(
     "Search in current app" : "Joriy ilovada qidirish",
     "Clear search" : "Qidiruvni tozalash",
     "Search everywhere" : "Hamma joyda qidirish",
-    "Searching …" : "Qidirilmoqda …",
     "Start typing to search" : "Qidirish uchun yozishni boshlang",
     "No matching results" : "Natijalar taaluqli emas",
     "Today" : "Bugun",
@@ -137,7 +122,6 @@ OC.L10N.register(
     "Load more results" : "Ko'proq natijalarni yuklang",
     "Search in" : "Qidirish",
     "Log in" : "Kirish",
-    "Logging in …" : "Kirilmoqda …",
     "Log in to {productName}" : " {productName}ga kirish",
     "Wrong login or password." : "Noto'g'ri login yoki parol.",
     "This account is disabled" : "Bu akkaunt o'chirilgan",
@@ -146,8 +130,8 @@ OC.L10N.register(
     "Account name" : "Akkaunt nomi",
     "Server side authentication failed!" : "Server tomoni autentifikatsiyasi muvaffaqiyatsiz tugadi!",
     "Please contact your administrator." : "Iltimos, administratoringizga murojaat qiling.",
-    "Temporary error" : "Hozirda xatolik",
-    "Please try again." : "Iltimos, qayta urinib ko'ring.",
+    "Session error" : "Seans xatosi",
+    "It appears your session token has expired, please refresh the page and try again." : "Tokeningiz seans muddati tugaganga o‘xshaydi, sahifani yangilang va qayta urinib ko‘ring.",
     "An internal error occurred." : "Ichki xato yuz berdi.",
     "Please try again or contact your administrator." : "Iltimos, qayta urinib ko'ring yoki administratoringizga murojaat qiling.",
     "Password" : "Parol",
@@ -174,21 +158,23 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Hamkorlikdagi hujjatlar, elektron jadvallar va taqdimotlar, Collabora onlayn asosida qurilgan.",
     "Distraction free note taking app." : "Eslatma olish ilovasi.",
     "Recommended apps" : "Tavsiya etilgan ilovalar",
-    "Loading apps …" : "Ilovalarni yuklash …",
     "Could not fetch list of apps from the App Store." : "App Store dan ilovalar ro'yxatini olib bo'lmadi.",
     "App download or installation failed" : "Ilovani yuklab olish yoki o'rnatish muvaffaqiyatsiz tugadi",
     "Cannot install this app because it is not compatible" : "Ushbu ilovani o'rnatib bo'lmadi, chunki u mos emas",
     "Cannot install this app" : "Ushbu ilovani o'rnatib bo'lmadi",
     "Skip" : "O'tkazib yuborish",
-    "Installing apps …" : "Ilovalarni o'rnatish …",
     "Install recommended apps" : "Tavsiya etilgan ilovalarni o'rnating",
+    "Online" : "Onlayn",
+    "Away" : "Uzoqda",
+    "Busy" : "Band",
+    "Do not disturb" : "Bezovta qilmang",
+    "Mute all notifications" : "Barcha bildirishnomalarni o'chirish",
+    "Invisible" : "Ko'rinmas",
+    "Appear offline" : "Oflayn ko'rinishda",
     "Avatar of {displayName}" : " {displayName} ning avatari",
     "Settings menu" : "Sozlamalar menyusi",
-    "Loading your contacts …" : "Kontaktlaringiz yuklanmoqda …",
-    "Looking for {term} …" : " {term} qidirilmoqda…",
     "Search contacts" : "Kontaktlarni qidirish",
     "Reset search" : "Qidiruvni tiklash",
-    "Search contacts …" : "Kontaktlarni qidirish …",
     "Could not load your contacts" : "Kontaktlaringizni yuklab bo'lmadi",
     "No contacts found" : "Kontaktlar topilmadi",
     "Show all contacts" : "Show all contacts",
@@ -200,7 +186,6 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : " {type}qidirish paytida xatolik yuz berdi",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Yozishni boshlaganingizdan so'ng qidiruv boshlanadi va natijalarga o'q tugmachalari yordamida erishish mumkin",
     "Search for {name} only" : "Faqat {name} qidirish",
-    "Loading more results …" : "Ko'proq natijalar yuklanmoqda …",
     "Forgot password?" : "Parolni unutdingizmi?",
     "Back to login form" : "Kirish formasiga qaytish",
     "Back" : "Orqaga",
@@ -239,7 +224,6 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Xost nomi bilan birga port raqamini ko'rsating (masalan, localhost:5432).",
     "Database host" : "Ma'lumotlar bazasi xosti",
     "localhost" : "localhost",
-    "Installing …" : "Oʻrnatilmoqda…",
     "Install" : "O'rnatish",
     "Need help?" : "Yordam kerakmi?",
     "See the documentation" : "Hujjatlarga qarang",
@@ -248,14 +232,13 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Sizning brauzeringiz qo'llab-quvvatlanmaydi. Iltimos, yangiroq yoki qo'llab-quvvatlanadigan versiyaga yangilang.",
     "Continue with this unsupported browser" : "Ushbu qo'llab-quvvatlanmaydigan brauzer bilan davom eting",
     "Supported versions" : "Qo'llab-quvvatlanadigan versiyalar",
-    "Search {types} …" : " {types}ta qidiruv…",
     "Choose {file}" : " {file}ta tanlash",
     "Choose" : "Tanlang",
     "Copy to {target}" : " {target}ga nusxalash",
     "Copy" : "Nusxalash",
     "Move to {target}" : " {target}ga o`tish",
     "Move" : "O`tish",
-    "OK" : "OK",
+    "OK" : "Yaxshi",
     "read-only" : "faqat o'qish uchun",
     "_{count} file conflict_::_{count} file conflicts_" : ["{count} fayl xatolilklari"],
     "One file conflict" : "Bitta fayl ziddiyati",
@@ -268,8 +251,7 @@ OC.L10N.register(
     "(all selected)" : "(barchasi tanlangan)",
     "({count} selected)" : "({count} tanlangan)",
     "Error loading file exists template" : "Fayl shablonini yuklashda xatolik yuz berdi",
-    "Saving …" : "Saqlanmoqda...",
-    "seconds ago" : "daqiqa avval",
+    "seconds ago" : "soniya avval",
     "Connection to server lost" : "Serverga ulanish uzildi",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Sahifani yuklashda muammo yuz berdi, %n sekundda qayta yuklanmoqda"],
     "Add to a project" : "Loyihaga qo'shish",
@@ -283,26 +265,17 @@ OC.L10N.register(
     "Type to search for existing projects" : "Mavjud loyihalarni qidirish uchun kiriting",
     "New in" : "Yangi kiritish",
     "View changelog" : "O'zgarishlar jurnalini ko'rish",
-    "No action available" : "Hech qanday amal mavjud emas",
-    "Error fetching contact actions" : "Kontakt amallarini olishda xatolik yuz berdi",
     "Close \"{dialogTitle}\" dialog" : " \"{dialogTitle}\" dialogini yopish",
     "Email length is at max (255)" : "Elektron xabar uzunligi maksimal (255)",
-    "Non-existing tag #{tag}" : "Mavjud bo'lmagan teg #{tag}",
-    "Restricted" : "Cheklangan",
-    "Invisible" : "Ko'rinmas",
-    "Delete" : "Oʻchirish",
-    "Rename" : "Nomini o'zgartirish",
-    "Collaborative tags" : "Hamkorlik teglari",
-    "No tags found" : "Hech qanday teg topilmadi",
     "Clipboard not available, please copy manually" : "Bufer mavjud emas, qo‘lda nusxa ko‘chiring",
     "Personal" : "Personal",
     "Accounts" : "Akkaunt",
     "Admin" : "Admin",
     "Help" : "Yordam",
     "Access forbidden" : "Kirish taqiqlangan",
+    "Back to %s" : "%sga qaytish",
     "Page not found" : "Sahifa topilmadi",
     "The page could not be found on the server or you may not be allowed to view it." : "Sahifani serverda topib bo'lmadi yoki sizga uni ko'rishga ruxsat berilmasligi mumkin.",
-    "Back to %s" : "%sga qaytish",
     "Too many requests" : "Juda koʻp soʻrovlar",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Tarmogʻingizdan juda koʻp soʻrovlar kelib tushdi. Keyinroq qayta urinib ko‘ring yoki xatolik yuz bergan bo‘lsa, administratoringizga murojaat qiling.",
     "Error" : "Xatolik",
@@ -378,23 +351,40 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Bu %s misol hozirda sozlanish rejimida, bu biroz vaqt olishi mumkin.",
     "This page will refresh itself when the instance is available again." : "Misol yana mavjud bo'lganda, bu sahifa o'zini yangilaydi.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Agar bu xabar davom etsa yoki kutilmaganda paydo bo'lsa, tizim administratoriga murojaat qiling.",
-    "Currently open" : "Hozirda ochiq",
-    "Login with username or email" : "Foydalanuvchi nomi yoki elektron pochta bilan kiring",
-    "Login with username" : "Foydalanuvchi nomi bilan kirish",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Suhbat, video qo'ng'iroqlar, skrinshotlar, onlayn uchrashuvlar va veb – konferentsiyalar-brauzeringizda va mobil ilovalar bilan.",
-    "You have not added any info yet" : "Siz hali hech qanday ma'lumot qo'shmadingiz",
-    "{user} has not added any info yet" : "{user} hali hech qanday ma'lumot qo'shmagan",
-    "Error opening the user status modal, try hard refreshing the page" : "Foydalanuvchi holati modalini ochishda xato, sahifani yangilashga harakat qiling",
-    "Edit Profile" : "Profilni Tahrirlash",
-    "The headline and about sections will show up here" : "The headline and about sections will show up here",
-    "Error loading message template: {error}" : " Xabar shablonini yuklashda xato ro'y berdi: {error}",
+    "Error occurred while checking server setup" : "Serverni sozlashni tekshirishda xatolik yuz berdi",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "Batafsil ma'lumot uchun {linkstart}documentatsiyasini ↗{linkend}qarang.",
+    "unknown text" : "noma'lum matn",
+    "Hello world!" : "Salom dunyo!",
+    "sunny" : "quyoshli",
+    "Hello {name}, the weather is {weather}" : "Salom {name}, Ob-havo hozir {weather}",
+    "Hello {name}" : "Salom {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Bu sizning qidiruv natijalaringiz<script>ogohlantirish(1)</script></strong>",
+    "new" : "yangi",
+    "_download %n file_::_download %n files_" : ["fayllarni yuklash %n "],
+    "Direct link copied to clipboard" : "Klipbordga nusxa olish",
+    "Searching …" : "Qidirilmoqda …",
+    "Logging in …" : "Kirilmoqda …",
+    "Loading apps …" : "Ilovalarni yuklash …",
+    "Installing apps …" : "Ilovalarni o'rnatish …",
+    "Loading your contacts …" : "Kontaktlaringiz yuklanmoqda …",
+    "Looking for {term} …" : " {term} qidirilmoqda…",
+    "Search contacts …" : "Kontaktlarni qidirish …",
+    "Loading more results …" : "Ko'proq natijalar yuklanmoqda …",
+    "Search {types} …" : " {types}ta qidiruv…",
+    "Saving …" : "Saqlanmoqda...",
     "Very weak password" : "Juda zaif parol",
     "Weak password" : "Zaif parol",
     "So-so password" : "Shunday parol",
     "Good password" : "Yaxshi parol",
     "Strong password" : "Kuchli parol",
-    "Profile not found" : "Profil topilmadi",
-    "The profile does not exist." : "Profil mavjud emas.",
+    "No action available" : "Hech qanday amal mavjud emas",
+    "Error fetching contact actions" : "Kontakt amallarini olishda xatolik yuz berdi",
+    "Non-existing tag #{tag}" : "Mavjud bo'lmagan teg #{tag}",
+    "Restricted" : "Cheklangan",
+    "Delete" : "Oʻchirish",
+    "Rename" : "Nomini o'zgartirish",
+    "Collaborative tags" : "Hamkorlik teglari",
+    "No tags found" : "Hech qanday teg topilmadi",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Sizning ma'lumotlar katalog va fayllar, chunki internetdan ehtimol yaxshi bo'ladi .htaccess fayl ishlamaydi.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : " Serveringizni qanday qilib to'g'ri sozlash haqida ma'lumot olish uchun<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">hujjatlarida</a>.",
     "<strong>Create an admin account</strong>" : "<strong>da </strong>administrator akkauntini yarating",
@@ -404,6 +394,7 @@ OC.L10N.register(
     "Toggle password visibility" : "Parol ko'rinishini o'zgartiring",
     "Configure the database" : "Ma'lumotlar bazasini moslashtiring",
     "Only %s is available." : "Faqat %s uchun mavjud.",
-    "Database account" : "Akkauntlar ma`lumotlar bazasi"
+    "Database account" : "Akkauntlar ma`lumotlar bazasi",
+    "Installing …" : "Oʻrnatilmoqda…"
 },
 "nplurals=1; plural=0;");
