@@ -5,9 +5,9 @@ OC.L10N.register(
     "This can usually be fixed by giving the web server write access to the config directory." : "Това обикновено може да бъде оправено като, се даде достъп на уеб сървъра да записва в config директорията.",
     "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Но ако предпочитате да запазите файла config.php само за четене, задайте опцията \"config_is_read_only\" на true/вярно/ в него.",
     "See %s" : "Вижте %s",
-    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Файловете на приложението %1$s не бяха заменени правилно. Уверете се, че версията е съвместима със сървъра.",
     "Sample configuration detected" : "Открита е примерна конфигурация",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Усетено беше че примерната конфигурация е копирана. Това може да развли инсталацията ти и не се поддържа. Моля, прочети документацията преди да правиш промени на config.php",
+    "The page could not be found on the server." : "Страницата не е намерена на сървъра.",
     "%s email verification" : "%s имейл потвърждение",
     "Email verification" : "Имейл потвърждение",
     "Click the following button to confirm your email." : "Щракнете върху следния бутон, за да потвърдите имейла си.",
@@ -18,7 +18,6 @@ OC.L10N.register(
     "%1$s, %2$s and %3$s" : "%1$s, %2$s и %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s и %4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s и %5$s",
-    "Education Edition" : "Образователно издание",
     "Enterprise bundle" : "Професионален пакет",
     "Groupware bundle" : "Софтуерен групов пакет",
     "Hub bundle" : "Хъб пакет",
@@ -35,9 +34,6 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "Поддържани са следните платформи: %s",
     "Server version %s or higher is required." : "Нужна е версия на сървъра %s или по-нова.",
     "Server version %s or lower is required." : "Нужна е версия на сървъра %s или по-ниска.",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Влезлият потребител трябва да е администратор, подадминистратор или да е получил специално право за достъп до тази настройка",
-    "Logged in user must be an admin or sub admin" : "Влезлият потребител трябва да е администратор или подадминистратор ",
-    "Logged in user must be an admin" : "Влезлият потребител трябва да е администратор",
     "Wiping of device %s has started" : "Започна изтриването на устройството %s",
     "Wiping of device »%s« has started" : "»%s« Започна изтриването на устройството ",
     "»%s« started remote wipe" : "»%s« започна отдалечено изтриване",
@@ -54,7 +50,10 @@ OC.L10N.register(
     "Unknown filetype" : "Непознат тип файл",
     "Invalid image" : "Невалидно изображение.",
     "Avatar image is not square" : "Изображението на аватара не е квадратно",
+    "Files" : "Файлове",
     "View profile" : "Преглед на профил",
+    "_%nh_::_%nh_" : ["%nч","%nч"],
+    "Local time: %s" : "Местно време: %s",
     "today" : "днес",
     "tomorrow" : "утре",
     "yesterday" : "вчера",
@@ -76,29 +75,32 @@ OC.L10N.register(
     "seconds ago" : "преди секунди",
     "Empty file" : "Празен файл",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Модул с ID: %s не съществува. Моля, активирайте го в настройките на приложенията си или се свържете с администратора си.",
+    "Dot files are not allowed" : "Файлове с точки не са разрешени",
+    "%1$s (renamed)" : "%1$s (преименуван)",
+    "renamed file" : "преименуван файл",
+    "Filenames must not end with \"%1$s\"." : "Имената на файловете не трябва да завършват с \"%1$s\"",
     "File already exists" : "Файлът вече съществува",
     "Invalid path" : "Невалиден път",
     "Failed to create file from template" : "Неуспешно създаване на файл от шаблон",
     "Templates" : "Шаблони",
-    "File name is a reserved word" : "Името на файла е запазена дума",
-    "File name contains at least one invalid character" : "Името на файла съдържа поне един невалиден символ",
-    "File name is too long" : "Името на файла е твърде дълго",
-    "Dot files are not allowed" : "Файлове с точки не са разрешени",
+    "Filename contains at least one invalid character" : "Името на файла съдържа поне един невалиден символ",
     "Empty filename is not allowed" : "Празно име на файл не е разрешено.",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "Приложението „%s“ не може да бъде инсталирано, защото appinfo/информация за приложението/ файлът не може да бъде прочетен.",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Приложението \"%s\" не може да бъде инсталирано, защото не е съвместимо с тази версия на сървъра.",
     "__language_name__" : "Български",
     "This is an automatically sent email, please do not reply." : "Имейлът е генериран автоматично, моля не отговаряйте.",
-    "Help" : "Помощ",
     "Appearance and accessibility" : "Изглед и достъпност",
     "Apps" : "Приложения",
     "Personal settings" : "Лични настройки",
     "Administration settings" : "Административни настройки",
     "Settings" : "Настройки",
     "Log out" : "Отписване",
-    "Users" : "Потребители",
+    "Accounts" : "Профили",
+    "Bluesky" : "Bluesky",
     "Email" : "Имейл",
     "Mail %s" : "Поща %s",
+    "Fediverse" : "Fediverse /съвкупност от обединени сървъри/",
+    "View %s on the fediverse" : "Преглед на %s във Fediverse",
     "Phone" : "Телефон",
     "Call %s" : "Обаждане %s",
     "Twitter" : "Twitter",
@@ -106,34 +108,28 @@ OC.L10N.register(
     "Website" : "Уеб сайт",
     "Visit %s" : "Посещение %s",
     "Address" : "Адрес",
-    "Profile picture" : "Снимка на профила",
+    "Profile picture" : "Профилна снимка",
     "About" : "Относно",
-    "Full name" : "Пълно име",
+    "Display name" : "Име за визуализация",
     "Headline" : "Заглавие",
-    "Organisation" : "Организация",
+    "Organization" : "Организиране",
     "Role" : "Роля",
-    "Unknown user" : "Непознат потребител",
+    "Pronouns" : "Обръщение",
     "Additional settings" : "Допълнителни настройки",
-    "MySQL username and/or password not valid" : "Име на потребител и/или паролата на MySQL не са валидни",
+    "Enter the database name for %s" : "Въведете името на базата данни за %s",
+    "You cannot use dots in the database name %s" : "Не можете да използвате точки в името на базата данни %s",
     "You need to enter details of an existing account." : "Трябва да въведете подробности за съществуващ профил.",
     "Oracle connection could not be established" : "Не можа да се установи връзка с Oracle",
-    "Oracle username and/or password not valid" : "Невалидно Oracle потребителско име и/или парола.",
-    "PostgreSQL username and/or password not valid" : "Невалидно PostgreSQL потребителско име и/или парола.",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X не се подържа и %s няма да работи правилно на тази платформа. Използвайте го на свой собствен риск!",
     "For the best results, please consider using a GNU/Linux server instead." : "За най-добри резултати, моля, помисли дали не бихте желали да използваште GNU/Linux сървър.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : " Изглежда, че този екземпляр %s работи в 32-битова PHP среда и open_basedir е конфигуриран в php.ini. Това ще доведе до проблеми с файлове над 4 GB и е силно обезкуражено.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Моля, премахтене настройката за open_basedir от вашия php.ini или преминете към 64-битово PHP.",
-    "Set an admin username." : "Задайте потребителско име за администратор.",
     "Set an admin password." : "Задай парола за администратор.",
     "Cannot create or write into the data directory %s" : "Неуспешно създаване или записване в директорията  с данни \"data\" %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Споделянето на сървърния %s трябва да поддържа OCP\\Share_Backend интерфейс.",
     "Sharing backend %s not found" : "Споделянето на сървърния %s не е открито.",
     "Sharing backend for %s not found" : "Споделянето на сървъра за %s не е открито.",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s сподели »%2$s« с вас и иска да добави:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s сподели »%2$s« с вас и иска да добави",
-    "»%s« added a note to a file shared with you" : "»%s« добави бележка към файл, споделен с вас ",
-    "Open »%s«" : "Отвори »%s«",
     "%1$s via %2$s" : "%1$s чрез %2$s",
+    "Unknown share type" : "Неизвестен тип споделяне",
     "You are not allowed to share %s" : "Не ти е разрешено да споделяш %s.",
     "Cannot increase permissions of %s" : "Не могат да се увеличат права на %s",
     "Files cannot be shared with delete permissions" : "Файловете не могат да се споделят с права за изтриване",
@@ -141,11 +137,8 @@ OC.L10N.register(
     "Expiration date is in the past" : "Срокът на валидност е изтекъл",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Не може да се зададе срок на валидност повече от %n дни в бъдещето","Не може да се зададе срок на валидност повече от %n дни в бъдещето"],
     "Sharing is only allowed with group members" : "Споделянето е разрешено само с членове на групата",
-    "Sharing %s failed, because this item is already shared with user %s" : "Неуспешно споделяне на %s, защото този елемент вече е споделен с потребителя %s",
-    "%1$s shared »%2$s« with you" : "%1$s сподели »%2$s« с вас",
-    "%1$s shared »%2$s« with you." : "%1$s сподели »%2$s« с вас.",
-    "Click the button below to open it." : "Щракнете върху бутона по-долу, за да го отворите.",
     "The requested share does not exist anymore" : "Исканото споделяне вече не съществува",
+    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Потребителят не е създаден, тъй като е достигнат лимитът на потребителите. Проверете вашите известия, за да научите повече.",
     "Could not find category \"%s\"" : "Невъзможно откриване на категорията \"%s\".",
     "Sunday" : "неделя",
     "Monday" : "понеделник",
@@ -192,21 +185,10 @@ OC.L10N.register(
     "Oct." : "окт",
     "Nov." : "ное",
     "Dec." : "дек",
-    "The user limit has been reached and the user was not created." : "Потребителският лимит е достигнат и потребителят не е създаден. ",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Потребителските имена може да съдържат следните знаци: \"a-z\", \"A-Z\", \"0-9\" и \"_.@-'\"",
-    "A valid username must be provided" : "Трябва да въведете валидно потребителско.",
-    "Username contains whitespace at the beginning or at the end" : "Потребителското име започва или завършва с интервал.",
-    "Username must not consist of dots only" : "Името на потребител не трябва да се състои само от точки",
-    "Username is invalid because files already exist for this user" : "Името на потребител е невалидно, тъй като файловете вече съществуват за този потребител",
     "A valid password must be provided" : "Трябва да въведете валидна парола.",
-    "The username is already being used" : "Потребителското име е вече заето.",
-    "Could not create user" : "Неуспешно създаване на потребител",
-    "User disabled" : "Потребителят е деактивиран",
     "Login canceled by app" : "Вписването е отказано от приложението",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Приложението „%1$s“ не може да бъде инсталирано, защото следните зависимости не са изпълнени: %2$s",
     "a safe home for all your data" : "безопасен дом за всички ваши данни",
-    "File is currently busy, please try again later" : "Файлът в момента е зает, моля, опитайте отново по-късно",
-    "Cannot download file" : "Файлът не можа да бъде изтеглен",
     "Application is not enabled" : "Приложението не е включено",
     "Authentication error" : "Грешка при удостоверяването",
     "Token expired. Please reload page." : "Изтекла сесия. Моля, презареди страницата.",
@@ -214,36 +196,25 @@ OC.L10N.register(
     "Cannot write into \"config\" directory." : "Не може да се пише в \"config\" директория.",
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Това обикновено може да бъде оправено като, се даде достъп на уеб сървъра да записва в config директорията. Погледнете %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Но ако предпочитате да запазите файла config.php само за четене, задайте опцията \"config_is_read_only\" на true/вярно/ в него. Погледнете %s",
-    "Cannot write into \"apps\" directory." : "Не може да се пише в \"apps\" директория.",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Това обикновено може да бъде оправено като се даде достъп на уеб сървъра да записва в app директорията или като изключи приложението магазин за приложения в config файла.",
     "Cannot create \"data\" directory." : "Неможе да се създаде \"data\" директория с данни.",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Това обикновено може да бъде оправено като, се даде достъп на уеб сървъра да записва в основната директория. Погледнете %s",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Права обикновено могат да бъдат оправени когато се даде достъп на уеб сървъра да пише в основната директория. Погледнете %s.",
     "Your data directory is not writable." : "Вашата директория с данни не е записваема.",
-    "Setting locale to %s failed." : "Неуспешно задаване на езикова променлива %s.",
-    "Please install one of these locales on your system and restart your web server." : "Моля, инсталирайте една от тези езикови променливи на вашата система и си рестартирайте уеб сървъра.",
+    "Setting locale to %s failed." : "Неуспешно задаване на регион %s. ",
+    "Please install one of these locales on your system and restart your web server." : "Моля, задайте един от следните региони във Вашата система след което рестартирайте сървъра.",
     "PHP module %s not installed." : "PHP модулът %s не е инсталиран.",
     "Please ask your server administrator to install the module." : "Моля, помолете вашия администратор да инсталира модула.",
     "PHP setting \"%s\" is not set to \"%s\"." : "PHP настройка \"%s\" не е зададена на \"%s\".",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Регулирането на тази настройка в php.ini ще накара Nextcloud да работи отново",
-    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> е настроен на <code>%s</code> вместо очакваната стойност <code>0</code>.",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "За оправяне на този проблем, задайте <code>mbstring.func_overload</code> на <code>0</code> във вашият php.ini.",
-    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Нужно е поне libxml2 2.7.0. В момента са инсталирани %s.",
-    "To fix this issue update your libxml2 version and restart your web server." : "За да отстраните този проблем, актуализирайте версията на libxml2 и рестартирайте вашия уеб сървър.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP е настроен да премахва inline doc блокове. Това ще направи няколко основни приложения недостъпни.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Това може да се дължи на cache/accelerator като Zend OPache или eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP модулите са инсталирани, но все още се обявяват като липсващи?",
     "Please ask your server administrator to restart the web server." : "Моля, поискай от своя администратор да рестартира уеб сървъра.",
     "The required %s config variable is not configured in the config.php file." : "Необходимата %s конфигурационна променлива не е конфигурирана във файла config.php.",
     "Please ask your server administrator to check the Nextcloud configuration." : "Моля, помолете администратора на вашия сървър да провери конфигурацията на Nextcloud.",
-    "PostgreSQL >= 9 required." : "Нужно е PostgreSQL >= 9",
-    "Please upgrade your database version." : "Моля, надстройте версията на вашата база данни.",
-    "Your data directory is readable by other users." : "Вашата директория с данни може да се чете от други потребители.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Моля, променете правата за достъп на 0770, за да не може директорията да бъде видяна от други потребители.",
     "Your data directory must be an absolute path." : "Вашата директория с данни трябва да е абсолютен път.",
     "Check the value of \"datadirectory\" in your configuration." : "Проверете стойността на \"datadirectory\" във вашата конфигурация.",
     "Your data directory is invalid." : "Вашата директория с данни е невалидна.",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Уверете се, че има файл, наречен \".ocdata\" в корена на директорията с данни.",
     "Action \"%s\" not supported or implemented." : "Действието „%s“ не се поддържа или изпълнява.",
     "Authentication failed, wrong token or provider ID given" : "Неуспешно удостоверяване, даден е грешен токен или идентификатор на доставчика ",
     "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Липсват параметри, за завършване на заявката. Липсващи параметри: \"%s\"",
@@ -255,28 +226,20 @@ OC.L10N.register(
     "Storage connection error. %s" : "Грешка при свързването с хранилище. %s",
     "Storage is temporarily not available" : "Временно хранилището не е налично",
     "Storage connection timeout. %s" : "Време за изчакване при свързването с хранилище. %s",
-    "This can usually be fixed by giving the webserver write access to the config directory." : "Това обикновено може да бъде оправено като, се даде достъп на уеб сървъра да записва в config директорията.",
-    "%s enter the database username and name." : "%s въведете потребителско име и име за базата данни",
-    "%s enter the database username." : "%s въведете потребител за базата данни.",
-    "%s enter the database name." : "%s въведи име на базата данни.",
-    "%s you may not use dots in the database name" : "%s, не може да ползваш точки в името на базата данни.",
-    "Cannot read file" : "Не може да се прочете файл",
-    "Cannot write into \"config\" directory" : "Неуспешен опит за запис в \"config\" папката.",
-    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Това обикновено може да бъде оправено като, се даде достъп на уеб сървъра да записва в config директорията. Погледнете %s",
-    "Cannot write into \"apps\" directory" : "Писането в папка приложения не е възможно",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the App Store in the config file." : "Това обикновено може да бъде оправено като %s се даде достъп на уеб сървъра да записва в app директорията или като изключи магазина за приложения в config файла.",
-    "Cannot create \"data\" directory" : "Неуспешно създаване на \"data\" директория с данни",
-    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Това обикновено може да бъде оправено като, се даде достъп на уеб сървъра да записва в основната директория. Погледнете %s",
-    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Правата обикновено могат да бъдат оправени когато се даде достъп на уеб сървъра да пише в основната папка. Погледнете %s.",
-    "Setting locale to %s failed" : "Неуспешно задаване на %s като настройка език-държава.",
-    "Please install one of these locales on your system and restart your webserver." : "Моля, инсталирай едно от следните език-държава на сървъра и рестартирай уеб сървъра.",
-    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload е настроен на \"%s\" вместо очакваната стойност \"0\"",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "За оправяне на този проблем, задайте <code>mbstring.func_overload</code> на <code>0</code> във вашият php.ini",
-    "PostgreSQL >= 9 required" : "Изисква се PostgreSQL >= 9",
-    "Please upgrade your database version" : "Моля, обнови базата данни.",
-    "Your data directory is readable by other users" : "Вашата директория с данни може да се чете от други потребители",
-    "Your data directory must be an absolute path" : "Вашата директория с данни трябва да е абсолютен път",
-    "Check the value of \"datadirectory\" in your configuration" : "Проверете стойността на \"datadirectory\" във вашата конфигурация",
-    "Your data directory is invalid" : "Вашата директория с данни е невалидна"
+    "Images" : "Изображения",
+    "Question" : "Въпрос",
+    "Confirmation" : "Потвърждение",
+    "Optical character recognition" : "Оптично разпознаване на символи",
+    "Prompt" : "Подкана",
+    "Text" : "Текст",
+    "Summary" : "Резюме",
+    "Translate" : "Превод",
+    "Target language" : "Целеви език",
+    "Result" : "Резултат",
+    "Organisation" : "Организация",
+    "Cannot write into \"apps\" directory." : "Не може да се пише в \"apps\" директория.",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Това обикновено може да бъде оправено като се даде достъп на уеб сървъра да записва в app директорията или като изключи приложението магазин за приложения в config файла.",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> е настроен на <code>%s</code> вместо очакваната стойност <code>0</code>.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "За оправяне на този проблем, задайте <code>mbstring.func_overload</code> на <code>0</code> във вашият php.ini."
 },
 "nplurals=2; plural=(n != 1);");
