@@ -93,6 +93,8 @@ OC.L10N.register(
     "Destination does not exist" : "Placeringen findes ikke",
     "Destination is not creatable" : "Placeringen kan ikke oprettes",
     "Dot files are not allowed" : "Filer med punktummer er ikke tilladt",
+    "%1$s (renamed)" : "%1$s (omdøbt)",
+    "renamed file" : "omdøbt fil",
     "\"%1$s\" is a forbidden file or folder name." : "\" %1$s\" er et forbudt fil- eller mappenavn.",
     "\"%1$s\" is a forbidden prefix for file or folder names." : "\" %1$s\" er et forbudt præfiks for fil- eller mappenavne.",
     "\"%1$s\" is not allowed inside a file or folder name." : "\" %1$s\" er ikke tilladt inde i et fil- eller mappenavn.",
@@ -127,6 +129,8 @@ OC.L10N.register(
     "Settings" : "Indstillinger",
     "Log out" : "Log ud",
     "Accounts" : "Konti",
+    "Bluesky" : "Bluesky",
+    "View %s on Bluesky" : "Vis %s på Bluesky",
     "Email" : "E-mail",
     "Mail %s" : "Mail %s",
     "Fediverse" : "Fediverse",
@@ -142,7 +146,7 @@ OC.L10N.register(
     "About" : "Om",
     "Display name" : "Vist navn",
     "Headline" : "Overskrift",
-    "Organisation" : "Organisation",
+    "Organization" : "Organisation",
     "Role" : "Rolle",
     "Pronouns" : "Pronominer",
     "Unknown account" : "Ukendt konto",
@@ -156,7 +160,6 @@ OC.L10N.register(
     "Oracle connection could not be established" : "Oracle forbindelsen kunne ikke etableres",
     "Oracle Login and/or password not valid" : "Oracle login og / eller adgangskode ikke gyldig",
     "PostgreSQL Login and/or password not valid" : "PostgreSQL login og / eller adgangskode ikke gyldig",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X understøttes ikke, og %s vil ikke fungere korrekt på denne platform. Brug det på eget ansvar!",
     "For the best results, please consider using a GNU/Linux server instead." : "For de bedste resultater, overvej venligst at bruge en GNU/Linux-server i stedet.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Det ser ud til, at denne %s-instans kører på et 32-bit PHP-miljø, samt at open_basedir er blevet konfigureret gennem php.ini. Dette vil føre til problemer med filer som er større end 4GB, og frarådes kraftigt.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Fjern venligst indstillingen for open_basedir inde i din php.ini eller skift til 64-bit PHP.",
@@ -273,6 +276,7 @@ OC.L10N.register(
     "A valid Login must be provided" : "Et gyldigt login skal angives",
     "Login contains whitespace at the beginning or at the end" : "Login indeholder mellemrum i begyndelsen eller slutningen",
     "Login must not consist of dots only" : "Login må ikke kun bestå af prikker",
+    "Username is too long" : "Brugernavn er for langt",
     "Login is invalid because files already exist for this user" : "Login er ugyldigt, fordi filer allerede eksisterer for denne bruger",
     "Account disabled" : "Konto deaktiveret",
     "Login canceled by app" : "Login annulleret af app",
@@ -285,8 +289,6 @@ OC.L10N.register(
     "Cannot write into \"config\" directory." : "Kan ikke skrive til mappen \"config\".",
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Dette kan som regel ordnes ved at give webserveren skrive adgang til config mappen. Se %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Men hvis du foretrækker at bibeholde config.php skrivebeskyttet, så sæt parameter \"config_is_read_only\" til true i filen. Se %s",
-    "Cannot write into \"apps\" directory." : "Kan ikke skrive til mappen \"apps\".",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Dette kan som regel rettes ved at give webserveren skriveadgang til apps-mappen eller slå appstore fra i config-filen.",
     "Cannot create \"data\" directory." : "Kan ikke oprette mappen \"data\".",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Dette kan som regel ordnes ved at give webserveren skrive adgang til rod mappen. Se %s",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Rettigheder kan som regel rettes ved at give webserveren skriveadgang til rodmappen. Se %s.",
@@ -297,8 +299,6 @@ OC.L10N.register(
     "Please ask your server administrator to install the module." : "Du bedes anmode din serveradministrator om at installere modulet.",
     "PHP setting \"%s\" is not set to \"%s\"." : "PHP-indstillingen \"%s\" er ikke angivet til \"%s\".",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Ændring af denne indstilling i php.ini vil tillade Nextcloud at køre igen",
-    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> er angivet til <code>%s</code>, i stedet for den forventede værdi <code>0</code>",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "For at rette dette problem, sæt <code>mbstring.func_overload</code> til <code>0</code> i din php.ini.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP er tilsyneladende sat op til at fjerne indlejrede doc-blokke. Dette vil gøre adskillige kerneprogrammer utilgængelige.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dette er sansynligvis forårsaget af et accelerator eller cache som Zend OPcache eller eAccelerator",
     "PHP modules have been installed, but they are still listed as missing?" : "Der er installeret PHP-moduler, men de fremstår stadig som fraværende?",
@@ -323,25 +323,48 @@ OC.L10N.register(
     "Storage is temporarily not available" : "Lagerplads er midlertidigt ikke tilgængeligt",
     "Storage connection timeout. %s" : "Lageret svarer ikke. %s",
     "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "For at tillade at denne kontrol køres så skal du sikre dig at din webserver kan forbinde til sig selv. Derfor skal den kunne opløse og forbinde til mindst en af dets `trusted_domains` eller `overwrite.cli.url`. Denne fejl kan være resultatet af en server-side DNS mismatch eller udadgående firewall regel.",
+    "Analyze images" : "Analysér billeder",
+    "Ask a question about the given images." : "Stil et spørgsmål om de givne billeder.",
+    "Images" : "Billeder",
+    "Images to ask a question about" : "Billeder til at stille et spørgsmål om",
+    "Question" : "Spørgsmål",
+    "What to ask about the images." : "Hvad kan du spørge om i forhold til billederne.",
+    "Generated response" : "Genereret respons",
+    "The answer to the question" : "Svaret på sprøgsmålet",
+    "Audio chat" : "Lydchat",
+    "Voice chat with the assistant" : "Stemmechat med assistenten",
+    "System prompt" : "Systemprompt",
+    "Define rules and assumptions that the assistant should follow during the conversation." : "Definer regler og antagelser, som assistenten skal følge under samtalen.",
+    "Chat voice message" : "Chatstemme beskeder",
+    "Describe a task that you want the assistant to do or ask a question." : "Beskriv en opgave som du ønsker at assistenten skal lave eller stil et spørgsmål.",
+    "Chat history" : "Chathistorik",
+    "The history of chat messages before the current message, starting with a message by the user." : "Historikken for chatbeskeder inden den aktuelle besked, startende med en besked fra brugeren.",
+    "Input transcript" : "Input transskribering",
+    "Transcription of the audio input" : "Transskription af lydinput",
+    "Response voice message" : "Respons lydbesked",
+    "The generated voice response as part of the conversation" : "Den genererede lydrespons som del af samtalen",
+    "Output transcript" : "Output transskription",
+    "Transcription of the audio output" : "Transskriptionen af lydoutputtet ",
     "Transcribe audio" : "Transskriber lyd",
     "Transcribe the things said in an audio" : "Transskriber de ting, der siges i en lydfil",
     "Audio input" : "Lydinput",
     "The audio to transcribe" : "Lyden der skal transskriberes",
     "Transcription" : "Transskription",
     "The transcribed text" : "Den transskriberede tekst",
-    "Chat with an agent" : "Chat med en agent",
-    "Chat message" : "Chatbeskeder",
-    "A chat message to send to the agent." : "En chatbesked til agenten.",
+    "Chat by voice with an agent" : "Chat med en agent med stemmen",
+    "Describe a task that you want the agent to do or ask a question." : "Beskriv en opgave som du ønsker at agenten skal løse eller stil et spørgsmål.",
     "Confirmation" : "Bekræftelse",
     "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "Om tidligere forespurgte handlinger skal bekræftes: 0 for nægtelse og 1 for bekræftelse.",
     "Conversation token" : "Samtaletoken",
     "A token representing the conversation." : "Et token, som repræsenterer samtalen.",
-    "Generated response" : "Genereret respons",
-    "The response from the chat model." : "Svaret fra chatmodellen.",
     "The new conversation token" : "Det nye samtaletoken",
     "Send this along with the next interaction." : "Send dette sammen med den næste interaktion.",
     "Requested actions by the agent" : "Krævede handlinger af agenten",
     "Actions that the agent would like to carry out in JSON format." : "Handlinger, som agenten gerne vil udføre i JSON-format.",
+    "Chat with an agent" : "Chat med en agent",
+    "Chat message" : "Chatbeskeder",
+    "A chat message to send to the agent." : "En chatbesked til agenten.",
+    "The response from the chat model." : "Svaret fra chatmodellen.",
     "Context write" : "Kontekstskrivning",
     "Writes text in a given style based on the provided source material." : "Skriver tekst i en given stil baseret på det medfølgende kildemateriale.",
     "Writing style" : "Skrivestil",
@@ -363,6 +386,11 @@ OC.L10N.register(
     "How many images to generate" : "Hvor mange billeder skal genereres",
     "Output images" : "Output billeder",
     "The generated images" : "De genererede billeder",
+    "Generate speech" : "Generér tale",
+    "Generate speech from a transcript" : "Generér tale ud fra en transskription",
+    "Write transcript that you want the assistant to generate speech from" : "Skriv transskribering som du ønsker at assistenten skal generere tale ud fra ",
+    "Output speech" : "Output tale",
+    "The generated speech" : "Den genererede tale",
     "Free text to text prompt" : "Fritekst til tekstprompt",
     "Runs an arbitrary prompt through a language model that returns a reply" : "Kører en vilkårlig prompt gennem en sprogmodel, der returnerer et svar",
     "Describe a task that you want the assistant to do or ask a question" : "Beskriv en opgave, som du ønsker at assistenten udføre eller stil et spørgsmål",
@@ -376,9 +404,6 @@ OC.L10N.register(
     "The rewritten text in the desired tone, written by the assistant:" : "Den omskrevne tekst i den ønskede tone, skrevet af assistenten:",
     "Chat" : "cHAT",
     "Chat with the assistant" : "Chat med assistent",
-    "System prompt" : "Systemprompt",
-    "Define rules and assumptions that the assistant should follow during the conversation." : "Definer regler og antagelser, som assistenten skal følge under samtalen.",
-    "Chat history" : "Chathistorik",
     "The history of chat messages before the current message, starting with a message by the user" : "Historikken for chatbeskeder før den aktuelle besked, startende med en besked fra brugeren",
     "Response message" : "Svarmeddelelse",
     "The generated response as part of the conversation" : "Det genererede svar som en del af samtalen",
@@ -442,20 +467,12 @@ OC.L10N.register(
     "Generate headline" : "Generer overskrift",
     "Summarizes text by reducing its length without losing key information." : "Opsummerer tekst ved at reducere dens længde uden at miste nøgleinformation.",
     "Extracts topics from a text and outputs them separated by commas." : "Uddrager emner fra en tekst og skriver dem adskilt af kommaer.",
-    "Education Edition" : "Uddanelses Version",
-    "File name is a reserved word" : "Filnavnet er et reserveret ord",
-    "File name contains at least one invalid character" : "Filnavnet indeholder mindst et ugyldigt tegn",
-    "File name is too long" : "Filnavnet er for langt",
-    "Users" : "Brugere",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s delte »%2$s« med dig og vil gerne tilføje:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s delte »%2$s« med dig og vil gerne tilføje",
-    "»%s« added a note to a file shared with you" : "»%s« tilføjede en note til en fil delt med dig",
-    "Open »%s«" : "Åbn »%s«",
-    "%1$s shared »%2$s« with you" : "%1$s delte »%2$s« med dig",
-    "%1$s shared »%2$s« with you." : "%1$s delte »%2$s« med dig",
-    "Click the button below to open it." : "Klik på knappen nedenunder for at åbne.",
-    "File is currently busy, please try again later" : "Filen er i øjeblikket optaget - forsøg igen senere",
-    "Cannot download file" : "Kan ikke downloade filen",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Du bedes sikre at filen \".ocdata\" befinder sig i roden af din datamappe."
+    "Organisation" : "Organisation",
+    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X understøttes ikke, og %s vil ikke fungere korrekt på denne platform. Brug det på eget ansvar!",
+    "Login is too long" : "Login er for lang",
+    "Cannot write into \"apps\" directory." : "Kan ikke skrive til mappen \"apps\".",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Dette kan som regel rettes ved at give webserveren skriveadgang til apps-mappen eller slå appstore fra i config-filen.",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> er angivet til <code>%s</code>, i stedet for den forventede værdi <code>0</code>",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "For at rette dette problem, sæt <code>mbstring.func_overload</code> til <code>0</code> i din php.ini."
 },
 "nplurals=2; plural=(n != 1);");
