@@ -93,6 +93,8 @@ OC.L10N.register(
     "Destination does not exist" : "Non existe ese destino",
     "Destination is not creatable" : "Non é posíbel crear o destino",
     "Dot files are not allowed" : "Non se admiten os ficheiros con punto",
+    "%1$s (renamed)" : "%1$s (renomeado)",
+    "renamed file" : "ficheiro renomeado",
     "\"%1$s\" is a forbidden file or folder name." : "«%1$s» é un nome de ficheiro ou cartafol prohibido.",
     "\"%1$s\" is a forbidden prefix for file or folder names." : "«%1$s» é un prefixo prohibido para os nomes de ficheiros ou cartafoles.",
     "\"%1$s\" is not allowed inside a file or folder name." : "«%1$s» non está permitido nun nome de ficheiro ou cartafol.",
@@ -112,7 +114,7 @@ OC.L10N.register(
     "Moving a storage (%s) into another storage (%s) is not allowed" : "Non está permitido mover un almacenamento (%s) cara a outro almacenamento (%s)",
     "Path contains invalid segments" : "A ruta contén segmentos non válidos",
     "Filename is a reserved word" : "O nome de ficheiro é unha palabra reservada",
-    "Filename contains at least one invalid character" : "O nome de ficheiro contén algún carácter incorrecto",
+    "Filename contains at least one invalid character" : "O nome de ficheiro contén algún carácter non aceptado",
     "Filename is too long" : "O nome de ficheiro é longo de máis",
     "Empty filename is not allowed" : "Non está permitido deixar baleiro o nome de ficheiro",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "Non é posíbel instalar a aplicación «%s» por mor de non poder ler o ficheiro appinfo.",
@@ -127,6 +129,8 @@ OC.L10N.register(
     "Settings" : "Axustes",
     "Log out" : "Saír",
     "Accounts" : "Contas",
+    "Bluesky" : "Bluesky",
+    "View %s on Bluesky" : "Ver %s en Bluesky",
     "Email" : "Correo-e",
     "Mail %s" : "Correo %s",
     "Fediverse" : "Fediverso",
@@ -142,7 +146,7 @@ OC.L10N.register(
     "About" : "Sobre",
     "Display name" : "Nome para amosar",
     "Headline" : "Titular",
-    "Organisation" : "Organización",
+    "Organization" : "Organización",
     "Role" : "Cargo",
     "Pronouns" : "Pronomes",
     "Unknown account" : "Conta descoñecida",
@@ -156,7 +160,6 @@ OC.L10N.register(
     "Oracle connection could not be established" : "Non foi posíbel estabelecer a conexión con Oracle",
     "Oracle Login and/or password not valid" : "O acceso de Oracle e/ou o contrasinal non son válidos",
     "PostgreSQL Login and/or password not valid" : "O acceso de PostgreSQL e/ou o contrasinal non son válidos",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X non é compatíbel e %s non funcionará correctamente nesta plataforma. Utilíceo baixo a súa responsabilidade!",
     "For the best results, please consider using a GNU/Linux server instead." : "Para obter mellores resultados, considere o emprego dun servidor GNU/Linux en troques.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Semella que esta instancia de %s está a funcionar nun contorno PHP de 32 bisst e o open_basedir foi configurado no php.ini. Isto provocará problemas con ficheiros maiores de 4 GB e está absolutamente desaconsellado.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Retire o axuste de open_basedir no php.ini ou cambie a PHP de 64 bits.",
@@ -184,7 +187,7 @@ OC.L10N.register(
     "Shared path must be set" : "Debe estar definida a ruta compartida",
     "Shared path must be either a file or a folder" : "A ruta compartida debe ser a un ficheiro ou un cartafol",
     "You cannot share your root folder" : "Non pode compartir o seu cartafol raíz",
-    "You are not allowed to share %s" : "Non ten permiso para compartir %s",
+    "You are not allowed to share %s" : "Vde. non ten permiso para compartir %s",
     "Valid permissions are required for sharing" : "Precisanse permisos válidos para compartir",
     "File shares cannot have create or delete permissions" : "As comparticións de ficheiros non poden crear ou eliminar permisos",
     "Cannot increase permissions of %s" : "Non é posíbel incrementar os permisos de %s",
@@ -201,7 +204,7 @@ OC.L10N.register(
     "Path is already shared with this group" : "A ruta xa está compartida con este grupo",
     "Link sharing is not allowed" : "Non se permite compartir ligazóns",
     "Public upload is not allowed" : "Non se permite o envío público",
-    "Path contains files shared with you" : "A ruta contén ficheiros compartidos con Vde.",
+    "You cannot share a folder that contains other shares" : "Non pode compartir un cartafol que conteña outras comparticións",
     "Sharing is disabled" : "A compartición está desactivada",
     "Sharing is disabled for you" : "A compartición está desactivada para Vde.",
     "Cannot share with the share owner" : "Non é posíbel compartir co propietario do compartido",
@@ -212,7 +215,7 @@ OC.L10N.register(
     "Cannot enable sending the password by Talk without setting a new password" : "Non é posíbel activar o envío do contrasinal mediante Parladoiro sen definir un novo contrasinal",
     "Cannot disable sending the password by Talk without setting a new password" : "Non é posíbel desactivar o envío do contrasinal medainte sen definir un novo contrasinal",
     "Share provider does not support accepting" : "O provedor de comparticións non admite a aceptación",
-    "Cannot change target of link share" : "Non é posíbel cambiar o destino da ligazón compartida",
+    "Cannot change target of link share" : "Non é posíbel cambiar o destino da ligazón para compartir",
     "Invalid share recipient" : "Destinatario de compartición incorrecto",
     "Group \"%s\" does not exist" : "O grupo «%s» non existe",
     "The requested share does not exist anymore" : "A compartición solicitada xa non existe",
@@ -273,6 +276,7 @@ OC.L10N.register(
     "A valid Login must be provided" : "Ten que fornecer un acceso válido",
     "Login contains whitespace at the beginning or at the end" : "O acceso contén espazos en branco ao comezo ou ao final",
     "Login must not consist of dots only" : "O acceso non debe estar composto só por puntos",
+    "Username is too long" : "O nome de usuario é longo de máis",
     "Login is invalid because files already exist for this user" : "O acceso non é válido porque xa existen ficheiros para este usuario",
     "Account disabled" : "Conta desactivada",
     "Login canceled by app" : "Acceso cancelado pola aplicación",
@@ -285,8 +289,6 @@ OC.L10N.register(
     "Cannot write into \"config\" directory." : "Non é posíbel escribir no directorio «config».",
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Isto, normalmente, pódese solucionar dándolle ao servidor web acceso de escritura ao directorio de configuración. Véxa %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Ou, se prefire conservar o ficheiro «config.php» como de só lectura, marque a opción «config_is_read_only» como «true» nel. Vexa %s",
-    "Cannot write into \"apps\" directory." : "Non é posíbel escribir no directorio «apps».",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Isto, normalmente, pódese solucionar dándolle ao servidor web acceso de escritura ao directorio de aplicacións ou desactivando a tenda de aplicacións no ficheiro de configuración.",
     "Cannot create \"data\" directory." : "Non é posíbel crear o directorio «data».",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Isto, normalmente, pódese solucionar dándolle ao servidor web acceso de escritura ao directorio raíz. Véxa %s",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Os permisos normalmente pódense corrixir dándolle ao servidor web acceso de escritura ao directorio raíz. Véxa %s.",
@@ -297,8 +299,6 @@ OC.L10N.register(
     "Please ask your server administrator to install the module." : "Pídalle á administración do seu servidor que instale o módulo.",
     "PHP setting \"%s\" is not set to \"%s\"." : "O axuste de PHP «%s» non está estabelecido a «%s».",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Cambiar este axuste no ficheiro php.ini fará que Nextcloud funcione de novo",
-    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> está estabelecido en <code>%s</code> en troques do valor agardado <code>0</code>.",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Para solucionar este problema, estabeleza <code>mbstring.func_overload</code> en <code>0</code> no seu php.ini.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Semella que PHP foi configurado para quitar bloques de documentos en liña. Isto fará que varios aplicativos sexan inaccesíbeis. ",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Isto probabelmente se debe unha memoria tobo/acelerador como Zend OPcache ou eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "Instaláronse os módulos de PHP, mais aínda aparecen listados como perdidos?",
@@ -323,26 +323,48 @@ OC.L10N.register(
     "Storage is temporarily not available" : "O almacenamento non está dispoñíbel temporalmente",
     "Storage connection timeout. %s" : "Esgotouse o tempo de conexión co almacenamento. %s",
     "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Para permitir que esta comprobación se execute, debe asegurarse de que o seu servidor web poida conectarse a si mesmo. Por tanto, debe ser quen de resolver e conectarse a polo menos un dos seus «trusted_domains» ou ao «overwrite.cli.url». Este fallo pode ser o resultado dunha falta de coincidencia de DNS do servidor ou dunha regra da devasa de saída.",
+    "Analyze images" : "Analizar as imaxes",
+    "Ask a question about the given images." : "Formule unha pregunta sobre as imaxes indicadas.",
+    "Images" : "Imaxes",
+    "Images to ask a question about" : "Imaxes sobre as que facer unha pregunta",
+    "Question" : "Pregunta",
+    "What to ask about the images." : "Que preguntar sobre as imaxes.",
+    "Generated response" : "Resposta xerada",
+    "The answer to the question" : "A resposta á pregunta",
+    "Audio chat" : "Parola de son",
+    "Voice chat with the assistant" : "Parola de voz co asistente",
+    "System prompt" : "Indicador do sistema",
+    "Define rules and assumptions that the assistant should follow during the conversation." : "Definir regras e supostos que o asistente debe seguir durante a conversa.",
+    "Chat voice message" : "Mensaxe de voz de parola",
+    "Describe a task that you want the assistant to do or ask a question." : "Describa unha tarefa que quere que realice o asistente ou formule unha pregunta.",
+    "Chat history" : "Historial de parola",
+    "The history of chat messages before the current message, starting with a message by the user." : "O historial das mensaxes de parola antes da mensaxe actual, comezando cunha mensaxe do usuario.",
+    "Input transcript" : "Transcrición de entrada",
+    "Transcription of the audio input" : "Transcrición da entrada de son",
+    "Response voice message" : "Mensaxe de voz de resposta",
+    "The generated voice response as part of the conversation" : "A resposta de voz xerada como parte da conversa",
+    "Output transcript" : "Transcrición de saída",
+    "Transcription of the audio output" : "Transcrición da saída de son",
     "Transcribe audio" : "Transcribir son",
     "Transcribe the things said in an audio" : "Transcribir as cousas ditas nun ficheiro de son",
     "Audio input" : "Entrada de son",
     "The audio to transcribe" : "O audio para transcribir",
     "Transcription" : "Transcrición",
     "The transcribed text" : "O texto transcrito",
-    "ContextAgent" : "Axente de contexto",
-    "Chat with an agent" : "Parolar cun axente",
-    "Chat message" : "Mensaxe de parola",
-    "A chat message to send to the agent." : "Unha mensaxe de parola para enviar ao axente.",
+    "Chat by voice with an agent" : "Parola por voz cun axente",
+    "Describe a task that you want the agent to do or ask a question." : "Describa unha tarefa que quere que realice o axente ou formule unha pregunta.",
     "Confirmation" : "Confirmación",
     "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "Indica se hai que confirmar as accións solicitadas anteriormente: 0 para a denegación e 1 para a confirmación.",
     "Conversation token" : "Testemuño de conversa",
     "A token representing the conversation." : "Un testemuño que representa a conversa.",
-    "Generated response" : "Resposta xerada",
-    "The response from the chat model." : "A resposta do modelo de parola.",
     "The new conversation token" : "O novo testemuño de conversa",
     "Send this along with the next interaction." : "Envía isto xunto coa seguinte interacción.",
     "Requested actions by the agent" : "Accións solicitadas polo axente",
     "Actions that the agent would like to carry out in JSON format." : "Accións que o axente quere levar a cabo en formato JSON.",
+    "Chat with an agent" : "Parolar cun axente",
+    "Chat message" : "Mensaxe de parola",
+    "A chat message to send to the agent." : "Unha mensaxe de parola para enviar ao axente.",
+    "The response from the chat model." : "A resposta do modelo de parola.",
     "Context write" : "Redacción por contexto",
     "Writes text in a given style based on the provided source material." : "Escribe texto nun estilo determinado baseándose no material orixinal fornecido.",
     "Writing style" : "Estilo de escritura",
@@ -356,6 +378,12 @@ OC.L10N.register(
     "The text to generate an emoji for" : "O texto para xerar un «emoji»",
     "Generated emoji" : "«Emoji» xerado",
     "The generated emoji based on the input text" : "O «emoji» xerado en función do texto introducido",
+    "Optical character recognition" : "Recoñecemento óptico de caracteres",
+    "Extract text from files like images or PDFs" : "Extraer texto de ficheiros como imaxes ou PDF",
+    "Input files" : "Ficheiros de entrada",
+    "The files to extract text from" : "Os ficheiros dos que extraer o texto",
+    "Output texts" : "Textos de saída",
+    "The texts that were extracted from the files" : "Os textos que foron extraídos dos ficheiros",
     "Generate image" : "Xerar imaxe",
     "Generate an image from a text prompt" : "Xerar unha imaxe a partir dunha indicación de texto",
     "Prompt" : "Indicación",
@@ -364,6 +392,11 @@ OC.L10N.register(
     "How many images to generate" : "Cantas imaxes xerar",
     "Output images" : "Imaxes de saída",
     "The generated images" : "As imaxes xeradas",
+    "Generate speech" : "Xerar parrafeo",
+    "Generate speech from a transcript" : "Xerar parrafeo a partir dunha transcrición",
+    "Write transcript that you want the assistant to generate speech from" : "Escriba a transcrición da que quere que o asistente xere o parrafeo",
+    "Output speech" : "Parrafeo de saída",
+    "The generated speech" : "O parrafeo xerado",
     "Free text to text prompt" : "Texto libre para indicación de texto",
     "Runs an arbitrary prompt through a language model that returns a reply" : "Procesa unha indicación arbitraria a través dun modelo de linguaxe que devolve unha resposta",
     "Describe a task that you want the assistant to do or ask a question" : "Describa unha tarefa que quere que realice o asistente ou formule unha pregunta",
@@ -377,9 +410,6 @@ OC.L10N.register(
     "The rewritten text in the desired tone, written by the assistant:" : "O texto reformulado no ton desexado, escrito polo asistente",
     "Chat" : "Parola",
     "Chat with the assistant" : "Parola co asistente",
-    "System prompt" : "Indicador do sistema",
-    "Define rules and assumptions that the assistant should follow during the conversation." : "Definir regras e supostos que o asistente debe seguir durante a conversa.",
-    "Chat history" : "Historial de parola",
     "The history of chat messages before the current message, starting with a message by the user" : "O historial das mensaxes de parola antes da mensaxe actual, comezando cunha mensaxe do usuario",
     "Response message" : "Mensaxe de resposta",
     "The generated response as part of the conversation" : "A resposta xerada como parte da conversa",
@@ -443,20 +473,12 @@ OC.L10N.register(
     "Generate headline" : "Xerar titular",
     "Summarizes text by reducing its length without losing key information." : "Resume o texto reducindo a súa lonxitude sen perder a información clave.",
     "Extracts topics from a text and outputs them separated by commas." : "Extrae temas dun texto e amósaos separados por comas.",
-    "Education Edition" : "Edición para educación",
-    "File name is a reserved word" : "O nome de ficheiro é unha palabra reservada",
-    "File name contains at least one invalid character" : "O nome de ficheiro contén algún carácter incorrecto",
-    "File name is too long" : "O nome de ficheiro é longo de máis",
-    "Users" : "Usuarios",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s compartiu «%2$s» con Vde. e quere engadir:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s compartiu «%2$s» con Vde. e quere engadir",
-    "»%s« added a note to a file shared with you" : "«%s» engadiu unha nota a un ficheiro compartido con Vde.",
-    "Open »%s«" : "Abrir «%s»",
-    "%1$s shared »%2$s« with you" : "%1$s compartiu «%2$s» con Vde.",
-    "%1$s shared »%2$s« with you." : "%1$s compartiu «%2$s» con Vde.",
-    "Click the button below to open it." : "Prema no botón de embaixo para abrilo.",
-    "File is currently busy, please try again later" : "O ficheiro está ocupado neste momento, ténteo máis adiante.",
-    "Cannot download file" : "Non é posíbel descargar o ficheiro",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Asegúrese de que existe un ficheiro chamado «.ocdata» na raíz do directorio de datos."
+    "Organisation" : "Organización",
+    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X non é compatíbel e %s non funcionará correctamente nesta plataforma. Utilíceo baixo a súa responsabilidade!",
+    "Login is too long" : "O acceso é longo de máis",
+    "Cannot write into \"apps\" directory." : "Non é posíbel escribir no directorio «apps».",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Isto, normalmente, pódese solucionar dándolle ao servidor web acceso de escritura ao directorio de aplicacións ou desactivando a tenda de aplicacións no ficheiro de configuración.",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> está estabelecido en <code>%s</code> en troques do valor agardado <code>0</code>.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Para solucionar este problema, estabeleza <code>mbstring.func_overload</code> en <code>0</code> no seu php.ini."
 },
 "nplurals=2; plural=(n != 1);");
