@@ -99,7 +99,6 @@ OC.L10N.register(
     "Profile picture" : "Profilna slika",
     "About" : "Informacije",
     "Headline" : "Naslov",
-    "Organisation" : "Organizacija",
     "Role" : "Uloga",
     "Additional settings" : "Dodatne postavke",
     "You need to enter details of an existing account." : "Trebate unijeti informacije o postojećem računu.",
@@ -196,23 +195,12 @@ OC.L10N.register(
     "Storage connection error. %s" : "Pogreška veze pohrane. %s",
     "Storage is temporarily not available" : "Pohrana privremeno nije dostupna",
     "Storage connection timeout. %s" : "Istek veze pohrane. %s",
+    "Images" : "Slike",
+    "Optical character recognition" : "Optičko prepoznavanje znakova",
     "Text" : "Tekst",
     "Summary" : "Sažetak",
     "Translate" : "Prevedi",
     "Result" : "Rezultat",
-    "Education Edition" : "Obrazovno izdanje",
-    "File name is a reserved word" : "Naziv datoteke je rezervirana riječ",
-    "File name contains at least one invalid character" : "Naziv datoteke sadrži barem jedan nevažeći znak",
-    "File name is too long" : "Naziv datoteke je predugačak",
-    "Users" : "Korisnici",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s dijeli »%2$s« s vama i želi dodati:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s dijeli »%2$s« s vama i želi dodati",
-    "»%s« added a note to a file shared with you" : "»%s« je dodao bilješku datoteci koju dijeli s vama",
-    "Open »%s«" : "Otvori »%s«",
-    "%1$s shared »%2$s« with you" : "%1$s dijeli »%2$s« s vama",
-    "%1$s shared »%2$s« with you." : "%1$s dijeli »%2$s« s vama.",
-    "Click the button below to open it." : "Kliknite gumb u nastavku za otvaranje.",
-    "File is currently busy, please try again later" : "Datoteka je trenutno zauzeta, pokušajte ponovo kasnije",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Provjerite postoji li datoteka pod nazivom „.ocdata” u korijenu podatkovnog direktorija."
+    "Organisation" : "Organizacija"
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
