@@ -232,12 +232,17 @@ OC.L10N.register(
     "Images" : "이미지",
     "Question" : "질문",
     "Generated response" : "생성된 응답",
+    "Transcribe audio" : "받아적기",
     "Audio input" : "음성 입력",
     "Confirmation" : "확인",
-    "Context write" : "컨텍스트 쓰기",
+    "Context write" : "글 쓰기",
     "Writes text in a given style based on the provided source material." : "제공된 소스 자료를 기반으로 특정 스타일로 텍스트를 작성합니다.",
-    "Writing style" : "작문 스타일",
+    "Writing style" : "쓰기 스타일",
+    "Demonstrate a writing style that you would like to immitate" : "흉내내고 싶은 쓰기 스타일 보여주기",
     "Source material" : "소스 자료",
+    "The content that would like to be rewritten in the new writing style" : "새로운 쓰기 스타일로 다시 쓰고 싶은 내용",
+    "Generated text" : "생성된 텍스트",
+    "Optical character recognition" : "광학 문자 인식 (OCR)",
     "Generate image" : "이미지 생성",
     "Prompt" : "프롬프트",
     "Change Tone" : "톤을 변경",
@@ -249,16 +254,32 @@ OC.L10N.register(
     "Generates a possible headline for a text." : "내용에 대한 헤드라인을 생성하십시오.",
     "Text" : "텍스트",
     "Summarize" : "요약",
+    "Summarizes a text" : "텍스트 요약",
+    "The original text to summarize" : "요약할 원문",
     "Summary" : "요약",
+    "The generated summary" : "생성된 요약",
     "Extract topics" : "주제 추출",
-    "Translate" : "번역:",
+    "Extracts topics from a text and outputs them separated by commas" : "텍스트에서 주제를 추출하고 쉼표로 구분하여 출력",
+    "The original text to extract topics from" : "주제를 추출할 원문",
+    "Topics" : "주제",
+    "The list of extracted topics" : "추출된 주제 목록",
+    "Translate" : "번역",
+    "Translate text from one language to another" : "다른 언어로 텍스트 번역",
+    "Origin text" : "원문",
+    "The text to translate" : "번역할 텍스트",
+    "Origin language" : "원래 언어",
+    "The language of the origin text" : "원문의 언어",
+    "Target language" : "목표 언어",
+    "The desired language to translate the origin text in" : "원문을 번역하고 싶은 언어",
     "Result" : "결과",
+    "The translated text" : "번역된 텍스트",
+    "Free prompt" : "자유로운 프롬프트",
+    "Runs an arbitrary prompt through the language model." : "언어모델을 통한 임의의 프롬프트 실행",
     "Generate headline" : "헤드라인 생성",
     "Summarizes text by reducing its length without losing key information." : "중요 정보로 내용을 축약하십시오.",
     "Extracts topics from a text and outputs them separated by commas." : "내용에서 주요 주제를 추출하고 쉼표로 이를 구분하십시오.",
     "Organisation" : "조직",
-    "File is currently busy, please try again later" : "파일이 현재 사용 중, 나중에 다시 시도하십시오",
-    "Cannot download file" : "파일을 다운로드할 수 없음",
+    "Login is too long" : "로그인이 너무 김",
     "Cannot write into \"apps\" directory." : "\"apps\" 디렉터리에 기록할 수 없습니다",
     "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "apps 디렉토리에 웹 서버의 쓰기 권한을 부여하거나 설정 파일에서 앱 스토어를 비활성화하면 해결됩니다.",
     "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "현재 <code>mbstring.func_overload</code>가 <code>%s</code>(으)로 설정되어 있으나, 올바른 값은 <code>0</code>입니다.",
