@@ -5,10 +5,10 @@ OC.L10N.register(
     "Unknown filetype" : "د فایل ډول نامعلوم دی",
     "Invalid image" : "انځور سم نه دی",
     "Files" : "فایلونه",
-    "Help" : "مرسته",
     "Apps" : "اپلېکشنونه",
     "Settings" : "سمونې",
-    "Users" : "کارنان",
-    "Storage is temporarily not available" : "ذخیره د لنډې مودې لپاره نشته"
+    "Accounts" : "Accounts",
+    "Storage is temporarily not available" : "ذخیره د لنډې مودې لپاره نشته",
+    "Images" : "سیبشسیب"
 },
 "nplurals=2; plural=(n != 1);");
