@@ -73,15 +73,15 @@ OC.L10N.register(
     "next month" : "Mês que vem",
     "last month" : "último mês",
     "_in %n month_::_in %n months_" : ["em %n mês","em %n meses","em %n meses"],
-    "_%n month ago_::_%n months ago_" : ["há %n mês atrás","há %n meses","há %n meses"],
+    "_%n month ago_::_%n months ago_" : ["%n mês atrás","%n meses atrás","%n meses atrás"],
     "next year" : "próximo ano",
     "last year" : "último ano",
     "_in %n year_::_in %n years_" : ["em %n ano","em %n anos","em %n anos"],
     "_%n year ago_::_%n years ago_" : ["%n ano atrás","%n anos atrás","%n anos atrás"],
     "_in %n hour_::_in %n hours_" : ["em %n hora","em %n horas","em %n horas"],
-    "_%n hour ago_::_%n hours ago_" : ["há %n hora atrás","há %n horas","há %n horas"],
+    "_%n hour ago_::_%n hours ago_" : ["%n hora atrás","%n horas atrás","%n horas atrás"],
     "_in %n minute_::_in %n minutes_" : ["em %n minuto","em %n minutos","em %n minutos"],
-    "_%n minute ago_::_%n minutes ago_" : ["há %n minuto atrás","há %n minutos","há %n minutos"],
+    "_%n minute ago_::_%n minutes ago_" : ["%n minuto atrás","%n minutos atrás","%n minutos atrás"],
     "in a few seconds" : "Em alguns segundos",
     "seconds ago" : "segundos atrás",
     "Empty file" : "Arquivo vazio",
@@ -93,6 +93,8 @@ OC.L10N.register(
     "Destination does not exist" : "Destino não existe",
     "Destination is not creatable" : "Destino não pode ser criado",
     "Dot files are not allowed" : "Arquivos Dot não são permitidos",
+    "%1$s (renamed)" : "%1$s (renomeado)",
+    "renamed file" : "arquivo renomeado",
     "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" é um nome de arquivo ou pasta proibido.",
     "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\" é um prefixo proibido para nomes de arquivos ou pastas.",
     "\"%1$s\" is not allowed inside a file or folder name." : "\"%1$s\" não é permitido dentro de um nome de arquivo ou pasta.",
@@ -127,6 +129,8 @@ OC.L10N.register(
     "Settings" : "Configurações",
     "Log out" : "Sair",
     "Accounts" : "Contas",
+    "Bluesky" : "Bluesky",
+    "View %s on Bluesky" : "Ver %s no Bluesky",
     "Email" : "E-mail",
     "Mail %s" : "Enviar e-mail para %s",
     "Fediverse" : "Fediverso",
@@ -141,8 +145,8 @@ OC.L10N.register(
     "Profile picture" : "Foto do perfil",
     "About" : "Sobre",
     "Display name" : "Nome de exibição",
-    "Headline" : "Título ",
-    "Organisation" : "Organização",
+    "Headline" : "Título",
+    "Organization" : "Organização",
     "Role" : "Função",
     "Pronouns" : "Pronomes",
     "Unknown account" : "Conta desconhecida",
@@ -156,7 +160,6 @@ OC.L10N.register(
     "Oracle connection could not be established" : "Conexão Oracle não pôde ser estabelecida",
     "Oracle Login and/or password not valid" : "Login e/ou senha do Oracle inválidos",
     "PostgreSQL Login and/or password not valid" : "Login e/ou senha do PostgreSQL inválidos",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "O Mac OS X não é compatível e %s não funcionará corretamente nessa plataforma. Use-o por sua própria conta e risco!",
     "For the best results, please consider using a GNU/Linux server instead." : "Para obter melhores resultados, por favor considere o uso de um servidor GNU/Linux em seu lugar.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Aparentemente a instância %s está rodando em um ambiente PHP de 32 bits e o open_basedir foi configurado no php.ini. Isto pode gerar problemas com arquivos maiores que 4GB e é altamente não recomendável.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Por favor, remova a configuração de open_basedir de seu php.ini ou mude o PHP para 64bit.",
@@ -273,6 +276,7 @@ OC.L10N.register(
     "A valid Login must be provided" : "Um Login válido deve ser fornecido",
     "Login contains whitespace at the beginning or at the end" : "O login contém espaços em branco no início ou no final",
     "Login must not consist of dots only" : "O login não deve consistir apenas de pontos",
+    "Username is too long" : "O nome de usuário é muito longo",
     "Login is invalid because files already exist for this user" : "O login é inválido porque já existem arquivos para este usuário",
     "Account disabled" : "Conta desativada",
     "Login canceled by app" : "Login cancelado pelo aplicativo",
@@ -285,25 +289,21 @@ OC.L10N.register(
     "Cannot write into \"config\" directory." : "Não é possível gravar no diretório \"config\".",
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Geralmente, isso pode ser corrigido dando ao servidor web acesso de gravação ao diretório de configuração. Consulte %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Ou, se você preferir manter o arquivo config.php somente para leitura, defina a opção \"config_is_read_only\" como true. Veja %s",
-    "Cannot write into \"apps\" directory." : "Não é possível gravar no diretório \"apps\".",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Geralmente, isso pode ser corrigido dando ao servidor web acesso de gravação ao diretório de aplicativos ou desabilitando a Loja de Aplicativos no arquivo de configuração.",
     "Cannot create \"data\" directory." : "Não é possível criar o diretório \"data\".",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Geralmente, isso pode ser corrigido dando ao servidor web acesso de gravação ao diretório raiz. Consulte %s",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Geralmente, as permissões podem ser corrigidas dando ao servidor web acesso de gravação ao diretório raiz. Consulte %s.",
     "Your data directory is not writable." : "Seu diretório de dados não é gravável.",
-    "Setting locale to %s failed." : "Falha ao definir a localidade para %s.",
-    "Please install one of these locales on your system and restart your web server." : "Por favor, instale uma dessas localidades em seu sistema e reinicie seu servidor web.",
+    "Setting locale to %s failed." : "Falha ao definir a configuração regional para %s.",
+    "Please install one of these locales on your system and restart your web server." : "Por favor, instale uma dessas configurações regionais em seu sistema e reinicie seu servidor web.",
     "PHP module %s not installed." : "Módulo PHP %s não instalado.",
     "Please ask your server administrator to install the module." : "Por favor, peça ao seu administrador do servidor para instalar o módulo.",
     "PHP setting \"%s\" is not set to \"%s\"." : "Configuração PHP \"%s\" não está configurado para \"%s\".",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Ajustar a configuração no php.ini fará com que o Nextcloud execute novamente",
-    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> está configurado para <code>%s</code> em vez do valor esperado <code>0</code>.",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Para corrigir este conjunto de problemas <code>mbstring.func_overload</code> para <code>0</code> no seu php.ini.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP aparentemente está configurado para retirar blocos doc inline. Isso fará com que vários aplicativos do núcleo fiquem inacessíveis.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Isso provavelmente é causado por um cache/acelerador, como Zend OPcache ou eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "Módulos do PHP foram instalados, mas eles ainda estão listados como faltantes?",
     "Please ask your server administrator to restart the web server." : "Por favor peça ao administrador do servidor para reiniciar o servidor web.",
-    "The required %s config variable is not configured in the config.php file." : "A variável %s de configuração necessária não está configurada no arquivo config.php.",
+    "The required %s config variable is not configured in the config.php file." : "A variável de configuração %s obrigatória não está configurada no arquivo config.php.",
     "Please ask your server administrator to check the Nextcloud configuration." : "Peça ao administrador do servidor para verificar a configuração do Nextcloud.",
     "Your data directory is readable by other people." : "Seu diretório de dados pode ser lido por outras pessoas.",
     "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Altere as permissões para 0770 para que o diretório não possa ser listado por outras pessoas.",
@@ -316,33 +316,56 @@ OC.L10N.register(
     "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Parâmetros ausentes para concluir a solicitação: \"%s\"",
     "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "A ID \"%1$s\" já é usada pelo provedor de nuvem federada \"%2$s\"",
     "Cloud Federation Provider with ID: \"%s\" does not exist." : "Provedor da Federação de Nuvem com ID: \"%s\" não existe.",
-    "Could not obtain lock type %d on \"%s\"." : "Não foi possível obter tipo de bloqueio %d em \"%s\".",
+    "Could not obtain lock type %d on \"%s\"." : "Não foi possível obter tipo de trancamento %d em \"%s\".",
     "Storage unauthorized. %s" : "Armazenamento não autorizado. %s",
     "Storage incomplete configuration. %s" : "Configuração incompleta do armazenamento. %s",
     "Storage connection error. %s" : "Erro na conexão de armazenamento. %s",
     "Storage is temporarily not available" : "Armazenamento temporariamente indisponível",
     "Storage connection timeout. %s" : "Atingido o tempo limite de conexão ao armazenamento. %s",
-    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Para permitir que esta verificação seja executada, você deve certificar-se de que seu servidor Web pode se conectar a si mesmo. Portanto, ele deve ser capaz de resolver e conectar-se a pelo menos um de seus `trusted_domains` ou `overwrite.cli.url`. Essa falha pode ser o resultado de uma incompatibilidade de DNS no servidor ou de uma regra de firewall de saída.",
+    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Para permitir que esta verificação seja executada, você deve certificar-se de que seu servidor web pode se conectar a si mesmo. Portanto, ele deve ser capaz de resolver e conectar a pelo menos um de seus `trusted_domains` ou `overwrite.cli.url`. Esta falha pode ser o resultado de uma incompatibilidade de DNS no servidor ou de uma regra de firewall de saída.",
+    "Analyze images" : "Analisar imagens",
+    "Ask a question about the given images." : "Faça uma pergunta sobre as imagens fornecidas.",
+    "Images" : "Imagens",
+    "Images to ask a question about" : "Imagens sobre as quais fazer uma pergunta",
+    "Question" : "Pergunta",
+    "What to ask about the images." : "O que perguntar sobre as imagens.",
+    "Generated response" : "Resposta gerada",
+    "The answer to the question" : "A resposta à pergunta",
+    "Audio chat" : "Conversa por áudio",
+    "Voice chat with the assistant" : "Conversa por voz com o assistente",
+    "System prompt" : "Prompt do sistema",
+    "Define rules and assumptions that the assistant should follow during the conversation." : "Defina regras e suposições que o assistente deve seguir durante a conversa.",
+    "Chat voice message" : "Mensagem de voz no chat",
+    "Describe a task that you want the assistant to do or ask a question." : "Descreva uma tarefa que você deseja que o assistente faça ou faça uma pergunta.",
+    "Chat history" : "Histórico de bate-papo",
+    "The history of chat messages before the current message, starting with a message by the user." : "O histórico de mensagens de bate-papo antes da mensagem atual, começando com uma mensagem do usuário.",
+    "Input transcript" : "Transcrição da entrada",
+    "Transcription of the audio input" : "Transcrição da entrada de áudio",
+    "Response voice message" : "Mensagem de voz de resposta",
+    "The generated voice response as part of the conversation" : "A resposta de voz gerada como parte da conversa",
+    "Output transcript" : "Transcrição da saída",
+    "Transcription of the audio output" : "Transcrição da saída de áudio",
     "Transcribe audio" : "Transcrever áudio",
-    "Transcribe the things said in an audio" : "Transcreva as coisas ditas em um áudio",
+    "Transcribe the things said in an audio" : "Transcrever o que foi dito em um áudio",
     "Audio input" : "Entrada de áudio",
     "The audio to transcribe" : "O áudio a ser transcrito",
     "Transcription" : "Transcrição",
     "The transcribed text" : "O texto transcrito",
-    "Chat with an agent" : "Conversar com um agente",
-    "Chat message" : "Mensagem de bate-papo",
-    "A chat message to send to the agent." : "Uma mensagem de bate-papo a ser enviada ao agente",
+    "Chat by voice with an agent" : "Bate-papo por voz com um agente",
+    "Describe a task that you want the agent to do or ask a question." : "Descreva uma tarefa que você deseja que o agente faça ou faça uma pergunta.",
     "Confirmation" : "Confirmação",
     "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "Se deve confirmar as ações solicitadas anteriormente: 0 para negação e 1 para confirmação.",
     "Conversation token" : "Token de conversação",
     "A token representing the conversation." : "Um token que representa a conversa.",
-    "Generated response" : "Resposta gerada",
-    "The response from the chat model." : "A resposta do modelo de bate-papo.",
     "The new conversation token" : "O novo token de conversa",
     "Send this along with the next interaction." : "Envie isso junto com a próxima interação.",
     "Requested actions by the agent" : "Ações solicitadas pelo agente",
     "Actions that the agent would like to carry out in JSON format." : "Ações que o agente gostaria de realizar no formato JSON.",
-    "Context write" : "Gravação de contexto",
+    "Chat with an agent" : "Conversar com um agente",
+    "Chat message" : "Mensagem de bate-papo",
+    "A chat message to send to the agent." : "Uma mensagem de bate-papo a ser enviada ao agente",
+    "The response from the chat model." : "A resposta do modelo de bate-papo.",
+    "Context write" : "Escrita contextual",
     "Writes text in a given style based on the provided source material." : "Escreve texto em um determinado estilo com base no material de origem fornecido.",
     "Writing style" : "Estilo de escrita",
     "Demonstrate a writing style that you would like to immitate" : "Demonstre um estilo de escrita que você gostaria de imitar",
@@ -352,17 +375,23 @@ OC.L10N.register(
     "The generated text with content from the source material in the given style" : "O texto gerado com conteúdo do material de origem no estilo determinado",
     "Emoji generator" : "Gerador de emojis",
     "Takes text and generates a representative emoji for it." : "Pega texto e gera um emoji representativo para ele.",
-    "The text to generate an emoji for" : "O texto para gerar um emoji para",
+    "The text to generate an emoji for" : "O texto para o qual gerar um emoji",
     "Generated emoji" : "Emoji gerado",
     "The generated emoji based on the input text" : "O emoji gerado com base no texto de entrada",
+    "Optical character recognition" : "Reconhecimento ótico de caracteres",
     "Generate image" : "Gerar imagem",
     "Generate an image from a text prompt" : "Gere uma imagem a partir de um prompt de texto",
     "Prompt" : "Prompt",
     "Describe the image you want to generate" : "Descreva a imagem que você deseja gerar",
     "Number of images" : "Número de imagens",
-    "How many images to generate" : "Quantas imagens gerar",
+    "How many images to generate" : "Quantas imagens devem ser geradas",
     "Output images" : "Imagens de saída",
     "The generated images" : "As imagens geradas",
+    "Generate speech" : "Gerar fala",
+    "Generate speech from a transcript" : "Gerar fala a partir de uma transcrição",
+    "Write transcript that you want the assistant to generate speech from" : "Escreva a transcrição a partir da qual você deseja que o assistente gere a fala",
+    "Output speech" : "Fala de saída",
+    "The generated speech" : "A fala gerada",
     "Free text to text prompt" : "Prompt de texto livre para texto",
     "Runs an arbitrary prompt through a language model that returns a reply" : "Usa um modelo de linguagem para gerar uma resposta a partir de um prompt.",
     "Describe a task that you want the assistant to do or ask a question" : "Descreva uma tarefa que você deseja que o assistente execute ou faça uma pergunta",
@@ -374,32 +403,29 @@ OC.L10N.register(
     "Desired tone" : "Tom desejado",
     "In which tone should your text be rewritten?" : "Em qual tom seu texto deve ser reescrito?",
     "The rewritten text in the desired tone, written by the assistant:" : "O texto reescrito no tom desejado, escrito pelo assistente:",
-    "Chat" : "Conversa",
+    "Chat" : "Bate-papo",
     "Chat with the assistant" : "Converse com o assistente",
-    "System prompt" : "Prompt do sistema",
-    "Define rules and assumptions that the assistant should follow during the conversation." : "Defina regras e suposições que o assistente deve seguir durante a conversa.",
-    "Chat history" : "Histórico de bate-papo",
     "The history of chat messages before the current message, starting with a message by the user" : "O histórico de mensagens de bate-papo antes da mensagem atual, começando com uma mensagem do usuário",
     "Response message" : "Mensagem de resposta",
     "The generated response as part of the conversation" : "A resposta gerada como parte da conversa",
     "Chat with tools" : "Conversar com ferramentas",
     "Chat with the language model with tool calling support." : "Converse com o modelo de linguagem com suporte a tool calling (\"chamadas a ferramentas\").",
     "Tool message" : "Mensagem da ferramenta",
-    "The result of tool calls in the last interaction" : "O resultado das chamadas de ferramentas na última interação",
+    "The result of tool calls in the last interaction" : "O resultado das chamadas a ferramentas na última interação",
     "Available tools" : "Ferramentas disponíveis",
     "The available tools in JSON format" : "As ferramentas disponíveis em formato JSON",
     "The response from the chat model" : "A resposta do modelo de bate-papo",
-    "Tool calls" : "Chamadas de ferramentas",
-    "Tools call instructions from the model in JSON format" : "Instruções de chamada de ferramentas do modelo no formato JSON",
+    "Tool calls" : "Chamadas a ferramentas",
+    "Tools call instructions from the model in JSON format" : "Instruções para chamadas a ferramentas do modelo no formato JSON",
     "Formalize text" : "Formalizar texto",
-    "Takes a text and makes it sound more formal" : "Pega um texto e faz com que ele soe mais formal",
+    "Takes a text and makes it sound more formal" : "Pega um texto e o faz parecer mais formal",
     "Write a text that you want the assistant to formalize" : "Escreva um texto que você deseja que o assistente formalize",
     "Formalized text" : "Texto formalizado",
     "The formalized text" : "O texto formalizado",
     "Generate a headline" : "Gere um título",
-    "Generates a possible headline for a text." : "Gera um título possível para um texto.",
+    "Generates a possible headline for a text." : "Gera um possível título para um texto.",
     "Original text" : "Texto original",
-    "The original text to generate a headline for" : "O texto original para gerar um título para",
+    "The original text to generate a headline for" : "O texto original para gerar um título",
     "The generated headline" : "O título gerado",
     "Proofread" : "Revisar",
     "Proofreads a text and lists corrections" : "Revisa um texto e lista as correções",
@@ -409,11 +435,11 @@ OC.L10N.register(
     "The corrections that should be made in your text" : "As correções que devem ser feitas em seu texto",
     "Reformulate text" : "Reformular texto",
     "Takes a text and reformulates it" : "Pega um texto e o reformula",
-    "Write a text that you want the assistant to reformulate" : "Escrever um texto que você deseja que o assistente reformule",
+    "Write a text that you want the assistant to reformulate" : "Escreva um texto que você deseja que o assistente reformule",
     "Reformulated text" : "Texto reformulado",
-    "The reformulated text, written by the assistant" : "O texto reformulado, escrito pela assistente",
+    "The reformulated text, written by the assistant" : "O texto reformulado, escrito pelo assistente",
     "Simplify text" : "Simplificar texto",
-    "Takes a text and simplifies it" : "Pega e simplifica um texto",
+    "Takes a text and simplifies it" : "Pega um texto e o simplifica",
     "Write a text that you want the assistant to simplify" : "Escreva um texto que você deseja que o assistente simplifique",
     "Simplified text" : "Texto simplificado",
     "The simplified text" : "O texto simplificado",
@@ -422,11 +448,11 @@ OC.L10N.register(
     "The original text to summarize" : "O texto original para resumir",
     "Summary" : "Resumo",
     "The generated summary" : "O resumo gerado",
-    "Extract topics" : "Extrair tópicos",
-    "Extracts topics from a text and outputs them separated by commas" : "Extrai tópicos de um texto e os exibe separados por vírgulas",
-    "The original text to extract topics from" : "O texto original para extrair tópicos de",
-    "Topics" : "Tópicos",
-    "The list of extracted topics" : "A lista de tópicos extraídos",
+    "Extract topics" : "Extrair temas",
+    "Extracts topics from a text and outputs them separated by commas" : "Extrai temas de um texto e os exibe separados por vírgulas",
+    "The original text to extract topics from" : "O texto original do qual extrair temas",
+    "Topics" : "Temas",
+    "The list of extracted topics" : "A lista de temas extraídos",
     "Translate" : "Traduzir",
     "Translate text from one language to another" : "Traduzir um texto de um idioma para outro",
     "Origin text" : "Texto original",
@@ -438,24 +464,16 @@ OC.L10N.register(
     "Result" : "Resultado",
     "The translated text" : "O texto traduzido",
     "Free prompt" : "Prompt livre",
-    "Runs an arbitrary prompt through the language model." : "Executa um prompt arbitrário por meio do modelo de idioma.",
+    "Runs an arbitrary prompt through the language model." : "Executa um prompt arbitrário por meio do modelo de linguagem.",
     "Generate headline" : "Gerar título",
     "Summarizes text by reducing its length without losing key information." : "Resume o texto reduzindo seu comprimento sem perder informações importantes.",
-    "Extracts topics from a text and outputs them separated by commas." : "Extrai tópicos de um texto e os gera separados por vírgulas.",
-    "Education Edition" : "Edição Educativa",
-    "File name is a reserved word" : "O nome do arquivo é uma palavra reservada",
-    "File name contains at least one invalid character" : "O nome do arquivo contém pelo menos um caracter inválido",
-    "File name is too long" : "O nome do arquivo é muito longo",
-    "Users" : "Usuários",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s compartilhou »%2$s« com você e quer adicionar:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s compartilhou »%2$s« com você e quer adicionar",
-    "»%s« added a note to a file shared with you" : "»%s« adicionou uma anotação num arquivo compartilhado com você",
-    "Open »%s«" : "Abrir »%s«",
-    "%1$s shared »%2$s« with you" : "%1$s compartilhou »%2$s« com você",
-    "%1$s shared »%2$s« with you." : "%1$s compartilhou »%2$s« com você.",
-    "Click the button below to open it." : "Clique no botão abaixo para abri-lo.",
-    "File is currently busy, please try again later" : "O arquivo está ocupado, tente novamente mais tarde",
-    "Cannot download file" : "Não é possível baixar o arquivo",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Assegure-se que exista um arquivo chamado \".ocdata\" na raiz do diretório \"data\"."
+    "Extracts topics from a text and outputs them separated by commas." : "Extrai temas de um texto e os exibe separados por vírgulas.",
+    "Organisation" : "Organização",
+    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "O Mac OS X não é compatível e %s não funcionará corretamente nessa plataforma. Use-o por sua própria conta e risco!",
+    "Login is too long" : "Login é muito longo",
+    "Cannot write into \"apps\" directory." : "Não é possível gravar no diretório \"apps\".",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Geralmente, isso pode ser corrigido dando ao servidor web acesso de gravação ao diretório de aplicativos ou desabilitando a Loja de Aplicativos no arquivo de configuração.",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> está configurado para <code>%s</code> em vez do valor esperado <code>0</code>.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Para corrigir esse problema, defina <code>mbstring.func_overload</code> como <code>0</code> em seu php.ini."
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
