@@ -127,6 +127,7 @@ OC.L10N.register(
     "Settings" : "Nastavenia",
     "Log out" : "Odhlásiť sa",
     "Accounts" : "Účty",
+    "Bluesky" : "Bluesky",
     "Email" : "E-mail",
     "Mail %s" : "Pošta pre %s",
     "Fediverse" : "Fediverse",
@@ -155,7 +156,6 @@ OC.L10N.register(
     "Oracle connection could not be established" : "Nie je možné pripojiť sa k Oracle",
     "Oracle Login and/or password not valid" : "Prihlasovacie meno a/alebo heslo pre Oracle databázu je neplatné",
     "PostgreSQL Login and/or password not valid" : "Prihlasovacie meno a/alebo heslo pre PostgreSQL databázu je neplatné",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X nie je podporovaný a %s nebude správne fungovať na tejto platforme. Použitie na vlastné riziko!",
     "For the best results, please consider using a GNU/Linux server instead." : "Pre dosiahnutie najlepších výsledkov, prosím zvážte použitie GNU/Linux servera.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Zdá sa, že táto inštancia %s beží v 32-bitovom prostredí PHP a v php.ini bola nastavená voľba open_basedir. To bude zdrojom problémov so súbormi väčšími ako 4GB a dôrazne sa neodporúča.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Prosím, odstráňte nastavenie open_basedir vo vašom php.ini alebo prejdite na 64-bit PHP.",
@@ -293,8 +293,6 @@ OC.L10N.register(
     "Please ask your server administrator to install the module." : "Prosím, požiadajte administrátora vášho servera o inštaláciu modulu.",
     "PHP setting \"%s\" is not set to \"%s\"." : "Voľba PHP „%s“ nie je nastavená na „%s“.",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Použitím týchto nastavení v php.ini dovolí Nextcloudu sa znova spustiť",
-    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> je nastavený na <code>%s</code>, namiesto predpokladanej hodnoty <code>0</code>.",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Oprava problému spočíva v nastavení <code>mbstring.func_overload</code> na <code>0</code> vo vašom php.ini.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP je zjavne nastavené, aby odstraňovalo bloky vloženej dokumentácie. To zneprístupní niekoľko základných aplikácií.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "To je pravdepodobne spôsobené cache/akcelerátorom ako napr. Zend OPcache alebo eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP moduly boli nainštalované, ale stále sa tvária, že chýbajú?",
@@ -322,9 +320,17 @@ OC.L10N.register(
     "Images" : "Obrázky",
     "Question" : "Otázka",
     "Generated response" : "Vygenerovaná odpoveď",
+    "Voice chat with the assistant" : "Hlasový chat s asistentom",
     "System prompt" : "Systémová výzva",
     "Define rules and assumptions that the assistant should follow during the conversation." : "Definovať pravidlá a predpoklady, ktoré by mal asistent počas rozhovoru dodržiavať.",
+    "Chat voice message" : "Hlasová správa v chate",
     "Chat history" : "História chatu",
+    "Input transcript" : "Vstupný prepis",
+    "Transcription of the audio input" : "Prepis audio vstupu",
+    "Response voice message" : "Odpovedať hlasovou správou",
+    "The generated voice response as part of the conversation" : "Vygenerovaná hlasová odpoveď ako súčasť konverzácie",
+    "Output transcript" : "Výstupný prepis",
+    "Transcription of the audio output" : "Prepis audio výstupu",
     "Transcribe audio" : "Prepísať zvuk",
     "Transcribe the things said in an audio" : "Prepísať veci povedané vo zvuku",
     "Audio input" : "Audio vstup",
@@ -356,6 +362,7 @@ OC.L10N.register(
     "The text to generate an emoji for" : "Text pre ktorý vygeneruje emotikon",
     "Generated emoji" : "Vygenerované emotikony",
     "The generated emoji based on the input text" : "Vygenerovaný emotikon založený na vstupnom texte",
+    "Optical character recognition" : "Optické rozpoznávanie znakov",
     "Generate image" : "Vygenerovať obrázok",
     "Generate an image from a text prompt" : "Vygenerovať obrázok na základe textového zadania",
     "Prompt" : "Zadanie",
@@ -441,9 +448,10 @@ OC.L10N.register(
     "Summarizes text by reducing its length without losing key information." : "Zhrňuje text tým, že znižuje jeho dĺžku bez straty kľúčových informácií.",
     "Extracts topics from a text and outputs them separated by commas." : "Extrahuje témy z textu a vypisuje ich oddelené čiarkami.",
     "Organisation" : "Organizácia",
-    "File is currently busy, please try again later" : "Súbor sa práve používa, skúste prosím neskôr",
-    "Cannot download file" : "Nemožno stiahnuť súbor",
+    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X nie je podporovaný a %s nebude správne fungovať na tejto platforme. Použitie na vlastné riziko!",
     "Cannot write into \"apps\" directory." : "Nie je možné zapisovať do priečinka \"apps\".",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Toto sa zvyčajne dá opraviť poskytnutím práva webového servera na zápis do priečinka s aplikáciami alebo vypnutím katalógu s aplikáciami v súbore s nastaveniami."
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Toto sa zvyčajne dá opraviť poskytnutím práva webového servera na zápis do priečinka s aplikáciami alebo vypnutím katalógu s aplikáciami v súbore s nastaveniami.",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> je nastavený na <code>%s</code>, namiesto predpokladanej hodnoty <code>0</code>.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Oprava problému spočíva v nastavení <code>mbstring.func_overload</code> na <code>0</code> vo vašom php.ini."
 },
 "nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
