@@ -129,6 +129,8 @@ OC.L10N.register(
     "Settings" : "Inställningar",
     "Log out" : "Logga ut",
     "Accounts" : "Konton",
+    "Bluesky" : "Bluesky",
+    "View %s on Bluesky" : "Se %s på Bluesky",
     "Email" : "E-post",
     "Mail %s" : "Skicka e-post %s",
     "Fediverse" : "Fediverse",
@@ -158,7 +160,6 @@ OC.L10N.register(
     "Oracle connection could not be established" : "Oracle-anslutning kunde inte etableras",
     "Oracle Login and/or password not valid" : "Oracle-inloggning och/eller lösenord är felaktigt",
     "PostgreSQL Login and/or password not valid" : "PostgreSQL-inloggning och/eller lösenord är felaktigt",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X stöds inte och %s kommer inte att fungera korrekt på denna plattform. Använd på egen risk!",
     "For the best results, please consider using a GNU/Linux server instead." : "För bästa resultat, överväg att använda en GNU/Linux-server istället.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Det verkar som om denna %s instans körs på en 32-bitars PHP miljö och open_basedir har konfigurerats i php.ini. Detta kommer att leda till problem med filer över 4 GB och är verkligen inte rekommenderat!",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Ta bort open_basedir-inställningen i din php.ini eller växla till 64-bitars PHP.",
@@ -288,8 +289,6 @@ OC.L10N.register(
     "Cannot write into \"config\" directory." : "Kan inte skriva i \"config\"-katalogen.",
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Detta kan vanligtvis åtgärdas genom att ge webbservern skrivåtkomst till config-katalogen. Se %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Eller, om du föredrar att behålla config.php skrivskyddad, sätt alternativet \"config_is_read_only\" till true i den. Se %s",
-    "Cannot write into \"apps\" directory." : "Kan inte skriva till \"apps\"-katalogen.",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Detta kan vanligtvis åtgärdas genom att ge webbservern skrivrättigheter till \"apps\"-katalogen eller stänga av appbutiken i konfigurationsfilen.",
     "Cannot create \"data\" directory." : "Kan inte skapa \"data\"-katalog.",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Detta kan vanligtvis åtgärdas genom att ge webbservern skrivåtkomst till rotkatalogen. Se %s",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Behörigheter kan vanligtvis fixas genom att ge webbservern skrivåtkomst till rotkatalogen. Se %s.",
@@ -300,8 +299,6 @@ OC.L10N.register(
     "Please ask your server administrator to install the module." : "Be serveradministratören att installera modulen.",
     "PHP setting \"%s\" is not set to \"%s\"." : "PHP-inställning \"%s\" är inte inställd på \"%s\".",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Att ändra denna inställning i php.ini kommer göra så att Nextcloud fungerar igen",
-    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> är satt till <code>%s</code> istället för förväntade värdet <code>0</code>.",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : " För att åtgärda detta problemet, sätt<code>mbstring.func_overload</code> till <code>0</code> i din php.ini.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP är tydligen inställt för att tömma \"inline doc blocks\". Detta kommer att göra flera kärnprogram otillgängliga.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Detta orsakas troligtvis av en cache/accelerator som t ex Zend OPchache eller eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP-moduler har installerats, men de listas fortfarande som saknade?",
@@ -326,18 +323,36 @@ OC.L10N.register(
     "Storage is temporarily not available" : "Lagringsutrymme är för tillfället inte tillgängligt",
     "Storage connection timeout. %s" : "Lagringsutrymme lyckas inte ansluta \"timeout\". %s",
     "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "För att denna kontroll ska kunna köra måste du se till att webbservern kan ansluta till sig själv. Den måste alltså kunna finna och ansluta till minst en av sina \"trusted_domains\" eller \"overwrite.cli.url\":en. Detta misslyckande kan vara resultatet av en DNS missmatch på serversidan eller utgående brandväggs-regler.",
+    "Analyze images" : "Analysera bilder",
+    "Ask a question about the given images." : "Ställ en fråga om de givna bilderna.",
     "Images" : "Bilder",
+    "Images to ask a question about" : "Bilder att fråga om",
     "Question" : "Fråga",
+    "What to ask about the images." : "Vad man ska fråga om bilderna.",
     "Generated response" : "Genererat svar",
+    "The answer to the question" : "Svaret på frågan",
+    "Audio chat" : "Ljudchatt",
+    "Voice chat with the assistant" : "Röstchatt med assistenten",
     "System prompt" : "Systemuppmaning",
     "Define rules and assumptions that the assistant should follow during the conversation." : "Definiera regler och antaganden som assistenten ska följa under samtalet.",
+    "Chat voice message" : "Röstmeddelande i chatt",
+    "Describe a task that you want the assistant to do or ask a question." : "Beskriv en uppgift som du vill att assistenten ska göra eller ställ en fråga.",
     "Chat history" : "Chatthistorik",
+    "The history of chat messages before the current message, starting with a message by the user." : "Historiken för chattmeddelanden före det aktuella meddelandet, som börjar med ett meddelande från användaren.",
+    "Input transcript" : "Ingående transkript",
+    "Transcription of the audio input" : "Transkribering av ljudinmatning",
+    "Response voice message" : "Svar som röstmeddelande",
+    "The generated voice response as part of the conversation" : "Den genererade röstsvaret som en del av konversationen",
+    "Output transcript" : "Utgående transkript",
+    "Transcription of the audio output" : "Transkribering av ljudutmatning",
     "Transcribe audio" : "Transkribera ljud",
     "Transcribe the things said in an audio" : "Transkribera det som sägs i ljud",
     "Audio input" : "Ljudinmatning",
     "The audio to transcribe" : "Ljudet att transkribera",
     "Transcription" : "Transkription",
     "The transcribed text" : "Den transkriberade texten",
+    "Chat by voice with an agent" : "Chatta via röst med en agent",
+    "Describe a task that you want the agent to do or ask a question." : "Beskriv en uppgift som du vill att assistenten ska göra eller ställ en fråga.",
     "Confirmation" : "Bekräftelse",
     "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "Om tidigare begärda åtgärder ska bekräftas: 0 för avslag och 1 för bekräftelse.",
     "Conversation token" : "Konversationstoken",
@@ -363,6 +378,7 @@ OC.L10N.register(
     "The text to generate an emoji for" : "Texten att generera en emoji för",
     "Generated emoji" : "Genererad emoji",
     "The generated emoji based on the input text" : "Den genererade emojin baserad på inmatningstexten",
+    "Optical character recognition" : "Optisk teckenigenkänning",
     "Generate image" : "Skapa bild",
     "Generate an image from a text prompt" : "Skapa en bild från en textuppmaning",
     "Prompt" : "Uppmaning",
@@ -453,8 +469,11 @@ OC.L10N.register(
     "Summarizes text by reducing its length without losing key information." : "Sammanfattar text genom att minska dess längd utan att förlora viktig information.",
     "Extracts topics from a text and outputs them separated by commas." : "Extraherar ämnen från en text och matar ut dem separerade med kommatecken.",
     "Organisation" : "Organisation",
-    "File is currently busy, please try again later" : "Filen är för tillfället upptagen, försök igen senare",
-    "Cannot download file" : "Kan inte ladda ner fil",
-    "Login is too long" : "Inloggningen är för lång"
+    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X stöds inte och %s kommer inte att fungera korrekt på denna plattform. Använd på egen risk!",
+    "Login is too long" : "Inloggningen är för lång",
+    "Cannot write into \"apps\" directory." : "Kan inte skriva till \"apps\"-katalogen.",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Detta kan vanligtvis åtgärdas genom att ge webbservern skrivrättigheter till \"apps\"-katalogen eller stänga av appbutiken i konfigurationsfilen.",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> är satt till <code>%s</code> istället för förväntade värdet <code>0</code>.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : " För att åtgärda detta problemet, sätt<code>mbstring.func_overload</code> till <code>0</code> i din php.ini."
 },
 "nplurals=2; plural=(n != 1);");
