@@ -2,19 +2,22 @@ OC.L10N.register(
     "lib",
     {
     "Cannot write into \"config\" directory!" : "Cannot write into \"config\" directory!",
+    "Authentication" : "Autentifikatsiya",
     "Unknown filetype" : "Unknown filetype",
     "Invalid image" : "Invalid image",
-    "Files" : "Files",
+    "Files" : "Fayllar",
     "View profile" : "View profile",
     "last month" : "last month",
     "seconds ago" : "seconds ago",
     "Apps" : "Apps",
-    "Settings" : "Settings",
+    "Settings" : "Sozlamalar",
+    "Accounts" : "Akkaunt",
     "Email" : "Email",
     "Website" : "Veb-sayt",
     "Address" : "Address",
     "Profile picture" : "Profil rasmi",
     "About" : "About",
+    "Additional settings" : "Parol",
     "Set an admin password." : "Set an admin password.",
     "Open %s" : "Ochiq %s",
     "Sunday" : "Yakshanba",
@@ -27,9 +30,9 @@ OC.L10N.register(
     "January" : "January",
     "Authentication error" : "Authentication error",
     "Storage is temporarily not available" : "Storage is temporarily not available",
+    "Images" : "Tasvirlar",
     "Confirmation" : "Tasdiqlash",
-    "File name is too long" : "File name is too long",
-    "Users" : "Users",
-    "Open »%s«" : "ochish »%s«"
+    "Text" : "Matn",
+    "Translate" : "Tarjima"
 },
 "nplurals=1; plural=0;");
