@@ -1,7 +1,7 @@
 OC.L10N.register(
     "lib",
     {
-    "Cannot write into \"config\" directory!" : "无法写入 \"config\" 目录！",
+    "Cannot write into \"config\" directory!" : "无法写入“config”目录！",
     "This can usually be fixed by giving the web server write access to the config directory." : "通常可以为 Web 服务器授予对 config 目录的写入权限来修复这个问题。",
     "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "但是，如果您更希望将 config.php 文件设为只读，可以将 \"config_is_read_only\" 选项设置为 true。",
     "See %s" : "查看 %s",
@@ -55,8 +55,8 @@ OC.L10N.register(
     "The remote wipe on %s has finished" : "%s上的远程擦除操作已完成",
     "Authentication" : "验证",
     "Unknown filetype" : "未知的文件类型",
-    "Invalid image" : "无效的图像",
-    "Avatar image is not square" : "头像图像不是正方形",
+    "Invalid image" : "无效的图片",
+    "Avatar image is not square" : "头像图片不是正方形",
     "Files" : "文件",
     "View profile" : "查看个人资料",
     "same time" : "同一时间",
@@ -93,6 +93,8 @@ OC.L10N.register(
     "Destination does not exist" : "目标不存在",
     "Destination is not creatable" : "目标不可创建",
     "Dot files are not allowed" : "以 . 开头的文件不被允许",
+    "%1$s (renamed)" : "%1$s（已重命名）",
+    "renamed file" : "已重命名文件",
     "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" 是禁止的文件或文件夹名称。",
     "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\" 是文件或文件夹名称的禁止前缀。",
     "\"%1$s\" is not allowed inside a file or folder name." : "文件或文件夹名称中不允许出现 \"%1$s\"。",
@@ -127,6 +129,8 @@ OC.L10N.register(
     "Settings" : "设置",
     "Log out" : "注销",
     "Accounts" : "账号",
+    "Bluesky" : "Bluesky",
+    "View %s on Bluesky" : "在 Bluesky 上查看 %s",
     "Email" : "电子邮箱",
     "Mail %s" : "发邮件给 %s",
     "Fediverse" : "联邦宇宙",
@@ -142,7 +146,7 @@ OC.L10N.register(
     "About" : "关于",
     "Display name" : "显示用户名",
     "Headline" : "标题",
-    "Organisation" : "组织",
+    "Organization" : "组织",
     "Role" : "角色",
     "Pronouns" : "称号",
     "Unknown account" : "未知帐户",
@@ -156,7 +160,6 @@ OC.L10N.register(
     "Oracle connection could not be established" : "无法建立 Oracle 连接",
     "Oracle Login and/or password not valid" : "Oracle 用户名或密码无效",
     "PostgreSQL Login and/or password not valid" : "PostgreSQL 用户名或密码无效",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "不支持 Mac OS X，%s 在此平台上无法正常工作。请自行承担使用风险！",
     "For the best results, please consider using a GNU/Linux server instead." : "为了达到最好的效果，请考虑使用 GNU/Linux 服务器。",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "看起来这个 %s 实例运行在32位 PHP 环境中并且已在 php.ini 中配置open_basedir。这将在文件超过4GB时出现问题，强烈不建议这样做。",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "请删除 php.ini 中的 open_basedir 设置或切换到64位PHP。",
@@ -273,6 +276,7 @@ OC.L10N.register(
     "A valid Login must be provided" : "必须提供有效的登录名",
     "Login contains whitespace at the beginning or at the end" : "登录名开头或结尾包含空格",
     "Login must not consist of dots only" : "登录名不能仅由点组成",
+    "Username is too long" : "用户名太长",
     "Login is invalid because files already exist for this user" : "登录无效，因为此用户的文件已存在",
     "Account disabled" : "帐户已禁用",
     "Login canceled by app" : "已通过应用取消登录",
@@ -285,8 +289,6 @@ OC.L10N.register(
     "Cannot write into \"config\" directory." : "无法写入 \"config\" 目录。",
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "通常可以为 Web 服务器授予对 config 目录的写入权限来修复这个问题。查看 %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "或者，如果希望保持 config.php 文件的只读权限，请将 \"config_is_read_only\" 设置为 true。查看 %s",
-    "Cannot write into \"apps\" directory." : "无法写入 \"apps\" 目录。",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "通常可以为 Web 服务器授予对 apps 目录的写入权限来修复这个问题，或在设置文件中禁用应用商店。",
     "Cannot create \"data\" directory." : "无法创建 “data” 目录",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "通常可以为 Web 服务器授予对根目录的写入权限来修复这个问题。查看：%s",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "通常可以为 Web 服务器授予对根目录的写入权限来修复权限问题。查看：%s。",
@@ -297,8 +299,6 @@ OC.L10N.register(
     "Please ask your server administrator to install the module." : "请联系您的服务器管理员安装模块。",
     "PHP setting \"%s\" is not set to \"%s\"." : "PHP 选项 \"%s\" 未设置为 \"%s\"。",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "在 php.ini 中调整该设置将导致 Nextcloud 重新运行",
-    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code>被设置为<code>%s</code>，而不是预期的 <code>0</code>。",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "为了修正该问题，请在您的 php.ini 中设置<code>mbstring.func_overload</code>为<code>0</code>。",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP 被设置为移除内联块，这将导致多个核心应用无法访问。",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "这可能由缓存/加速器导致的，例如 Zend OPcache 或 eAccelerator。",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP 模块已经安装，但仍然显示未安装？",
@@ -323,25 +323,48 @@ OC.L10N.register(
     "Storage is temporarily not available" : "存储暂时不可用",
     "Storage connection timeout. %s" : "存储连接超时。%s",
     "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "要允许此检查运行，您必须确保您的 Web 服务器可以连接到自身。因此，它必须能够解析并连接到其 \"trusted_domains\" 或 \"overwrite.cli.url\" 中的至少一个。此失败可能是服务端 DNS 不匹配或出站防火墙规则的结果。",
+    "Analyze images" : "分析图片",
+    "Ask a question about the given images." : "询问有关给定图片的问题。",
+    "Images" : "图片",
+    "Images to ask a question about" : "要提问的图片",
+    "Question" : "问题",
+    "What to ask about the images." : "关于图片要问什么问题。",
+    "Generated response" : "生成的回复",
+    "The answer to the question" : "问题的答案",
+    "Audio chat" : "语音聊天",
+    "Voice chat with the assistant" : "与助手进行语音聊天",
+    "System prompt" : "系统提示",
+    "Define rules and assumptions that the assistant should follow during the conversation." : "定义助手在对话过程中应遵循的规则和假设。",
+    "Chat voice message" : "聊天语音消息",
+    "Describe a task that you want the assistant to do or ask a question." : "描述您想要助手执行的任务或提出问题。",
+    "Chat history" : "聊天记录",
+    "The history of chat messages before the current message, starting with a message by the user." : "当前消息之前的聊天消息历史记录，从用户发送的消息开始。",
+    "Input transcript" : "输入转录",
+    "Transcription of the audio input" : "音频输入的转录内容",
+    "Response voice message" : "回复语音消息",
+    "The generated voice response as part of the conversation" : "生成的语音回复是对话的一部分",
+    "Output transcript" : "输出转录",
+    "Transcription of the audio output" : "音频输出的转录内容",
     "Transcribe audio" : "转写音频",
     "Transcribe the things said in an audio" : "将音频中的内容转录下来",
     "Audio input" : "音频输入",
     "The audio to transcribe" : "要转录的音频",
     "Transcription" : "转录",
     "The transcribed text" : "已转录的文本",
-    "Chat with an agent" : "和 agent 对话",
-    "Chat message" : "聊天消息",
-    "A chat message to send to the agent." : "要发送给 agent 的聊天消息。",
+    "Chat by voice with an agent" : "与 agent 语音聊天",
+    "Describe a task that you want the agent to do or ask a question." : "描述您想要 agent 执行的任务或提出问题。",
     "Confirmation" : "确认",
     "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "是否确认之前的操作：0表示拒绝，1表示确认。",
     "Conversation token" : "对话令牌",
     "A token representing the conversation." : "代表对话的 token。",
-    "Generated response" : "生成的回复",
-    "The response from the chat model." : "来自聊天模型的回应。",
     "The new conversation token" : "新的对话 token",
     "Send this along with the next interaction." : "下次交互时一起发送。",
     "Requested actions by the agent" : "Agent 要求的操作",
     "Actions that the agent would like to carry out in JSON format." : "代理想以 JSON 格式执行的操作。",
+    "Chat with an agent" : "和 agent 对话",
+    "Chat message" : "聊天消息",
+    "A chat message to send to the agent." : "要发送给 agent 的聊天消息。",
+    "The response from the chat model." : "聊天模型的回复。",
     "Context write" : "文本撰写",
     "Writes text in a given style based on the provided source material." : "通过给出语料的风格生成文字",
     "Writing style" : "撰写风格",
@@ -355,14 +378,25 @@ OC.L10N.register(
     "The text to generate an emoji for" : "用于生成表情的文字",
     "Generated emoji" : "生成的表情",
     "The generated emoji based on the input text" : "根据输入文本生成的表情符号",
+    "Optical character recognition" : "光学字符识别",
+    "Extract text from files like images or PDFs" : "从图片或 PDF 等文件中提取文本",
+    "Input files" : "输入文件",
+    "The files to extract text from" : "从中提取文本的文件",
+    "Output texts" : "输出文本",
+    "The texts that were extracted from the files" : "从文件中提取的文本",
     "Generate image" : "生成图片",
-    "Generate an image from a text prompt" : "根据文本提示生成图像",
+    "Generate an image from a text prompt" : "从文本提示生成图片",
     "Prompt" : "提示",
-    "Describe the image you want to generate" : "描述你想要生成的图像",
-    "Number of images" : "图像数量",
+    "Describe the image you want to generate" : "描述您要生成的图片",
+    "Number of images" : "图片数量",
     "How many images to generate" : "生成多少张图片",
-    "Output images" : "输出图像",
-    "The generated images" : "生成的图像",
+    "Output images" : "输出图片",
+    "The generated images" : "生成的图片",
+    "Generate speech" : "生成语音",
+    "Generate speech from a transcript" : "从转录生成语音",
+    "Write transcript that you want the assistant to generate speech from" : "编写您想要助手从中生成语音的转录内容",
+    "Output speech" : "输出语音",
+    "The generated speech" : "生成的语音",
     "Free text to text prompt" : "免费文本转文本提示",
     "Runs an arbitrary prompt through a language model that returns a reply" : "通过语言模型运行任意提示并返回答复",
     "Describe a task that you want the assistant to do or ask a question" : "描述你希望助手执行的任务或提出问题",
@@ -376,19 +410,16 @@ OC.L10N.register(
     "The rewritten text in the desired tone, written by the assistant:" : "由助手以所需的语气重写的文本：",
     "Chat" : "聊天",
     "Chat with the assistant" : "与助手聊天",
-    "System prompt" : "系统提示",
-    "Define rules and assumptions that the assistant should follow during the conversation." : "定义助手在对话过程中应遵循的规则和假设。",
-    "Chat history" : "聊天记录",
     "The history of chat messages before the current message, starting with a message by the user" : "当前消息之前的聊天消息历史记录，从用户发送的消息开始",
-    "Response message" : "应答消息",
-    "The generated response as part of the conversation" : "作为对话的一部分生成的响应",
+    "Response message" : "回复消息",
+    "The generated response as part of the conversation" : "生成的回复是对话的一部分",
     "Chat with tools" : "使用工具聊天",
     "Chat with the language model with tool calling support." : "使用工具调用支持与语言模型聊天。",
     "Tool message" : "工具消息",
     "The result of tool calls in the last interaction" : "上次互动中工具调用的结果",
     "Available tools" : "可用工具",
     "The available tools in JSON format" : "JSON 格式的可用工具",
-    "The response from the chat model" : "聊天模型的应答",
+    "The response from the chat model" : "聊天模型的回复",
     "Tool calls" : "工具调用",
     "Tools call instructions from the model in JSON format" : "工具以 JSON 格式从模型调用指令",
     "Formalize text" : "正式化文本",
@@ -442,20 +473,12 @@ OC.L10N.register(
     "Generate headline" : "生成标题",
     "Summarizes text by reducing its length without losing key information." : "总结一段文本以减少长度而不丢失关键信息",
     "Extracts topics from a text and outputs them separated by commas." : "从文本中摘出主题，输出逗号分隔的结果",
-    "Education Edition" : "教育版",
-    "File name is a reserved word" : "文件名包含敏感字符",
-    "File name contains at least one invalid character" : "文件名中存在至少一个非法字符",
-    "File name is too long" : "文件名过长",
-    "Users" : "用户",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s 与您共享了 »%2$s« 并希望添加：",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s 与您共享了 »%2$s« 并希望添加",
-    "»%s« added a note to a file shared with you" : "»%s« 在与你共享的文件中添加了备注",
-    "Open »%s«" : "打开 »%s«",
-    "%1$s shared »%2$s« with you" : "%1$s 对您共享了 »%2$s«",
-    "%1$s shared »%2$s« with you." : "%1$s 对您共享了 »%2$s«。",
-    "Click the button below to open it." : "点击下方按钮可打开它。",
-    "File is currently busy, please try again later" : "文件当前正忙，请稍后再试",
-    "Cannot download file" : "无法下载文件",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "请确定在根目录下有一个名为\".ocdata\"的文件。"
+    "Organisation" : "组织",
+    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "不支持 Mac OS X，%s 在此平台上无法正常工作。请自行承担使用风险！",
+    "Login is too long" : "登录名太长",
+    "Cannot write into \"apps\" directory." : "无法写入 \"apps\" 目录。",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "通常可以为 Web 服务器授予对 apps 目录的写入权限来修复这个问题，或在设置文件中禁用应用商店。",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code>被设置为<code>%s</code>，而不是预期的 <code>0</code>。",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "为了修正该问题，请在您的 php.ini 中设置<code>mbstring.func_overload</code>为<code>0</code>。"
 },
 "nplurals=1; plural=0;");
