@@ -93,6 +93,8 @@ OC.L10N.register(
     "Destination does not exist" : "目的地不存在",
     "Destination is not creatable" : "無法建立目的地",
     "Dot files are not allowed" : "不允許小數點開頭的檔案",
+    "%1$s (renamed)" : "%1$s（已重新命名）",
+    "renamed file" : "已重新命名檔案",
     "\"%1$s\" is a forbidden file or folder name." : "「%1$s」是禁止的檔案或資料夾名稱。",
     "\"%1$s\" is a forbidden prefix for file or folder names." : "「%1$s」是禁止的檔案或資料夾名稱前綴。",
     "\"%1$s\" is not allowed inside a file or folder name." : "「%1$s」不允許出現在檔案或資料夾名稱中。",
@@ -127,6 +129,8 @@ OC.L10N.register(
     "Settings" : "設定",
     "Log out" : "登出",
     "Accounts" : "帳號",
+    "Bluesky" : "Bluesky",
+    "View %s on Bluesky" : "在 Bluesky 上檢視 %s",
     "Email" : "電子郵件",
     "Mail %s" : "寄送郵件給 %s",
     "Fediverse" : "聯邦宇宙",
@@ -142,7 +146,7 @@ OC.L10N.register(
     "About" : "關於",
     "Display name" : "顯示名稱",
     "Headline" : "重要經歷",
-    "Organisation" : "組織單位",
+    "Organization" : "組織",
     "Role" : "職位",
     "Pronouns" : "代名詞",
     "Unknown account" : "未知的帳號",
@@ -156,7 +160,6 @@ OC.L10N.register(
     "Oracle connection could not be established" : "無法建立 Oracle 資料庫連線",
     "Oracle Login and/or password not valid" : "Oracle 帳號或密碼不正確",
     "PostgreSQL Login and/or password not valid" : "PostgreSQL 帳號或密碼無效",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "不支援 Mac OS X，%s 在此平台上無法正常運作。請自行承擔使用風險！",
     "For the best results, please consider using a GNU/Linux server instead." : "請考慮改用 GNU/Linux 伺服器以獲得最佳結果。",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "%s 站台似乎是在 32 位元 PHP 環境執行，且似乎設定了 php.ini 中的 open_basedir。這將導致超過 4 GB 的檔案出現問題，因此強烈建議不要這麼做。",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "請移除 php.ini 中的 open_basedir 設定，或是改用 64 位元的 PHP。",
@@ -201,7 +204,7 @@ OC.L10N.register(
     "Path is already shared with this group" : "路徑已與此群組分享",
     "Link sharing is not allowed" : "不允許連結分享",
     "Public upload is not allowed" : "不允許公開上傳",
-    "Path contains files shared with you" : "路徑包含與您分享的檔案",
+    "You cannot share a folder that contains other shares" : "您無法分享包含其他分享的資料夾",
     "Sharing is disabled" : "已停用分享",
     "Sharing is disabled for you" : "您已停用分享",
     "Cannot share with the share owner" : "無法與分享擁有者分享",
@@ -273,6 +276,7 @@ OC.L10N.register(
     "A valid Login must be provided" : "必須提供有效帳號",
     "Login contains whitespace at the beginning or at the end" : "帳號的開頭或結尾有空白",
     "Login must not consist of dots only" : "帳號不能只包含小數點",
+    "Username is too long" : "使用者名稱太長了",
     "Login is invalid because files already exist for this user" : "帳號無效，因為使用者的檔案已經存在",
     "Account disabled" : "帳號已停用",
     "Login canceled by app" : "應用程式取消了登入",
@@ -285,8 +289,6 @@ OC.L10N.register(
     "Cannot write into \"config\" directory." : "無法寫入「config」目錄。",
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "開通網頁伺服器寫入 config 目錄的存取權，通常可以解決這個問題。請見 %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "或者，如果您比較希望保留 config.php 的唯讀狀態，請在該組態設定檔中將 「config_is_read_only」設定為 true。請見 %s",
-    "Cannot write into \"apps\" directory." : "無法寫入「apps」目錄。",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "開通網頁伺服器寫入 apps 目錄的存取權，或是在組態設定檔中停用應用程式商店，通常可以解決這個問題。",
     "Cannot create \"data\" directory." : "無法建立「data」目錄。",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "開通網頁伺服器寫入根目錄的存取權，通常可以修正這個問題。請見 %s",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "開通網頁伺服器可寫入根目錄的存取權，通常可以修正權限問題。請見 %s。",
@@ -297,8 +299,6 @@ OC.L10N.register(
     "Please ask your server administrator to install the module." : "請要求您的伺服器管理員安裝模組。",
     "PHP setting \"%s\" is not set to \"%s\"." : "PHP 設定值「%s」未設定為「%s」。",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "調整 php.ini 中的設定，會讓 Nextcloud 重新執行",
-    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> 設定為 <code>%s</code>，而非預期中的 <code>0</code>。",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "為了修正這個問題，請到 php.ini 將 <code>mbstring.func_overload</code> 的值改為 <code>0</code>。",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP 顯然設定為剪除 inline 的文件嵌入區塊。這會讓多個核心應用程式無法運作。",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "這可能是快取或加速程式（如 Zend OPcache 或 eAccelerator）所造成。",
     "PHP modules have been installed, but they are still listed as missing?" : "您已安裝指定的 PHP 模組，可是還是顯示為找不到嗎？",
@@ -323,26 +323,48 @@ OC.L10N.register(
     "Storage is temporarily not available" : "儲存空間暫時無法使用",
     "Storage connection timeout. %s" : "儲存空間連線逾時。%s",
     "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "若要允許執行此檢查，您必須確保您的網路伺服器可以連線到其自身。因此，其必須可以解析並連線到 `trusted_domains` 或 `overwrite.cli.url` 至少其中一個。此失敗可能是因為伺服器端 DNS 不符或連出防火牆規則造成的。",
+    "Analyze images" : "分析影像",
+    "Ask a question about the given images." : "詢問關於指定影像的問題。",
+    "Images" : "圖片",
+    "Images to ask a question about" : "要提出問題的影像",
+    "Question" : "問題",
+    "What to ask about the images." : "要問什麼關於影像的問題。",
+    "Generated response" : "已產生的回應",
+    "The answer to the question" : "問題的答案",
+    "Audio chat" : "語音聊天",
+    "Voice chat with the assistant" : "與小幫手使用語音聊天",
+    "System prompt" : "系統提示詞",
+    "Define rules and assumptions that the assistant should follow during the conversation." : "定義小幫手在對話期間應遵守的規則與假設。",
+    "Chat voice message" : "聊天語音訊息",
+    "Describe a task that you want the assistant to do or ask a question." : "描述您希望助理執行的任務或提出問題。",
+    "Chat history" : "聊天歷史紀錄",
+    "The history of chat messages before the current message, starting with a message by the user." : "目前訊息開始之前的聊天歷史紀錄，從使用者的訊息開始。",
+    "Input transcript" : "輸入轉錄",
+    "Transcription of the audio input" : "語音輸入轉錄",
+    "Response voice message" : "回應語音訊息",
+    "The generated voice response as part of the conversation" : "產生的語音回應是對話的一部分",
+    "Output transcript" : "輸出轉錄",
+    "Transcription of the audio output" : "音訊輸出轉錄",
     "Transcribe audio" : "轉錄音訊",
     "Transcribe the things said in an audio" : "轉錄音訊中所說的話",
     "Audio input" : "音訊輸入",
     "The audio to transcribe" : "要轉錄的音訊",
     "Transcription" : "轉錄",
     "The transcribed text" : "已轉錄的文字",
-    "ContextAgent" : "ContextAgent",
-    "Chat with an agent" : "與 agent 聊天",
-    "Chat message" : "聊天訊息",
-    "A chat message to send to the agent." : "要傳送給 agent 的聊天訊息。",
+    "Chat by voice with an agent" : "與 agent 語音聊天",
+    "Describe a task that you want the agent to do or ask a question." : "描述您希望 agent執行的任務或提出問題。",
     "Confirmation" : "確認",
     "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "是否確認先前要求的動作：0 代表拒絕，1 代表確認。",
     "Conversation token" : "對話權杖",
     "A token representing the conversation." : "代表對話的權杖。",
-    "Generated response" : "已產生的回應",
-    "The response from the chat model." : "來自聊天模型的回應。",
     "The new conversation token" : "新對話權杖",
     "Send this along with the next interaction." : "將這個與下一次互動一起傳送。",
     "Requested actions by the agent" : "Agent 要求的動作",
     "Actions that the agent would like to carry out in JSON format." : "Agent 希望以 JSON 格式執行的動作。",
+    "Chat with an agent" : "與 agent 聊天",
+    "Chat message" : "聊天訊息",
+    "A chat message to send to the agent." : "要傳送給 agent 的聊天訊息。",
+    "The response from the chat model." : "來自聊天模型的回應。",
     "Context write" : "寫作情境",
     "Writes text in a given style based on the provided source material." : "根據提供的來源資料以指定的風格編寫文字",
     "Writing style" : "寫作風格",
@@ -356,6 +378,12 @@ OC.L10N.register(
     "The text to generate an emoji for" : "用來產生表情符號的文字",
     "Generated emoji" : "已產生表情符號",
     "The generated emoji based on the input text" : "以輸入文字為基礎產生的表情符號",
+    "Optical character recognition" : "光學字元辨識 (OCR)",
+    "Extract text from files like images or PDFs" : "從影像或 PDF 等檔案中擷取文字",
+    "Input files" : "輸入檔案",
+    "The files to extract text from" : "用來擷取文字的檔案",
+    "Output texts" : "輸出文字",
+    "The texts that were extracted from the files" : "從檔案擷取的文字",
     "Generate image" : "產生影像",
     "Generate an image from a text prompt" : "根據文字提示產生影像",
     "Prompt" : "提示詞",
@@ -364,6 +392,11 @@ OC.L10N.register(
     "How many images to generate" : "要產生多少影像",
     "Output images" : "輸出影像",
     "The generated images" : "產生的影像",
+    "Generate speech" : "產生語音",
+    "Generate speech from a transcript" : "從轉錄稿產生語音",
+    "Write transcript that you want the assistant to generate speech from" : "寫下您想要小幫手產生語音的來源轉錄稿",
+    "Output speech" : "輸出語音",
+    "The generated speech" : "產生的語音",
     "Free text to text prompt" : "文字提示的自由文字",
     "Runs an arbitrary prompt through a language model that returns a reply" : "透過回傳回覆的語言模型執行任意提示",
     "Describe a task that you want the assistant to do or ask a question" : "描述您希望助理執行的任務或提出問題",
@@ -377,9 +410,6 @@ OC.L10N.register(
     "The rewritten text in the desired tone, written by the assistant:" : "小幫手以您希望的語氣重寫後的文字：",
     "Chat" : "聊天",
     "Chat with the assistant" : "與小幫手聊天",
-    "System prompt" : "系統提示詞",
-    "Define rules and assumptions that the assistant should follow during the conversation." : "定義小幫手在對話期間應遵守的規則與假設。",
-    "Chat history" : "聊天歷史紀錄",
     "The history of chat messages before the current message, starting with a message by the user" : "目前訊息開始之前的聊天歷史紀錄，從使用者的訊息開始",
     "Response message" : "回應訊息",
     "The generated response as part of the conversation" : "作為對話一部份產生的回應",
@@ -443,20 +473,12 @@ OC.L10N.register(
     "Generate headline" : "生成標題",
     "Summarizes text by reducing its length without losing key information." : "寫成摘要，減少文字長度而不丟失關鍵資訊。",
     "Extracts topics from a text and outputs them separated by commas." : "從文字中取出涵蓋的主題並輸出，然後用逗號分隔。",
-    "Education Edition" : "教育版",
-    "File name is a reserved word" : "檔案名稱是保留字",
-    "File name contains at least one invalid character" : "檔案名稱含有不允許的字元",
-    "File name is too long" : "檔案名稱太長",
-    "Users" : "使用者",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s 與您分享了「%2$s 」，且想要新增：",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s 與您分享了「%2$s」，且想要新增",
-    "»%s« added a note to a file shared with you" : "「%s」在與您分享的檔案中加入了備註",
-    "Open »%s«" : "開啟「%s」",
-    "%1$s shared »%2$s« with you" : "%1$s 與您分享了「%2$s」",
-    "%1$s shared »%2$s« with you." : "%1$s 與您分享了「%2$s」。",
-    "Click the button below to open it." : "點擊下方的按鈕將其打開。",
-    "File is currently busy, please try again later" : "檔案目前忙碌中，請稍候再試",
-    "Cannot download file" : "無法下載檔案",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "請確保資料目錄最上層有一個「.ocdata」檔案。"
+    "Organisation" : "組織單位",
+    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "不支援 Mac OS X，%s 在此平台上無法正常運作。請自行承擔使用風險！",
+    "Login is too long" : "帳號太長了",
+    "Cannot write into \"apps\" directory." : "無法寫入「apps」目錄。",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "開通網頁伺服器寫入 apps 目錄的存取權，或是在組態設定檔中停用應用程式商店，通常可以解決這個問題。",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> 設定為 <code>%s</code>，而非預期中的 <code>0</code>。",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "為了修正這個問題，請到 php.ini 將 <code>mbstring.func_overload</code> 的值改為 <code>0</code>。"
 },
 "nplurals=1; plural=0;");
